#!/usr/bin/perl
################################################################################
#
# Copyright (c) 2002-2024 Marcus Holland-Moritz. All rights reserved.
# This program is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
################################################################################

use Test::More tests => 9031;
use Convert::Binary::C @ARGV;
use strict;

$^W = 1;

my $BIN = $] < 5.006 ? '%x' : '%08b';

my @compiler = (
  {
    'name' => 'cygwin/gcc32_plain',
    'config' => {
      'LongSize' => 4,
      'IntSize' => 4,
      'ByteOrder' => 'LittleEndian',
      'ShortSize' => 2,
      'DoubleSize' => 8,
      'CharSize' => 1,
      'PointerSize' => 4,
      'EnumSize' => 4,
      'FloatSize' => 4,
      'Alignment' => 8,
      'LongLongSize' => 8,
      'LongDoubleSize' => 12,
      'HasCPPComments' => 1,
      'CompoundAlignment' => 1
    }
  },
  {
    'name' => 'decosf_alpha/cc_plain',
    'config' => {
      'LongSize' => 8,
      'IntSize' => 4,
      'ByteOrder' => 'LittleEndian',
      'ShortSize' => 2,
      'DoubleSize' => 8,
      'CharSize' => 1,
      'PointerSize' => 8,
      'EnumSize' => 4,
      'FloatSize' => 4,
      'Alignment' => 8,
      'LongLongSize' => 8,
      'LongDoubleSize' => 16,
      'HasCPPComments' => 1,
      'CompoundAlignment' => 1
    }
  },
  {
    'name' => 'freebsd_alpha/gcc_plain',
    'config' => {
      'LongSize' => 8,
      'IntSize' => 4,
      'ByteOrder' => 'LittleEndian',
      'ShortSize' => 2,
      'DoubleSize' => 8,
      'CharSize' => 1,
      'PointerSize' => 8,
      'EnumSize' => 4,
      'FloatSize' => 4,
      'Alignment' => 8,
      'LongLongSize' => 8,
      'LongDoubleSize' => 8,
      'HasCPPComments' => 1,
      'CompoundAlignment' => 1
    }
  },
  {
    'name' => 'hpux11_ia64/cc_plain',
    'config' => {
      'LongSize' => 4,
      'IntSize' => 4,
      'ByteOrder' => 'BigEndian',
      'ShortSize' => 2,
      'DoubleSize' => 8,
      'CharSize' => 1,
      'PointerSize' => 4,
      'EnumSize' => 4,
      'FloatSize' => 4,
      'Alignment' => 8,
      'LongLongSize' => 8,
      'LongDoubleSize' => 16,
      'HasCPPComments' => 1,
      'CompoundAlignment' => 1
    }
  },
  {
    'name' => 'linux/armgcc34_plain',
    'config' => {
      'LongSize' => 4,
      'IntSize' => 4,
      'ByteOrder' => 'LittleEndian',
      'ShortSize' => 2,
      'DoubleSize' => 8,
      'CharSize' => 1,
      'PointerSize' => 4,
      'EnumSize' => 4,
      'FloatSize' => 4,
      'Alignment' => 4,
      'LongLongSize' => 8,
      'LongDoubleSize' => 8,
      'HasCPPComments' => 1,
      'CompoundAlignment' => 4
    }
  },
  {
    'name' => 'linux/gcc41_plain',
    'config' => {
      'LongSize' => 4,
      'IntSize' => 4,
      'ByteOrder' => 'LittleEndian',
      'ShortSize' => 2,
      'DoubleSize' => 8,
      'CharSize' => 1,
      'PointerSize' => 4,
      'EnumSize' => 4,
      'FloatSize' => 4,
      'Alignment' => 4,
      'LongLongSize' => 8,
      'LongDoubleSize' => 12,
      'HasCPPComments' => 1,
      'CompoundAlignment' => 1
    }
  },
  {
    'name' => 'linux/hppagcc33_plain',
    'config' => {
      'LongSize' => 8,
      'IntSize' => 4,
      'ByteOrder' => 'BigEndian',
      'ShortSize' => 2,
      'DoubleSize' => 8,
      'CharSize' => 1,
      'PointerSize' => 8,
      'EnumSize' => 4,
      'FloatSize' => 4,
      'Alignment' => 8,
      'LongLongSize' => 8,
      'LongDoubleSize' => 16,
      'HasCPPComments' => 1,
      'CompoundAlignment' => 1
    }
  },
  {
    'name' => 'linux/vaxgcc33_plain',
    'config' => {
      'LongSize' => 4,
      'IntSize' => 4,
      'ByteOrder' => 'LittleEndian',
      'ShortSize' => 2,
      'DoubleSize' => 8,
      'CharSize' => 1,
      'PointerSize' => 4,
      'EnumSize' => 4,
      'FloatSize' => 4,
      'Alignment' => 4,
      'LongLongSize' => 8,
      'LongDoubleSize' => 8,
      'HasCPPComments' => 1,
      'CompoundAlignment' => 1
    }
  },
  {
    'name' => 'linux_parisc64/gcc_plain',
    'config' => {
      'ByteOrder' => 'BigEndian',
      'LongSize' => '4',
      'IntSize' => '4',
      'ShortSize' => '2',
      'DoubleSize' => '8',
      'CharSize' => '1',
      'PointerSize' => '4',
      'EnumSize' => '4',
      'FloatSize' => '4',
      'LongLongSize' => '8',
      'Alignment' => '8',
      'LongDoubleSize' => '8',
      'HasCPPComments' => 1,
      'CompoundAlignment' => '1'
    }
  }
);


my @c = eval { map { Convert::Binary::C->new(Bitfields => {Engine => 'Generic'},
                                             EnumType  => 'String',
                                             %{$_->{config}}) } @compiler };
is($@, '', "failed to create Convert::Binary::C objects");

sub debug
{
  $ENV{CBC_TEST_DEBUG} and diag(@_);
}

sub showbits
{
  join ' ', map { sprintf $BIN, $_ } unpack "C*", shift;
}

sub get_data
{
  my $want = shift || 'list';
  my $term = shift || '[-=]';
  local $_;
  my @lines;
  while (<DATA>) {
    if (/^($term)$/) {
      $term = $1;
      last;
    }
    push @lines, $_
  }
  if ($want eq 'list') {
    chomp @lines;
    return $term, @lines;
  }
  return $term, join('', @lines);
}

sub reccmp
{
  my($ref, $val) = @_;

  unless (defined $ref and defined $val) {
    return defined($ref) == defined($val);
  }

  ref $ref or return $ref eq $val;

  if (ref $ref eq 'ARRAY') {
    @$ref == @$val or return 0;
    for (0..$#$ref) {
      reccmp($ref->[$_], $val->[$_]) or return 0;
    }
  }
  elsif (ref $ref eq 'HASH') {
    @{[keys %$ref]} == @{[keys %$val]} or return 0;
    for (keys %$ref) {
      reccmp($ref->{$_}, $val->{$_}) or return 0;
    }
  }
  else { return 0 }

  return 1;
}

while (1) {
  my(undef, $code) = get_data('block');
  last if $code !~ /\S/;
  debug("Code:\n$code");
  eval { $_->clean->parse($code) for @c };
  is($@, '', "parse code") or diag($code);
  is(scalar $c[0]->compound_names, 1, join(', ', $c[0]->compound_names));
  my($type) = $c[0]->compound_names;
  while (1) {
    my($term, $init, @packed) = get_data;
    debug("Init: $init");
    my $data = eval $init;
    my $succ = 0;
    for (@packed) { $_ = pack "H*", $_ }
    for my $i (0 .. $#packed) {
      debug("Compiler: [$i] $compiler[$i]{name}");
      $c[$i]->sizeof($type) == length($packed[$i]) and $succ++;

      my $p = $c[$i]->pack($type, $data);
      if ($p eq $packed[$i]) {
        $succ++;
      }
      else {
        diag("[$i] $compiler[$i]{name}\n",
             $code,
             "data = $init\n",
             "expected: ", showbits($packed[$i]), "\n",
             "     got: ", showbits($p), "\n");
      }

      my $u = $c[$i]->unpack($type, $packed[$i]);
      if (reccmp($data, $u)) {
        $succ++;
      }
      else {
        diag("[$i] $compiler[$i]{name}\n", $code, "data = $init\n");
        eval {
          require Data::Dumper;
          diag(Data::Dumper->Dump([$data, $u], [qw(*expected *got)]));
        };
      }
    }
    is($succ, 3*@packed, "$type ($init)");
    last if $term eq '=';
  }
}

__DATA__
struct basic {
  unsigned int a:9;
};
-
{a=>509}
fd010000
fd010000
fd010000
fe800000
fd010000
fd010000
fe800000
fd010000
fe800000
-
{a=>352}
60010000
60010000
60010000
b0000000
60010000
60010000
b0000000
60010000
b0000000
-
{a=>349}
5d010000
5d010000
5d010000
ae800000
5d010000
5d010000
ae800000
5d010000
ae800000
-
{a=>398}
8e010000
8e010000
8e010000
c7000000
8e010000
8e010000
c7000000
8e010000
c7000000
-
{a=>453}
c5010000
c5010000
c5010000
e2800000
c5010000
c5010000
e2800000
c5010000
e2800000
=
struct basic {
  unsigned int a:9;
  unsigned int b:2;
};
-
{a=>228,b=>3}
e4060000
e4060000
e4060000
72600000
e4060000
e4060000
72600000
e4060000
72600000
-
{a=>163,b=>0}
a3000000
a3000000
a3000000
51800000
a3000000
a3000000
51800000
a3000000
51800000
-
{a=>333,b=>3}
4d070000
4d070000
4d070000
a6e00000
4d070000
4d070000
a6e00000
4d070000
a6e00000
-
{a=>495,b=>3}
ef070000
ef070000
ef070000
f7e00000
ef070000
ef070000
f7e00000
ef070000
f7e00000
-
{a=>193,b=>3}
c1060000
c1060000
c1060000
60e00000
c1060000
c1060000
60e00000
c1060000
60e00000
=
struct basic {
  unsigned int a:9;
  unsigned int b:2;
  unsigned int  :3;
};
-
{a=>115,b=>1}
73020000
73020000
73020000
39a00000
73020000
73020000
39a00000
73020000
39a00000
-
{a=>283,b=>0}
1b010000
1b010000
1b010000
8d800000
1b010000
1b010000
8d800000
1b010000
8d800000
-
{a=>12,b=>1}
0c020000
0c020000
0c020000
06200000
0c020000
0c020000
06200000
0c020000
06200000
-
{a=>417,b=>3}
a1070000
a1070000
a1070000
d0e00000
a1070000
a1070000
d0e00000
a1070000
d0e00000
-
{a=>129,b=>2}
81040000
81040000
81040000
40c00000
81040000
81040000
40c00000
81040000
40c00000
=
struct basic {
  unsigned int a:9;
  unsigned int b:2;
  unsigned int  :3;
  unsigned int c:2;
};
-
{c=>1,a=>473,b=>1}
d9430000
d9430000
d9430000
eca10000
d9430000
d9430000
eca10000
d9430000
eca10000
-
{c=>2,a=>149,b=>2}
95840000
95840000
95840000
4ac20000
95840000
95840000
4ac20000
95840000
4ac20000
-
{c=>3,a=>227,b=>2}
e3c40000
e3c40000
e3c40000
71c30000
e3c40000
e3c40000
71c30000
e3c40000
71c30000
-
{c=>0,a=>114,b=>0}
72000000
72000000
72000000
39000000
72000000
72000000
39000000
72000000
39000000
-
{c=>2,a=>83,b=>3}
53860000
53860000
53860000
29e20000
53860000
53860000
29e20000
53860000
29e20000
=
struct basic {
  unsigned int a:9;
  unsigned int b:2;
  unsigned int  :3;
  unsigned int c:2;
  unsigned int d;
};
-
{c=>0,a=>134,b=>3,d=>231}
86060000e7000000
86060000e7000000
86060000e7000000
43600000000000e7
86060000e7000000
86060000e7000000
43600000000000e7
86060000e7000000
43600000000000e7
-
{c=>0,a=>60,b=>0,d=>10}
3c0000000a000000
3c0000000a000000
3c0000000a000000
1e0000000000000a
3c0000000a000000
3c0000000a000000
1e0000000000000a
3c0000000a000000
1e0000000000000a
-
{c=>2,a=>170,b=>2,d=>252}
aa840000fc000000
aa840000fc000000
aa840000fc000000
55420000000000fc
aa840000fc000000
aa840000fc000000
55420000000000fc
aa840000fc000000
55420000000000fc
-
{c=>3,a=>53,b=>1,d=>248}
35c20000f8000000
35c20000f8000000
35c20000f8000000
1aa30000000000f8
35c20000f8000000
35c20000f8000000
1aa30000000000f8
35c20000f8000000
1aa30000000000f8
-
{c=>3,a=>74,b=>3,d=>85}
4ac6000055000000
4ac6000055000000
4ac6000055000000
2563000000000055
4ac6000055000000
4ac6000055000000
2563000000000055
4ac6000055000000
2563000000000055
=
struct basic {
  char a;
  unsigned int b:9;
};
-
{a=>95,b=>334}
5f4e0100
5f4e0100
5f4e0100
5fa70000
5f4e0100
5f4e0100
5fa70000
5f4e0100
5fa70000
-
{a=>43,b=>139}
2b8b0000
2b8b0000
2b8b0000
2b458000
2b8b0000
2b8b0000
2b458000
2b8b0000
2b458000
-
{a=>103,b=>500}
67f40100
67f40100
67f40100
67fa0000
67f40100
67f40100
67fa0000
67f40100
67fa0000
-
{a=>-82,b=>491}
aeeb0100
aeeb0100
aeeb0100
aef58000
aeeb0100
aeeb0100
aef58000
aeeb0100
aef58000
-
{a=>-81,b=>456}
afc80100
afc80100
afc80100
afe40000
afc80100
afc80100
afe40000
afc80100
afe40000
=
struct basic {
  char a;
  unsigned int b:9;
  unsigned int c:2;
};
-
{c=>1,a=>62,b=>455}
3ec70300
3ec70300
3ec70300
3ee3a000
3ec70300
3ec70300
3ee3a000
3ec70300
3ee3a000
-
{c=>0,a=>-46,b=>32}
d2200000
d2200000
d2200000
d2100000
d2200000
d2200000
d2100000
d2200000
d2100000
-
{c=>0,a=>55,b=>501}
37f50100
37f50100
37f50100
37fa8000
37f50100
37f50100
37fa8000
37f50100
37fa8000
-
{c=>3,a=>72,b=>97}
48610600
48610600
48610600
4830e000
48610600
48610600
4830e000
48610600
4830e000
-
{c=>3,a=>91,b=>180}
5bb40600
5bb40600
5bb40600
5b5a6000
5bb40600
5bb40600
5b5a6000
5bb40600
5b5a6000
=
struct basic {
  char a;
  unsigned int b:9;
  unsigned int c:2;
  unsigned int  :3;
};
-
{c=>1,a=>-64,b=>1}
c0010200
c0010200
c0010200
c000a000
c0010200
c0010200
c000a000
c0010200
c000a000
-
{c=>3,a=>43,b=>409}
2b990700
2b990700
2b990700
2bcce000
2b990700
2b990700
2bcce000
2b990700
2bcce000
-
{c=>1,a=>-30,b=>413}
e29d0300
e29d0300
e29d0300
e2cea000
e29d0300
e29d0300
e2cea000
e29d0300
e2cea000
-
{c=>3,a=>107,b=>399}
6b8f0700
6b8f0700
6b8f0700
6bc7e000
6b8f0700
6b8f0700
6bc7e000
6b8f0700
6bc7e000
-
{c=>2,a=>-59,b=>474}
c5da0500
c5da0500
c5da0500
c5ed4000
c5da0500
c5da0500
c5ed4000
c5da0500
c5ed4000
=
struct basic {
  char a;
  unsigned int b:9;
  unsigned int c:2;
  unsigned int  :3;
  unsigned int d:2;
};
-
{c=>0,a=>-60,b=>352,d=>2}
c4608100
c4608100
c4608100
c4b00200
c4608100
c4608100
c4b00200
c4608100
c4b00200
-
{c=>1,a=>89,b=>103,d=>2}
59678200
59678200
59678200
5933a200
59678200
59678200
5933a200
59678200
5933a200
-
{c=>0,a=>31,b=>136,d=>2}
1f888000
1f888000
1f888000
1f440200
1f888000
1f888000
1f440200
1f888000
1f440200
-
{c=>0,a=>-103,b=>343,d=>0}
99570100
99570100
99570100
99ab8000
99570100
99570100
99ab8000
99570100
99ab8000
-
{c=>2,a=>-102,b=>358,d=>0}
9a660500
9a660500
9a660500
9ab34000
9a660500
9a660500
9ab34000
9a660500
9ab34000
=
struct basic {
  char a;
  unsigned int b:9;
  unsigned int c:2;
  unsigned int  :3;
  unsigned int d:2;
  unsigned int e;
};
-
{e=>205,c=>0,a=>57,b=>85,d=>3}
3955c000cd000000
3955c000cd000000
3955c000cd000000
392a8300000000cd
3955c000cd000000
3955c000cd000000
392a8300000000cd
3955c000cd000000
392a8300000000cd
-
{e=>218,c=>2,a=>-89,b=>129,d=>1}
a7814400da000000
a7814400da000000
a7814400da000000
a740c100000000da
a7814400da000000
a7814400da000000
a740c100000000da
a7814400da000000
a740c100000000da
-
{e=>90,c=>3,a=>105,b=>77,d=>1}
694d46005a000000
694d46005a000000
694d46005a000000
6926e1000000005a
694d46005a000000
694d46005a000000
6926e1000000005a
694d46005a000000
6926e1000000005a
-
{e=>82,c=>3,a=>89,b=>507,d=>0}
59fb070052000000
59fb070052000000
59fb070052000000
59fde00000000052
59fb070052000000
59fb070052000000
59fde00000000052
59fb070052000000
59fde00000000052
-
{e=>10,c=>1,a=>-7,b=>126,d=>0}
f97e02000a000000
f97e02000a000000
f97e02000a000000
f93f20000000000a
f97e02000a000000
f97e02000a000000
f93f20000000000a
f97e02000a000000
f93f20000000000a
=
struct basic {
  short a;
  unsigned int b:9;
};
-
{a=>44,b=>211}
2c00d300
2c00d300
2c00d300
002c6980
2c00d300
2c00d300
002c6980
2c00d300
002c6980
-
{a=>106,b=>55}
6a003700
6a003700
6a003700
006a1b80
6a003700
6a003700
006a1b80
6a003700
006a1b80
-
{a=>-99,b=>100}
9dff6400
9dff6400
9dff6400
ff9d3200
9dff6400
9dff6400
ff9d3200
9dff6400
ff9d3200
-
{a=>-25,b=>17}
e7ff1100
e7ff1100
e7ff1100
ffe70880
e7ff1100
e7ff1100
ffe70880
e7ff1100
ffe70880
-
{a=>-60,b=>31}
c4ff1f00
c4ff1f00
c4ff1f00
ffc40f80
c4ff1f00
c4ff1f00
ffc40f80
c4ff1f00
ffc40f80
=
struct basic {
  short a;
  unsigned int b:9;
  unsigned int c:2;
};
-
{c=>0,a=>-3,b=>65}
fdff4100
fdff4100
fdff4100
fffd2080
fdff4100
fdff4100
fffd2080
fdff4100
fffd2080
-
{c=>3,a=>127,b=>141}
7f008d06
7f008d06
7f008d06
007f46e0
7f008d06
7f008d06
007f46e0
7f008d06
007f46e0
-
{c=>1,a=>-53,b=>123}
cbff7b02
cbff7b02
cbff7b02
ffcb3da0
cbff7b02
cbff7b02
ffcb3da0
cbff7b02
ffcb3da0
-
{c=>3,a=>-110,b=>69}
92ff4506
92ff4506
92ff4506
ff9222e0
92ff4506
92ff4506
ff9222e0
92ff4506
ff9222e0
-
{c=>1,a=>-63,b=>183}
c1ffb702
c1ffb702
c1ffb702
ffc15ba0
c1ffb702
c1ffb702
ffc15ba0
c1ffb702
ffc15ba0
=
struct basic {
  short a;
  unsigned int b:9;
  unsigned int c:2;
  unsigned int  :3;
};
-
{c=>1,a=>-32,b=>280}
e0ff1803
e0ff1803
e0ff1803
ffe08c20
e0ff1803
e0ff1803
ffe08c20
e0ff1803
ffe08c20
-
{c=>0,a=>-76,b=>473}
b4ffd901
b4ffd901
b4ffd901
ffb4ec80
b4ffd901
b4ffd901
ffb4ec80
b4ffd901
ffb4ec80
-
{c=>2,a=>-60,b=>271}
c4ff0f05
c4ff0f05
c4ff0f05
ffc487c0
c4ff0f05
c4ff0f05
ffc487c0
c4ff0f05
ffc487c0
-
{c=>1,a=>72,b=>50}
48003202
48003202
48003202
00481920
48003202
48003202
00481920
48003202
00481920
-
{c=>1,a=>-97,b=>440}
9fffb803
9fffb803
9fffb803
ff9fdc20
9fffb803
9fffb803
ff9fdc20
9fffb803
ff9fdc20
=
struct basic {
  short a;
  unsigned int b:9;
  unsigned int c:2;
  unsigned int  :3;
  unsigned int d:2;
};
-
{c=>3,a=>-78,b=>286,d=>1}
b2ff1e47
b2ff1e47
b2ff1e47
ffb28f61
b2ff1e47
b2ff1e47
ffb28f61
b2ff1e47
ffb28f61
-
{c=>2,a=>-105,b=>330,d=>3}
97ff4ac5
97ff4ac5
97ff4ac5
ff97a543
97ff4ac5
97ff4ac5
ff97a543
97ff4ac5
ff97a543
-
{c=>0,a=>73,b=>33,d=>1}
49002140
49002140
49002140
00491081
49002140
49002140
00491081
49002140
00491081
-
{c=>0,a=>-67,b=>463,d=>2}
bdffcf81
bdffcf81
bdffcf81
ffbde782
bdffcf81
bdffcf81
ffbde782
bdffcf81
ffbde782
-
{c=>0,a=>87,b=>452,d=>2}
5700c481
5700c481
5700c481
0057e202
5700c481
5700c481
0057e202
5700c481
0057e202
=
struct basic {
  short a;
  unsigned int b:9;
  unsigned int c:2;
  unsigned int  :3;
  unsigned int d:2;
  unsigned int e;
};
-
{e=>78,c=>2,a=>-39,b=>178,d=>3}
d9ffb2c44e000000
d9ffb2c44e000000
d9ffb2c44e000000
ffd959430000004e
d9ffb2c44e000000
d9ffb2c44e000000
ffd959430000004e
d9ffb2c44e000000
ffd959430000004e
-
{e=>4,c=>2,a=>51,b=>65,d=>2}
3300418404000000
3300418404000000
3300418404000000
003320c200000004
3300418404000000
3300418404000000
003320c200000004
3300418404000000
003320c200000004
-
{e=>225,c=>1,a=>-16,b=>99,d=>1}
f0ff6342e1000000
f0ff6342e1000000
f0ff6342e1000000
fff031a1000000e1
f0ff6342e1000000
f0ff6342e1000000
fff031a1000000e1
f0ff6342e1000000
fff031a1000000e1
-
{e=>23,c=>0,a=>-1,b=>254,d=>0}
fffffe0017000000
fffffe0017000000
fffffe0017000000
ffff7f0000000017
fffffe0017000000
fffffe0017000000
ffff7f0000000017
fffffe0017000000
ffff7f0000000017
-
{e=>75,c=>0,a=>7,b=>128,d=>1}
070080404b000000
070080404b000000
070080404b000000
000740010000004b
070080404b000000
070080404b000000
000740010000004b
070080404b000000
000740010000004b
=
struct basic {
  int a;
  unsigned int b:9;
};
-
{a=>26,b=>294}
1a00000026010000
1a00000026010000
1a00000026010000
0000001a93000000
1a00000026010000
1a00000026010000
0000001a93000000
1a00000026010000
0000001a93000000
-
{a=>120,b=>54}
7800000036000000
7800000036000000
7800000036000000
000000781b000000
7800000036000000
7800000036000000
000000781b000000
7800000036000000
000000781b000000
-
{a=>-16,b=>377}
f0ffffff79010000
f0ffffff79010000
f0ffffff79010000
fffffff0bc800000
f0ffffff79010000
f0ffffff79010000
fffffff0bc800000
f0ffffff79010000
fffffff0bc800000
-
{a=>38,b=>179}
26000000b3000000
26000000b3000000
26000000b3000000
0000002659800000
26000000b3000000
26000000b3000000
0000002659800000
26000000b3000000
0000002659800000
-
{a=>116,b=>289}
7400000021010000
7400000021010000
7400000021010000
0000007490800000
7400000021010000
7400000021010000
0000007490800000
7400000021010000
0000007490800000
=
struct basic {
  int a;
  unsigned int b:9;
  unsigned int c:2;
};
-
{c=>1,a=>49,b=>430}
31000000ae030000
31000000ae030000
31000000ae030000
00000031d7200000
31000000ae030000
31000000ae030000
00000031d7200000
31000000ae030000
00000031d7200000
-
{c=>3,a=>118,b=>459}
76000000cb070000
76000000cb070000
76000000cb070000
00000076e5e00000
76000000cb070000
76000000cb070000
00000076e5e00000
76000000cb070000
00000076e5e00000
-
{c=>0,a=>1,b=>148}
0100000094000000
0100000094000000
0100000094000000
000000014a000000
0100000094000000
0100000094000000
000000014a000000
0100000094000000
000000014a000000
-
{c=>0,a=>-80,b=>164}
b0ffffffa4000000
b0ffffffa4000000
b0ffffffa4000000
ffffffb052000000
b0ffffffa4000000
b0ffffffa4000000
ffffffb052000000
b0ffffffa4000000
ffffffb052000000
-
{c=>3,a=>-5,b=>38}
fbffffff26060000
fbffffff26060000
fbffffff26060000
fffffffb13600000
fbffffff26060000
fbffffff26060000
fffffffb13600000
fbffffff26060000
fffffffb13600000
=
struct basic {
  int a;
  unsigned int b:9;
  unsigned int c:2;
  unsigned int  :3;
};
-
{c=>0,a=>73,b=>253}
49000000fd000000
49000000fd000000
49000000fd000000
000000497e800000
49000000fd000000
49000000fd000000
000000497e800000
49000000fd000000
000000497e800000
-
{c=>3,a=>91,b=>302}
5b0000002e070000
5b0000002e070000
5b0000002e070000
0000005b97600000
5b0000002e070000
5b0000002e070000
0000005b97600000
5b0000002e070000
0000005b97600000
-
{c=>3,a=>30,b=>58}
1e0000003a060000
1e0000003a060000
1e0000003a060000
0000001e1d600000
1e0000003a060000
1e0000003a060000
0000001e1d600000
1e0000003a060000
0000001e1d600000
-
{c=>0,a=>-109,b=>436}
93ffffffb4010000
93ffffffb4010000
93ffffffb4010000
ffffff93da000000
93ffffffb4010000
93ffffffb4010000
ffffff93da000000
93ffffffb4010000
ffffff93da000000
-
{c=>3,a=>-89,b=>300}
a7ffffff2c070000
a7ffffff2c070000
a7ffffff2c070000
ffffffa796600000
a7ffffff2c070000
a7ffffff2c070000
ffffffa796600000
a7ffffff2c070000
ffffffa796600000
=
struct basic {
  int a;
  unsigned int b:9;
  unsigned int c:2;
  unsigned int  :3;
  unsigned int d:2;
};
-
{c=>2,a=>-81,b=>332,d=>0}
afffffff4c050000
afffffff4c050000
afffffff4c050000
ffffffafa6400000
afffffff4c050000
afffffff4c050000
ffffffafa6400000
afffffff4c050000
ffffffafa6400000
-
{c=>0,a=>-118,b=>311,d=>3}
8affffff37c10000
8affffff37c10000
8affffff37c10000
ffffff8a9b830000
8affffff37c10000
8affffff37c10000
ffffff8a9b830000
8affffff37c10000
ffffff8a9b830000
-
{c=>2,a=>93,b=>362,d=>1}
5d0000006a450000
5d0000006a450000
5d0000006a450000
0000005db5410000
5d0000006a450000
5d0000006a450000
0000005db5410000
5d0000006a450000
0000005db5410000
-
{c=>0,a=>122,b=>370,d=>0}
7a00000072010000
7a00000072010000
7a00000072010000
0000007ab9000000
7a00000072010000
7a00000072010000
0000007ab9000000
7a00000072010000
0000007ab9000000
-
{c=>2,a=>87,b=>107,d=>2}
570000006b840000
570000006b840000
570000006b840000
0000005735c20000
570000006b840000
570000006b840000
0000005735c20000
570000006b840000
0000005735c20000
=
struct basic {
  int a;
  unsigned int b:9;
  unsigned int c:2;
  unsigned int  :3;
  unsigned int d:2;
  unsigned int e;
};
-
{e=>246,c=>1,a=>109,b=>275,d=>1}
6d00000013430000f6000000
6d00000013430000f6000000
6d00000013430000f6000000
0000006d89a10000000000f6
6d00000013430000f6000000
6d00000013430000f6000000
0000006d89a10000000000f6
6d00000013430000f6000000
0000006d89a10000000000f6
-
{e=>120,c=>3,a=>80,b=>215,d=>2}
50000000d786000078000000
50000000d786000078000000
50000000d786000078000000
000000506be2000000000078
50000000d786000078000000
50000000d786000078000000
000000506be2000000000078
50000000d786000078000000
000000506be2000000000078
-
{e=>236,c=>0,a=>88,b=>484,d=>2}
58000000e4810000ec000000
58000000e4810000ec000000
58000000e4810000ec000000
00000058f2020000000000ec
58000000e4810000ec000000
58000000e4810000ec000000
00000058f2020000000000ec
58000000e4810000ec000000
00000058f2020000000000ec
-
{e=>9,c=>1,a=>-20,b=>117,d=>2}
ecffffff7582000009000000
ecffffff7582000009000000
ecffffff7582000009000000
ffffffec3aa2000000000009
ecffffff7582000009000000
ecffffff7582000009000000
ffffffec3aa2000000000009
ecffffff7582000009000000
ffffffec3aa2000000000009
-
{e=>135,c=>3,a=>126,b=>333,d=>1}
7e0000004d47000087000000
7e0000004d47000087000000
7e0000004d47000087000000
0000007ea6e1000000000087
7e0000004d47000087000000
7e0000004d47000087000000
0000007ea6e1000000000087
7e0000004d47000087000000
0000007ea6e1000000000087
=
struct basic {
  long a;
  unsigned int b:9;
};
-
{a=>-90,b=>99}
a6ffffff63000000
a6ffffffffffffff6300000000000000
a6ffffffffffffff6300000000000000
ffffffa631800000
a6ffffff63000000
a6ffffff63000000
ffffffffffffffa63180000000000000
a6ffffff63000000
ffffffa631800000
-
{a=>18,b=>50}
1200000032000000
12000000000000003200000000000000
12000000000000003200000000000000
0000001219000000
1200000032000000
1200000032000000
00000000000000121900000000000000
1200000032000000
0000001219000000
-
{a=>-120,b=>264}
88ffffff08010000
88ffffffffffffff0801000000000000
88ffffffffffffff0801000000000000
ffffff8884000000
88ffffff08010000
88ffffff08010000
ffffffffffffff888400000000000000
88ffffff08010000
ffffff8884000000
-
{a=>23,b=>32}
1700000020000000
17000000000000002000000000000000
17000000000000002000000000000000
0000001710000000
1700000020000000
1700000020000000
00000000000000171000000000000000
1700000020000000
0000001710000000
-
{a=>42,b=>321}
2a00000041010000
2a000000000000004101000000000000
2a000000000000004101000000000000
0000002aa0800000
2a00000041010000
2a00000041010000
000000000000002aa080000000000000
2a00000041010000
0000002aa0800000
=
struct basic {
  long a;
  unsigned int b:9;
  unsigned int c:2;
};
-
{c=>3,a=>37,b=>303}
250000002f070000
25000000000000002f07000000000000
25000000000000002f07000000000000
0000002597e00000
250000002f070000
250000002f070000
000000000000002597e0000000000000
250000002f070000
0000002597e00000
-
{c=>3,a=>-87,b=>458}
a9ffffffca070000
a9ffffffffffffffca07000000000000
a9ffffffffffffffca07000000000000
ffffffa9e5600000
a9ffffffca070000
a9ffffffca070000
ffffffffffffffa9e560000000000000
a9ffffffca070000
ffffffa9e5600000
-
{c=>3,a=>-86,b=>453}
aaffffffc5070000
aaffffffffffffffc507000000000000
aaffffffffffffffc507000000000000
ffffffaae2e00000
aaffffffc5070000
aaffffffc5070000
ffffffffffffffaae2e0000000000000
aaffffffc5070000
ffffffaae2e00000
-
{c=>0,a=>96,b=>71}
6000000047000000
60000000000000004700000000000000
60000000000000004700000000000000
0000006023800000
6000000047000000
6000000047000000
00000000000000602380000000000000
6000000047000000
0000006023800000
-
{c=>0,a=>-46,b=>254}
d2fffffffe000000
d2fffffffffffffffe00000000000000
d2fffffffffffffffe00000000000000
ffffffd27f000000
d2fffffffe000000
d2fffffffe000000
ffffffffffffffd27f00000000000000
d2fffffffe000000
ffffffd27f000000
=
struct basic {
  long a;
  unsigned int b:9;
  unsigned int c:2;
  unsigned int  :3;
};
-
{c=>1,a=>-123,b=>56}
85ffffff38020000
85ffffffffffffff3802000000000000
85ffffffffffffff3802000000000000
ffffff851c200000
85ffffff38020000
85ffffff38020000
ffffffffffffff851c20000000000000
85ffffff38020000
ffffff851c200000
-
{c=>1,a=>-36,b=>276}
dcffffff14030000
dcffffffffffffff1403000000000000
dcffffffffffffff1403000000000000
ffffffdc8a200000
dcffffff14030000
dcffffff14030000
ffffffffffffffdc8a20000000000000
dcffffff14030000
ffffffdc8a200000
-
{c=>2,a=>26,b=>453}
1a000000c5050000
1a00000000000000c505000000000000
1a00000000000000c505000000000000
0000001ae2c00000
1a000000c5050000
1a000000c5050000
000000000000001ae2c0000000000000
1a000000c5050000
0000001ae2c00000
-
{c=>0,a=>95,b=>479}
5f000000df010000
5f00000000000000df01000000000000
5f00000000000000df01000000000000
0000005fef800000
5f000000df010000
5f000000df010000
000000000000005fef80000000000000
5f000000df010000
0000005fef800000
-
{c=>1,a=>28,b=>16}
1c00000010020000
1c000000000000001002000000000000
1c000000000000001002000000000000
0000001c08200000
1c00000010020000
1c00000010020000
000000000000001c0820000000000000
1c00000010020000
0000001c08200000
=
struct basic {
  long a;
  unsigned int b:9;
  unsigned int c:2;
  unsigned int  :3;
  unsigned int d:2;
};
-
{c=>3,a=>-75,b=>292,d=>0}
b5ffffff24070000
b5ffffffffffffff2407000000000000
b5ffffffffffffff2407000000000000
ffffffb592600000
b5ffffff24070000
b5ffffff24070000
ffffffffffffffb59260000000000000
b5ffffff24070000
ffffffb592600000
-
{c=>0,a=>24,b=>330,d=>0}
180000004a010000
18000000000000004a01000000000000
18000000000000004a01000000000000
00000018a5000000
180000004a010000
180000004a010000
0000000000000018a500000000000000
180000004a010000
00000018a5000000
-
{c=>3,a=>2,b=>332,d=>1}
020000004c470000
02000000000000004c47000000000000
02000000000000004c47000000000000
00000002a6610000
020000004c470000
020000004c470000
0000000000000002a661000000000000
020000004c470000
00000002a6610000
-
{c=>2,a=>74,b=>257,d=>1}
4a00000001450000
4a000000000000000145000000000000
4a000000000000000145000000000000
0000004a80c10000
4a00000001450000
4a00000001450000
000000000000004a80c1000000000000
4a00000001450000
0000004a80c10000
-
{c=>2,a=>106,b=>208,d=>3}
6a000000d0c40000
6a00000000000000d0c4000000000000
6a00000000000000d0c4000000000000
0000006a68430000
6a000000d0c40000
6a000000d0c40000
000000000000006a6843000000000000
6a000000d0c40000
0000006a68430000
=
struct basic {
  long a;
  unsigned int b:9;
  unsigned int c:2;
  unsigned int  :3;
  unsigned int d:2;
  unsigned int e;
};
-
{e=>118,c=>0,a=>26,b=>490,d=>2}
1a000000ea81000076000000
1a00000000000000ea81000076000000
1a00000000000000ea81000076000000
0000001af502000000000076
1a000000ea81000076000000
1a000000ea81000076000000
000000000000001af502000000000076
1a000000ea81000076000000
0000001af502000000000076
-
{e=>200,c=>0,a=>6,b=>418,d=>1}
06000000a2410000c8000000
0600000000000000a2410000c8000000
0600000000000000a2410000c8000000
00000006d1010000000000c8
06000000a2410000c8000000
06000000a2410000c8000000
0000000000000006d1010000000000c8
06000000a2410000c8000000
00000006d1010000000000c8
-
{e=>40,c=>1,a=>41,b=>444,d=>2}
29000000bc83000028000000
2900000000000000bc83000028000000
2900000000000000bc83000028000000
00000029de22000000000028
29000000bc83000028000000
29000000bc83000028000000
0000000000000029de22000000000028
29000000bc83000028000000
00000029de22000000000028
-
{e=>154,c=>0,a=>0,b=>88,d=>3}
0000000058c000009a000000
000000000000000058c000009a000000
000000000000000058c000009a000000
000000002c0300000000009a
0000000058c000009a000000
0000000058c000009a000000
00000000000000002c0300000000009a
0000000058c000009a000000
000000002c0300000000009a
-
{e=>163,c=>3,a=>-5,b=>393,d=>0}
fbffffff89070000a3000000
fbffffffffffffff89070000a3000000
fbffffffffffffff89070000a3000000
fffffffbc4e00000000000a3
fbffffff89070000a3000000
fbffffff89070000a3000000
fffffffffffffffbc4e00000000000a3
fbffffff89070000a3000000
fffffffbc4e00000000000a3
=
struct uchar {
  unsigned char  a:1;
};
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>1}
01
01
01
80
01000000
01
80
01
80
-
{a=>1}
01
01
01
80
01000000
01
80
01
80
=
struct uchar {
  unsigned char  a:1;
  unsigned char  b:1;
};
-
{a=>1,b=>0}
01
01
01
80
01000000
01
80
01
80
-
{a=>1,b=>1}
03
03
03
c0
03000000
03
c0
03
c0
-
{a=>0,b=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>1,b=>1}
03
03
03
c0
03000000
03
c0
03
c0
-
{a=>0,b=>1}
02
02
02
40
02000000
02
40
02
40
=
struct uchar {
  unsigned char  a:1;
  unsigned char  b:1;
  unsigned char  c:1;
};
-
{c=>1,a=>1,b=>1}
07
07
07
e0
07000000
07
e0
07
e0
-
{c=>1,a=>0,b=>0}
04
04
04
20
04000000
04
20
04
20
-
{c=>0,a=>0,b=>0}
00
00
00
00
00000000
00
00
00
00
-
{c=>1,a=>1,b=>1}
07
07
07
e0
07000000
07
e0
07
e0
-
{c=>1,a=>1,b=>0}
05
05
05
a0
05000000
05
a0
05
a0
=
struct uchar {
  unsigned char  a:1;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
};
-
{c=>1,a=>0,b=>1,d=>1}
0e
0e
0e
70
0e000000
0e
70
0e
70
-
{c=>0,a=>1,b=>0,d=>0}
01
01
01
80
01000000
01
80
01
80
-
{c=>0,a=>0,b=>1,d=>1}
0a
0a
0a
50
0a000000
0a
50
0a
50
-
{c=>1,a=>0,b=>0,d=>1}
0c
0c
0c
30
0c000000
0c
30
0c
30
-
{c=>0,a=>1,b=>0,d=>0}
01
01
01
80
01000000
01
80
01
80
=
struct uchar {
  unsigned char  a:1;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
  unsigned int   e;
};
-
{e=>111,c=>1,a=>1,b=>1,d=>1}
0f0000006f000000
0f0000006f000000
0f0000006f000000
f00000000000006f
0f0000006f000000
0f0000006f000000
f00000000000006f
0f0000006f000000
f00000000000006f
-
{e=>24,c=>0,a=>0,b=>1,d=>0}
0200000018000000
0200000018000000
0200000018000000
4000000000000018
0200000018000000
0200000018000000
4000000000000018
0200000018000000
4000000000000018
-
{e=>185,c=>0,a=>0,b=>1,d=>0}
02000000b9000000
02000000b9000000
02000000b9000000
40000000000000b9
02000000b9000000
02000000b9000000
40000000000000b9
02000000b9000000
40000000000000b9
-
{e=>229,c=>1,a=>0,b=>1,d=>1}
0e000000e5000000
0e000000e5000000
0e000000e5000000
70000000000000e5
0e000000e5000000
0e000000e5000000
70000000000000e5
0e000000e5000000
70000000000000e5
-
{e=>255,c=>0,a=>1,b=>0,d=>1}
09000000ff000000
09000000ff000000
09000000ff000000
90000000000000ff
09000000ff000000
09000000ff000000
90000000000000ff
09000000ff000000
90000000000000ff
=
struct uchar {
  char a;
  unsigned char  b:1;
};
-
{a=>-120,b=>1}
8801
8801
8801
8880
88010000
8801
8880
8801
8880
-
{a=>70,b=>0}
4600
4600
4600
4600
46000000
4600
4600
4600
4600
-
{a=>81,b=>0}
5100
5100
5100
5100
51000000
5100
5100
5100
5100
-
{a=>56,b=>1}
3801
3801
3801
3880
38010000
3801
3880
3801
3880
-
{a=>126,b=>0}
7e00
7e00
7e00
7e00
7e000000
7e00
7e00
7e00
7e00
=
struct uchar {
  char a;
  unsigned char  b:1;
  unsigned char  c:1;
};
-
{c=>1,a=>16,b=>1}
1003
1003
1003
10c0
10030000
1003
10c0
1003
10c0
-
{c=>0,a=>90,b=>1}
5a01
5a01
5a01
5a80
5a010000
5a01
5a80
5a01
5a80
-
{c=>0,a=>-85,b=>0}
ab00
ab00
ab00
ab00
ab000000
ab00
ab00
ab00
ab00
-
{c=>0,a=>74,b=>1}
4a01
4a01
4a01
4a80
4a010000
4a01
4a80
4a01
4a80
-
{c=>0,a=>-127,b=>0}
8100
8100
8100
8100
81000000
8100
8100
8100
8100
=
struct uchar {
  char a;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
};
-
{c=>1,a=>-84,b=>0,d=>1}
ac06
ac06
ac06
ac60
ac060000
ac06
ac60
ac06
ac60
-
{c=>1,a=>-93,b=>1,d=>0}
a303
a303
a303
a3c0
a3030000
a303
a3c0
a303
a3c0
-
{c=>1,a=>-94,b=>1,d=>1}
a207
a207
a207
a2e0
a2070000
a207
a2e0
a207
a2e0
-
{c=>1,a=>116,b=>0,d=>0}
7402
7402
7402
7440
74020000
7402
7440
7402
7440
-
{c=>1,a=>92,b=>0,d=>1}
5c06
5c06
5c06
5c60
5c060000
5c06
5c60
5c06
5c60
=
struct uchar {
  char a;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
  unsigned char  e:1;
};
-
{e=>1,c=>0,a=>-104,b=>1,d=>0}
9809
9809
9809
9890
98090000
9809
9890
9809
9890
-
{e=>0,c=>1,a=>-94,b=>0,d=>0}
a202
a202
a202
a240
a2020000
a202
a240
a202
a240
-
{e=>0,c=>0,a=>113,b=>1,d=>0}
7101
7101
7101
7180
71010000
7101
7180
7101
7180
-
{e=>1,c=>0,a=>25,b=>1,d=>1}
190d
190d
190d
19b0
190d0000
190d
19b0
190d
19b0
-
{e=>0,c=>0,a=>-21,b=>1,d=>1}
eb05
eb05
eb05
eba0
eb050000
eb05
eba0
eb05
eba0
=
struct uchar {
  char a;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
  unsigned char  e:1;
  unsigned int   f;
};
-
{e=>1,c=>1,a=>58,b=>1,d=>0,f=>7}
3a0b000007000000
3a0b000007000000
3a0b000007000000
3ad0000000000007
3a0b000007000000
3a0b000007000000
3ad0000000000007
3a0b000007000000
3ad0000000000007
-
{e=>0,c=>0,a=>9,b=>0,d=>1,f=>220}
09040000dc000000
09040000dc000000
09040000dc000000
09200000000000dc
09040000dc000000
09040000dc000000
09200000000000dc
09040000dc000000
09200000000000dc
-
{e=>0,c=>1,a=>123,b=>1,d=>0,f=>59}
7b0300003b000000
7b0300003b000000
7b0300003b000000
7bc000000000003b
7b0300003b000000
7b0300003b000000
7bc000000000003b
7b0300003b000000
7bc000000000003b
-
{e=>0,c=>1,a=>-113,b=>1,d=>1,f=>172}
8f070000ac000000
8f070000ac000000
8f070000ac000000
8fe00000000000ac
8f070000ac000000
8f070000ac000000
8fe00000000000ac
8f070000ac000000
8fe00000000000ac
-
{e=>0,c=>1,a=>75,b=>0,d=>1,f=>175}
4b060000af000000
4b060000af000000
4b060000af000000
4b600000000000af
4b060000af000000
4b060000af000000
4b600000000000af
4b060000af000000
4b600000000000af
=
struct uchar {
  short a;
  unsigned char  b:1;
};
-
{a=>-46,b=>1}
d2ff0100
d2ff0100
d2ff0100
ffd28000
d2ff0100
d2ff0100
ffd28000
d2ff0100
ffd28000
-
{a=>32,b=>1}
20000100
20000100
20000100
00208000
20000100
20000100
00208000
20000100
00208000
-
{a=>-26,b=>0}
e6ff0000
e6ff0000
e6ff0000
ffe60000
e6ff0000
e6ff0000
ffe60000
e6ff0000
ffe60000
-
{a=>122,b=>0}
7a000000
7a000000
7a000000
007a0000
7a000000
7a000000
007a0000
7a000000
007a0000
-
{a=>-51,b=>0}
cdff0000
cdff0000
cdff0000
ffcd0000
cdff0000
cdff0000
ffcd0000
cdff0000
ffcd0000
=
struct uchar {
  short a;
  unsigned char  b:1;
  unsigned char  c:1;
};
-
{c=>1,a=>14,b=>0}
0e000200
0e000200
0e000200
000e4000
0e000200
0e000200
000e4000
0e000200
000e4000
-
{c=>1,a=>-41,b=>0}
d7ff0200
d7ff0200
d7ff0200
ffd74000
d7ff0200
d7ff0200
ffd74000
d7ff0200
ffd74000
-
{c=>1,a=>-93,b=>1}
a3ff0300
a3ff0300
a3ff0300
ffa3c000
a3ff0300
a3ff0300
ffa3c000
a3ff0300
ffa3c000
-
{c=>0,a=>-76,b=>1}
b4ff0100
b4ff0100
b4ff0100
ffb48000
b4ff0100
b4ff0100
ffb48000
b4ff0100
ffb48000
-
{c=>0,a=>-111,b=>0}
91ff0000
91ff0000
91ff0000
ff910000
91ff0000
91ff0000
ff910000
91ff0000
ff910000
=
struct uchar {
  short a;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
};
-
{c=>0,a=>7,b=>1,d=>0}
07000100
07000100
07000100
00078000
07000100
07000100
00078000
07000100
00078000
-
{c=>0,a=>64,b=>0,d=>0}
40000000
40000000
40000000
00400000
40000000
40000000
00400000
40000000
00400000
-
{c=>1,a=>7,b=>0,d=>0}
07000200
07000200
07000200
00074000
07000200
07000200
00074000
07000200
00074000
-
{c=>1,a=>-72,b=>1,d=>1}
b8ff0700
b8ff0700
b8ff0700
ffb8e000
b8ff0700
b8ff0700
ffb8e000
b8ff0700
ffb8e000
-
{c=>1,a=>62,b=>0,d=>1}
3e000600
3e000600
3e000600
003e6000
3e000600
3e000600
003e6000
3e000600
003e6000
=
struct uchar {
  short a;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
  unsigned char  e:1;
};
-
{e=>0,c=>1,a=>-108,b=>1,d=>0}
94ff0300
94ff0300
94ff0300
ff94c000
94ff0300
94ff0300
ff94c000
94ff0300
ff94c000
-
{e=>1,c=>0,a=>-125,b=>1,d=>0}
83ff0900
83ff0900
83ff0900
ff839000
83ff0900
83ff0900
ff839000
83ff0900
ff839000
-
{e=>0,c=>1,a=>52,b=>1,d=>0}
34000300
34000300
34000300
0034c000
34000300
34000300
0034c000
34000300
0034c000
-
{e=>0,c=>0,a=>-93,b=>0,d=>0}
a3ff0000
a3ff0000
a3ff0000
ffa30000
a3ff0000
a3ff0000
ffa30000
a3ff0000
ffa30000
-
{e=>1,c=>0,a=>-128,b=>0,d=>1}
80ff0c00
80ff0c00
80ff0c00
ff803000
80ff0c00
80ff0c00
ff803000
80ff0c00
ff803000
=
struct uchar {
  short a;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
  unsigned char  e:1;
  unsigned int   f;
};
-
{e=>0,c=>0,a=>72,b=>1,d=>1,f=>111}
480005006f000000
480005006f000000
480005006f000000
0048a0000000006f
480005006f000000
480005006f000000
0048a0000000006f
480005006f000000
0048a0000000006f
-
{e=>0,c=>1,a=>-44,b=>0,d=>0,f=>40}
d4ff020028000000
d4ff020028000000
d4ff020028000000
ffd4400000000028
d4ff020028000000
d4ff020028000000
ffd4400000000028
d4ff020028000000
ffd4400000000028
-
{e=>1,c=>1,a=>121,b=>1,d=>0,f=>41}
79000b0029000000
79000b0029000000
79000b0029000000
0079d00000000029
79000b0029000000
79000b0029000000
0079d00000000029
79000b0029000000
0079d00000000029
-
{e=>0,c=>1,a=>-68,b=>1,d=>0,f=>136}
bcff030088000000
bcff030088000000
bcff030088000000
ffbcc00000000088
bcff030088000000
bcff030088000000
ffbcc00000000088
bcff030088000000
ffbcc00000000088
-
{e=>0,c=>0,a=>-73,b=>1,d=>0,f=>25}
b7ff010019000000
b7ff010019000000
b7ff010019000000
ffb7800000000019
b7ff010019000000
b7ff010019000000
ffb7800000000019
b7ff010019000000
ffb7800000000019
=
struct uchar {
  int a;
  unsigned char  b:1;
};
-
{a=>-57,b=>0}
c7ffffff00000000
c7ffffff00000000
c7ffffff00000000
ffffffc700000000
c7ffffff00000000
c7ffffff00000000
ffffffc700000000
c7ffffff00000000
ffffffc700000000
-
{a=>-29,b=>0}
e3ffffff00000000
e3ffffff00000000
e3ffffff00000000
ffffffe300000000
e3ffffff00000000
e3ffffff00000000
ffffffe300000000
e3ffffff00000000
ffffffe300000000
-
{a=>-23,b=>0}
e9ffffff00000000
e9ffffff00000000
e9ffffff00000000
ffffffe900000000
e9ffffff00000000
e9ffffff00000000
ffffffe900000000
e9ffffff00000000
ffffffe900000000
-
{a=>-128,b=>1}
80ffffff01000000
80ffffff01000000
80ffffff01000000
ffffff8080000000
80ffffff01000000
80ffffff01000000
ffffff8080000000
80ffffff01000000
ffffff8080000000
-
{a=>-58,b=>0}
c6ffffff00000000
c6ffffff00000000
c6ffffff00000000
ffffffc600000000
c6ffffff00000000
c6ffffff00000000
ffffffc600000000
c6ffffff00000000
ffffffc600000000
=
struct uchar {
  int a;
  unsigned char  b:1;
  unsigned char  c:1;
};
-
{c=>1,a=>-78,b=>1}
b2ffffff03000000
b2ffffff03000000
b2ffffff03000000
ffffffb2c0000000
b2ffffff03000000
b2ffffff03000000
ffffffb2c0000000
b2ffffff03000000
ffffffb2c0000000
-
{c=>0,a=>-100,b=>1}
9cffffff01000000
9cffffff01000000
9cffffff01000000
ffffff9c80000000
9cffffff01000000
9cffffff01000000
ffffff9c80000000
9cffffff01000000
ffffff9c80000000
-
{c=>0,a=>-27,b=>0}
e5ffffff00000000
e5ffffff00000000
e5ffffff00000000
ffffffe500000000
e5ffffff00000000
e5ffffff00000000
ffffffe500000000
e5ffffff00000000
ffffffe500000000
-
{c=>1,a=>-123,b=>1}
85ffffff03000000
85ffffff03000000
85ffffff03000000
ffffff85c0000000
85ffffff03000000
85ffffff03000000
ffffff85c0000000
85ffffff03000000
ffffff85c0000000
-
{c=>0,a=>-84,b=>0}
acffffff00000000
acffffff00000000
acffffff00000000
ffffffac00000000
acffffff00000000
acffffff00000000
ffffffac00000000
acffffff00000000
ffffffac00000000
=
struct uchar {
  int a;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
};
-
{c=>1,a=>82,b=>0,d=>0}
5200000002000000
5200000002000000
5200000002000000
0000005240000000
5200000002000000
5200000002000000
0000005240000000
5200000002000000
0000005240000000
-
{c=>0,a=>20,b=>0,d=>1}
1400000004000000
1400000004000000
1400000004000000
0000001420000000
1400000004000000
1400000004000000
0000001420000000
1400000004000000
0000001420000000
-
{c=>1,a=>95,b=>0,d=>0}
5f00000002000000
5f00000002000000
5f00000002000000
0000005f40000000
5f00000002000000
5f00000002000000
0000005f40000000
5f00000002000000
0000005f40000000
-
{c=>0,a=>71,b=>0,d=>0}
4700000000000000
4700000000000000
4700000000000000
0000004700000000
4700000000000000
4700000000000000
0000004700000000
4700000000000000
0000004700000000
-
{c=>1,a=>-38,b=>0,d=>0}
daffffff02000000
daffffff02000000
daffffff02000000
ffffffda40000000
daffffff02000000
daffffff02000000
ffffffda40000000
daffffff02000000
ffffffda40000000
=
struct uchar {
  int a;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
  unsigned char  e:1;
};
-
{e=>0,c=>0,a=>-32,b=>1,d=>1}
e0ffffff05000000
e0ffffff05000000
e0ffffff05000000
ffffffe0a0000000
e0ffffff05000000
e0ffffff05000000
ffffffe0a0000000
e0ffffff05000000
ffffffe0a0000000
-
{e=>0,c=>1,a=>-34,b=>1,d=>1}
deffffff07000000
deffffff07000000
deffffff07000000
ffffffdee0000000
deffffff07000000
deffffff07000000
ffffffdee0000000
deffffff07000000
ffffffdee0000000
-
{e=>1,c=>1,a=>70,b=>1,d=>1}
460000000f000000
460000000f000000
460000000f000000
00000046f0000000
460000000f000000
460000000f000000
00000046f0000000
460000000f000000
00000046f0000000
-
{e=>0,c=>1,a=>127,b=>1,d=>1}
7f00000007000000
7f00000007000000
7f00000007000000
0000007fe0000000
7f00000007000000
7f00000007000000
0000007fe0000000
7f00000007000000
0000007fe0000000
-
{e=>1,c=>0,a=>54,b=>1,d=>1}
360000000d000000
360000000d000000
360000000d000000
00000036b0000000
360000000d000000
360000000d000000
00000036b0000000
360000000d000000
00000036b0000000
=
struct uchar {
  int a;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
  unsigned char  e:1;
  unsigned int   f;
};
-
{e=>0,c=>0,a=>-63,b=>1,d=>1,f=>112}
c1ffffff0500000070000000
c1ffffff0500000070000000
c1ffffff0500000070000000
ffffffc1a000000000000070
c1ffffff0500000070000000
c1ffffff0500000070000000
ffffffc1a000000000000070
c1ffffff0500000070000000
ffffffc1a000000000000070
-
{e=>0,c=>1,a=>-107,b=>0,d=>0,f=>190}
95ffffff02000000be000000
95ffffff02000000be000000
95ffffff02000000be000000
ffffff9540000000000000be
95ffffff02000000be000000
95ffffff02000000be000000
ffffff9540000000000000be
95ffffff02000000be000000
ffffff9540000000000000be
-
{e=>0,c=>0,a=>-47,b=>1,d=>1,f=>78}
d1ffffff050000004e000000
d1ffffff050000004e000000
d1ffffff050000004e000000
ffffffd1a00000000000004e
d1ffffff050000004e000000
d1ffffff050000004e000000
ffffffd1a00000000000004e
d1ffffff050000004e000000
ffffffd1a00000000000004e
-
{e=>1,c=>0,a=>65,b=>1,d=>1,f=>14}
410000000d0000000e000000
410000000d0000000e000000
410000000d0000000e000000
00000041b00000000000000e
410000000d0000000e000000
410000000d0000000e000000
00000041b00000000000000e
410000000d0000000e000000
00000041b00000000000000e
-
{e=>1,c=>0,a=>52,b=>0,d=>1,f=>169}
340000000c000000a9000000
340000000c000000a9000000
340000000c000000a9000000
0000003430000000000000a9
340000000c000000a9000000
340000000c000000a9000000
0000003430000000000000a9
340000000c000000a9000000
0000003430000000000000a9
=
struct uchar {
  long a;
  unsigned char  b:1;
};
-
{a=>118,b=>0}
7600000000000000
76000000000000000000000000000000
76000000000000000000000000000000
0000007600000000
7600000000000000
7600000000000000
00000000000000760000000000000000
7600000000000000
0000007600000000
-
{a=>-95,b=>1}
a1ffffff01000000
a1ffffffffffffff0100000000000000
a1ffffffffffffff0100000000000000
ffffffa180000000
a1ffffff01000000
a1ffffff01000000
ffffffffffffffa18000000000000000
a1ffffff01000000
ffffffa180000000
-
{a=>38,b=>0}
2600000000000000
26000000000000000000000000000000
26000000000000000000000000000000
0000002600000000
2600000000000000
2600000000000000
00000000000000260000000000000000
2600000000000000
0000002600000000
-
{a=>50,b=>0}
3200000000000000
32000000000000000000000000000000
32000000000000000000000000000000
0000003200000000
3200000000000000
3200000000000000
00000000000000320000000000000000
3200000000000000
0000003200000000
-
{a=>81,b=>0}
5100000000000000
51000000000000000000000000000000
51000000000000000000000000000000
0000005100000000
5100000000000000
5100000000000000
00000000000000510000000000000000
5100000000000000
0000005100000000
=
struct uchar {
  long a;
  unsigned char  b:1;
  unsigned char  c:1;
};
-
{c=>0,a=>97,b=>0}
6100000000000000
61000000000000000000000000000000
61000000000000000000000000000000
0000006100000000
6100000000000000
6100000000000000
00000000000000610000000000000000
6100000000000000
0000006100000000
-
{c=>0,a=>-20,b=>0}
ecffffff00000000
ecffffffffffffff0000000000000000
ecffffffffffffff0000000000000000
ffffffec00000000
ecffffff00000000
ecffffff00000000
ffffffffffffffec0000000000000000
ecffffff00000000
ffffffec00000000
-
{c=>0,a=>-81,b=>0}
afffffff00000000
afffffffffffffff0000000000000000
afffffffffffffff0000000000000000
ffffffaf00000000
afffffff00000000
afffffff00000000
ffffffffffffffaf0000000000000000
afffffff00000000
ffffffaf00000000
-
{c=>0,a=>75,b=>0}
4b00000000000000
4b000000000000000000000000000000
4b000000000000000000000000000000
0000004b00000000
4b00000000000000
4b00000000000000
000000000000004b0000000000000000
4b00000000000000
0000004b00000000
-
{c=>0,a=>-108,b=>1}
94ffffff01000000
94ffffffffffffff0100000000000000
94ffffffffffffff0100000000000000
ffffff9480000000
94ffffff01000000
94ffffff01000000
ffffffffffffff948000000000000000
94ffffff01000000
ffffff9480000000
=
struct uchar {
  long a;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
};
-
{c=>1,a=>101,b=>1,d=>0}
6500000003000000
65000000000000000300000000000000
65000000000000000300000000000000
00000065c0000000
6500000003000000
6500000003000000
0000000000000065c000000000000000
6500000003000000
00000065c0000000
-
{c=>0,a=>-71,b=>0,d=>1}
b9ffffff04000000
b9ffffffffffffff0400000000000000
b9ffffffffffffff0400000000000000
ffffffb920000000
b9ffffff04000000
b9ffffff04000000
ffffffffffffffb92000000000000000
b9ffffff04000000
ffffffb920000000
-
{c=>1,a=>-61,b=>0,d=>1}
c3ffffff06000000
c3ffffffffffffff0600000000000000
c3ffffffffffffff0600000000000000
ffffffc360000000
c3ffffff06000000
c3ffffff06000000
ffffffffffffffc36000000000000000
c3ffffff06000000
ffffffc360000000
-
{c=>1,a=>-98,b=>0,d=>1}
9effffff06000000
9effffffffffffff0600000000000000
9effffffffffffff0600000000000000
ffffff9e60000000
9effffff06000000
9effffff06000000
ffffffffffffff9e6000000000000000
9effffff06000000
ffffff9e60000000
-
{c=>0,a=>86,b=>0,d=>0}
5600000000000000
56000000000000000000000000000000
56000000000000000000000000000000
0000005600000000
5600000000000000
5600000000000000
00000000000000560000000000000000
5600000000000000
0000005600000000
=
struct uchar {
  long a;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
  unsigned char  e:1;
};
-
{e=>0,c=>1,a=>-117,b=>1,d=>1}
8bffffff07000000
8bffffffffffffff0700000000000000
8bffffffffffffff0700000000000000
ffffff8be0000000
8bffffff07000000
8bffffff07000000
ffffffffffffff8be000000000000000
8bffffff07000000
ffffff8be0000000
-
{e=>1,c=>0,a=>47,b=>1,d=>1}
2f0000000d000000
2f000000000000000d00000000000000
2f000000000000000d00000000000000
0000002fb0000000
2f0000000d000000
2f0000000d000000
000000000000002fb000000000000000
2f0000000d000000
0000002fb0000000
-
{e=>1,c=>1,a=>-116,b=>0,d=>0}
8cffffff0a000000
8cffffffffffffff0a00000000000000
8cffffffffffffff0a00000000000000
ffffff8c50000000
8cffffff0a000000
8cffffff0a000000
ffffffffffffff8c5000000000000000
8cffffff0a000000
ffffff8c50000000
-
{e=>1,c=>1,a=>-118,b=>0,d=>1}
8affffff0e000000
8affffffffffffff0e00000000000000
8affffffffffffff0e00000000000000
ffffff8a70000000
8affffff0e000000
8affffff0e000000
ffffffffffffff8a7000000000000000
8affffff0e000000
ffffff8a70000000
-
{e=>1,c=>1,a=>-38,b=>0,d=>1}
daffffff0e000000
daffffffffffffff0e00000000000000
daffffffffffffff0e00000000000000
ffffffda70000000
daffffff0e000000
daffffff0e000000
ffffffffffffffda7000000000000000
daffffff0e000000
ffffffda70000000
=
struct uchar {
  long a;
  unsigned char  b:1;
  unsigned char  c:1;
  unsigned char  d:1;
  unsigned char  e:1;
  unsigned int   f;
};
-
{e=>0,c=>1,a=>-47,b=>0,d=>1,f=>41}
d1ffffff0600000029000000
d1ffffffffffffff0600000029000000
d1ffffffffffffff0600000029000000
ffffffd16000000000000029
d1ffffff0600000029000000
d1ffffff0600000029000000
ffffffffffffffd16000000000000029
d1ffffff0600000029000000
ffffffd16000000000000029
-
{e=>0,c=>1,a=>-89,b=>1,d=>0,f=>152}
a7ffffff0300000098000000
a7ffffffffffffff0300000098000000
a7ffffffffffffff0300000098000000
ffffffa7c000000000000098
a7ffffff0300000098000000
a7ffffff0300000098000000
ffffffffffffffa7c000000000000098
a7ffffff0300000098000000
ffffffa7c000000000000098
-
{e=>1,c=>1,a=>114,b=>1,d=>1,f=>37}
720000000f00000025000000
72000000000000000f00000025000000
72000000000000000f00000025000000
00000072f000000000000025
720000000f00000025000000
720000000f00000025000000
0000000000000072f000000000000025
720000000f00000025000000
00000072f000000000000025
-
{e=>1,c=>1,a=>127,b=>1,d=>1,f=>22}
7f0000000f00000016000000
7f000000000000000f00000016000000
7f000000000000000f00000016000000
0000007ff000000000000016
7f0000000f00000016000000
7f0000000f00000016000000
000000000000007ff000000000000016
7f0000000f00000016000000
0000007ff000000000000016
-
{e=>0,c=>0,a=>-95,b=>1,d=>0,f=>125}
a1ffffff010000007d000000
a1ffffffffffffff010000007d000000
a1ffffffffffffff010000007d000000
ffffffa1800000000000007d
a1ffffff010000007d000000
a1ffffff010000007d000000
ffffffffffffffa1800000000000007d
a1ffffff010000007d000000
ffffffa1800000000000007d
=
struct ushort {
  unsigned short a:1;
};
-
{a=>1}
0100
0100
0100
8000
01000000
0100
8000
0100
8000
-
{a=>1}
0100
0100
0100
8000
01000000
0100
8000
0100
8000
-
{a=>0}
0000
0000
0000
0000
00000000
0000
0000
0000
0000
-
{a=>0}
0000
0000
0000
0000
00000000
0000
0000
0000
0000
-
{a=>0}
0000
0000
0000
0000
00000000
0000
0000
0000
0000
=
struct ushort {
  unsigned short a:1;
  unsigned short b:1;
};
-
{a=>1,b=>1}
0300
0300
0300
c000
03000000
0300
c000
0300
c000
-
{a=>0,b=>0}
0000
0000
0000
0000
00000000
0000
0000
0000
0000
-
{a=>1,b=>0}
0100
0100
0100
8000
01000000
0100
8000
0100
8000
-
{a=>0,b=>0}
0000
0000
0000
0000
00000000
0000
0000
0000
0000
-
{a=>0,b=>1}
0200
0200
0200
4000
02000000
0200
4000
0200
4000
=
struct ushort {
  unsigned short a:1;
  unsigned short b:1;
  unsigned short c:1;
};
-
{c=>1,a=>0,b=>1}
0600
0600
0600
6000
06000000
0600
6000
0600
6000
-
{c=>0,a=>1,b=>1}
0300
0300
0300
c000
03000000
0300
c000
0300
c000
-
{c=>1,a=>0,b=>1}
0600
0600
0600
6000
06000000
0600
6000
0600
6000
-
{c=>0,a=>0,b=>1}
0200
0200
0200
4000
02000000
0200
4000
0200
4000
-
{c=>1,a=>0,b=>1}
0600
0600
0600
6000
06000000
0600
6000
0600
6000
=
struct ushort {
  unsigned short a:1;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
};
-
{c=>0,a=>0,b=>0,d=>1}
0800
0800
0800
1000
08000000
0800
1000
0800
1000
-
{c=>1,a=>1,b=>1,d=>0}
0700
0700
0700
e000
07000000
0700
e000
0700
e000
-
{c=>1,a=>1,b=>1,d=>1}
0f00
0f00
0f00
f000
0f000000
0f00
f000
0f00
f000
-
{c=>1,a=>1,b=>0,d=>0}
0500
0500
0500
a000
05000000
0500
a000
0500
a000
-
{c=>1,a=>0,b=>0,d=>0}
0400
0400
0400
2000
04000000
0400
2000
0400
2000
=
struct ushort {
  unsigned short a:1;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
  unsigned int   e;
};
-
{e=>78,c=>1,a=>0,b=>0,d=>1}
0c0000004e000000
0c0000004e000000
0c0000004e000000
300000000000004e
0c0000004e000000
0c0000004e000000
300000000000004e
0c0000004e000000
300000000000004e
-
{e=>118,c=>1,a=>1,b=>0,d=>0}
0500000076000000
0500000076000000
0500000076000000
a000000000000076
0500000076000000
0500000076000000
a000000000000076
0500000076000000
a000000000000076
-
{e=>65,c=>0,a=>0,b=>1,d=>1}
0a00000041000000
0a00000041000000
0a00000041000000
5000000000000041
0a00000041000000
0a00000041000000
5000000000000041
0a00000041000000
5000000000000041
-
{e=>216,c=>0,a=>0,b=>1,d=>1}
0a000000d8000000
0a000000d8000000
0a000000d8000000
50000000000000d8
0a000000d8000000
0a000000d8000000
50000000000000d8
0a000000d8000000
50000000000000d8
-
{e=>98,c=>0,a=>0,b=>1,d=>1}
0a00000062000000
0a00000062000000
0a00000062000000
5000000000000062
0a00000062000000
0a00000062000000
5000000000000062
0a00000062000000
5000000000000062
=
struct ushort {
  char a;
  unsigned short b:1;
};
-
{a=>22,b=>1}
1601
1601
1601
1680
16010000
1601
1680
1601
1680
-
{a=>-76,b=>0}
b400
b400
b400
b400
b4000000
b400
b400
b400
b400
-
{a=>101,b=>1}
6501
6501
6501
6580
65010000
6501
6580
6501
6580
-
{a=>110,b=>0}
6e00
6e00
6e00
6e00
6e000000
6e00
6e00
6e00
6e00
-
{a=>19,b=>1}
1301
1301
1301
1380
13010000
1301
1380
1301
1380
=
struct ushort {
  char a;
  unsigned short b:1;
  unsigned short c:1;
};
-
{c=>0,a=>103,b=>1}
6701
6701
6701
6780
67010000
6701
6780
6701
6780
-
{c=>1,a=>-109,b=>1}
9303
9303
9303
93c0
93030000
9303
93c0
9303
93c0
-
{c=>1,a=>-16,b=>0}
f002
f002
f002
f040
f0020000
f002
f040
f002
f040
-
{c=>1,a=>124,b=>1}
7c03
7c03
7c03
7cc0
7c030000
7c03
7cc0
7c03
7cc0
-
{c=>1,a=>109,b=>0}
6d02
6d02
6d02
6d40
6d020000
6d02
6d40
6d02
6d40
=
struct ushort {
  char a;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
};
-
{c=>0,a=>-25,b=>1,d=>0}
e701
e701
e701
e780
e7010000
e701
e780
e701
e780
-
{c=>1,a=>-79,b=>0,d=>0}
b102
b102
b102
b140
b1020000
b102
b140
b102
b140
-
{c=>1,a=>102,b=>0,d=>1}
6606
6606
6606
6660
66060000
6606
6660
6606
6660
-
{c=>0,a=>125,b=>1,d=>1}
7d05
7d05
7d05
7da0
7d050000
7d05
7da0
7d05
7da0
-
{c=>0,a=>5,b=>1,d=>1}
0505
0505
0505
05a0
05050000
0505
05a0
0505
05a0
=
struct ushort {
  char a;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
  unsigned short e:1;
};
-
{e=>1,c=>0,a=>9,b=>1,d=>0}
0909
0909
0909
0990
09090000
0909
0990
0909
0990
-
{e=>1,c=>0,a=>44,b=>1,d=>1}
2c0d
2c0d
2c0d
2cb0
2c0d0000
2c0d
2cb0
2c0d
2cb0
-
{e=>0,c=>0,a=>44,b=>0,d=>0}
2c00
2c00
2c00
2c00
2c000000
2c00
2c00
2c00
2c00
-
{e=>1,c=>1,a=>-13,b=>0,d=>1}
f30e
f30e
f30e
f370
f30e0000
f30e
f370
f30e
f370
-
{e=>0,c=>1,a=>-2,b=>0,d=>0}
fe02
fe02
fe02
fe40
fe020000
fe02
fe40
fe02
fe40
=
struct ushort {
  char a;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
  unsigned short e:1;
  unsigned int   f;
};
-
{e=>1,c=>1,a=>107,b=>1,d=>0,f=>112}
6b0b000070000000
6b0b000070000000
6b0b000070000000
6bd0000000000070
6b0b000070000000
6b0b000070000000
6bd0000000000070
6b0b000070000000
6bd0000000000070
-
{e=>0,c=>1,a=>-68,b=>1,d=>1,f=>129}
bc07000081000000
bc07000081000000
bc07000081000000
bce0000000000081
bc07000081000000
bc07000081000000
bce0000000000081
bc07000081000000
bce0000000000081
-
{e=>0,c=>0,a=>72,b=>1,d=>1,f=>226}
48050000e2000000
48050000e2000000
48050000e2000000
48a00000000000e2
48050000e2000000
48050000e2000000
48a00000000000e2
48050000e2000000
48a00000000000e2
-
{e=>0,c=>0,a=>-102,b=>0,d=>1,f=>147}
9a04000093000000
9a04000093000000
9a04000093000000
9a20000000000093
9a04000093000000
9a04000093000000
9a20000000000093
9a04000093000000
9a20000000000093
-
{e=>1,c=>1,a=>-25,b=>1,d=>1,f=>7}
e70f000007000000
e70f000007000000
e70f000007000000
e7f0000000000007
e70f000007000000
e70f000007000000
e7f0000000000007
e70f000007000000
e7f0000000000007
=
struct ushort {
  short a;
  unsigned short b:1;
};
-
{a=>89,b=>1}
59000100
59000100
59000100
00598000
59000100
59000100
00598000
59000100
00598000
-
{a=>-24,b=>0}
e8ff0000
e8ff0000
e8ff0000
ffe80000
e8ff0000
e8ff0000
ffe80000
e8ff0000
ffe80000
-
{a=>53,b=>1}
35000100
35000100
35000100
00358000
35000100
35000100
00358000
35000100
00358000
-
{a=>60,b=>1}
3c000100
3c000100
3c000100
003c8000
3c000100
3c000100
003c8000
3c000100
003c8000
-
{a=>-33,b=>1}
dfff0100
dfff0100
dfff0100
ffdf8000
dfff0100
dfff0100
ffdf8000
dfff0100
ffdf8000
=
struct ushort {
  short a;
  unsigned short b:1;
  unsigned short c:1;
};
-
{c=>1,a=>-21,b=>0}
ebff0200
ebff0200
ebff0200
ffeb4000
ebff0200
ebff0200
ffeb4000
ebff0200
ffeb4000
-
{c=>0,a=>65,b=>0}
41000000
41000000
41000000
00410000
41000000
41000000
00410000
41000000
00410000
-
{c=>0,a=>-82,b=>0}
aeff0000
aeff0000
aeff0000
ffae0000
aeff0000
aeff0000
ffae0000
aeff0000
ffae0000
-
{c=>1,a=>-45,b=>0}
d3ff0200
d3ff0200
d3ff0200
ffd34000
d3ff0200
d3ff0200
ffd34000
d3ff0200
ffd34000
-
{c=>1,a=>-105,b=>0}
97ff0200
97ff0200
97ff0200
ff974000
97ff0200
97ff0200
ff974000
97ff0200
ff974000
=
struct ushort {
  short a;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
};
-
{c=>0,a=>5,b=>1,d=>1}
05000500
05000500
05000500
0005a000
05000500
05000500
0005a000
05000500
0005a000
-
{c=>1,a=>-68,b=>1,d=>0}
bcff0300
bcff0300
bcff0300
ffbcc000
bcff0300
bcff0300
ffbcc000
bcff0300
ffbcc000
-
{c=>1,a=>-4,b=>0,d=>0}
fcff0200
fcff0200
fcff0200
fffc4000
fcff0200
fcff0200
fffc4000
fcff0200
fffc4000
-
{c=>1,a=>122,b=>1,d=>1}
7a000700
7a000700
7a000700
007ae000
7a000700
7a000700
007ae000
7a000700
007ae000
-
{c=>1,a=>-64,b=>1,d=>0}
c0ff0300
c0ff0300
c0ff0300
ffc0c000
c0ff0300
c0ff0300
ffc0c000
c0ff0300
ffc0c000
=
struct ushort {
  short a;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
  unsigned short e:1;
};
-
{e=>1,c=>1,a=>96,b=>1,d=>1}
60000f00
60000f00
60000f00
0060f000
60000f00
60000f00
0060f000
60000f00
0060f000
-
{e=>0,c=>0,a=>-110,b=>1,d=>0}
92ff0100
92ff0100
92ff0100
ff928000
92ff0100
92ff0100
ff928000
92ff0100
ff928000
-
{e=>1,c=>1,a=>-47,b=>1,d=>0}
d1ff0b00
d1ff0b00
d1ff0b00
ffd1d000
d1ff0b00
d1ff0b00
ffd1d000
d1ff0b00
ffd1d000
-
{e=>0,c=>1,a=>71,b=>1,d=>0}
47000300
47000300
47000300
0047c000
47000300
47000300
0047c000
47000300
0047c000
-
{e=>1,c=>1,a=>-110,b=>1,d=>1}
92ff0f00
92ff0f00
92ff0f00
ff92f000
92ff0f00
92ff0f00
ff92f000
92ff0f00
ff92f000
=
struct ushort {
  short a;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
  unsigned short e:1;
  unsigned int   f;
};
-
{e=>0,c=>1,a=>-77,b=>1,d=>0,f=>56}
b3ff030038000000
b3ff030038000000
b3ff030038000000
ffb3c00000000038
b3ff030038000000
b3ff030038000000
ffb3c00000000038
b3ff030038000000
ffb3c00000000038
-
{e=>0,c=>0,a=>108,b=>1,d=>1,f=>82}
6c00050052000000
6c00050052000000
6c00050052000000
006ca00000000052
6c00050052000000
6c00050052000000
006ca00000000052
6c00050052000000
006ca00000000052
-
{e=>0,c=>0,a=>4,b=>1,d=>1,f=>96}
0400050060000000
0400050060000000
0400050060000000
0004a00000000060
0400050060000000
0400050060000000
0004a00000000060
0400050060000000
0004a00000000060
-
{e=>0,c=>0,a=>93,b=>1,d=>1,f=>28}
5d0005001c000000
5d0005001c000000
5d0005001c000000
005da0000000001c
5d0005001c000000
5d0005001c000000
005da0000000001c
5d0005001c000000
005da0000000001c
-
{e=>1,c=>0,a=>40,b=>1,d=>1,f=>174}
28000d00ae000000
28000d00ae000000
28000d00ae000000
0028b000000000ae
28000d00ae000000
28000d00ae000000
0028b000000000ae
28000d00ae000000
0028b000000000ae
=
struct ushort {
  int a;
  unsigned short b:1;
};
-
{a=>88,b=>1}
5800000001000000
5800000001000000
5800000001000000
0000005880000000
5800000001000000
5800000001000000
0000005880000000
5800000001000000
0000005880000000
-
{a=>-118,b=>1}
8affffff01000000
8affffff01000000
8affffff01000000
ffffff8a80000000
8affffff01000000
8affffff01000000
ffffff8a80000000
8affffff01000000
ffffff8a80000000
-
{a=>122,b=>1}
7a00000001000000
7a00000001000000
7a00000001000000
0000007a80000000
7a00000001000000
7a00000001000000
0000007a80000000
7a00000001000000
0000007a80000000
-
{a=>-125,b=>0}
83ffffff00000000
83ffffff00000000
83ffffff00000000
ffffff8300000000
83ffffff00000000
83ffffff00000000
ffffff8300000000
83ffffff00000000
ffffff8300000000
-
{a=>-83,b=>0}
adffffff00000000
adffffff00000000
adffffff00000000
ffffffad00000000
adffffff00000000
adffffff00000000
ffffffad00000000
adffffff00000000
ffffffad00000000
=
struct ushort {
  int a;
  unsigned short b:1;
  unsigned short c:1;
};
-
{c=>0,a=>-73,b=>1}
b7ffffff01000000
b7ffffff01000000
b7ffffff01000000
ffffffb780000000
b7ffffff01000000
b7ffffff01000000
ffffffb780000000
b7ffffff01000000
ffffffb780000000
-
{c=>1,a=>41,b=>0}
2900000002000000
2900000002000000
2900000002000000
0000002940000000
2900000002000000
2900000002000000
0000002940000000
2900000002000000
0000002940000000
-
{c=>0,a=>-10,b=>0}
f6ffffff00000000
f6ffffff00000000
f6ffffff00000000
fffffff600000000
f6ffffff00000000
f6ffffff00000000
fffffff600000000
f6ffffff00000000
fffffff600000000
-
{c=>1,a=>46,b=>1}
2e00000003000000
2e00000003000000
2e00000003000000
0000002ec0000000
2e00000003000000
2e00000003000000
0000002ec0000000
2e00000003000000
0000002ec0000000
-
{c=>0,a=>91,b=>1}
5b00000001000000
5b00000001000000
5b00000001000000
0000005b80000000
5b00000001000000
5b00000001000000
0000005b80000000
5b00000001000000
0000005b80000000
=
struct ushort {
  int a;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
};
-
{c=>0,a=>62,b=>1,d=>1}
3e00000005000000
3e00000005000000
3e00000005000000
0000003ea0000000
3e00000005000000
3e00000005000000
0000003ea0000000
3e00000005000000
0000003ea0000000
-
{c=>1,a=>-98,b=>1,d=>1}
9effffff07000000
9effffff07000000
9effffff07000000
ffffff9ee0000000
9effffff07000000
9effffff07000000
ffffff9ee0000000
9effffff07000000
ffffff9ee0000000
-
{c=>0,a=>-94,b=>0,d=>0}
a2ffffff00000000
a2ffffff00000000
a2ffffff00000000
ffffffa200000000
a2ffffff00000000
a2ffffff00000000
ffffffa200000000
a2ffffff00000000
ffffffa200000000
-
{c=>0,a=>36,b=>1,d=>0}
2400000001000000
2400000001000000
2400000001000000
0000002480000000
2400000001000000
2400000001000000
0000002480000000
2400000001000000
0000002480000000
-
{c=>1,a=>-4,b=>0,d=>1}
fcffffff06000000
fcffffff06000000
fcffffff06000000
fffffffc60000000
fcffffff06000000
fcffffff06000000
fffffffc60000000
fcffffff06000000
fffffffc60000000
=
struct ushort {
  int a;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
  unsigned short e:1;
};
-
{e=>0,c=>0,a=>96,b=>0,d=>0}
6000000000000000
6000000000000000
6000000000000000
0000006000000000
6000000000000000
6000000000000000
0000006000000000
6000000000000000
0000006000000000
-
{e=>1,c=>0,a=>127,b=>1,d=>0}
7f00000009000000
7f00000009000000
7f00000009000000
0000007f90000000
7f00000009000000
7f00000009000000
0000007f90000000
7f00000009000000
0000007f90000000
-
{e=>1,c=>0,a=>40,b=>0,d=>0}
2800000008000000
2800000008000000
2800000008000000
0000002810000000
2800000008000000
2800000008000000
0000002810000000
2800000008000000
0000002810000000
-
{e=>1,c=>0,a=>96,b=>0,d=>1}
600000000c000000
600000000c000000
600000000c000000
0000006030000000
600000000c000000
600000000c000000
0000006030000000
600000000c000000
0000006030000000
-
{e=>0,c=>0,a=>-42,b=>0,d=>1}
d6ffffff04000000
d6ffffff04000000
d6ffffff04000000
ffffffd620000000
d6ffffff04000000
d6ffffff04000000
ffffffd620000000
d6ffffff04000000
ffffffd620000000
=
struct ushort {
  int a;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
  unsigned short e:1;
  unsigned int   f;
};
-
{e=>0,c=>1,a=>15,b=>0,d=>0,f=>0}
0f0000000200000000000000
0f0000000200000000000000
0f0000000200000000000000
0000000f4000000000000000
0f0000000200000000000000
0f0000000200000000000000
0000000f4000000000000000
0f0000000200000000000000
0000000f4000000000000000
-
{e=>1,c=>0,a=>-90,b=>1,d=>1,f=>104}
a6ffffff0d00000068000000
a6ffffff0d00000068000000
a6ffffff0d00000068000000
ffffffa6b000000000000068
a6ffffff0d00000068000000
a6ffffff0d00000068000000
ffffffa6b000000000000068
a6ffffff0d00000068000000
ffffffa6b000000000000068
-
{e=>1,c=>0,a=>-53,b=>1,d=>0,f=>14}
cbffffff090000000e000000
cbffffff090000000e000000
cbffffff090000000e000000
ffffffcb900000000000000e
cbffffff090000000e000000
cbffffff090000000e000000
ffffffcb900000000000000e
cbffffff090000000e000000
ffffffcb900000000000000e
-
{e=>0,c=>1,a=>41,b=>0,d=>1,f=>247}
2900000006000000f7000000
2900000006000000f7000000
2900000006000000f7000000
0000002960000000000000f7
2900000006000000f7000000
2900000006000000f7000000
0000002960000000000000f7
2900000006000000f7000000
0000002960000000000000f7
-
{e=>1,c=>1,a=>-21,b=>0,d=>0,f=>111}
ebffffff0a0000006f000000
ebffffff0a0000006f000000
ebffffff0a0000006f000000
ffffffeb500000000000006f
ebffffff0a0000006f000000
ebffffff0a0000006f000000
ffffffeb500000000000006f
ebffffff0a0000006f000000
ffffffeb500000000000006f
=
struct ushort {
  long a;
  unsigned short b:1;
};
-
{a=>-109,b=>0}
93ffffff00000000
93ffffffffffffff0000000000000000
93ffffffffffffff0000000000000000
ffffff9300000000
93ffffff00000000
93ffffff00000000
ffffffffffffff930000000000000000
93ffffff00000000
ffffff9300000000
-
{a=>68,b=>1}
4400000001000000
44000000000000000100000000000000
44000000000000000100000000000000
0000004480000000
4400000001000000
4400000001000000
00000000000000448000000000000000
4400000001000000
0000004480000000
-
{a=>-127,b=>0}
81ffffff00000000
81ffffffffffffff0000000000000000
81ffffffffffffff0000000000000000
ffffff8100000000
81ffffff00000000
81ffffff00000000
ffffffffffffff810000000000000000
81ffffff00000000
ffffff8100000000
-
{a=>-101,b=>1}
9bffffff01000000
9bffffffffffffff0100000000000000
9bffffffffffffff0100000000000000
ffffff9b80000000
9bffffff01000000
9bffffff01000000
ffffffffffffff9b8000000000000000
9bffffff01000000
ffffff9b80000000
-
{a=>65,b=>1}
4100000001000000
41000000000000000100000000000000
41000000000000000100000000000000
0000004180000000
4100000001000000
4100000001000000
00000000000000418000000000000000
4100000001000000
0000004180000000
=
struct ushort {
  long a;
  unsigned short b:1;
  unsigned short c:1;
};
-
{c=>0,a=>-118,b=>0}
8affffff00000000
8affffffffffffff0000000000000000
8affffffffffffff0000000000000000
ffffff8a00000000
8affffff00000000
8affffff00000000
ffffffffffffff8a0000000000000000
8affffff00000000
ffffff8a00000000
-
{c=>0,a=>98,b=>1}
6200000001000000
62000000000000000100000000000000
62000000000000000100000000000000
0000006280000000
6200000001000000
6200000001000000
00000000000000628000000000000000
6200000001000000
0000006280000000
-
{c=>0,a=>20,b=>0}
1400000000000000
14000000000000000000000000000000
14000000000000000000000000000000
0000001400000000
1400000000000000
1400000000000000
00000000000000140000000000000000
1400000000000000
0000001400000000
-
{c=>0,a=>-71,b=>0}
b9ffffff00000000
b9ffffffffffffff0000000000000000
b9ffffffffffffff0000000000000000
ffffffb900000000
b9ffffff00000000
b9ffffff00000000
ffffffffffffffb90000000000000000
b9ffffff00000000
ffffffb900000000
-
{c=>0,a=>-104,b=>1}
98ffffff01000000
98ffffffffffffff0100000000000000
98ffffffffffffff0100000000000000
ffffff9880000000
98ffffff01000000
98ffffff01000000
ffffffffffffff988000000000000000
98ffffff01000000
ffffff9880000000
=
struct ushort {
  long a;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
};
-
{c=>0,a=>31,b=>1,d=>1}
1f00000005000000
1f000000000000000500000000000000
1f000000000000000500000000000000
0000001fa0000000
1f00000005000000
1f00000005000000
000000000000001fa000000000000000
1f00000005000000
0000001fa0000000
-
{c=>1,a=>105,b=>0,d=>1}
6900000006000000
69000000000000000600000000000000
69000000000000000600000000000000
0000006960000000
6900000006000000
6900000006000000
00000000000000696000000000000000
6900000006000000
0000006960000000
-
{c=>1,a=>-124,b=>1,d=>0}
84ffffff03000000
84ffffffffffffff0300000000000000
84ffffffffffffff0300000000000000
ffffff84c0000000
84ffffff03000000
84ffffff03000000
ffffffffffffff84c000000000000000
84ffffff03000000
ffffff84c0000000
-
{c=>1,a=>11,b=>1,d=>1}
0b00000007000000
0b000000000000000700000000000000
0b000000000000000700000000000000
0000000be0000000
0b00000007000000
0b00000007000000
000000000000000be000000000000000
0b00000007000000
0000000be0000000
-
{c=>1,a=>21,b=>0,d=>1}
1500000006000000
15000000000000000600000000000000
15000000000000000600000000000000
0000001560000000
1500000006000000
1500000006000000
00000000000000156000000000000000
1500000006000000
0000001560000000
=
struct ushort {
  long a;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
  unsigned short e:1;
};
-
{e=>0,c=>0,a=>51,b=>0,d=>0}
3300000000000000
33000000000000000000000000000000
33000000000000000000000000000000
0000003300000000
3300000000000000
3300000000000000
00000000000000330000000000000000
3300000000000000
0000003300000000
-
{e=>1,c=>1,a=>16,b=>1,d=>1}
100000000f000000
10000000000000000f00000000000000
10000000000000000f00000000000000
00000010f0000000
100000000f000000
100000000f000000
0000000000000010f000000000000000
100000000f000000
00000010f0000000
-
{e=>1,c=>1,a=>-30,b=>1,d=>1}
e2ffffff0f000000
e2ffffffffffffff0f00000000000000
e2ffffffffffffff0f00000000000000
ffffffe2f0000000
e2ffffff0f000000
e2ffffff0f000000
ffffffffffffffe2f000000000000000
e2ffffff0f000000
ffffffe2f0000000
-
{e=>1,c=>0,a=>-27,b=>1,d=>0}
e5ffffff09000000
e5ffffffffffffff0900000000000000
e5ffffffffffffff0900000000000000
ffffffe590000000
e5ffffff09000000
e5ffffff09000000
ffffffffffffffe59000000000000000
e5ffffff09000000
ffffffe590000000
-
{e=>0,c=>0,a=>44,b=>1,d=>1}
2c00000005000000
2c000000000000000500000000000000
2c000000000000000500000000000000
0000002ca0000000
2c00000005000000
2c00000005000000
000000000000002ca000000000000000
2c00000005000000
0000002ca0000000
=
struct ushort {
  long a;
  unsigned short b:1;
  unsigned short c:1;
  unsigned short d:1;
  unsigned short e:1;
  unsigned int   f;
};
-
{e=>0,c=>1,a=>-43,b=>1,d=>0,f=>98}
d5ffffff0300000062000000
d5ffffffffffffff0300000062000000
d5ffffffffffffff0300000062000000
ffffffd5c000000000000062
d5ffffff0300000062000000
d5ffffff0300000062000000
ffffffffffffffd5c000000000000062
d5ffffff0300000062000000
ffffffd5c000000000000062
-
{e=>1,c=>0,a=>-40,b=>1,d=>1,f=>138}
d8ffffff0d0000008a000000
d8ffffffffffffff0d0000008a000000
d8ffffffffffffff0d0000008a000000
ffffffd8b00000000000008a
d8ffffff0d0000008a000000
d8ffffff0d0000008a000000
ffffffffffffffd8b00000000000008a
d8ffffff0d0000008a000000
ffffffd8b00000000000008a
-
{e=>1,c=>0,a=>14,b=>1,d=>1,f=>44}
0e0000000d0000002c000000
0e000000000000000d0000002c000000
0e000000000000000d0000002c000000
0000000eb00000000000002c
0e0000000d0000002c000000
0e0000000d0000002c000000
000000000000000eb00000000000002c
0e0000000d0000002c000000
0000000eb00000000000002c
-
{e=>1,c=>1,a=>-30,b=>1,d=>0,f=>32}
e2ffffff0b00000020000000
e2ffffffffffffff0b00000020000000
e2ffffffffffffff0b00000020000000
ffffffe2d000000000000020
e2ffffff0b00000020000000
e2ffffff0b00000020000000
ffffffffffffffe2d000000000000020
e2ffffff0b00000020000000
ffffffe2d000000000000020
-
{e=>0,c=>1,a=>87,b=>0,d=>1,f=>216}
5700000006000000d8000000
570000000000000006000000d8000000
570000000000000006000000d8000000
0000005760000000000000d8
5700000006000000d8000000
5700000006000000d8000000
000000000000005760000000000000d8
5700000006000000d8000000
0000005760000000000000d8
=
struct uint {
  unsigned int   a:1;
};
-
{a=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
-
{a=>1}
01000000
01000000
01000000
80000000
01000000
01000000
80000000
01000000
80000000
-
{a=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
-
{a=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
-
{a=>1}
01000000
01000000
01000000
80000000
01000000
01000000
80000000
01000000
80000000
=
struct uint {
  unsigned int   a:1;
  unsigned int   b:1;
};
-
{a=>0,b=>1}
02000000
02000000
02000000
40000000
02000000
02000000
40000000
02000000
40000000
-
{a=>0,b=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
-
{a=>1,b=>0}
01000000
01000000
01000000
80000000
01000000
01000000
80000000
01000000
80000000
-
{a=>0,b=>1}
02000000
02000000
02000000
40000000
02000000
02000000
40000000
02000000
40000000
-
{a=>0,b=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
=
struct uint {
  unsigned int   a:1;
  unsigned int   b:1;
  unsigned int   c:1;
};
-
{c=>0,a=>0,b=>1}
02000000
02000000
02000000
40000000
02000000
02000000
40000000
02000000
40000000
-
{c=>1,a=>1,b=>0}
05000000
05000000
05000000
a0000000
05000000
05000000
a0000000
05000000
a0000000
-
{c=>0,a=>1,b=>1}
03000000
03000000
03000000
c0000000
03000000
03000000
c0000000
03000000
c0000000
-
{c=>1,a=>0,b=>0}
04000000
04000000
04000000
20000000
04000000
04000000
20000000
04000000
20000000
-
{c=>0,a=>0,b=>1}
02000000
02000000
02000000
40000000
02000000
02000000
40000000
02000000
40000000
=
struct uint {
  unsigned int   a:1;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
};
-
{c=>0,a=>1,b=>1,d=>0}
03000000
03000000
03000000
c0000000
03000000
03000000
c0000000
03000000
c0000000
-
{c=>0,a=>0,b=>0,d=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
-
{c=>1,a=>0,b=>0,d=>1}
0c000000
0c000000
0c000000
30000000
0c000000
0c000000
30000000
0c000000
30000000
-
{c=>0,a=>0,b=>1,d=>0}
02000000
02000000
02000000
40000000
02000000
02000000
40000000
02000000
40000000
-
{c=>1,a=>0,b=>1,d=>0}
06000000
06000000
06000000
60000000
06000000
06000000
60000000
06000000
60000000
=
struct uint {
  unsigned int   a:1;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
  unsigned char  e;
};
-
{e=>191,c=>1,a=>1,b=>1,d=>1}
0fbf0000
0fbf0000
0fbf0000
f0bf0000
0fbf0000
0fbf0000
f0bf0000
0fbf0000
f0bf0000
-
{e=>169,c=>0,a=>1,b=>0,d=>0}
01a90000
01a90000
01a90000
80a90000
01a90000
01a90000
80a90000
01a90000
80a90000
-
{e=>146,c=>0,a=>1,b=>1,d=>0}
03920000
03920000
03920000
c0920000
03920000
03920000
c0920000
03920000
c0920000
-
{e=>101,c=>1,a=>1,b=>0,d=>0}
05650000
05650000
05650000
a0650000
05650000
05650000
a0650000
05650000
a0650000
-
{e=>214,c=>0,a=>0,b=>1,d=>0}
02d60000
02d60000
02d60000
40d60000
02d60000
02d60000
40d60000
02d60000
40d60000
=
struct uint {
  char a;
  unsigned int   b:1;
};
-
{a=>75,b=>1}
4b010000
4b010000
4b010000
4b800000
4b010000
4b010000
4b800000
4b010000
4b800000
-
{a=>-108,b=>1}
94010000
94010000
94010000
94800000
94010000
94010000
94800000
94010000
94800000
-
{a=>-66,b=>0}
be000000
be000000
be000000
be000000
be000000
be000000
be000000
be000000
be000000
-
{a=>70,b=>0}
46000000
46000000
46000000
46000000
46000000
46000000
46000000
46000000
46000000
-
{a=>42,b=>0}
2a000000
2a000000
2a000000
2a000000
2a000000
2a000000
2a000000
2a000000
2a000000
=
struct uint {
  char a;
  unsigned int   b:1;
  unsigned int   c:1;
};
-
{c=>1,a=>-100,b=>1}
9c030000
9c030000
9c030000
9cc00000
9c030000
9c030000
9cc00000
9c030000
9cc00000
-
{c=>1,a=>93,b=>0}
5d020000
5d020000
5d020000
5d400000
5d020000
5d020000
5d400000
5d020000
5d400000
-
{c=>1,a=>40,b=>0}
28020000
28020000
28020000
28400000
28020000
28020000
28400000
28020000
28400000
-
{c=>1,a=>-20,b=>1}
ec030000
ec030000
ec030000
ecc00000
ec030000
ec030000
ecc00000
ec030000
ecc00000
-
{c=>1,a=>5,b=>0}
05020000
05020000
05020000
05400000
05020000
05020000
05400000
05020000
05400000
=
struct uint {
  char a;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
};
-
{c=>0,a=>-26,b=>0,d=>0}
e6000000
e6000000
e6000000
e6000000
e6000000
e6000000
e6000000
e6000000
e6000000
-
{c=>0,a=>-121,b=>0,d=>0}
87000000
87000000
87000000
87000000
87000000
87000000
87000000
87000000
87000000
-
{c=>1,a=>2,b=>0,d=>1}
02060000
02060000
02060000
02600000
02060000
02060000
02600000
02060000
02600000
-
{c=>1,a=>-54,b=>1,d=>0}
ca030000
ca030000
ca030000
cac00000
ca030000
ca030000
cac00000
ca030000
cac00000
-
{c=>1,a=>79,b=>0,d=>0}
4f020000
4f020000
4f020000
4f400000
4f020000
4f020000
4f400000
4f020000
4f400000
=
struct uint {
  char a;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
  unsigned int   e:1;
};
-
{e=>0,c=>1,a=>123,b=>0,d=>1}
7b060000
7b060000
7b060000
7b600000
7b060000
7b060000
7b600000
7b060000
7b600000
-
{e=>0,c=>0,a=>-85,b=>1,d=>0}
ab010000
ab010000
ab010000
ab800000
ab010000
ab010000
ab800000
ab010000
ab800000
-
{e=>0,c=>1,a=>108,b=>1,d=>0}
6c030000
6c030000
6c030000
6cc00000
6c030000
6c030000
6cc00000
6c030000
6cc00000
-
{e=>0,c=>0,a=>5,b=>1,d=>0}
05010000
05010000
05010000
05800000
05010000
05010000
05800000
05010000
05800000
-
{e=>1,c=>0,a=>37,b=>0,d=>0}
25080000
25080000
25080000
25100000
25080000
25080000
25100000
25080000
25100000
=
struct uint {
  char a;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
  unsigned int   e:1;
  unsigned char  f;
};
-
{e=>1,c=>1,a=>-3,b=>0,d=>0,f=>33}
fd0a2100
fd0a2100
fd0a2100
fd502100
fd0a2100
fd0a2100
fd502100
fd0a2100
fd502100
-
{e=>1,c=>0,a=>-54,b=>1,d=>1,f=>25}
ca0d1900
ca0d1900
ca0d1900
cab01900
ca0d1900
ca0d1900
cab01900
ca0d1900
cab01900
-
{e=>1,c=>1,a=>99,b=>0,d=>0,f=>1}
630a0100
630a0100
630a0100
63500100
630a0100
630a0100
63500100
630a0100
63500100
-
{e=>0,c=>0,a=>36,b=>0,d=>1,f=>171}
2404ab00
2404ab00
2404ab00
2420ab00
2404ab00
2404ab00
2420ab00
2404ab00
2420ab00
-
{e=>0,c=>0,a=>-112,b=>0,d=>1,f=>44}
90042c00
90042c00
90042c00
90202c00
90042c00
90042c00
90202c00
90042c00
90202c00
=
struct uint {
  short a;
  unsigned int   b:1;
};
-
{a=>17,b=>1}
11000100
11000100
11000100
00118000
11000100
11000100
00118000
11000100
00118000
-
{a=>-109,b=>0}
93ff0000
93ff0000
93ff0000
ff930000
93ff0000
93ff0000
ff930000
93ff0000
ff930000
-
{a=>66,b=>1}
42000100
42000100
42000100
00428000
42000100
42000100
00428000
42000100
00428000
-
{a=>15,b=>0}
0f000000
0f000000
0f000000
000f0000
0f000000
0f000000
000f0000
0f000000
000f0000
-
{a=>67,b=>1}
43000100
43000100
43000100
00438000
43000100
43000100
00438000
43000100
00438000
=
struct uint {
  short a;
  unsigned int   b:1;
  unsigned int   c:1;
};
-
{c=>1,a=>-17,b=>0}
efff0200
efff0200
efff0200
ffef4000
efff0200
efff0200
ffef4000
efff0200
ffef4000
-
{c=>0,a=>-96,b=>0}
a0ff0000
a0ff0000
a0ff0000
ffa00000
a0ff0000
a0ff0000
ffa00000
a0ff0000
ffa00000
-
{c=>0,a=>19,b=>0}
13000000
13000000
13000000
00130000
13000000
13000000
00130000
13000000
00130000
-
{c=>1,a=>-75,b=>1}
b5ff0300
b5ff0300
b5ff0300
ffb5c000
b5ff0300
b5ff0300
ffb5c000
b5ff0300
ffb5c000
-
{c=>0,a=>-26,b=>1}
e6ff0100
e6ff0100
e6ff0100
ffe68000
e6ff0100
e6ff0100
ffe68000
e6ff0100
ffe68000
=
struct uint {
  short a;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
};
-
{c=>0,a=>-128,b=>0,d=>1}
80ff0400
80ff0400
80ff0400
ff802000
80ff0400
80ff0400
ff802000
80ff0400
ff802000
-
{c=>0,a=>6,b=>0,d=>1}
06000400
06000400
06000400
00062000
06000400
06000400
00062000
06000400
00062000
-
{c=>1,a=>-76,b=>1,d=>0}
b4ff0300
b4ff0300
b4ff0300
ffb4c000
b4ff0300
b4ff0300
ffb4c000
b4ff0300
ffb4c000
-
{c=>0,a=>-60,b=>1,d=>0}
c4ff0100
c4ff0100
c4ff0100
ffc48000
c4ff0100
c4ff0100
ffc48000
c4ff0100
ffc48000
-
{c=>1,a=>-102,b=>1,d=>1}
9aff0700
9aff0700
9aff0700
ff9ae000
9aff0700
9aff0700
ff9ae000
9aff0700
ff9ae000
=
struct uint {
  short a;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
  unsigned int   e:1;
};
-
{e=>0,c=>0,a=>-11,b=>0,d=>1}
f5ff0400
f5ff0400
f5ff0400
fff52000
f5ff0400
f5ff0400
fff52000
f5ff0400
fff52000
-
{e=>1,c=>0,a=>-23,b=>1,d=>1}
e9ff0d00
e9ff0d00
e9ff0d00
ffe9b000
e9ff0d00
e9ff0d00
ffe9b000
e9ff0d00
ffe9b000
-
{e=>1,c=>1,a=>81,b=>0,d=>0}
51000a00
51000a00
51000a00
00515000
51000a00
51000a00
00515000
51000a00
00515000
-
{e=>0,c=>0,a=>16,b=>0,d=>0}
10000000
10000000
10000000
00100000
10000000
10000000
00100000
10000000
00100000
-
{e=>1,c=>1,a=>90,b=>1,d=>0}
5a000b00
5a000b00
5a000b00
005ad000
5a000b00
5a000b00
005ad000
5a000b00
005ad000
=
struct uint {
  short a;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
  unsigned int   e:1;
  unsigned char  f;
};
-
{e=>0,c=>1,a=>108,b=>0,d=>1,f=>91}
6c00065b
6c00065b
6c00065b
006c605b
6c00065b
6c00065b
006c605b
6c00065b
006c605b
-
{e=>0,c=>0,a=>113,b=>1,d=>0,f=>123}
7100017b
7100017b
7100017b
0071807b
7100017b
7100017b
0071807b
7100017b
0071807b
-
{e=>0,c=>0,a=>-118,b=>1,d=>1,f=>27}
8aff051b
8aff051b
8aff051b
ff8aa01b
8aff051b
8aff051b
ff8aa01b
8aff051b
ff8aa01b
-
{e=>0,c=>0,a=>105,b=>1,d=>1,f=>227}
690005e3
690005e3
690005e3
0069a0e3
690005e3
690005e3
0069a0e3
690005e3
0069a0e3
-
{e=>0,c=>1,a=>58,b=>0,d=>0,f=>37}
3a000225
3a000225
3a000225
003a4025
3a000225
3a000225
003a4025
3a000225
003a4025
=
struct uint {
  int a;
  unsigned int   b:1;
};
-
{a=>123,b=>0}
7b00000000000000
7b00000000000000
7b00000000000000
0000007b00000000
7b00000000000000
7b00000000000000
0000007b00000000
7b00000000000000
0000007b00000000
-
{a=>-82,b=>1}
aeffffff01000000
aeffffff01000000
aeffffff01000000
ffffffae80000000
aeffffff01000000
aeffffff01000000
ffffffae80000000
aeffffff01000000
ffffffae80000000
-
{a=>-71,b=>0}
b9ffffff00000000
b9ffffff00000000
b9ffffff00000000
ffffffb900000000
b9ffffff00000000
b9ffffff00000000
ffffffb900000000
b9ffffff00000000
ffffffb900000000
-
{a=>-16,b=>0}
f0ffffff00000000
f0ffffff00000000
f0ffffff00000000
fffffff000000000
f0ffffff00000000
f0ffffff00000000
fffffff000000000
f0ffffff00000000
fffffff000000000
-
{a=>82,b=>0}
5200000000000000
5200000000000000
5200000000000000
0000005200000000
5200000000000000
5200000000000000
0000005200000000
5200000000000000
0000005200000000
=
struct uint {
  int a;
  unsigned int   b:1;
  unsigned int   c:1;
};
-
{c=>0,a=>-82,b=>1}
aeffffff01000000
aeffffff01000000
aeffffff01000000
ffffffae80000000
aeffffff01000000
aeffffff01000000
ffffffae80000000
aeffffff01000000
ffffffae80000000
-
{c=>1,a=>76,b=>1}
4c00000003000000
4c00000003000000
4c00000003000000
0000004cc0000000
4c00000003000000
4c00000003000000
0000004cc0000000
4c00000003000000
0000004cc0000000
-
{c=>0,a=>90,b=>1}
5a00000001000000
5a00000001000000
5a00000001000000
0000005a80000000
5a00000001000000
5a00000001000000
0000005a80000000
5a00000001000000
0000005a80000000
-
{c=>0,a=>-87,b=>1}
a9ffffff01000000
a9ffffff01000000
a9ffffff01000000
ffffffa980000000
a9ffffff01000000
a9ffffff01000000
ffffffa980000000
a9ffffff01000000
ffffffa980000000
-
{c=>1,a=>-70,b=>0}
baffffff02000000
baffffff02000000
baffffff02000000
ffffffba40000000
baffffff02000000
baffffff02000000
ffffffba40000000
baffffff02000000
ffffffba40000000
=
struct uint {
  int a;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
};
-
{c=>0,a=>103,b=>1,d=>1}
6700000005000000
6700000005000000
6700000005000000
00000067a0000000
6700000005000000
6700000005000000
00000067a0000000
6700000005000000
00000067a0000000
-
{c=>0,a=>-102,b=>1,d=>0}
9affffff01000000
9affffff01000000
9affffff01000000
ffffff9a80000000
9affffff01000000
9affffff01000000
ffffff9a80000000
9affffff01000000
ffffff9a80000000
-
{c=>1,a=>8,b=>1,d=>1}
0800000007000000
0800000007000000
0800000007000000
00000008e0000000
0800000007000000
0800000007000000
00000008e0000000
0800000007000000
00000008e0000000
-
{c=>1,a=>24,b=>0,d=>1}
1800000006000000
1800000006000000
1800000006000000
0000001860000000
1800000006000000
1800000006000000
0000001860000000
1800000006000000
0000001860000000
-
{c=>0,a=>-37,b=>1,d=>1}
dbffffff05000000
dbffffff05000000
dbffffff05000000
ffffffdba0000000
dbffffff05000000
dbffffff05000000
ffffffdba0000000
dbffffff05000000
ffffffdba0000000
=
struct uint {
  int a;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
  unsigned int   e:1;
};
-
{e=>1,c=>1,a=>73,b=>0,d=>0}
490000000a000000
490000000a000000
490000000a000000
0000004950000000
490000000a000000
490000000a000000
0000004950000000
490000000a000000
0000004950000000
-
{e=>0,c=>0,a=>-47,b=>1,d=>1}
d1ffffff05000000
d1ffffff05000000
d1ffffff05000000
ffffffd1a0000000
d1ffffff05000000
d1ffffff05000000
ffffffd1a0000000
d1ffffff05000000
ffffffd1a0000000
-
{e=>1,c=>1,a=>105,b=>0,d=>1}
690000000e000000
690000000e000000
690000000e000000
0000006970000000
690000000e000000
690000000e000000
0000006970000000
690000000e000000
0000006970000000
-
{e=>1,c=>0,a=>39,b=>1,d=>1}
270000000d000000
270000000d000000
270000000d000000
00000027b0000000
270000000d000000
270000000d000000
00000027b0000000
270000000d000000
00000027b0000000
-
{e=>0,c=>1,a=>-19,b=>0,d=>0}
edffffff02000000
edffffff02000000
edffffff02000000
ffffffed40000000
edffffff02000000
edffffff02000000
ffffffed40000000
edffffff02000000
ffffffed40000000
=
struct uint {
  int a;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
  unsigned int   e:1;
  unsigned char  f;
};
-
{e=>0,c=>1,a=>-13,b=>0,d=>0,f=>179}
f3ffffff02b30000
f3ffffff02b30000
f3ffffff02b30000
fffffff340b30000
f3ffffff02b30000
f3ffffff02b30000
fffffff340b30000
f3ffffff02b30000
fffffff340b30000
-
{e=>0,c=>1,a=>-50,b=>0,d=>1,f=>86}
ceffffff06560000
ceffffff06560000
ceffffff06560000
ffffffce60560000
ceffffff06560000
ceffffff06560000
ffffffce60560000
ceffffff06560000
ffffffce60560000
-
{e=>1,c=>1,a=>127,b=>0,d=>1,f=>197}
7f0000000ec50000
7f0000000ec50000
7f0000000ec50000
0000007f70c50000
7f0000000ec50000
7f0000000ec50000
0000007f70c50000
7f0000000ec50000
0000007f70c50000
-
{e=>0,c=>1,a=>22,b=>0,d=>1,f=>205}
1600000006cd0000
1600000006cd0000
1600000006cd0000
0000001660cd0000
1600000006cd0000
1600000006cd0000
0000001660cd0000
1600000006cd0000
0000001660cd0000
-
{e=>1,c=>1,a=>-24,b=>1,d=>0,f=>208}
e8ffffff0bd00000
e8ffffff0bd00000
e8ffffff0bd00000
ffffffe8d0d00000
e8ffffff0bd00000
e8ffffff0bd00000
ffffffe8d0d00000
e8ffffff0bd00000
ffffffe8d0d00000
=
struct uint {
  long a;
  unsigned int   b:1;
};
-
{a=>125,b=>0}
7d00000000000000
7d000000000000000000000000000000
7d000000000000000000000000000000
0000007d00000000
7d00000000000000
7d00000000000000
000000000000007d0000000000000000
7d00000000000000
0000007d00000000
-
{a=>76,b=>0}
4c00000000000000
4c000000000000000000000000000000
4c000000000000000000000000000000
0000004c00000000
4c00000000000000
4c00000000000000
000000000000004c0000000000000000
4c00000000000000
0000004c00000000
-
{a=>118,b=>1}
7600000001000000
76000000000000000100000000000000
76000000000000000100000000000000
0000007680000000
7600000001000000
7600000001000000
00000000000000768000000000000000
7600000001000000
0000007680000000
-
{a=>39,b=>1}
2700000001000000
27000000000000000100000000000000
27000000000000000100000000000000
0000002780000000
2700000001000000
2700000001000000
00000000000000278000000000000000
2700000001000000
0000002780000000
-
{a=>117,b=>0}
7500000000000000
75000000000000000000000000000000
75000000000000000000000000000000
0000007500000000
7500000000000000
7500000000000000
00000000000000750000000000000000
7500000000000000
0000007500000000
=
struct uint {
  long a;
  unsigned int   b:1;
  unsigned int   c:1;
};
-
{c=>0,a=>96,b=>1}
6000000001000000
60000000000000000100000000000000
60000000000000000100000000000000
0000006080000000
6000000001000000
6000000001000000
00000000000000608000000000000000
6000000001000000
0000006080000000
-
{c=>0,a=>85,b=>0}
5500000000000000
55000000000000000000000000000000
55000000000000000000000000000000
0000005500000000
5500000000000000
5500000000000000
00000000000000550000000000000000
5500000000000000
0000005500000000
-
{c=>0,a=>-120,b=>1}
88ffffff01000000
88ffffffffffffff0100000000000000
88ffffffffffffff0100000000000000
ffffff8880000000
88ffffff01000000
88ffffff01000000
ffffffffffffff888000000000000000
88ffffff01000000
ffffff8880000000
-
{c=>1,a=>46,b=>1}
2e00000003000000
2e000000000000000300000000000000
2e000000000000000300000000000000
0000002ec0000000
2e00000003000000
2e00000003000000
000000000000002ec000000000000000
2e00000003000000
0000002ec0000000
-
{c=>1,a=>-15,b=>1}
f1ffffff03000000
f1ffffffffffffff0300000000000000
f1ffffffffffffff0300000000000000
fffffff1c0000000
f1ffffff03000000
f1ffffff03000000
fffffffffffffff1c000000000000000
f1ffffff03000000
fffffff1c0000000
=
struct uint {
  long a;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
};
-
{c=>1,a=>86,b=>0,d=>0}
5600000002000000
56000000000000000200000000000000
56000000000000000200000000000000
0000005640000000
5600000002000000
5600000002000000
00000000000000564000000000000000
5600000002000000
0000005640000000
-
{c=>0,a=>-29,b=>1,d=>1}
e3ffffff05000000
e3ffffffffffffff0500000000000000
e3ffffffffffffff0500000000000000
ffffffe3a0000000
e3ffffff05000000
e3ffffff05000000
ffffffffffffffe3a000000000000000
e3ffffff05000000
ffffffe3a0000000
-
{c=>0,a=>97,b=>1,d=>0}
6100000001000000
61000000000000000100000000000000
61000000000000000100000000000000
0000006180000000
6100000001000000
6100000001000000
00000000000000618000000000000000
6100000001000000
0000006180000000
-
{c=>1,a=>92,b=>1,d=>0}
5c00000003000000
5c000000000000000300000000000000
5c000000000000000300000000000000
0000005cc0000000
5c00000003000000
5c00000003000000
000000000000005cc000000000000000
5c00000003000000
0000005cc0000000
-
{c=>1,a=>-52,b=>0,d=>1}
ccffffff06000000
ccffffffffffffff0600000000000000
ccffffffffffffff0600000000000000
ffffffcc60000000
ccffffff06000000
ccffffff06000000
ffffffffffffffcc6000000000000000
ccffffff06000000
ffffffcc60000000
=
struct uint {
  long a;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
  unsigned int   e:1;
};
-
{e=>1,c=>1,a=>46,b=>1,d=>0}
2e0000000b000000
2e000000000000000b00000000000000
2e000000000000000b00000000000000
0000002ed0000000
2e0000000b000000
2e0000000b000000
000000000000002ed000000000000000
2e0000000b000000
0000002ed0000000
-
{e=>0,c=>1,a=>6,b=>0,d=>1}
0600000006000000
06000000000000000600000000000000
06000000000000000600000000000000
0000000660000000
0600000006000000
0600000006000000
00000000000000066000000000000000
0600000006000000
0000000660000000
-
{e=>0,c=>1,a=>-88,b=>1,d=>0}
a8ffffff03000000
a8ffffffffffffff0300000000000000
a8ffffffffffffff0300000000000000
ffffffa8c0000000
a8ffffff03000000
a8ffffff03000000
ffffffffffffffa8c000000000000000
a8ffffff03000000
ffffffa8c0000000
-
{e=>1,c=>1,a=>61,b=>0,d=>0}
3d0000000a000000
3d000000000000000a00000000000000
3d000000000000000a00000000000000
0000003d50000000
3d0000000a000000
3d0000000a000000
000000000000003d5000000000000000
3d0000000a000000
0000003d50000000
-
{e=>1,c=>1,a=>-91,b=>0,d=>1}
a5ffffff0e000000
a5ffffffffffffff0e00000000000000
a5ffffffffffffff0e00000000000000
ffffffa570000000
a5ffffff0e000000
a5ffffff0e000000
ffffffffffffffa57000000000000000
a5ffffff0e000000
ffffffa570000000
=
struct uint {
  long a;
  unsigned int   b:1;
  unsigned int   c:1;
  unsigned int   d:1;
  unsigned int   e:1;
  unsigned char  f;
};
-
{e=>1,c=>0,a=>0,b=>0,d=>0,f=>3}
0000000008030000
00000000000000000803000000000000
00000000000000000803000000000000
0000000010030000
0000000008030000
0000000008030000
00000000000000001003000000000000
0000000008030000
0000000010030000
-
{e=>1,c=>0,a=>-78,b=>1,d=>0,f=>176}
b2ffffff09b00000
b2ffffffffffffff09b0000000000000
b2ffffffffffffff09b0000000000000
ffffffb290b00000
b2ffffff09b00000
b2ffffff09b00000
ffffffffffffffb290b0000000000000
b2ffffff09b00000
ffffffb290b00000
-
{e=>0,c=>1,a=>-121,b=>1,d=>1,f=>153}
87ffffff07990000
87ffffffffffffff0799000000000000
87ffffffffffffff0799000000000000
ffffff87e0990000
87ffffff07990000
87ffffff07990000
ffffffffffffff87e099000000000000
87ffffff07990000
ffffff87e0990000
-
{e=>0,c=>1,a=>-50,b=>1,d=>0,f=>143}
ceffffff038f0000
ceffffffffffffff038f000000000000
ceffffffffffffff038f000000000000
ffffffcec08f0000
ceffffff038f0000
ceffffff038f0000
ffffffffffffffcec08f000000000000
ceffffff038f0000
ffffffcec08f0000
-
{e=>0,c=>1,a=>-106,b=>0,d=>0,f=>229}
96ffffff02e50000
96ffffffffffffff02e5000000000000
96ffffffffffffff02e5000000000000
ffffff9640e50000
96ffffff02e50000
96ffffff02e50000
ffffffffffffff9640e5000000000000
96ffffff02e50000
ffffff9640e50000
=
struct ulong {
  unsigned long  a:1;
};
-
{a=>0}
00000000
0000000000000000
0000000000000000
00000000
00000000
00000000
0000000000000000
00000000
00000000
-
{a=>0}
00000000
0000000000000000
0000000000000000
00000000
00000000
00000000
0000000000000000
00000000
00000000
-
{a=>0}
00000000
0000000000000000
0000000000000000
00000000
00000000
00000000
0000000000000000
00000000
00000000
-
{a=>1}
01000000
0100000000000000
0100000000000000
80000000
01000000
01000000
8000000000000000
01000000
80000000
-
{a=>0}
00000000
0000000000000000
0000000000000000
00000000
00000000
00000000
0000000000000000
00000000
00000000
=
struct ulong {
  unsigned long  a:1;
  unsigned long  b:1;
};
-
{a=>0,b=>0}
00000000
0000000000000000
0000000000000000
00000000
00000000
00000000
0000000000000000
00000000
00000000
-
{a=>1,b=>1}
03000000
0300000000000000
0300000000000000
c0000000
03000000
03000000
c000000000000000
03000000
c0000000
-
{a=>1,b=>0}
01000000
0100000000000000
0100000000000000
80000000
01000000
01000000
8000000000000000
01000000
80000000
-
{a=>1,b=>1}
03000000
0300000000000000
0300000000000000
c0000000
03000000
03000000
c000000000000000
03000000
c0000000
-
{a=>0,b=>1}
02000000
0200000000000000
0200000000000000
40000000
02000000
02000000
4000000000000000
02000000
40000000
=
struct ulong {
  unsigned long  a:1;
  unsigned long  b:1;
  unsigned long  c:1;
};
-
{c=>0,a=>0,b=>0}
00000000
0000000000000000
0000000000000000
00000000
00000000
00000000
0000000000000000
00000000
00000000
-
{c=>0,a=>1,b=>1}
03000000
0300000000000000
0300000000000000
c0000000
03000000
03000000
c000000000000000
03000000
c0000000
-
{c=>0,a=>0,b=>1}
02000000
0200000000000000
0200000000000000
40000000
02000000
02000000
4000000000000000
02000000
40000000
-
{c=>1,a=>0,b=>1}
06000000
0600000000000000
0600000000000000
60000000
06000000
06000000
6000000000000000
06000000
60000000
-
{c=>1,a=>0,b=>0}
04000000
0400000000000000
0400000000000000
20000000
04000000
04000000
2000000000000000
04000000
20000000
=
struct ulong {
  unsigned long  a:1;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
};
-
{c=>1,a=>1,b=>1,d=>0}
07000000
0700000000000000
0700000000000000
e0000000
07000000
07000000
e000000000000000
07000000
e0000000
-
{c=>1,a=>0,b=>0,d=>0}
04000000
0400000000000000
0400000000000000
20000000
04000000
04000000
2000000000000000
04000000
20000000
-
{c=>0,a=>1,b=>1,d=>1}
0b000000
0b00000000000000
0b00000000000000
d0000000
0b000000
0b000000
d000000000000000
0b000000
d0000000
-
{c=>0,a=>1,b=>0,d=>0}
01000000
0100000000000000
0100000000000000
80000000
01000000
01000000
8000000000000000
01000000
80000000
-
{c=>1,a=>0,b=>1,d=>0}
06000000
0600000000000000
0600000000000000
60000000
06000000
06000000
6000000000000000
06000000
60000000
=
struct ulong {
  unsigned long  a:1;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
  unsigned char  e;
};
-
{e=>171,c=>0,a=>1,b=>0,d=>0}
01ab0000
01ab000000000000
01ab000000000000
80ab0000
01ab0000
01ab0000
80ab000000000000
01ab0000
80ab0000
-
{e=>112,c=>0,a=>0,b=>0,d=>0}
00700000
0070000000000000
0070000000000000
00700000
00700000
00700000
0070000000000000
00700000
00700000
-
{e=>62,c=>0,a=>0,b=>0,d=>1}
083e0000
083e000000000000
083e000000000000
103e0000
083e0000
083e0000
103e000000000000
083e0000
103e0000
-
{e=>210,c=>0,a=>0,b=>1,d=>1}
0ad20000
0ad2000000000000
0ad2000000000000
50d20000
0ad20000
0ad20000
50d2000000000000
0ad20000
50d20000
-
{e=>159,c=>1,a=>0,b=>1,d=>1}
0e9f0000
0e9f000000000000
0e9f000000000000
709f0000
0e9f0000
0e9f0000
709f000000000000
0e9f0000
709f0000
=
struct ulong {
  char a;
  unsigned long  b:1;
};
-
{a=>-121,b=>1}
87010000
8701000000000000
8701000000000000
87800000
87010000
87010000
8780000000000000
87010000
87800000
-
{a=>50,b=>1}
32010000
3201000000000000
3201000000000000
32800000
32010000
32010000
3280000000000000
32010000
32800000
-
{a=>-89,b=>1}
a7010000
a701000000000000
a701000000000000
a7800000
a7010000
a7010000
a780000000000000
a7010000
a7800000
-
{a=>92,b=>0}
5c000000
5c00000000000000
5c00000000000000
5c000000
5c000000
5c000000
5c00000000000000
5c000000
5c000000
-
{a=>-41,b=>0}
d7000000
d700000000000000
d700000000000000
d7000000
d7000000
d7000000
d700000000000000
d7000000
d7000000
=
struct ulong {
  char a;
  unsigned long  b:1;
  unsigned long  c:1;
};
-
{c=>1,a=>-46,b=>1}
d2030000
d203000000000000
d203000000000000
d2c00000
d2030000
d2030000
d2c0000000000000
d2030000
d2c00000
-
{c=>0,a=>-85,b=>0}
ab000000
ab00000000000000
ab00000000000000
ab000000
ab000000
ab000000
ab00000000000000
ab000000
ab000000
-
{c=>0,a=>78,b=>0}
4e000000
4e00000000000000
4e00000000000000
4e000000
4e000000
4e000000
4e00000000000000
4e000000
4e000000
-
{c=>0,a=>-50,b=>0}
ce000000
ce00000000000000
ce00000000000000
ce000000
ce000000
ce000000
ce00000000000000
ce000000
ce000000
-
{c=>1,a=>-57,b=>1}
c7030000
c703000000000000
c703000000000000
c7c00000
c7030000
c7030000
c7c0000000000000
c7030000
c7c00000
=
struct ulong {
  char a;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
};
-
{c=>0,a=>-7,b=>0,d=>1}
f9040000
f904000000000000
f904000000000000
f9200000
f9040000
f9040000
f920000000000000
f9040000
f9200000
-
{c=>0,a=>69,b=>0,d=>0}
45000000
4500000000000000
4500000000000000
45000000
45000000
45000000
4500000000000000
45000000
45000000
-
{c=>1,a=>78,b=>1,d=>1}
4e070000
4e07000000000000
4e07000000000000
4ee00000
4e070000
4e070000
4ee0000000000000
4e070000
4ee00000
-
{c=>1,a=>19,b=>0,d=>0}
13020000
1302000000000000
1302000000000000
13400000
13020000
13020000
1340000000000000
13020000
13400000
-
{c=>1,a=>-18,b=>1,d=>0}
ee030000
ee03000000000000
ee03000000000000
eec00000
ee030000
ee030000
eec0000000000000
ee030000
eec00000
=
struct ulong {
  char a;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
  unsigned long  e:1;
};
-
{e=>1,c=>0,a=>-82,b=>1,d=>1}
ae0d0000
ae0d000000000000
ae0d000000000000
aeb00000
ae0d0000
ae0d0000
aeb0000000000000
ae0d0000
aeb00000
-
{e=>1,c=>1,a=>125,b=>0,d=>1}
7d0e0000
7d0e000000000000
7d0e000000000000
7d700000
7d0e0000
7d0e0000
7d70000000000000
7d0e0000
7d700000
-
{e=>1,c=>1,a=>-119,b=>0,d=>1}
890e0000
890e000000000000
890e000000000000
89700000
890e0000
890e0000
8970000000000000
890e0000
89700000
-
{e=>1,c=>1,a=>39,b=>0,d=>1}
270e0000
270e000000000000
270e000000000000
27700000
270e0000
270e0000
2770000000000000
270e0000
27700000
-
{e=>0,c=>1,a=>14,b=>0,d=>0}
0e020000
0e02000000000000
0e02000000000000
0e400000
0e020000
0e020000
0e40000000000000
0e020000
0e400000
=
struct ulong {
  char a;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
  unsigned long  e:1;
  unsigned char  f;
};
-
{e=>1,c=>0,a=>-3,b=>1,d=>0,f=>197}
fd09c500
fd09c50000000000
fd09c50000000000
fd90c500
fd09c500
fd09c500
fd90c50000000000
fd09c500
fd90c500
-
{e=>0,c=>1,a=>87,b=>0,d=>0,f=>225}
5702e100
5702e10000000000
5702e10000000000
5740e100
5702e100
5702e100
5740e10000000000
5702e100
5740e100
-
{e=>0,c=>1,a=>-120,b=>1,d=>1,f=>123}
88077b00
88077b0000000000
88077b0000000000
88e07b00
88077b00
88077b00
88e07b0000000000
88077b00
88e07b00
-
{e=>1,c=>0,a=>-101,b=>0,d=>0,f=>120}
9b087800
9b08780000000000
9b08780000000000
9b107800
9b087800
9b087800
9b10780000000000
9b087800
9b107800
-
{e=>1,c=>1,a=>13,b=>0,d=>1,f=>245}
0d0ef500
0d0ef50000000000
0d0ef50000000000
0d70f500
0d0ef500
0d0ef500
0d70f50000000000
0d0ef500
0d70f500
=
struct ulong {
  short a;
  unsigned long  b:1;
};
-
{a=>-34,b=>1}
deff0100
deff010000000000
deff010000000000
ffde8000
deff0100
deff0100
ffde800000000000
deff0100
ffde8000
-
{a=>-97,b=>1}
9fff0100
9fff010000000000
9fff010000000000
ff9f8000
9fff0100
9fff0100
ff9f800000000000
9fff0100
ff9f8000
-
{a=>125,b=>0}
7d000000
7d00000000000000
7d00000000000000
007d0000
7d000000
7d000000
007d000000000000
7d000000
007d0000
-
{a=>-4,b=>1}
fcff0100
fcff010000000000
fcff010000000000
fffc8000
fcff0100
fcff0100
fffc800000000000
fcff0100
fffc8000
-
{a=>-46,b=>0}
d2ff0000
d2ff000000000000
d2ff000000000000
ffd20000
d2ff0000
d2ff0000
ffd2000000000000
d2ff0000
ffd20000
=
struct ulong {
  short a;
  unsigned long  b:1;
  unsigned long  c:1;
};
-
{c=>0,a=>54,b=>1}
36000100
3600010000000000
3600010000000000
00368000
36000100
36000100
0036800000000000
36000100
00368000
-
{c=>1,a=>25,b=>1}
19000300
1900030000000000
1900030000000000
0019c000
19000300
19000300
0019c00000000000
19000300
0019c000
-
{c=>1,a=>-112,b=>1}
90ff0300
90ff030000000000
90ff030000000000
ff90c000
90ff0300
90ff0300
ff90c00000000000
90ff0300
ff90c000
-
{c=>0,a=>53,b=>1}
35000100
3500010000000000
3500010000000000
00358000
35000100
35000100
0035800000000000
35000100
00358000
-
{c=>0,a=>-72,b=>0}
b8ff0000
b8ff000000000000
b8ff000000000000
ffb80000
b8ff0000
b8ff0000
ffb8000000000000
b8ff0000
ffb80000
=
struct ulong {
  short a;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
};
-
{c=>0,a=>-37,b=>0,d=>1}
dbff0400
dbff040000000000
dbff040000000000
ffdb2000
dbff0400
dbff0400
ffdb200000000000
dbff0400
ffdb2000
-
{c=>1,a=>59,b=>0,d=>1}
3b000600
3b00060000000000
3b00060000000000
003b6000
3b000600
3b000600
003b600000000000
3b000600
003b6000
-
{c=>1,a=>-10,b=>1,d=>1}
f6ff0700
f6ff070000000000
f6ff070000000000
fff6e000
f6ff0700
f6ff0700
fff6e00000000000
f6ff0700
fff6e000
-
{c=>0,a=>-39,b=>1,d=>0}
d9ff0100
d9ff010000000000
d9ff010000000000
ffd98000
d9ff0100
d9ff0100
ffd9800000000000
d9ff0100
ffd98000
-
{c=>0,a=>26,b=>0,d=>1}
1a000400
1a00040000000000
1a00040000000000
001a2000
1a000400
1a000400
001a200000000000
1a000400
001a2000
=
struct ulong {
  short a;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
  unsigned long  e:1;
};
-
{e=>1,c=>1,a=>77,b=>1,d=>0}
4d000b00
4d000b0000000000
4d000b0000000000
004dd000
4d000b00
4d000b00
004dd00000000000
4d000b00
004dd000
-
{e=>0,c=>0,a=>71,b=>1,d=>1}
47000500
4700050000000000
4700050000000000
0047a000
47000500
47000500
0047a00000000000
47000500
0047a000
-
{e=>1,c=>0,a=>12,b=>1,d=>0}
0c000900
0c00090000000000
0c00090000000000
000c9000
0c000900
0c000900
000c900000000000
0c000900
000c9000
-
{e=>1,c=>1,a=>-120,b=>1,d=>1}
88ff0f00
88ff0f0000000000
88ff0f0000000000
ff88f000
88ff0f00
88ff0f00
ff88f00000000000
88ff0f00
ff88f000
-
{e=>0,c=>0,a=>-106,b=>0,d=>1}
96ff0400
96ff040000000000
96ff040000000000
ff962000
96ff0400
96ff0400
ff96200000000000
96ff0400
ff962000
=
struct ulong {
  short a;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
  unsigned long  e:1;
  unsigned char  f;
};
-
{e=>1,c=>1,a=>93,b=>1,d=>0,f=>203}
5d000bcb
5d000bcb00000000
5d000bcb00000000
005dd0cb
5d000bcb
5d000bcb
005dd0cb00000000
5d000bcb
005dd0cb
-
{e=>1,c=>1,a=>-61,b=>1,d=>0,f=>222}
c3ff0bde
c3ff0bde00000000
c3ff0bde00000000
ffc3d0de
c3ff0bde
c3ff0bde
ffc3d0de00000000
c3ff0bde
ffc3d0de
-
{e=>0,c=>1,a=>-4,b=>0,d=>0,f=>177}
fcff02b1
fcff02b100000000
fcff02b100000000
fffc40b1
fcff02b1
fcff02b1
fffc40b100000000
fcff02b1
fffc40b1
-
{e=>0,c=>1,a=>-34,b=>1,d=>1,f=>92}
deff075c
deff075c00000000
deff075c00000000
ffdee05c
deff075c
deff075c
ffdee05c00000000
deff075c
ffdee05c
-
{e=>0,c=>1,a=>6,b=>0,d=>1,f=>117}
06000675
0600067500000000
0600067500000000
00066075
06000675
06000675
0006607500000000
06000675
00066075
=
struct ulong {
  int a;
  unsigned long  b:1;
};
-
{a=>20,b=>1}
1400000001000000
1400000001000000
1400000001000000
0000001480000000
1400000001000000
1400000001000000
0000001480000000
1400000001000000
0000001480000000
-
{a=>-70,b=>1}
baffffff01000000
baffffff01000000
baffffff01000000
ffffffba80000000
baffffff01000000
baffffff01000000
ffffffba80000000
baffffff01000000
ffffffba80000000
-
{a=>-124,b=>0}
84ffffff00000000
84ffffff00000000
84ffffff00000000
ffffff8400000000
84ffffff00000000
84ffffff00000000
ffffff8400000000
84ffffff00000000
ffffff8400000000
-
{a=>-106,b=>0}
96ffffff00000000
96ffffff00000000
96ffffff00000000
ffffff9600000000
96ffffff00000000
96ffffff00000000
ffffff9600000000
96ffffff00000000
ffffff9600000000
-
{a=>25,b=>1}
1900000001000000
1900000001000000
1900000001000000
0000001980000000
1900000001000000
1900000001000000
0000001980000000
1900000001000000
0000001980000000
=
struct ulong {
  int a;
  unsigned long  b:1;
  unsigned long  c:1;
};
-
{c=>1,a=>42,b=>0}
2a00000002000000
2a00000002000000
2a00000002000000
0000002a40000000
2a00000002000000
2a00000002000000
0000002a40000000
2a00000002000000
0000002a40000000
-
{c=>1,a=>-120,b=>1}
88ffffff03000000
88ffffff03000000
88ffffff03000000
ffffff88c0000000
88ffffff03000000
88ffffff03000000
ffffff88c0000000
88ffffff03000000
ffffff88c0000000
-
{c=>1,a=>-122,b=>1}
86ffffff03000000
86ffffff03000000
86ffffff03000000
ffffff86c0000000
86ffffff03000000
86ffffff03000000
ffffff86c0000000
86ffffff03000000
ffffff86c0000000
-
{c=>0,a=>-34,b=>0}
deffffff00000000
deffffff00000000
deffffff00000000
ffffffde00000000
deffffff00000000
deffffff00000000
ffffffde00000000
deffffff00000000
ffffffde00000000
-
{c=>0,a=>-40,b=>0}
d8ffffff00000000
d8ffffff00000000
d8ffffff00000000
ffffffd800000000
d8ffffff00000000
d8ffffff00000000
ffffffd800000000
d8ffffff00000000
ffffffd800000000
=
struct ulong {
  int a;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
};
-
{c=>0,a=>44,b=>1,d=>0}
2c00000001000000
2c00000001000000
2c00000001000000
0000002c80000000
2c00000001000000
2c00000001000000
0000002c80000000
2c00000001000000
0000002c80000000
-
{c=>1,a=>119,b=>1,d=>0}
7700000003000000
7700000003000000
7700000003000000
00000077c0000000
7700000003000000
7700000003000000
00000077c0000000
7700000003000000
00000077c0000000
-
{c=>1,a=>30,b=>1,d=>0}
1e00000003000000
1e00000003000000
1e00000003000000
0000001ec0000000
1e00000003000000
1e00000003000000
0000001ec0000000
1e00000003000000
0000001ec0000000
-
{c=>0,a=>-76,b=>0,d=>0}
b4ffffff00000000
b4ffffff00000000
b4ffffff00000000
ffffffb400000000
b4ffffff00000000
b4ffffff00000000
ffffffb400000000
b4ffffff00000000
ffffffb400000000
-
{c=>1,a=>71,b=>0,d=>1}
4700000006000000
4700000006000000
4700000006000000
0000004760000000
4700000006000000
4700000006000000
0000004760000000
4700000006000000
0000004760000000
=
struct ulong {
  int a;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
  unsigned long  e:1;
};
-
{e=>0,c=>0,a=>-96,b=>1,d=>0}
a0ffffff01000000
a0ffffff01000000
a0ffffff01000000
ffffffa080000000
a0ffffff01000000
a0ffffff01000000
ffffffa080000000
a0ffffff01000000
ffffffa080000000
-
{e=>0,c=>0,a=>112,b=>1,d=>0}
7000000001000000
7000000001000000
7000000001000000
0000007080000000
7000000001000000
7000000001000000
0000007080000000
7000000001000000
0000007080000000
-
{e=>1,c=>0,a=>-48,b=>1,d=>0}
d0ffffff09000000
d0ffffff09000000
d0ffffff09000000
ffffffd090000000
d0ffffff09000000
d0ffffff09000000
ffffffd090000000
d0ffffff09000000
ffffffd090000000
-
{e=>0,c=>0,a=>101,b=>0,d=>0}
6500000000000000
6500000000000000
6500000000000000
0000006500000000
6500000000000000
6500000000000000
0000006500000000
6500000000000000
0000006500000000
-
{e=>0,c=>0,a=>113,b=>1,d=>1}
7100000005000000
7100000005000000
7100000005000000
00000071a0000000
7100000005000000
7100000005000000
00000071a0000000
7100000005000000
00000071a0000000
=
struct ulong {
  int a;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
  unsigned long  e:1;
  unsigned char  f;
};
-
{e=>1,c=>1,a=>53,b=>0,d=>1,f=>237}
350000000eed0000
350000000eed0000
350000000eed0000
0000003570ed0000
350000000eed0000
350000000eed0000
0000003570ed0000
350000000eed0000
0000003570ed0000
-
{e=>1,c=>0,a=>-64,b=>1,d=>0,f=>197}
c0ffffff09c50000
c0ffffff09c50000
c0ffffff09c50000
ffffffc090c50000
c0ffffff09c50000
c0ffffff09c50000
ffffffc090c50000
c0ffffff09c50000
ffffffc090c50000
-
{e=>0,c=>1,a=>-88,b=>1,d=>0,f=>178}
a8ffffff03b20000
a8ffffff03b20000
a8ffffff03b20000
ffffffa8c0b20000
a8ffffff03b20000
a8ffffff03b20000
ffffffa8c0b20000
a8ffffff03b20000
ffffffa8c0b20000
-
{e=>1,c=>1,a=>-104,b=>0,d=>1,f=>185}
98ffffff0eb90000
98ffffff0eb90000
98ffffff0eb90000
ffffff9870b90000
98ffffff0eb90000
98ffffff0eb90000
ffffff9870b90000
98ffffff0eb90000
ffffff9870b90000
-
{e=>1,c=>1,a=>121,b=>0,d=>1,f=>176}
790000000eb00000
790000000eb00000
790000000eb00000
0000007970b00000
790000000eb00000
790000000eb00000
0000007970b00000
790000000eb00000
0000007970b00000
=
struct ulong {
  long a;
  unsigned long  b:1;
};
-
{a=>123,b=>0}
7b00000000000000
7b000000000000000000000000000000
7b000000000000000000000000000000
0000007b00000000
7b00000000000000
7b00000000000000
000000000000007b0000000000000000
7b00000000000000
0000007b00000000
-
{a=>-51,b=>1}
cdffffff01000000
cdffffffffffffff0100000000000000
cdffffffffffffff0100000000000000
ffffffcd80000000
cdffffff01000000
cdffffff01000000
ffffffffffffffcd8000000000000000
cdffffff01000000
ffffffcd80000000
-
{a=>123,b=>0}
7b00000000000000
7b000000000000000000000000000000
7b000000000000000000000000000000
0000007b00000000
7b00000000000000
7b00000000000000
000000000000007b0000000000000000
7b00000000000000
0000007b00000000
-
{a=>-16,b=>1}
f0ffffff01000000
f0ffffffffffffff0100000000000000
f0ffffffffffffff0100000000000000
fffffff080000000
f0ffffff01000000
f0ffffff01000000
fffffffffffffff08000000000000000
f0ffffff01000000
fffffff080000000
-
{a=>-33,b=>1}
dfffffff01000000
dfffffffffffffff0100000000000000
dfffffffffffffff0100000000000000
ffffffdf80000000
dfffffff01000000
dfffffff01000000
ffffffffffffffdf8000000000000000
dfffffff01000000
ffffffdf80000000
=
struct ulong {
  long a;
  unsigned long  b:1;
  unsigned long  c:1;
};
-
{c=>1,a=>65,b=>1}
4100000003000000
41000000000000000300000000000000
41000000000000000300000000000000
00000041c0000000
4100000003000000
4100000003000000
0000000000000041c000000000000000
4100000003000000
00000041c0000000
-
{c=>1,a=>108,b=>0}
6c00000002000000
6c000000000000000200000000000000
6c000000000000000200000000000000
0000006c40000000
6c00000002000000
6c00000002000000
000000000000006c4000000000000000
6c00000002000000
0000006c40000000
-
{c=>1,a=>-3,b=>1}
fdffffff03000000
fdffffffffffffff0300000000000000
fdffffffffffffff0300000000000000
fffffffdc0000000
fdffffff03000000
fdffffff03000000
fffffffffffffffdc000000000000000
fdffffff03000000
fffffffdc0000000
-
{c=>0,a=>48,b=>1}
3000000001000000
30000000000000000100000000000000
30000000000000000100000000000000
0000003080000000
3000000001000000
3000000001000000
00000000000000308000000000000000
3000000001000000
0000003080000000
-
{c=>0,a=>39,b=>0}
2700000000000000
27000000000000000000000000000000
27000000000000000000000000000000
0000002700000000
2700000000000000
2700000000000000
00000000000000270000000000000000
2700000000000000
0000002700000000
=
struct ulong {
  long a;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
};
-
{c=>0,a=>-118,b=>0,d=>1}
8affffff04000000
8affffffffffffff0400000000000000
8affffffffffffff0400000000000000
ffffff8a20000000
8affffff04000000
8affffff04000000
ffffffffffffff8a2000000000000000
8affffff04000000
ffffff8a20000000
-
{c=>1,a=>-68,b=>1,d=>1}
bcffffff07000000
bcffffffffffffff0700000000000000
bcffffffffffffff0700000000000000
ffffffbce0000000
bcffffff07000000
bcffffff07000000
ffffffffffffffbce000000000000000
bcffffff07000000
ffffffbce0000000
-
{c=>0,a=>-88,b=>1,d=>1}
a8ffffff05000000
a8ffffffffffffff0500000000000000
a8ffffffffffffff0500000000000000
ffffffa8a0000000
a8ffffff05000000
a8ffffff05000000
ffffffffffffffa8a000000000000000
a8ffffff05000000
ffffffa8a0000000
-
{c=>0,a=>-79,b=>0,d=>1}
b1ffffff04000000
b1ffffffffffffff0400000000000000
b1ffffffffffffff0400000000000000
ffffffb120000000
b1ffffff04000000
b1ffffff04000000
ffffffffffffffb12000000000000000
b1ffffff04000000
ffffffb120000000
-
{c=>1,a=>-62,b=>0,d=>0}
c2ffffff02000000
c2ffffffffffffff0200000000000000
c2ffffffffffffff0200000000000000
ffffffc240000000
c2ffffff02000000
c2ffffff02000000
ffffffffffffffc24000000000000000
c2ffffff02000000
ffffffc240000000
=
struct ulong {
  long a;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
  unsigned long  e:1;
};
-
{e=>1,c=>1,a=>-102,b=>1,d=>0}
9affffff0b000000
9affffffffffffff0b00000000000000
9affffffffffffff0b00000000000000
ffffff9ad0000000
9affffff0b000000
9affffff0b000000
ffffffffffffff9ad000000000000000
9affffff0b000000
ffffff9ad0000000
-
{e=>1,c=>0,a=>-99,b=>1,d=>0}
9dffffff09000000
9dffffffffffffff0900000000000000
9dffffffffffffff0900000000000000
ffffff9d90000000
9dffffff09000000
9dffffff09000000
ffffffffffffff9d9000000000000000
9dffffff09000000
ffffff9d90000000
-
{e=>0,c=>0,a=>3,b=>0,d=>0}
0300000000000000
03000000000000000000000000000000
03000000000000000000000000000000
0000000300000000
0300000000000000
0300000000000000
00000000000000030000000000000000
0300000000000000
0000000300000000
-
{e=>1,c=>0,a=>6,b=>1,d=>0}
0600000009000000
06000000000000000900000000000000
06000000000000000900000000000000
0000000690000000
0600000009000000
0600000009000000
00000000000000069000000000000000
0600000009000000
0000000690000000
-
{e=>0,c=>1,a=>105,b=>0,d=>0}
6900000002000000
69000000000000000200000000000000
69000000000000000200000000000000
0000006940000000
6900000002000000
6900000002000000
00000000000000694000000000000000
6900000002000000
0000006940000000
=
struct ulong {
  long a;
  unsigned long  b:1;
  unsigned long  c:1;
  unsigned long  d:1;
  unsigned long  e:1;
  unsigned char  f;
};
-
{e=>1,c=>0,a=>73,b=>1,d=>1,f=>147}
490000000d930000
49000000000000000d93000000000000
49000000000000000d93000000000000
00000049b0930000
490000000d930000
490000000d930000
0000000000000049b093000000000000
490000000d930000
00000049b0930000
-
{e=>0,c=>1,a=>9,b=>0,d=>0,f=>160}
0900000002a00000
090000000000000002a0000000000000
090000000000000002a0000000000000
0000000940a00000
0900000002a00000
0900000002a00000
000000000000000940a0000000000000
0900000002a00000
0000000940a00000
-
{e=>0,c=>1,a=>78,b=>1,d=>1,f=>51}
4e00000007330000
4e000000000000000733000000000000
4e000000000000000733000000000000
0000004ee0330000
4e00000007330000
4e00000007330000
000000000000004ee033000000000000
4e00000007330000
0000004ee0330000
-
{e=>1,c=>0,a=>96,b=>1,d=>1,f=>245}
600000000df50000
60000000000000000df5000000000000
60000000000000000df5000000000000
00000060b0f50000
600000000df50000
600000000df50000
0000000000000060b0f5000000000000
600000000df50000
00000060b0f50000
-
{e=>0,c=>0,a=>101,b=>1,d=>1,f=>35}
6500000005230000
65000000000000000523000000000000
65000000000000000523000000000000
00000065a0230000
6500000005230000
6500000005230000
0000000000000065a023000000000000
6500000005230000
00000065a0230000
=
struct umixed {
  unsigned char  a:1;
};
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>1}
01
01
01
80
01000000
01
80
01
80
-
{a=>1}
01
01
01
80
01000000
01
80
01
80
=
struct umixed {
  unsigned char  a:1;
  unsigned short b:1;
};
-
{a=>0,b=>0}
0000
0000
0000
0000
00000000
0000
0000
0000
0000
-
{a=>0,b=>1}
0200
0200
0200
4000
02000000
0200
4000
0200
4000
-
{a=>0,b=>0}
0000
0000
0000
0000
00000000
0000
0000
0000
0000
-
{a=>0,b=>1}
0200
0200
0200
4000
02000000
0200
4000
0200
4000
-
{a=>1,b=>0}
0100
0100
0100
8000
01000000
0100
8000
0100
8000
=
struct umixed {
  unsigned char  a:1;
  unsigned short b:1;
  unsigned int   c:1;
};
-
{c=>0,a=>1,b=>1}
03000000
03000000
03000000
c0000000
03000000
03000000
c0000000
03000000
c0000000
-
{c=>1,a=>0,b=>0}
04000000
04000000
04000000
20000000
04000000
04000000
20000000
04000000
20000000
-
{c=>1,a=>0,b=>1}
06000000
06000000
06000000
60000000
06000000
06000000
60000000
06000000
60000000
-
{c=>0,a=>1,b=>1}
03000000
03000000
03000000
c0000000
03000000
03000000
c0000000
03000000
c0000000
-
{c=>0,a=>0,b=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
=
struct umixed {
  unsigned char  a:1;
  unsigned short b:1;
  unsigned int   c:1;
  unsigned long  d:1;
};
-
{c=>1,a=>1,b=>0,d=>1}
0d000000
0d00000000000000
0d00000000000000
b0000000
0d000000
0d000000
b000000000000000
0d000000
b0000000
-
{c=>0,a=>0,b=>0,d=>1}
08000000
0800000000000000
0800000000000000
10000000
08000000
08000000
1000000000000000
08000000
10000000
-
{c=>1,a=>1,b=>0,d=>1}
0d000000
0d00000000000000
0d00000000000000
b0000000
0d000000
0d000000
b000000000000000
0d000000
b0000000
-
{c=>0,a=>0,b=>1,d=>0}
02000000
0200000000000000
0200000000000000
40000000
02000000
02000000
4000000000000000
02000000
40000000
-
{c=>0,a=>0,b=>1,d=>1}
0a000000
0a00000000000000
0a00000000000000
50000000
0a000000
0a000000
5000000000000000
0a000000
50000000
=
struct umixed {
  unsigned char  a:1;
  unsigned short b:1;
  unsigned int   c:1;
  unsigned long  d:1;
  unsigned char  e;
};
-
{e=>216,c=>0,a=>1,b=>0,d=>1}
09d80000
09d8000000000000
09d8000000000000
90d80000
09d80000
09d80000
90d8000000000000
09d80000
90d80000
-
{e=>111,c=>0,a=>0,b=>1,d=>0}
026f0000
026f000000000000
026f000000000000
406f0000
026f0000
026f0000
406f000000000000
026f0000
406f0000
-
{e=>156,c=>1,a=>0,b=>0,d=>0}
049c0000
049c000000000000
049c000000000000
209c0000
049c0000
049c0000
209c000000000000
049c0000
209c0000
-
{e=>93,c=>0,a=>0,b=>1,d=>0}
025d0000
025d000000000000
025d000000000000
405d0000
025d0000
025d0000
405d000000000000
025d0000
405d0000
-
{e=>187,c=>0,a=>0,b=>1,d=>0}
02bb0000
02bb000000000000
02bb000000000000
40bb0000
02bb0000
02bb0000
40bb000000000000
02bb0000
40bb0000
=
struct umixed {
  char a;
  unsigned char  b:1;
};
-
{a=>122,b=>0}
7a00
7a00
7a00
7a00
7a000000
7a00
7a00
7a00
7a00
-
{a=>102,b=>0}
6600
6600
6600
6600
66000000
6600
6600
6600
6600
-
{a=>105,b=>0}
6900
6900
6900
6900
69000000
6900
6900
6900
6900
-
{a=>6,b=>1}
0601
0601
0601
0680
06010000
0601
0680
0601
0680
-
{a=>110,b=>0}
6e00
6e00
6e00
6e00
6e000000
6e00
6e00
6e00
6e00
=
struct umixed {
  char a;
  unsigned char  b:1;
  unsigned short c:1;
};
-
{c=>0,a=>-64,b=>0}
c000
c000
c000
c000
c0000000
c000
c000
c000
c000
-
{c=>0,a=>92,b=>1}
5c01
5c01
5c01
5c80
5c010000
5c01
5c80
5c01
5c80
-
{c=>1,a=>-60,b=>1}
c403
c403
c403
c4c0
c4030000
c403
c4c0
c403
c4c0
-
{c=>0,a=>0,b=>0}
0000
0000
0000
0000
00000000
0000
0000
0000
0000
-
{c=>0,a=>-90,b=>1}
a601
a601
a601
a680
a6010000
a601
a680
a601
a680
=
struct umixed {
  char a;
  unsigned char  b:1;
  unsigned short c:1;
  unsigned int   d:1;
};
-
{c=>1,a=>43,b=>0,d=>1}
2b060000
2b060000
2b060000
2b600000
2b060000
2b060000
2b600000
2b060000
2b600000
-
{c=>0,a=>65,b=>1,d=>1}
41050000
41050000
41050000
41a00000
41050000
41050000
41a00000
41050000
41a00000
-
{c=>1,a=>-28,b=>0,d=>1}
e4060000
e4060000
e4060000
e4600000
e4060000
e4060000
e4600000
e4060000
e4600000
-
{c=>1,a=>-67,b=>1,d=>0}
bd030000
bd030000
bd030000
bdc00000
bd030000
bd030000
bdc00000
bd030000
bdc00000
-
{c=>1,a=>-56,b=>0,d=>1}
c8060000
c8060000
c8060000
c8600000
c8060000
c8060000
c8600000
c8060000
c8600000
=
struct umixed {
  char a;
  unsigned char  b:1;
  unsigned short c:1;
  unsigned int   d:1;
  unsigned long  e:1;
};
-
{e=>1,c=>1,a=>-36,b=>0,d=>0}
dc0a0000
dc0a000000000000
dc0a000000000000
dc500000
dc0a0000
dc0a0000
dc50000000000000
dc0a0000
dc500000
-
{e=>1,c=>1,a=>-40,b=>1,d=>1}
d80f0000
d80f000000000000
d80f000000000000
d8f00000
d80f0000
d80f0000
d8f0000000000000
d80f0000
d8f00000
-
{e=>0,c=>1,a=>56,b=>0,d=>1}
38060000
3806000000000000
3806000000000000
38600000
38060000
38060000
3860000000000000
38060000
38600000
-
{e=>0,c=>1,a=>18,b=>1,d=>0}
12030000
1203000000000000
1203000000000000
12c00000
12030000
12030000
12c0000000000000
12030000
12c00000
-
{e=>1,c=>0,a=>-68,b=>1,d=>0}
bc090000
bc09000000000000
bc09000000000000
bc900000
bc090000
bc090000
bc90000000000000
bc090000
bc900000
=
struct umixed {
  char a;
  unsigned char  b:1;
  unsigned short c:1;
  unsigned int   d:1;
  unsigned long  e:1;
  unsigned char  f;
};
-
{e=>1,c=>1,a=>77,b=>0,d=>0,f=>112}
4d0a7000
4d0a700000000000
4d0a700000000000
4d507000
4d0a7000
4d0a7000
4d50700000000000
4d0a7000
4d507000
-
{e=>1,c=>0,a=>115,b=>0,d=>1,f=>9}
730c0900
730c090000000000
730c090000000000
73300900
730c0900
730c0900
7330090000000000
730c0900
73300900
-
{e=>0,c=>0,a=>-25,b=>0,d=>0,f=>91}
e7005b00
e7005b0000000000
e7005b0000000000
e7005b00
e7005b00
e7005b00
e7005b0000000000
e7005b00
e7005b00
-
{e=>0,c=>0,a=>-68,b=>1,d=>0,f=>5}
bc010500
bc01050000000000
bc01050000000000
bc800500
bc010500
bc010500
bc80050000000000
bc010500
bc800500
-
{e=>0,c=>1,a=>86,b=>0,d=>0,f=>30}
56021e00
56021e0000000000
56021e0000000000
56401e00
56021e00
56021e00
56401e0000000000
56021e00
56401e00
=
struct umixed {
  short a;
  unsigned char  b:1;
};
-
{a=>49,b=>0}
31000000
31000000
31000000
00310000
31000000
31000000
00310000
31000000
00310000
-
{a=>84,b=>1}
54000100
54000100
54000100
00548000
54000100
54000100
00548000
54000100
00548000
-
{a=>-73,b=>0}
b7ff0000
b7ff0000
b7ff0000
ffb70000
b7ff0000
b7ff0000
ffb70000
b7ff0000
ffb70000
-
{a=>92,b=>0}
5c000000
5c000000
5c000000
005c0000
5c000000
5c000000
005c0000
5c000000
005c0000
-
{a=>76,b=>0}
4c000000
4c000000
4c000000
004c0000
4c000000
4c000000
004c0000
4c000000
004c0000
=
struct umixed {
  short a;
  unsigned char  b:1;
  unsigned short c:1;
};
-
{c=>1,a=>-69,b=>0}
bbff0200
bbff0200
bbff0200
ffbb4000
bbff0200
bbff0200
ffbb4000
bbff0200
ffbb4000
-
{c=>1,a=>103,b=>0}
67000200
67000200
67000200
00674000
67000200
67000200
00674000
67000200
00674000
-
{c=>0,a=>-68,b=>0}
bcff0000
bcff0000
bcff0000
ffbc0000
bcff0000
bcff0000
ffbc0000
bcff0000
ffbc0000
-
{c=>0,a=>-31,b=>0}
e1ff0000
e1ff0000
e1ff0000
ffe10000
e1ff0000
e1ff0000
ffe10000
e1ff0000
ffe10000
-
{c=>0,a=>87,b=>1}
57000100
57000100
57000100
00578000
57000100
57000100
00578000
57000100
00578000
=
struct umixed {
  short a;
  unsigned char  b:1;
  unsigned short c:1;
  unsigned int   d:1;
};
-
{c=>0,a=>-26,b=>1,d=>0}
e6ff0100
e6ff0100
e6ff0100
ffe68000
e6ff0100
e6ff0100
ffe68000
e6ff0100
ffe68000
-
{c=>1,a=>41,b=>0,d=>1}
29000600
29000600
29000600
00296000
29000600
29000600
00296000
29000600
00296000
-
{c=>0,a=>47,b=>1,d=>1}
2f000500
2f000500
2f000500
002fa000
2f000500
2f000500
002fa000
2f000500
002fa000
-
{c=>0,a=>-115,b=>0,d=>0}
8dff0000
8dff0000
8dff0000
ff8d0000
8dff0000
8dff0000
ff8d0000
8dff0000
ff8d0000
-
{c=>1,a=>16,b=>1,d=>0}
10000300
10000300
10000300
0010c000
10000300
10000300
0010c000
10000300
0010c000
=
struct umixed {
  short a;
  unsigned char  b:1;
  unsigned short c:1;
  unsigned int   d:1;
  unsigned long  e:1;
};
-
{e=>1,c=>1,a=>-24,b=>0,d=>0}
e8ff0a00
e8ff0a0000000000
e8ff0a0000000000
ffe85000
e8ff0a00
e8ff0a00
ffe8500000000000
e8ff0a00
ffe85000
-
{e=>1,c=>1,a=>-4,b=>1,d=>0}
fcff0b00
fcff0b0000000000
fcff0b0000000000
fffcd000
fcff0b00
fcff0b00
fffcd00000000000
fcff0b00
fffcd000
-
{e=>0,c=>0,a=>-80,b=>1,d=>0}
b0ff0100
b0ff010000000000
b0ff010000000000
ffb08000
b0ff0100
b0ff0100
ffb0800000000000
b0ff0100
ffb08000
-
{e=>0,c=>0,a=>18,b=>1,d=>0}
12000100
1200010000000000
1200010000000000
00128000
12000100
12000100
0012800000000000
12000100
00128000
-
{e=>0,c=>0,a=>-46,b=>1,d=>0}
d2ff0100
d2ff010000000000
d2ff010000000000
ffd28000
d2ff0100
d2ff0100
ffd2800000000000
d2ff0100
ffd28000
=
struct umixed {
  short a;
  unsigned char  b:1;
  unsigned short c:1;
  unsigned int   d:1;
  unsigned long  e:1;
  unsigned char  f;
};
-
{e=>1,c=>1,a=>5,b=>0,d=>0,f=>113}
05000a71
05000a7100000000
05000a7100000000
00055071
05000a71
05000a71
0005507100000000
05000a71
00055071
-
{e=>0,c=>0,a=>67,b=>1,d=>1,f=>126}
4300057e
4300057e00000000
4300057e00000000
0043a07e
4300057e
4300057e
0043a07e00000000
4300057e
0043a07e
-
{e=>0,c=>0,a=>49,b=>0,d=>1,f=>165}
310004a5
310004a500000000
310004a500000000
003120a5
310004a5
310004a5
003120a500000000
310004a5
003120a5
-
{e=>1,c=>0,a=>0,b=>0,d=>1,f=>40}
00000c28
00000c2800000000
00000c2800000000
00003028
00000c28
00000c28
0000302800000000
00000c28
00003028
-
{e=>0,c=>1,a=>66,b=>0,d=>1,f=>177}
420006b1
420006b100000000
420006b100000000
004260b1
420006b1
420006b1
004260b100000000
420006b1
004260b1
=
struct umixed {
  int a;
  unsigned char  b:1;
};
-
{a=>-94,b=>0}
a2ffffff00000000
a2ffffff00000000
a2ffffff00000000
ffffffa200000000
a2ffffff00000000
a2ffffff00000000
ffffffa200000000
a2ffffff00000000
ffffffa200000000
-
{a=>-14,b=>0}
f2ffffff00000000
f2ffffff00000000
f2ffffff00000000
fffffff200000000
f2ffffff00000000
f2ffffff00000000
fffffff200000000
f2ffffff00000000
fffffff200000000
-
{a=>-40,b=>0}
d8ffffff00000000
d8ffffff00000000
d8ffffff00000000
ffffffd800000000
d8ffffff00000000
d8ffffff00000000
ffffffd800000000
d8ffffff00000000
ffffffd800000000
-
{a=>89,b=>0}
5900000000000000
5900000000000000
5900000000000000
0000005900000000
5900000000000000
5900000000000000
0000005900000000
5900000000000000
0000005900000000
-
{a=>-2,b=>1}
feffffff01000000
feffffff01000000
feffffff01000000
fffffffe80000000
feffffff01000000
feffffff01000000
fffffffe80000000
feffffff01000000
fffffffe80000000
=
struct umixed {
  int a;
  unsigned char  b:1;
  unsigned short c:1;
};
-
{c=>0,a=>114,b=>1}
7200000001000000
7200000001000000
7200000001000000
0000007280000000
7200000001000000
7200000001000000
0000007280000000
7200000001000000
0000007280000000
-
{c=>1,a=>-68,b=>1}
bcffffff03000000
bcffffff03000000
bcffffff03000000
ffffffbcc0000000
bcffffff03000000
bcffffff03000000
ffffffbcc0000000
bcffffff03000000
ffffffbcc0000000
-
{c=>0,a=>60,b=>1}
3c00000001000000
3c00000001000000
3c00000001000000
0000003c80000000
3c00000001000000
3c00000001000000
0000003c80000000
3c00000001000000
0000003c80000000
-
{c=>0,a=>-105,b=>1}
97ffffff01000000
97ffffff01000000
97ffffff01000000
ffffff9780000000
97ffffff01000000
97ffffff01000000
ffffff9780000000
97ffffff01000000
ffffff9780000000
-
{c=>1,a=>-90,b=>0}
a6ffffff02000000
a6ffffff02000000
a6ffffff02000000
ffffffa640000000
a6ffffff02000000
a6ffffff02000000
ffffffa640000000
a6ffffff02000000
ffffffa640000000
=
struct umixed {
  int a;
  unsigned char  b:1;
  unsigned short c:1;
  unsigned int   d:1;
};
-
{c=>1,a=>44,b=>0,d=>1}
2c00000006000000
2c00000006000000
2c00000006000000
0000002c60000000
2c00000006000000
2c00000006000000
0000002c60000000
2c00000006000000
0000002c60000000
-
{c=>1,a=>-90,b=>0,d=>0}
a6ffffff02000000
a6ffffff02000000
a6ffffff02000000
ffffffa640000000
a6ffffff02000000
a6ffffff02000000
ffffffa640000000
a6ffffff02000000
ffffffa640000000
-
{c=>1,a=>-11,b=>0,d=>0}
f5ffffff02000000
f5ffffff02000000
f5ffffff02000000
fffffff540000000
f5ffffff02000000
f5ffffff02000000
fffffff540000000
f5ffffff02000000
fffffff540000000
-
{c=>1,a=>18,b=>1,d=>1}
1200000007000000
1200000007000000
1200000007000000
00000012e0000000
1200000007000000
1200000007000000
00000012e0000000
1200000007000000
00000012e0000000
-
{c=>0,a=>-25,b=>0,d=>0}
e7ffffff00000000
e7ffffff00000000
e7ffffff00000000
ffffffe700000000
e7ffffff00000000
e7ffffff00000000
ffffffe700000000
e7ffffff00000000
ffffffe700000000
=
struct umixed {
  int a;
  unsigned char  b:1;
  unsigned short c:1;
  unsigned int   d:1;
  unsigned long  e:1;
};
-
{e=>0,c=>0,a=>-47,b=>1,d=>0}
d1ffffff01000000
d1ffffff01000000
d1ffffff01000000
ffffffd180000000
d1ffffff01000000
d1ffffff01000000
ffffffd180000000
d1ffffff01000000
ffffffd180000000
-
{e=>0,c=>1,a=>-12,b=>0,d=>1}
f4ffffff06000000
f4ffffff06000000
f4ffffff06000000
fffffff460000000
f4ffffff06000000
f4ffffff06000000
fffffff460000000
f4ffffff06000000
fffffff460000000
-
{e=>1,c=>1,a=>-74,b=>1,d=>0}
b6ffffff0b000000
b6ffffff0b000000
b6ffffff0b000000
ffffffb6d0000000
b6ffffff0b000000
b6ffffff0b000000
ffffffb6d0000000
b6ffffff0b000000
ffffffb6d0000000
-
{e=>1,c=>1,a=>-49,b=>1,d=>0}
cfffffff0b000000
cfffffff0b000000
cfffffff0b000000
ffffffcfd0000000
cfffffff0b000000
cfffffff0b000000
ffffffcfd0000000
cfffffff0b000000
ffffffcfd0000000
-
{e=>1,c=>1,a=>61,b=>1,d=>0}
3d0000000b000000
3d0000000b000000
3d0000000b000000
0000003dd0000000
3d0000000b000000
3d0000000b000000
0000003dd0000000
3d0000000b000000
0000003dd0000000
=
struct umixed {
  int a;
  unsigned char  b:1;
  unsigned short c:1;
  unsigned int   d:1;
  unsigned long  e:1;
  unsigned char  f;
};
-
{e=>1,c=>1,a=>-19,b=>0,d=>0,f=>112}
edffffff0a700000
edffffff0a700000
edffffff0a700000
ffffffed50700000
edffffff0a700000
edffffff0a700000
ffffffed50700000
edffffff0a700000
ffffffed50700000
-
{e=>1,c=>0,a=>-74,b=>1,d=>0,f=>149}
b6ffffff09950000
b6ffffff09950000
b6ffffff09950000
ffffffb690950000
b6ffffff09950000
b6ffffff09950000
ffffffb690950000
b6ffffff09950000
ffffffb690950000
-
{e=>0,c=>1,a=>-124,b=>1,d=>1,f=>78}
84ffffff074e0000
84ffffff074e0000
84ffffff074e0000
ffffff84e04e0000
84ffffff074e0000
84ffffff074e0000
ffffff84e04e0000
84ffffff074e0000
ffffff84e04e0000
-
{e=>1,c=>0,a=>-25,b=>0,d=>0,f=>222}
e7ffffff08de0000
e7ffffff08de0000
e7ffffff08de0000
ffffffe710de0000
e7ffffff08de0000
e7ffffff08de0000
ffffffe710de0000
e7ffffff08de0000
ffffffe710de0000
-
{e=>0,c=>0,a=>127,b=>1,d=>0,f=>81}
7f00000001510000
7f00000001510000
7f00000001510000
0000007f80510000
7f00000001510000
7f00000001510000
0000007f80510000
7f00000001510000
0000007f80510000
=
struct umixed {
  long a;
  unsigned char  b:1;
};
-
{a=>127,b=>0}
7f00000000000000
7f000000000000000000000000000000
7f000000000000000000000000000000
0000007f00000000
7f00000000000000
7f00000000000000
000000000000007f0000000000000000
7f00000000000000
0000007f00000000
-
{a=>66,b=>1}
4200000001000000
42000000000000000100000000000000
42000000000000000100000000000000
0000004280000000
4200000001000000
4200000001000000
00000000000000428000000000000000
4200000001000000
0000004280000000
-
{a=>13,b=>1}
0d00000001000000
0d000000000000000100000000000000
0d000000000000000100000000000000
0000000d80000000
0d00000001000000
0d00000001000000
000000000000000d8000000000000000
0d00000001000000
0000000d80000000
-
{a=>114,b=>0}
7200000000000000
72000000000000000000000000000000
72000000000000000000000000000000
0000007200000000
7200000000000000
7200000000000000
00000000000000720000000000000000
7200000000000000
0000007200000000
-
{a=>-73,b=>1}
b7ffffff01000000
b7ffffffffffffff0100000000000000
b7ffffffffffffff0100000000000000
ffffffb780000000
b7ffffff01000000
b7ffffff01000000
ffffffffffffffb78000000000000000
b7ffffff01000000
ffffffb780000000
=
struct umixed {
  long a;
  unsigned char  b:1;
  unsigned short c:1;
};
-
{c=>1,a=>105,b=>0}
6900000002000000
69000000000000000200000000000000
69000000000000000200000000000000
0000006940000000
6900000002000000
6900000002000000
00000000000000694000000000000000
6900000002000000
0000006940000000
-
{c=>1,a=>-8,b=>0}
f8ffffff02000000
f8ffffffffffffff0200000000000000
f8ffffffffffffff0200000000000000
fffffff840000000
f8ffffff02000000
f8ffffff02000000
fffffffffffffff84000000000000000
f8ffffff02000000
fffffff840000000
-
{c=>0,a=>5,b=>0}
0500000000000000
05000000000000000000000000000000
05000000000000000000000000000000
0000000500000000
0500000000000000
0500000000000000
00000000000000050000000000000000
0500000000000000
0000000500000000
-
{c=>1,a=>-123,b=>0}
85ffffff02000000
85ffffffffffffff0200000000000000
85ffffffffffffff0200000000000000
ffffff8540000000
85ffffff02000000
85ffffff02000000
ffffffffffffff854000000000000000
85ffffff02000000
ffffff8540000000
-
{c=>1,a=>103,b=>1}
6700000003000000
67000000000000000300000000000000
67000000000000000300000000000000
00000067c0000000
6700000003000000
6700000003000000
0000000000000067c000000000000000
6700000003000000
00000067c0000000
=
struct umixed {
  long a;
  unsigned char  b:1;
  unsigned short c:1;
  unsigned int   d:1;
};
-
{c=>1,a=>-17,b=>1,d=>0}
efffffff03000000
efffffffffffffff0300000000000000
efffffffffffffff0300000000000000
ffffffefc0000000
efffffff03000000
efffffff03000000
ffffffffffffffefc000000000000000
efffffff03000000
ffffffefc0000000
-
{c=>1,a=>-127,b=>1,d=>0}
81ffffff03000000
81ffffffffffffff0300000000000000
81ffffffffffffff0300000000000000
ffffff81c0000000
81ffffff03000000
81ffffff03000000
ffffffffffffff81c000000000000000
81ffffff03000000
ffffff81c0000000
-
{c=>1,a=>102,b=>1,d=>1}
6600000007000000
66000000000000000700000000000000
66000000000000000700000000000000
00000066e0000000
6600000007000000
6600000007000000
0000000000000066e000000000000000
6600000007000000
00000066e0000000
-
{c=>1,a=>-88,b=>1,d=>1}
a8ffffff07000000
a8ffffffffffffff0700000000000000
a8ffffffffffffff0700000000000000
ffffffa8e0000000
a8ffffff07000000
a8ffffff07000000
ffffffffffffffa8e000000000000000
a8ffffff07000000
ffffffa8e0000000
-
{c=>1,a=>15,b=>1,d=>1}
0f00000007000000
0f000000000000000700000000000000
0f000000000000000700000000000000
0000000fe0000000
0f00000007000000
0f00000007000000
000000000000000fe000000000000000
0f00000007000000
0000000fe0000000
=
struct umixed {
  long a;
  unsigned char  b:1;
  unsigned short c:1;
  unsigned int   d:1;
  unsigned long  e:1;
};
-
{e=>1,c=>1,a=>118,b=>1,d=>1}
760000000f000000
76000000000000000f00000000000000
76000000000000000f00000000000000
00000076f0000000
760000000f000000
760000000f000000
0000000000000076f000000000000000
760000000f000000
00000076f0000000
-
{e=>1,c=>0,a=>-90,b=>0,d=>1}
a6ffffff0c000000
a6ffffffffffffff0c00000000000000
a6ffffffffffffff0c00000000000000
ffffffa630000000
a6ffffff0c000000
a6ffffff0c000000
ffffffffffffffa63000000000000000
a6ffffff0c000000
ffffffa630000000
-
{e=>0,c=>0,a=>103,b=>0,d=>0}
6700000000000000
67000000000000000000000000000000
67000000000000000000000000000000
0000006700000000
6700000000000000
6700000000000000
00000000000000670000000000000000
6700000000000000
0000006700000000
-
{e=>0,c=>1,a=>-84,b=>0,d=>1}
acffffff06000000
acffffffffffffff0600000000000000
acffffffffffffff0600000000000000
ffffffac60000000
acffffff06000000
acffffff06000000
ffffffffffffffac6000000000000000
acffffff06000000
ffffffac60000000
-
{e=>1,c=>1,a=>92,b=>0,d=>0}
5c0000000a000000
5c000000000000000a00000000000000
5c000000000000000a00000000000000
0000005c50000000
5c0000000a000000
5c0000000a000000
000000000000005c5000000000000000
5c0000000a000000
0000005c50000000
=
struct umixed {
  long a;
  unsigned char  b:1;
  unsigned short c:1;
  unsigned int   d:1;
  unsigned long  e:1;
  unsigned char  f;
};
-
{e=>1,c=>0,a=>51,b=>0,d=>0,f=>187}
3300000008bb0000
330000000000000008bb000000000000
330000000000000008bb000000000000
0000003310bb0000
3300000008bb0000
3300000008bb0000
000000000000003310bb000000000000
3300000008bb0000
0000003310bb0000
-
{e=>0,c=>1,a=>-115,b=>1,d=>1,f=>46}
8dffffff072e0000
8dffffffffffffff072e000000000000
8dffffffffffffff072e000000000000
ffffff8de02e0000
8dffffff072e0000
8dffffff072e0000
ffffffffffffff8de02e000000000000
8dffffff072e0000
ffffff8de02e0000
-
{e=>1,c=>0,a=>105,b=>0,d=>0,f=>59}
69000000083b0000
6900000000000000083b000000000000
6900000000000000083b000000000000
00000069103b0000
69000000083b0000
69000000083b0000
0000000000000069103b000000000000
69000000083b0000
00000069103b0000
-
{e=>1,c=>1,a=>-128,b=>0,d=>1,f=>86}
80ffffff0e560000
80ffffffffffffff0e56000000000000
80ffffffffffffff0e56000000000000
ffffff8070560000
80ffffff0e560000
80ffffff0e560000
ffffffffffffff807056000000000000
80ffffff0e560000
ffffff8070560000
-
{e=>1,c=>1,a=>24,b=>1,d=>1,f=>117}
180000000f750000
18000000000000000f75000000000000
18000000000000000f75000000000000
00000018f0750000
180000000f750000
180000000f750000
0000000000000018f075000000000000
180000000f750000
00000018f0750000
=
struct smixed {
  signed char  a:1;
};
-
{a=>-1}
01
01
01
80
01000000
01
80
01
80
-
{a=>-1}
01
01
01
80
01000000
01
80
01
80
-
{a=>-1}
01
01
01
80
01000000
01
80
01
80
-
{a=>-1}
01
01
01
80
01000000
01
80
01
80
-
{a=>-1}
01
01
01
80
01000000
01
80
01
80
=
struct smixed {
  signed char  a:1;
  signed short b:1;
};
-
{a=>0,b=>0}
0000
0000
0000
0000
00000000
0000
0000
0000
0000
-
{a=>-1,b=>0}
0100
0100
0100
8000
01000000
0100
8000
0100
8000
-
{a=>0,b=>-1}
0200
0200
0200
4000
02000000
0200
4000
0200
4000
-
{a=>0,b=>-1}
0200
0200
0200
4000
02000000
0200
4000
0200
4000
-
{a=>0,b=>-1}
0200
0200
0200
4000
02000000
0200
4000
0200
4000
=
struct smixed {
  signed char  a:1;
  signed short b:1;
  signed int   c:1;
};
-
{c=>0,a=>0,b=>-1}
02000000
02000000
02000000
40000000
02000000
02000000
40000000
02000000
40000000
-
{c=>-1,a=>-1,b=>0}
05000000
05000000
05000000
a0000000
05000000
05000000
a0000000
05000000
a0000000
-
{c=>0,a=>0,b=>-1}
02000000
02000000
02000000
40000000
02000000
02000000
40000000
02000000
40000000
-
{c=>-1,a=>0,b=>0}
04000000
04000000
04000000
20000000
04000000
04000000
20000000
04000000
20000000
-
{c=>0,a=>0,b=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
=
struct smixed {
  signed char  a:1;
  signed short b:1;
  signed int   c:1;
  signed long  d:1;
};
-
{c=>-1,a=>-1,b=>-1,d=>-1}
0f000000
0f00000000000000
0f00000000000000
f0000000
0f000000
0f000000
f000000000000000
0f000000
f0000000
-
{c=>0,a=>-1,b=>0,d=>0}
01000000
0100000000000000
0100000000000000
80000000
01000000
01000000
8000000000000000
01000000
80000000
-
{c=>-1,a=>0,b=>-1,d=>-1}
0e000000
0e00000000000000
0e00000000000000
70000000
0e000000
0e000000
7000000000000000
0e000000
70000000
-
{c=>-1,a=>-1,b=>0,d=>0}
05000000
0500000000000000
0500000000000000
a0000000
05000000
05000000
a000000000000000
05000000
a0000000
-
{c=>0,a=>-1,b=>0,d=>-1}
09000000
0900000000000000
0900000000000000
90000000
09000000
09000000
9000000000000000
09000000
90000000
=
struct smixed {
  signed char  a:1;
  signed short b:1;
  signed int   c:1;
  signed long  d:1;
  signed int   e;
};
-
{e=>-8,c=>0,a=>-1,b=>0,d=>-1}
09000000f8ffffff
09000000f8ffffff
09000000f8ffffff
90000000fffffff8
09000000f8ffffff
09000000f8ffffff
90000000fffffff8
09000000f8ffffff
90000000fffffff8
-
{e=>93,c=>-1,a=>0,b=>-1,d=>0}
060000005d000000
060000005d000000
060000005d000000
600000000000005d
060000005d000000
060000005d000000
600000000000005d
060000005d000000
600000000000005d
-
{e=>98,c=>-1,a=>-1,b=>-1,d=>-1}
0f00000062000000
0f00000062000000
0f00000062000000
f000000000000062
0f00000062000000
0f00000062000000
f000000000000062
0f00000062000000
f000000000000062
-
{e=>-79,c=>0,a=>0,b=>-1,d=>-1}
0a000000b1ffffff
0a000000b1ffffff
0a000000b1ffffff
50000000ffffffb1
0a000000b1ffffff
0a000000b1ffffff
50000000ffffffb1
0a000000b1ffffff
50000000ffffffb1
-
{e=>-60,c=>-1,a=>0,b=>0,d=>-1}
0c000000c4ffffff
0c000000c4ffffff
0c000000c4ffffff
30000000ffffffc4
0c000000c4ffffff
0c000000c4ffffff
30000000ffffffc4
0c000000c4ffffff
30000000ffffffc4
=
struct smixed {
  char a;
  signed char  b:1;
};
-
{a=>28,b=>0}
1c00
1c00
1c00
1c00
1c000000
1c00
1c00
1c00
1c00
-
{a=>-89,b=>-1}
a701
a701
a701
a780
a7010000
a701
a780
a701
a780
-
{a=>52,b=>-1}
3401
3401
3401
3480
34010000
3401
3480
3401
3480
-
{a=>91,b=>0}
5b00
5b00
5b00
5b00
5b000000
5b00
5b00
5b00
5b00
-
{a=>-106,b=>0}
9600
9600
9600
9600
96000000
9600
9600
9600
9600
=
struct smixed {
  char a;
  signed char  b:1;
  signed short c:1;
};
-
{c=>-1,a=>-38,b=>0}
da02
da02
da02
da40
da020000
da02
da40
da02
da40
-
{c=>0,a=>-57,b=>-1}
c701
c701
c701
c780
c7010000
c701
c780
c701
c780
-
{c=>-1,a=>-94,b=>-1}
a203
a203
a203
a2c0
a2030000
a203
a2c0
a203
a2c0
-
{c=>-1,a=>107,b=>-1}
6b03
6b03
6b03
6bc0
6b030000
6b03
6bc0
6b03
6bc0
-
{c=>0,a=>-95,b=>0}
a100
a100
a100
a100
a1000000
a100
a100
a100
a100
=
struct smixed {
  char a;
  signed char  b:1;
  signed short c:1;
  signed int   d:1;
};
-
{c=>0,a=>35,b=>-1,d=>0}
23010000
23010000
23010000
23800000
23010000
23010000
23800000
23010000
23800000
-
{c=>-1,a=>-97,b=>-1,d=>0}
9f030000
9f030000
9f030000
9fc00000
9f030000
9f030000
9fc00000
9f030000
9fc00000
-
{c=>0,a=>79,b=>-1,d=>-1}
4f050000
4f050000
4f050000
4fa00000
4f050000
4f050000
4fa00000
4f050000
4fa00000
-
{c=>0,a=>-2,b=>0,d=>-1}
fe040000
fe040000
fe040000
fe200000
fe040000
fe040000
fe200000
fe040000
fe200000
-
{c=>-1,a=>52,b=>-1,d=>0}
34030000
34030000
34030000
34c00000
34030000
34030000
34c00000
34030000
34c00000
=
struct smixed {
  char a;
  signed char  b:1;
  signed short c:1;
  signed int   d:1;
  signed long  e:1;
};
-
{e=>0,c=>0,a=>63,b=>-1,d=>-1}
3f050000
3f05000000000000
3f05000000000000
3fa00000
3f050000
3f050000
3fa0000000000000
3f050000
3fa00000
-
{e=>-1,c=>0,a=>105,b=>0,d=>-1}
690c0000
690c000000000000
690c000000000000
69300000
690c0000
690c0000
6930000000000000
690c0000
69300000
-
{e=>0,c=>-1,a=>84,b=>0,d=>-1}
54060000
5406000000000000
5406000000000000
54600000
54060000
54060000
5460000000000000
54060000
54600000
-
{e=>-1,c=>0,a=>40,b=>-1,d=>-1}
280d0000
280d000000000000
280d000000000000
28b00000
280d0000
280d0000
28b0000000000000
280d0000
28b00000
-
{e=>0,c=>0,a=>114,b=>-1,d=>0}
72010000
7201000000000000
7201000000000000
72800000
72010000
72010000
7280000000000000
72010000
72800000
=
struct smixed {
  char a;
  signed char  b:1;
  signed short c:1;
  signed int   d:1;
  signed long  e:1;
  signed int   f;
};
-
{e=>-1,c=>-1,a=>-50,b=>-1,d=>-1,f=>37}
ce0f000025000000
ce0f000025000000
ce0f000025000000
cef0000000000025
ce0f000025000000
ce0f000025000000
cef0000000000025
ce0f000025000000
cef0000000000025
-
{e=>-1,c=>-1,a=>-111,b=>-1,d=>-1,f=>-13}
910f0000f3ffffff
910f0000f3ffffff
910f0000f3ffffff
91f00000fffffff3
910f0000f3ffffff
910f0000f3ffffff
91f00000fffffff3
910f0000f3ffffff
91f00000fffffff3
-
{e=>0,c=>0,a=>-7,b=>0,d=>-1,f=>-107}
f904000095ffffff
f904000095ffffff
f904000095ffffff
f9200000ffffff95
f904000095ffffff
f904000095ffffff
f9200000ffffff95
f904000095ffffff
f9200000ffffff95
-
{e=>0,c=>-1,a=>8,b=>0,d=>-1,f=>-10}
08060000f6ffffff
08060000f6ffffff
08060000f6ffffff
08600000fffffff6
08060000f6ffffff
08060000f6ffffff
08600000fffffff6
08060000f6ffffff
08600000fffffff6
-
{e=>-1,c=>-1,a=>-89,b=>0,d=>-1,f=>127}
a70e00007f000000
a70e00007f000000
a70e00007f000000
a77000000000007f
a70e00007f000000
a70e00007f000000
a77000000000007f
a70e00007f000000
a77000000000007f
=
struct smixed {
  short a;
  signed char  b:1;
};
-
{a=>-94,b=>-1}
a2ff0100
a2ff0100
a2ff0100
ffa28000
a2ff0100
a2ff0100
ffa28000
a2ff0100
ffa28000
-
{a=>19,b=>-1}
13000100
13000100
13000100
00138000
13000100
13000100
00138000
13000100
00138000
-
{a=>-68,b=>-1}
bcff0100
bcff0100
bcff0100
ffbc8000
bcff0100
bcff0100
ffbc8000
bcff0100
ffbc8000
-
{a=>-102,b=>-1}
9aff0100
9aff0100
9aff0100
ff9a8000
9aff0100
9aff0100
ff9a8000
9aff0100
ff9a8000
-
{a=>-111,b=>-1}
91ff0100
91ff0100
91ff0100
ff918000
91ff0100
91ff0100
ff918000
91ff0100
ff918000
=
struct smixed {
  short a;
  signed char  b:1;
  signed short c:1;
};
-
{c=>-1,a=>41,b=>0}
29000200
29000200
29000200
00294000
29000200
29000200
00294000
29000200
00294000
-
{c=>-1,a=>99,b=>0}
63000200
63000200
63000200
00634000
63000200
63000200
00634000
63000200
00634000
-
{c=>-1,a=>-58,b=>0}
c6ff0200
c6ff0200
c6ff0200
ffc64000
c6ff0200
c6ff0200
ffc64000
c6ff0200
ffc64000
-
{c=>-1,a=>28,b=>0}
1c000200
1c000200
1c000200
001c4000
1c000200
1c000200
001c4000
1c000200
001c4000
-
{c=>-1,a=>-117,b=>0}
8bff0200
8bff0200
8bff0200
ff8b4000
8bff0200
8bff0200
ff8b4000
8bff0200
ff8b4000
=
struct smixed {
  short a;
  signed char  b:1;
  signed short c:1;
  signed int   d:1;
};
-
{c=>-1,a=>114,b=>-1,d=>-1}
72000700
72000700
72000700
0072e000
72000700
72000700
0072e000
72000700
0072e000
-
{c=>0,a=>-58,b=>-1,d=>-1}
c6ff0500
c6ff0500
c6ff0500
ffc6a000
c6ff0500
c6ff0500
ffc6a000
c6ff0500
ffc6a000
-
{c=>-1,a=>15,b=>-1,d=>0}
0f000300
0f000300
0f000300
000fc000
0f000300
0f000300
000fc000
0f000300
000fc000
-
{c=>0,a=>-98,b=>0,d=>0}
9eff0000
9eff0000
9eff0000
ff9e0000
9eff0000
9eff0000
ff9e0000
9eff0000
ff9e0000
-
{c=>-1,a=>26,b=>0,d=>0}
1a000200
1a000200
1a000200
001a4000
1a000200
1a000200
001a4000
1a000200
001a4000
=
struct smixed {
  short a;
  signed char  b:1;
  signed short c:1;
  signed int   d:1;
  signed long  e:1;
};
-
{e=>-1,c=>0,a=>-4,b=>0,d=>0}
fcff0800
fcff080000000000
fcff080000000000
fffc1000
fcff0800
fcff0800
fffc100000000000
fcff0800
fffc1000
-
{e=>-1,c=>0,a=>6,b=>0,d=>-1}
06000c00
06000c0000000000
06000c0000000000
00063000
06000c00
06000c00
0006300000000000
06000c00
00063000
-
{e=>0,c=>-1,a=>40,b=>-1,d=>-1}
28000700
2800070000000000
2800070000000000
0028e000
28000700
28000700
0028e00000000000
28000700
0028e000
-
{e=>-1,c=>0,a=>32,b=>-1,d=>0}
20000900
2000090000000000
2000090000000000
00209000
20000900
20000900
0020900000000000
20000900
00209000
-
{e=>0,c=>-1,a=>-119,b=>0,d=>-1}
89ff0600
89ff060000000000
89ff060000000000
ff896000
89ff0600
89ff0600
ff89600000000000
89ff0600
ff896000
=
struct smixed {
  short a;
  signed char  b:1;
  signed short c:1;
  signed int   d:1;
  signed long  e:1;
  signed int   f;
};
-
{e=>0,c=>0,a=>-8,b=>-1,d=>-1,f=>-2}
f8ff0500feffffff
f8ff0500feffffff
f8ff0500feffffff
fff8a000fffffffe
f8ff0500feffffff
f8ff0500feffffff
fff8a000fffffffe
f8ff0500feffffff
fff8a000fffffffe
-
{e=>-1,c=>0,a=>-61,b=>-1,d=>0,f=>-61}
c3ff0900c3ffffff
c3ff0900c3ffffff
c3ff0900c3ffffff
ffc39000ffffffc3
c3ff0900c3ffffff
c3ff0900c3ffffff
ffc39000ffffffc3
c3ff0900c3ffffff
ffc39000ffffffc3
-
{e=>0,c=>0,a=>63,b=>-1,d=>-1,f=>-95}
3f000500a1ffffff
3f000500a1ffffff
3f000500a1ffffff
003fa000ffffffa1
3f000500a1ffffff
3f000500a1ffffff
003fa000ffffffa1
3f000500a1ffffff
003fa000ffffffa1
-
{e=>0,c=>0,a=>60,b=>0,d=>0,f=>92}
3c0000005c000000
3c0000005c000000
3c0000005c000000
003c00000000005c
3c0000005c000000
3c0000005c000000
003c00000000005c
3c0000005c000000
003c00000000005c
-
{e=>0,c=>-1,a=>-67,b=>0,d=>-1,f=>19}
bdff060013000000
bdff060013000000
bdff060013000000
ffbd600000000013
bdff060013000000
bdff060013000000
ffbd600000000013
bdff060013000000
ffbd600000000013
=
struct smixed {
  int a;
  signed char  b:1;
};
-
{a=>95,b=>-1}
5f00000001000000
5f00000001000000
5f00000001000000
0000005f80000000
5f00000001000000
5f00000001000000
0000005f80000000
5f00000001000000
0000005f80000000
-
{a=>50,b=>0}
3200000000000000
3200000000000000
3200000000000000
0000003200000000
3200000000000000
3200000000000000
0000003200000000
3200000000000000
0000003200000000
-
{a=>-64,b=>-1}
c0ffffff01000000
c0ffffff01000000
c0ffffff01000000
ffffffc080000000
c0ffffff01000000
c0ffffff01000000
ffffffc080000000
c0ffffff01000000
ffffffc080000000
-
{a=>-33,b=>-1}
dfffffff01000000
dfffffff01000000
dfffffff01000000
ffffffdf80000000
dfffffff01000000
dfffffff01000000
ffffffdf80000000
dfffffff01000000
ffffffdf80000000
-
{a=>-44,b=>-1}
d4ffffff01000000
d4ffffff01000000
d4ffffff01000000
ffffffd480000000
d4ffffff01000000
d4ffffff01000000
ffffffd480000000
d4ffffff01000000
ffffffd480000000
=
struct smixed {
  int a;
  signed char  b:1;
  signed short c:1;
};
-
{c=>0,a=>-115,b=>0}
8dffffff00000000
8dffffff00000000
8dffffff00000000
ffffff8d00000000
8dffffff00000000
8dffffff00000000
ffffff8d00000000
8dffffff00000000
ffffff8d00000000
-
{c=>-1,a=>-6,b=>0}
faffffff02000000
faffffff02000000
faffffff02000000
fffffffa40000000
faffffff02000000
faffffff02000000
fffffffa40000000
faffffff02000000
fffffffa40000000
-
{c=>0,a=>40,b=>-1}
2800000001000000
2800000001000000
2800000001000000
0000002880000000
2800000001000000
2800000001000000
0000002880000000
2800000001000000
0000002880000000
-
{c=>-1,a=>-100,b=>-1}
9cffffff03000000
9cffffff03000000
9cffffff03000000
ffffff9cc0000000
9cffffff03000000
9cffffff03000000
ffffff9cc0000000
9cffffff03000000
ffffff9cc0000000
-
{c=>-1,a=>-26,b=>-1}
e6ffffff03000000
e6ffffff03000000
e6ffffff03000000
ffffffe6c0000000
e6ffffff03000000
e6ffffff03000000
ffffffe6c0000000
e6ffffff03000000
ffffffe6c0000000
=
struct smixed {
  int a;
  signed char  b:1;
  signed short c:1;
  signed int   d:1;
};
-
{c=>0,a=>111,b=>-1,d=>0}
6f00000001000000
6f00000001000000
6f00000001000000
0000006f80000000
6f00000001000000
6f00000001000000
0000006f80000000
6f00000001000000
0000006f80000000
-
{c=>-1,a=>-15,b=>-1,d=>0}
f1ffffff03000000
f1ffffff03000000
f1ffffff03000000
fffffff1c0000000
f1ffffff03000000
f1ffffff03000000
fffffff1c0000000
f1ffffff03000000
fffffff1c0000000
-
{c=>-1,a=>27,b=>-1,d=>0}
1b00000003000000
1b00000003000000
1b00000003000000
0000001bc0000000
1b00000003000000
1b00000003000000
0000001bc0000000
1b00000003000000
0000001bc0000000
-
{c=>0,a=>95,b=>-1,d=>0}
5f00000001000000
5f00000001000000
5f00000001000000
0000005f80000000
5f00000001000000
5f00000001000000
0000005f80000000
5f00000001000000
0000005f80000000
-
{c=>0,a=>40,b=>0,d=>0}
2800000000000000
2800000000000000
2800000000000000
0000002800000000
2800000000000000
2800000000000000
0000002800000000
2800000000000000
0000002800000000
=
struct smixed {
  int a;
  signed char  b:1;
  signed short c:1;
  signed int   d:1;
  signed long  e:1;
};
-
{e=>0,c=>0,a=>106,b=>0,d=>-1}
6a00000004000000
6a00000004000000
6a00000004000000
0000006a20000000
6a00000004000000
6a00000004000000
0000006a20000000
6a00000004000000
0000006a20000000
-
{e=>0,c=>0,a=>-60,b=>-1,d=>-1}
c4ffffff05000000
c4ffffff05000000
c4ffffff05000000
ffffffc4a0000000
c4ffffff05000000
c4ffffff05000000
ffffffc4a0000000
c4ffffff05000000
ffffffc4a0000000
-
{e=>-1,c=>-1,a=>21,b=>0,d=>-1}
150000000e000000
150000000e000000
150000000e000000
0000001570000000
150000000e000000
150000000e000000
0000001570000000
150000000e000000
0000001570000000
-
{e=>-1,c=>-1,a=>12,b=>0,d=>0}
0c0000000a000000
0c0000000a000000
0c0000000a000000
0000000c50000000
0c0000000a000000
0c0000000a000000
0000000c50000000
0c0000000a000000
0000000c50000000
-
{e=>0,c=>-1,a=>-11,b=>-1,d=>-1}
f5ffffff07000000
f5ffffff07000000
f5ffffff07000000
fffffff5e0000000
f5ffffff07000000
f5ffffff07000000
fffffff5e0000000
f5ffffff07000000
fffffff5e0000000
=
struct smixed {
  int a;
  signed char  b:1;
  signed short c:1;
  signed int   d:1;
  signed long  e:1;
  signed int   f;
};
-
{e=>-1,c=>-1,a=>1,b=>-1,d=>-1,f=>-92}
010000000f000000a4ffffff
010000000f000000a4ffffff00000000
010000000f000000a4ffffff00000000
00000001f0000000ffffffa4
010000000f000000a4ffffff
010000000f000000a4ffffff
00000001f0000000ffffffa400000000
010000000f000000a4ffffff
00000001f0000000ffffffa4
-
{e=>-1,c=>-1,a=>-79,b=>0,d=>0,f=>47}
b1ffffff0a0000002f000000
b1ffffff0a0000002f00000000000000
b1ffffff0a0000002f00000000000000
ffffffb1500000000000002f
b1ffffff0a0000002f000000
b1ffffff0a0000002f000000
ffffffb1500000000000002f00000000
b1ffffff0a0000002f000000
ffffffb1500000000000002f
-
{e=>-1,c=>-1,a=>81,b=>-1,d=>0,f=>-106}
510000000b00000096ffffff
510000000b00000096ffffff00000000
510000000b00000096ffffff00000000
00000051d0000000ffffff96
510000000b00000096ffffff
510000000b00000096ffffff
00000051d0000000ffffff9600000000
510000000b00000096ffffff
00000051d0000000ffffff96
-
{e=>0,c=>0,a=>15,b=>0,d=>-1,f=>2}
0f0000000400000002000000
0f000000040000000200000000000000
0f000000040000000200000000000000
0000000f2000000000000002
0f0000000400000002000000
0f0000000400000002000000
0000000f200000000000000200000000
0f0000000400000002000000
0000000f2000000000000002
-
{e=>0,c=>0,a=>91,b=>-1,d=>0,f=>98}
5b0000000100000062000000
5b000000010000006200000000000000
5b000000010000006200000000000000
0000005b8000000000000062
5b0000000100000062000000
5b0000000100000062000000
0000005b800000000000006200000000
5b0000000100000062000000
0000005b8000000000000062
=
struct smixed {
  long a;
  signed char  b:1;
};
-
{a=>60,b=>-1}
3c00000001000000
3c000000000000000100000000000000
3c000000000000000100000000000000
0000003c80000000
3c00000001000000
3c00000001000000
000000000000003c8000000000000000
3c00000001000000
0000003c80000000
-
{a=>125,b=>-1}
7d00000001000000
7d000000000000000100000000000000
7d000000000000000100000000000000
0000007d80000000
7d00000001000000
7d00000001000000
000000000000007d8000000000000000
7d00000001000000
0000007d80000000
-
{a=>-23,b=>-1}
e9ffffff01000000
e9ffffffffffffff0100000000000000
e9ffffffffffffff0100000000000000
ffffffe980000000
e9ffffff01000000
e9ffffff01000000
ffffffffffffffe98000000000000000
e9ffffff01000000
ffffffe980000000
-
{a=>-14,b=>-1}
f2ffffff01000000
f2ffffffffffffff0100000000000000
f2ffffffffffffff0100000000000000
fffffff280000000
f2ffffff01000000
f2ffffff01000000
fffffffffffffff28000000000000000
f2ffffff01000000
fffffff280000000
-
{a=>51,b=>0}
3300000000000000
33000000000000000000000000000000
33000000000000000000000000000000
0000003300000000
3300000000000000
3300000000000000
00000000000000330000000000000000
3300000000000000
0000003300000000
=
struct smixed {
  long a;
  signed char  b:1;
  signed short c:1;
};
-
{c=>-1,a=>-105,b=>-1}
97ffffff03000000
97ffffffffffffff0300000000000000
97ffffffffffffff0300000000000000
ffffff97c0000000
97ffffff03000000
97ffffff03000000
ffffffffffffff97c000000000000000
97ffffff03000000
ffffff97c0000000
-
{c=>0,a=>31,b=>0}
1f00000000000000
1f000000000000000000000000000000
1f000000000000000000000000000000
0000001f00000000
1f00000000000000
1f00000000000000
000000000000001f0000000000000000
1f00000000000000
0000001f00000000
-
{c=>0,a=>43,b=>0}
2b00000000000000
2b000000000000000000000000000000
2b000000000000000000000000000000
0000002b00000000
2b00000000000000
2b00000000000000
000000000000002b0000000000000000
2b00000000000000
0000002b00000000
-
{c=>0,a=>-128,b=>0}
80ffffff00000000
80ffffffffffffff0000000000000000
80ffffffffffffff0000000000000000
ffffff8000000000
80ffffff00000000
80ffffff00000000
ffffffffffffff800000000000000000
80ffffff00000000
ffffff8000000000
-
{c=>-1,a=>101,b=>0}
6500000002000000
65000000000000000200000000000000
65000000000000000200000000000000
0000006540000000
6500000002000000
6500000002000000
00000000000000654000000000000000
6500000002000000
0000006540000000
=
struct smixed {
  long a;
  signed char  b:1;
  signed short c:1;
  signed int   d:1;
};
-
{c=>0,a=>18,b=>0,d=>-1}
1200000004000000
12000000000000000400000000000000
12000000000000000400000000000000
0000001220000000
1200000004000000
1200000004000000
00000000000000122000000000000000
1200000004000000
0000001220000000
-
{c=>-1,a=>-93,b=>-1,d=>0}
a3ffffff03000000
a3ffffffffffffff0300000000000000
a3ffffffffffffff0300000000000000
ffffffa3c0000000
a3ffffff03000000
a3ffffff03000000
ffffffffffffffa3c000000000000000
a3ffffff03000000
ffffffa3c0000000
-
{c=>-1,a=>-110,b=>-1,d=>-1}
92ffffff07000000
92ffffffffffffff0700000000000000
92ffffffffffffff0700000000000000
ffffff92e0000000
92ffffff07000000
92ffffff07000000
ffffffffffffff92e000000000000000
92ffffff07000000
ffffff92e0000000
-
{c=>-1,a=>-52,b=>0,d=>-1}
ccffffff06000000
ccffffffffffffff0600000000000000
ccffffffffffffff0600000000000000
ffffffcc60000000
ccffffff06000000
ccffffff06000000
ffffffffffffffcc6000000000000000
ccffffff06000000
ffffffcc60000000
-
{c=>0,a=>120,b=>-1,d=>-1}
7800000005000000
78000000000000000500000000000000
78000000000000000500000000000000
00000078a0000000
7800000005000000
7800000005000000
0000000000000078a000000000000000
7800000005000000
00000078a0000000
=
struct smixed {
  long a;
  signed char  b:1;
  signed short c:1;
  signed int   d:1;
  signed long  e:1;
};
-
{e=>-1,c=>-1,a=>-121,b=>0,d=>-1}
87ffffff0e000000
87ffffffffffffff0e00000000000000
87ffffffffffffff0e00000000000000
ffffff8770000000
87ffffff0e000000
87ffffff0e000000
ffffffffffffff877000000000000000
87ffffff0e000000
ffffff8770000000
-
{e=>0,c=>0,a=>-86,b=>0,d=>-1}
aaffffff04000000
aaffffffffffffff0400000000000000
aaffffffffffffff0400000000000000
ffffffaa20000000
aaffffff04000000
aaffffff04000000
ffffffffffffffaa2000000000000000
aaffffff04000000
ffffffaa20000000
-
{e=>-1,c=>0,a=>115,b=>-1,d=>0}
7300000009000000
73000000000000000900000000000000
73000000000000000900000000000000
0000007390000000
7300000009000000
7300000009000000
00000000000000739000000000000000
7300000009000000
0000007390000000
-
{e=>-1,c=>-1,a=>26,b=>-1,d=>-1}
1a0000000f000000
1a000000000000000f00000000000000
1a000000000000000f00000000000000
0000001af0000000
1a0000000f000000
1a0000000f000000
000000000000001af000000000000000
1a0000000f000000
0000001af0000000
-
{e=>-1,c=>-1,a=>-108,b=>-1,d=>-1}
94ffffff0f000000
94ffffffffffffff0f00000000000000
94ffffffffffffff0f00000000000000
ffffff94f0000000
94ffffff0f000000
94ffffff0f000000
ffffffffffffff94f000000000000000
94ffffff0f000000
ffffff94f0000000
=
struct smixed {
  long a;
  signed char  b:1;
  signed short c:1;
  signed int   d:1;
  signed long  e:1;
  signed int   f;
};
-
{e=>-1,c=>-1,a=>26,b=>0,d=>-1,f=>-117}
1a0000000e0000008bffffff
1a000000000000000e0000008bffffff
1a000000000000000e0000008bffffff
0000001a70000000ffffff8b
1a0000000e0000008bffffff
1a0000000e0000008bffffff
000000000000001a70000000ffffff8b
1a0000000e0000008bffffff
0000001a70000000ffffff8b
-
{e=>-1,c=>0,a=>-97,b=>0,d=>-1,f=>99}
9fffffff0c00000063000000
9fffffffffffffff0c00000063000000
9fffffffffffffff0c00000063000000
ffffff9f3000000000000063
9fffffff0c00000063000000
9fffffff0c00000063000000
ffffffffffffff9f3000000000000063
9fffffff0c00000063000000
ffffff9f3000000000000063
-
{e=>0,c=>-1,a=>-23,b=>-1,d=>0,f=>63}
e9ffffff030000003f000000
e9ffffffffffffff030000003f000000
e9ffffffffffffff030000003f000000
ffffffe9c00000000000003f
e9ffffff030000003f000000
e9ffffff030000003f000000
ffffffffffffffe9c00000000000003f
e9ffffff030000003f000000
ffffffe9c00000000000003f
-
{e=>0,c=>-1,a=>95,b=>0,d=>-1,f=>108}
5f000000060000006c000000
5f00000000000000060000006c000000
5f00000000000000060000006c000000
0000005f600000000000006c
5f000000060000006c000000
5f000000060000006c000000
000000000000005f600000000000006c
5f000000060000006c000000
0000005f600000000000006c
-
{e=>-1,c=>0,a=>-97,b=>0,d=>0,f=>86}
9fffffff0800000056000000
9fffffffffffffff0800000056000000
9fffffffffffffff0800000056000000
ffffff9f1000000000000056
9fffffff0800000056000000
9fffffff0800000056000000
ffffffffffffff9f1000000000000056
9fffffff0800000056000000
ffffff9f1000000000000056
=
struct mixed {
  unsigned char  a:1;
};
-
{a=>1}
01
01
01
80
01000000
01
80
01
80
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>1}
01
01
01
80
01000000
01
80
01
80
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
=
struct mixed {
  unsigned char  a:1;
  signed   char  b:1;
};
-
{a=>0,b=>-1}
02
02
02
40
02000000
02
40
02
40
-
{a=>1,b=>0}
01
01
01
80
01000000
01
80
01
80
-
{a=>0,b=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>1,b=>0}
01
01
01
80
01000000
01
80
01
80
-
{a=>1,b=>0}
01
01
01
80
01000000
01
80
01
80
=
struct mixed {
  unsigned char  a:1;
  signed   char  b:1;
  unsigned short c:1;
};
-
{c=>1,a=>0,b=>0}
0400
0400
0400
2000
04000000
0400
2000
0400
2000
-
{c=>1,a=>1,b=>-1}
0700
0700
0700
e000
07000000
0700
e000
0700
e000
-
{c=>1,a=>0,b=>0}
0400
0400
0400
2000
04000000
0400
2000
0400
2000
-
{c=>1,a=>1,b=>-1}
0700
0700
0700
e000
07000000
0700
e000
0700
e000
-
{c=>1,a=>0,b=>-1}
0600
0600
0600
6000
06000000
0600
6000
0600
6000
=
struct mixed {
  unsigned char  a:1;
  signed   char  b:1;
  unsigned short c:1;
  signed   short d:1;
};
-
{c=>0,a=>1,b=>0,d=>-1}
0900
0900
0900
9000
09000000
0900
9000
0900
9000
-
{c=>0,a=>1,b=>0,d=>-1}
0900
0900
0900
9000
09000000
0900
9000
0900
9000
-
{c=>0,a=>1,b=>-1,d=>0}
0300
0300
0300
c000
03000000
0300
c000
0300
c000
-
{c=>1,a=>1,b=>-1,d=>0}
0700
0700
0700
e000
07000000
0700
e000
0700
e000
-
{c=>1,a=>0,b=>-1,d=>-1}
0e00
0e00
0e00
7000
0e000000
0e00
7000
0e00
7000
=
struct mixed {
  unsigned char  a:1;
  signed   char  b:1;
  unsigned short c:1;
  signed   short d:1;
  unsigned int   e:1;
};
-
{e=>1,c=>1,a=>0,b=>-1,d=>-1}
1e000000
1e000000
1e000000
78000000
1e000000
1e000000
78000000
1e000000
78000000
-
{e=>0,c=>1,a=>1,b=>-1,d=>-1}
0f000000
0f000000
0f000000
f0000000
0f000000
0f000000
f0000000
0f000000
f0000000
-
{e=>1,c=>1,a=>0,b=>0,d=>0}
14000000
14000000
14000000
28000000
14000000
14000000
28000000
14000000
28000000
-
{e=>0,c=>1,a=>1,b=>0,d=>-1}
0d000000
0d000000
0d000000
b0000000
0d000000
0d000000
b0000000
0d000000
b0000000
-
{e=>0,c=>0,a=>1,b=>0,d=>-1}
09000000
09000000
09000000
90000000
09000000
09000000
90000000
09000000
90000000
=
struct mixed {
  unsigned char  a:1;
  signed   char  b:1;
  unsigned short c:1;
  signed   short d:1;
  unsigned int   e:1;
  signed   int   f:1;
};
-
{e=>0,c=>0,a=>0,b=>0,d=>-1,f=>-1}
28000000
28000000
28000000
14000000
28000000
28000000
14000000
28000000
14000000
-
{e=>0,c=>0,a=>1,b=>0,d=>-1,f=>-1}
29000000
29000000
29000000
94000000
29000000
29000000
94000000
29000000
94000000
-
{e=>0,c=>1,a=>0,b=>-1,d=>-1,f=>-1}
2e000000
2e000000
2e000000
74000000
2e000000
2e000000
74000000
2e000000
74000000
-
{e=>1,c=>0,a=>0,b=>-1,d=>-1,f=>0}
1a000000
1a000000
1a000000
58000000
1a000000
1a000000
58000000
1a000000
58000000
-
{e=>0,c=>0,a=>0,b=>0,d=>0,f=>-1}
20000000
20000000
20000000
04000000
20000000
20000000
04000000
20000000
04000000
=
struct mixed {
  unsigned char  a:1;
  signed   char  b:1;
  unsigned short c:1;
  signed   short d:1;
  unsigned int   e:1;
  signed   int   f:1;
  unsigned long  g:1;
};
-
{e=>0,c=>0,a=>0,g=>0,b=>-1,d=>0,f=>0}
02000000
0200000000000000
0200000000000000
40000000
02000000
02000000
4000000000000000
02000000
40000000
-
{e=>1,c=>0,a=>1,g=>0,b=>0,d=>-1,f=>-1}
39000000
3900000000000000
3900000000000000
9c000000
39000000
39000000
9c00000000000000
39000000
9c000000
-
{e=>1,c=>0,a=>1,g=>1,b=>0,d=>0,f=>0}
51000000
5100000000000000
5100000000000000
8a000000
51000000
51000000
8a00000000000000
51000000
8a000000
-
{e=>0,c=>0,a=>1,g=>0,b=>-1,d=>-1,f=>0}
0b000000
0b00000000000000
0b00000000000000
d0000000
0b000000
0b000000
d000000000000000
0b000000
d0000000
-
{e=>0,c=>1,a=>0,g=>1,b=>-1,d=>0,f=>0}
46000000
4600000000000000
4600000000000000
62000000
46000000
46000000
6200000000000000
46000000
62000000
=
struct mixed {
  unsigned char  a:1;
  signed   char  b:1;
  unsigned short c:1;
  signed   short d:1;
  unsigned int   e:1;
  signed   int   f:1;
  unsigned long  g:1;
  signed   long  h:1;
};
-
{e=>1,a=>1,d=>-1,c=>1,h=>0,b=>-1,g=>1,f=>-1}
7f000000
7f00000000000000
7f00000000000000
fe000000
7f000000
7f000000
fe00000000000000
7f000000
fe000000
-
{e=>0,a=>0,d=>-1,c=>1,h=>0,b=>0,g=>0,f=>0}
0c000000
0c00000000000000
0c00000000000000
30000000
0c000000
0c000000
3000000000000000
0c000000
30000000
-
{e=>1,a=>0,d=>-1,c=>0,h=>-1,b=>0,g=>1,f=>0}
d8000000
d800000000000000
d800000000000000
1b000000
d8000000
d8000000
1b00000000000000
d8000000
1b000000
-
{e=>1,a=>0,d=>-1,c=>0,h=>-1,b=>0,g=>0,f=>0}
98000000
9800000000000000
9800000000000000
19000000
98000000
98000000
1900000000000000
98000000
19000000
-
{e=>1,a=>1,d=>0,c=>1,h=>0,b=>-1,g=>0,f=>0}
17000000
1700000000000000
1700000000000000
e8000000
17000000
17000000
e800000000000000
17000000
e8000000
=
struct mixed {
  unsigned char  a:1;
  signed   char  b:1;
  unsigned short c:1;
  signed   short d:1;
  unsigned int   e:1;
  signed   int   f:1;
  unsigned long  g:1;
  signed   long  h:1;
  unsigned char  i;
};
-
{e=>1,a=>0,d=>-1,c=>1,h=>-1,b=>-1,g=>0,f=>-1,i=>162}
bea20000
bea2000000000000
bea2000000000000
7da20000
bea20000
bea20000
7da2000000000000
bea20000
7da20000
-
{e=>1,a=>1,d=>0,c=>0,h=>0,b=>-1,g=>0,f=>0,i=>113}
13710000
1371000000000000
1371000000000000
c8710000
13710000
13710000
c871000000000000
13710000
c8710000
-
{e=>0,a=>1,d=>0,c=>1,h=>0,b=>0,g=>1,f=>-1,i=>177}
65b10000
65b1000000000000
65b1000000000000
a6b10000
65b10000
65b10000
a6b1000000000000
65b10000
a6b10000
-
{e=>0,a=>1,d=>-1,c=>1,h=>0,b=>0,g=>1,f=>-1,i=>254}
6dfe0000
6dfe000000000000
6dfe000000000000
b6fe0000
6dfe0000
6dfe0000
b6fe000000000000
6dfe0000
b6fe0000
-
{e=>1,a=>0,d=>-1,c=>0,h=>0,b=>0,g=>0,f=>-1,i=>196}
38c40000
38c4000000000000
38c4000000000000
1cc40000
38c40000
38c40000
1cc4000000000000
38c40000
1cc40000
=
struct mixed {
  char a;
  unsigned char  b:1;
};
-
{a=>59,b=>1}
3b01
3b01
3b01
3b80
3b010000
3b01
3b80
3b01
3b80
-
{a=>126,b=>1}
7e01
7e01
7e01
7e80
7e010000
7e01
7e80
7e01
7e80
-
{a=>58,b=>1}
3a01
3a01
3a01
3a80
3a010000
3a01
3a80
3a01
3a80
-
{a=>84,b=>0}
5400
5400
5400
5400
54000000
5400
5400
5400
5400
-
{a=>-59,b=>1}
c501
c501
c501
c580
c5010000
c501
c580
c501
c580
=
struct mixed {
  char a;
  unsigned char  b:1;
  signed   char  c:1;
};
-
{c=>0,a=>-8,b=>1}
f801
f801
f801
f880
f8010000
f801
f880
f801
f880
-
{c=>-1,a=>-61,b=>1}
c303
c303
c303
c3c0
c3030000
c303
c3c0
c303
c3c0
-
{c=>0,a=>38,b=>0}
2600
2600
2600
2600
26000000
2600
2600
2600
2600
-
{c=>0,a=>103,b=>1}
6701
6701
6701
6780
67010000
6701
6780
6701
6780
-
{c=>0,a=>-74,b=>0}
b600
b600
b600
b600
b6000000
b600
b600
b600
b600
=
struct mixed {
  char a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
};
-
{c=>-1,a=>-94,b=>0,d=>0}
a202
a202
a202
a240
a2020000
a202
a240
a202
a240
-
{c=>0,a=>18,b=>1,d=>0}
1201
1201
1201
1280
12010000
1201
1280
1201
1280
-
{c=>0,a=>83,b=>1,d=>1}
5305
5305
5305
53a0
53050000
5305
53a0
5305
53a0
-
{c=>-1,a=>41,b=>1,d=>1}
2907
2907
2907
29e0
29070000
2907
29e0
2907
29e0
-
{c=>-1,a=>28,b=>0,d=>1}
1c06
1c06
1c06
1c60
1c060000
1c06
1c60
1c06
1c60
=
struct mixed {
  char a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
};
-
{e=>0,c=>-1,a=>112,b=>1,d=>0}
7003
7003
7003
70c0
70030000
7003
70c0
7003
70c0
-
{e=>-1,c=>0,a=>72,b=>1,d=>1}
480d
480d
480d
48b0
480d0000
480d
48b0
480d
48b0
-
{e=>-1,c=>0,a=>33,b=>0,d=>1}
210c
210c
210c
2130
210c0000
210c
2130
210c
2130
-
{e=>-1,c=>-1,a=>57,b=>1,d=>0}
390b
390b
390b
39d0
390b0000
390b
39d0
390b
39d0
-
{e=>0,c=>0,a=>99,b=>1,d=>1}
6305
6305
6305
63a0
63050000
6305
63a0
6305
63a0
=
struct mixed {
  char a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
};
-
{e=>0,c=>0,a=>-16,b=>0,d=>0,f=>1}
f0100000
f0100000
f0100000
f0080000
f0100000
f0100000
f0080000
f0100000
f0080000
-
{e=>0,c=>0,a=>35,b=>0,d=>1,f=>1}
23140000
23140000
23140000
23280000
23140000
23140000
23280000
23140000
23280000
-
{e=>0,c=>-1,a=>24,b=>1,d=>0,f=>1}
18130000
18130000
18130000
18c80000
18130000
18130000
18c80000
18130000
18c80000
-
{e=>-1,c=>0,a=>-56,b=>0,d=>1,f=>1}
c81c0000
c81c0000
c81c0000
c8380000
c81c0000
c81c0000
c8380000
c81c0000
c8380000
-
{e=>0,c=>0,a=>-67,b=>1,d=>0,f=>0}
bd010000
bd010000
bd010000
bd800000
bd010000
bd010000
bd800000
bd010000
bd800000
=
struct mixed {
  char a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
};
-
{e=>-1,c=>0,a=>-105,g=>0,b=>0,d=>0,f=>0}
97080000
97080000
97080000
97100000
97080000
97080000
97100000
97080000
97100000
-
{e=>0,c=>-1,a=>101,g=>-1,b=>0,d=>0,f=>0}
65220000
65220000
65220000
65440000
65220000
65220000
65440000
65220000
65440000
-
{e=>0,c=>0,a=>-86,g=>-1,b=>0,d=>1,f=>0}
aa240000
aa240000
aa240000
aa240000
aa240000
aa240000
aa240000
aa240000
aa240000
-
{e=>0,c=>-1,a=>-47,g=>-1,b=>0,d=>0,f=>0}
d1220000
d1220000
d1220000
d1440000
d1220000
d1220000
d1440000
d1220000
d1440000
-
{e=>0,c=>0,a=>117,g=>-1,b=>1,d=>0,f=>0}
75210000
75210000
75210000
75840000
75210000
75210000
75840000
75210000
75840000
=
struct mixed {
  char a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
  unsigned long  h:1;
};
-
{e=>-1,a=>77,d=>0,c=>0,h=>0,b=>1,g=>0,f=>1}
4d190000
4d19000000000000
4d19000000000000
4d980000
4d190000
4d190000
4d98000000000000
4d190000
4d980000
-
{e=>-1,a=>-38,d=>1,c=>-1,h=>1,b=>0,g=>0,f=>0}
da4e0000
da4e000000000000
da4e000000000000
da720000
da4e0000
da4e0000
da72000000000000
da4e0000
da720000
-
{e=>-1,a=>-89,d=>0,c=>0,h=>1,b=>1,g=>-1,f=>1}
a7790000
a779000000000000
a779000000000000
a79e0000
a7790000
a7790000
a79e000000000000
a7790000
a79e0000
-
{e=>0,a=>-55,d=>1,c=>-1,h=>1,b=>1,g=>-1,f=>1}
c9770000
c977000000000000
c977000000000000
c9ee0000
c9770000
c9770000
c9ee000000000000
c9770000
c9ee0000
-
{e=>0,a=>76,d=>0,c=>-1,h=>0,b=>0,g=>-1,f=>1}
4c320000
4c32000000000000
4c32000000000000
4c4c0000
4c320000
4c320000
4c4c000000000000
4c320000
4c4c0000
=
struct mixed {
  char a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
  unsigned long  h:1;
  signed   long  i:1;
};
-
{e=>0,a=>51,d=>1,c=>0,h=>1,b=>1,g=>-1,f=>0,i=>-1}
33e50000
33e5000000000000
33e5000000000000
33a70000
33e50000
33e50000
33a7000000000000
33e50000
33a70000
-
{e=>0,a=>101,d=>0,c=>-1,h=>1,b=>0,g=>-1,f=>0,i=>-1}
65e20000
65e2000000000000
65e2000000000000
65470000
65e20000
65e20000
6547000000000000
65e20000
65470000
-
{e=>0,a=>-74,d=>1,c=>-1,h=>0,b=>0,g=>0,f=>0,i=>0}
b6060000
b606000000000000
b606000000000000
b6600000
b6060000
b6060000
b660000000000000
b6060000
b6600000
-
{e=>0,a=>124,d=>1,c=>-1,h=>0,b=>1,g=>0,f=>1,i=>-1}
7c970000
7c97000000000000
7c97000000000000
7ce90000
7c970000
7c970000
7ce9000000000000
7c970000
7ce90000
-
{e=>-1,a=>24,d=>0,c=>-1,h=>0,b=>1,g=>0,f=>1,i=>0}
181b0000
181b000000000000
181b000000000000
18d80000
181b0000
181b0000
18d8000000000000
181b0000
18d80000
=
struct mixed {
  char a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
  unsigned long  h:1;
  signed   long  i:1;
  unsigned char  j;
};
-
{e=>-1,a=>-115,d=>0,j=>73,c=>-1,h=>1,b=>0,g=>0,f=>0,i=>-1}
8dca4900
8dca490000000000
8dca490000000000
8d534900
8dca4900
8dca4900
8d53490000000000
8dca4900
8d534900
-
{e=>0,a=>112,d=>0,j=>186,c=>0,h=>1,b=>0,g=>0,f=>1,i=>0}
7050ba00
7050ba0000000000
7050ba0000000000
700aba00
7050ba00
7050ba00
700aba0000000000
7050ba00
700aba00
-
{e=>0,a=>27,d=>0,j=>247,c=>-1,h=>1,b=>1,g=>0,f=>1,i=>0}
1b53f700
1b53f70000000000
1b53f70000000000
1bcaf700
1b53f700
1b53f700
1bcaf70000000000
1b53f700
1bcaf700
-
{e=>-1,a=>0,d=>1,j=>68,c=>-1,h=>1,b=>0,g=>0,f=>0,i=>0}
004e4400
004e440000000000
004e440000000000
00724400
004e4400
004e4400
0072440000000000
004e4400
00724400
-
{e=>-1,a=>116,d=>0,j=>30,c=>-1,h=>1,b=>0,g=>-1,f=>1,i=>0}
747a1e00
747a1e0000000000
747a1e0000000000
745e1e00
747a1e00
747a1e00
745e1e0000000000
747a1e00
745e1e00
=
struct mixed {
  short a;
  unsigned char  b:1;
};
-
{a=>43,b=>0}
2b000000
2b000000
2b000000
002b0000
2b000000
2b000000
002b0000
2b000000
002b0000
-
{a=>-77,b=>0}
b3ff0000
b3ff0000
b3ff0000
ffb30000
b3ff0000
b3ff0000
ffb30000
b3ff0000
ffb30000
-
{a=>-127,b=>0}
81ff0000
81ff0000
81ff0000
ff810000
81ff0000
81ff0000
ff810000
81ff0000
ff810000
-
{a=>-70,b=>0}
baff0000
baff0000
baff0000
ffba0000
baff0000
baff0000
ffba0000
baff0000
ffba0000
-
{a=>-21,b=>0}
ebff0000
ebff0000
ebff0000
ffeb0000
ebff0000
ebff0000
ffeb0000
ebff0000
ffeb0000
=
struct mixed {
  short a;
  unsigned char  b:1;
  signed   char  c:1;
};
-
{c=>0,a=>1,b=>1}
01000100
01000100
01000100
00018000
01000100
01000100
00018000
01000100
00018000
-
{c=>-1,a=>-65,b=>0}
bfff0200
bfff0200
bfff0200
ffbf4000
bfff0200
bfff0200
ffbf4000
bfff0200
ffbf4000
-
{c=>0,a=>-122,b=>0}
86ff0000
86ff0000
86ff0000
ff860000
86ff0000
86ff0000
ff860000
86ff0000
ff860000
-
{c=>-1,a=>-8,b=>1}
f8ff0300
f8ff0300
f8ff0300
fff8c000
f8ff0300
f8ff0300
fff8c000
f8ff0300
fff8c000
-
{c=>-1,a=>50,b=>1}
32000300
32000300
32000300
0032c000
32000300
32000300
0032c000
32000300
0032c000
=
struct mixed {
  short a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
};
-
{c=>0,a=>24,b=>1,d=>1}
18000500
18000500
18000500
0018a000
18000500
18000500
0018a000
18000500
0018a000
-
{c=>0,a=>-41,b=>0,d=>1}
d7ff0400
d7ff0400
d7ff0400
ffd72000
d7ff0400
d7ff0400
ffd72000
d7ff0400
ffd72000
-
{c=>-1,a=>-82,b=>0,d=>0}
aeff0200
aeff0200
aeff0200
ffae4000
aeff0200
aeff0200
ffae4000
aeff0200
ffae4000
-
{c=>0,a=>124,b=>1,d=>0}
7c000100
7c000100
7c000100
007c8000
7c000100
7c000100
007c8000
7c000100
007c8000
-
{c=>0,a=>-85,b=>0,d=>1}
abff0400
abff0400
abff0400
ffab2000
abff0400
abff0400
ffab2000
abff0400
ffab2000
=
struct mixed {
  short a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
};
-
{e=>-1,c=>0,a=>92,b=>1,d=>0}
5c000900
5c000900
5c000900
005c9000
5c000900
5c000900
005c9000
5c000900
005c9000
-
{e=>0,c=>0,a=>104,b=>1,d=>0}
68000100
68000100
68000100
00688000
68000100
68000100
00688000
68000100
00688000
-
{e=>-1,c=>-1,a=>-96,b=>1,d=>0}
a0ff0b00
a0ff0b00
a0ff0b00
ffa0d000
a0ff0b00
a0ff0b00
ffa0d000
a0ff0b00
ffa0d000
-
{e=>0,c=>0,a=>-66,b=>0,d=>1}
beff0400
beff0400
beff0400
ffbe2000
beff0400
beff0400
ffbe2000
beff0400
ffbe2000
-
{e=>0,c=>0,a=>126,b=>0,d=>0}
7e000000
7e000000
7e000000
007e0000
7e000000
7e000000
007e0000
7e000000
007e0000
=
struct mixed {
  short a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
};
-
{e=>0,c=>0,a=>-15,b=>1,d=>1,f=>1}
f1ff1500
f1ff1500
f1ff1500
fff1a800
f1ff1500
f1ff1500
fff1a800
f1ff1500
fff1a800
-
{e=>-1,c=>-1,a=>15,b=>0,d=>0,f=>1}
0f001a00
0f001a00
0f001a00
000f5800
0f001a00
0f001a00
000f5800
0f001a00
000f5800
-
{e=>-1,c=>-1,a=>75,b=>1,d=>1,f=>1}
4b001f00
4b001f00
4b001f00
004bf800
4b001f00
4b001f00
004bf800
4b001f00
004bf800
-
{e=>0,c=>0,a=>127,b=>0,d=>0,f=>1}
7f001000
7f001000
7f001000
007f0800
7f001000
7f001000
007f0800
7f001000
007f0800
-
{e=>-1,c=>-1,a=>0,b=>0,d=>0,f=>0}
00000a00
00000a00
00000a00
00005000
00000a00
00000a00
00005000
00000a00
00005000
=
struct mixed {
  short a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
};
-
{e=>-1,c=>0,a=>-96,g=>0,b=>0,d=>1,f=>0}
a0ff0c00
a0ff0c00
a0ff0c00
ffa03000
a0ff0c00
a0ff0c00
ffa03000
a0ff0c00
ffa03000
-
{e=>-1,c=>-1,a=>-116,g=>-1,b=>0,d=>1,f=>1}
8cff3e00
8cff3e00
8cff3e00
ff8c7c00
8cff3e00
8cff3e00
ff8c7c00
8cff3e00
ff8c7c00
-
{e=>0,c=>0,a=>16,g=>0,b=>1,d=>0,f=>1}
10001100
10001100
10001100
00108800
10001100
10001100
00108800
10001100
00108800
-
{e=>-1,c=>0,a=>108,g=>-1,b=>1,d=>0,f=>1}
6c003900
6c003900
6c003900
006c9c00
6c003900
6c003900
006c9c00
6c003900
006c9c00
-
{e=>-1,c=>0,a=>89,g=>0,b=>1,d=>1,f=>0}
59000d00
59000d00
59000d00
0059b000
59000d00
59000d00
0059b000
59000d00
0059b000
=
struct mixed {
  short a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
  unsigned long  h:1;
};
-
{e=>0,a=>-94,d=>1,c=>0,h=>1,b=>0,g=>0,f=>0}
a2ff4400
a2ff440000000000
a2ff440000000000
ffa22200
a2ff4400
a2ff4400
ffa2220000000000
a2ff4400
ffa22200
-
{e=>-1,a=>-38,d=>1,c=>0,h=>0,b=>1,g=>-1,f=>1}
daff3d00
daff3d0000000000
daff3d0000000000
ffdabc00
daff3d00
daff3d00
ffdabc0000000000
daff3d00
ffdabc00
-
{e=>0,a=>-42,d=>0,c=>0,h=>0,b=>0,g=>-1,f=>0}
d6ff2000
d6ff200000000000
d6ff200000000000
ffd60400
d6ff2000
d6ff2000
ffd6040000000000
d6ff2000
ffd60400
-
{e=>0,a=>-80,d=>0,c=>0,h=>1,b=>0,g=>0,f=>0}
b0ff4000
b0ff400000000000
b0ff400000000000
ffb00200
b0ff4000
b0ff4000
ffb0020000000000
b0ff4000
ffb00200
-
{e=>0,a=>-7,d=>0,c=>0,h=>1,b=>1,g=>0,f=>1}
f9ff5100
f9ff510000000000
f9ff510000000000
fff98a00
f9ff5100
f9ff5100
fff98a0000000000
f9ff5100
fff98a00
=
struct mixed {
  short a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
  unsigned long  h:1;
  signed   long  i:1;
};
-
{e=>-1,a=>106,d=>1,c=>-1,h=>0,b=>1,g=>0,f=>1,i=>0}
6a001f00
6a001f0000000000
6a001f0000000000
006af800
6a001f00
6a001f00
006af80000000000
6a001f00
006af800
-
{e=>0,a=>10,d=>0,c=>0,h=>1,b=>0,g=>-1,f=>0,i=>-1}
0a00e000
0a00e00000000000
0a00e00000000000
000a0700
0a00e000
0a00e000
000a070000000000
0a00e000
000a0700
-
{e=>-1,a=>93,d=>1,c=>0,h=>0,b=>0,g=>0,f=>0,i=>0}
5d000c00
5d000c0000000000
5d000c0000000000
005d3000
5d000c00
5d000c00
005d300000000000
5d000c00
005d3000
-
{e=>-1,a=>-24,d=>0,c=>0,h=>1,b=>1,g=>0,f=>1,i=>0}
e8ff5900
e8ff590000000000
e8ff590000000000
ffe89a00
e8ff5900
e8ff5900
ffe89a0000000000
e8ff5900
ffe89a00
-
{e=>0,a=>-98,d=>0,c=>0,h=>1,b=>0,g=>-1,f=>1,i=>-1}
9efff000
9efff00000000000
9efff00000000000
ff9e0f00
9efff000
9efff000
ff9e0f0000000000
9efff000
ff9e0f00
=
struct mixed {
  short a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
  unsigned long  h:1;
  signed   long  i:1;
  unsigned char  j;
};
-
{e=>-1,a=>-30,d=>0,j=>167,c=>0,h=>1,b=>1,g=>0,f=>0,i=>0}
e2ff49a7
e2ff49a700000000
e2ff49a700000000
ffe292a7
e2ff49a7
e2ff49a7
ffe292a700000000
e2ff49a7
ffe292a7
-
{e=>0,a=>34,d=>1,j=>13,c=>0,h=>1,b=>1,g=>0,f=>0,i=>-1}
2200c50d
2200c50d00000000
2200c50d00000000
0022a30d
2200c50d
2200c50d
0022a30d00000000
2200c50d
0022a30d
-
{e=>-1,a=>-125,d=>0,j=>209,c=>0,h=>0,b=>0,g=>0,f=>0,i=>0}
83ff08d1
83ff08d100000000
83ff08d100000000
ff8310d1
83ff08d1
83ff08d1
ff8310d100000000
83ff08d1
ff8310d1
-
{e=>0,a=>57,d=>0,j=>197,c=>0,h=>0,b=>0,g=>-1,f=>1,i=>-1}
3900b0c5
3900b0c500000000
3900b0c500000000
00390dc5
3900b0c5
3900b0c5
00390dc500000000
3900b0c5
00390dc5
-
{e=>-1,a=>101,d=>1,j=>141,c=>-1,h=>0,b=>1,g=>0,f=>1,i=>-1}
65009f8d
65009f8d00000000
65009f8d00000000
0065f98d
65009f8d
65009f8d
0065f98d00000000
65009f8d
0065f98d
=
struct mixed {
  int a;
  unsigned char  b:1;
};
-
{a=>59,b=>1}
3b00000001000000
3b00000001000000
3b00000001000000
0000003b80000000
3b00000001000000
3b00000001000000
0000003b80000000
3b00000001000000
0000003b80000000
-
{a=>25,b=>0}
1900000000000000
1900000000000000
1900000000000000
0000001900000000
1900000000000000
1900000000000000
0000001900000000
1900000000000000
0000001900000000
-
{a=>-69,b=>1}
bbffffff01000000
bbffffff01000000
bbffffff01000000
ffffffbb80000000
bbffffff01000000
bbffffff01000000
ffffffbb80000000
bbffffff01000000
ffffffbb80000000
-
{a=>106,b=>0}
6a00000000000000
6a00000000000000
6a00000000000000
0000006a00000000
6a00000000000000
6a00000000000000
0000006a00000000
6a00000000000000
0000006a00000000
-
{a=>112,b=>1}
7000000001000000
7000000001000000
7000000001000000
0000007080000000
7000000001000000
7000000001000000
0000007080000000
7000000001000000
0000007080000000
=
struct mixed {
  int a;
  unsigned char  b:1;
  signed   char  c:1;
};
-
{c=>-1,a=>17,b=>0}
1100000002000000
1100000002000000
1100000002000000
0000001140000000
1100000002000000
1100000002000000
0000001140000000
1100000002000000
0000001140000000
-
{c=>-1,a=>-75,b=>1}
b5ffffff03000000
b5ffffff03000000
b5ffffff03000000
ffffffb5c0000000
b5ffffff03000000
b5ffffff03000000
ffffffb5c0000000
b5ffffff03000000
ffffffb5c0000000
-
{c=>-1,a=>86,b=>0}
5600000002000000
5600000002000000
5600000002000000
0000005640000000
5600000002000000
5600000002000000
0000005640000000
5600000002000000
0000005640000000
-
{c=>0,a=>-126,b=>1}
82ffffff01000000
82ffffff01000000
82ffffff01000000
ffffff8280000000
82ffffff01000000
82ffffff01000000
ffffff8280000000
82ffffff01000000
ffffff8280000000
-
{c=>-1,a=>49,b=>1}
3100000003000000
3100000003000000
3100000003000000
00000031c0000000
3100000003000000
3100000003000000
00000031c0000000
3100000003000000
00000031c0000000
=
struct mixed {
  int a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
};
-
{c=>-1,a=>-126,b=>0,d=>0}
82ffffff02000000
82ffffff02000000
82ffffff02000000
ffffff8240000000
82ffffff02000000
82ffffff02000000
ffffff8240000000
82ffffff02000000
ffffff8240000000
-
{c=>0,a=>-97,b=>0,d=>1}
9fffffff04000000
9fffffff04000000
9fffffff04000000
ffffff9f20000000
9fffffff04000000
9fffffff04000000
ffffff9f20000000
9fffffff04000000
ffffff9f20000000
-
{c=>0,a=>25,b=>0,d=>0}
1900000000000000
1900000000000000
1900000000000000
0000001900000000
1900000000000000
1900000000000000
0000001900000000
1900000000000000
0000001900000000
-
{c=>0,a=>-28,b=>1,d=>1}
e4ffffff05000000
e4ffffff05000000
e4ffffff05000000
ffffffe4a0000000
e4ffffff05000000
e4ffffff05000000
ffffffe4a0000000
e4ffffff05000000
ffffffe4a0000000
-
{c=>-1,a=>112,b=>1,d=>0}
7000000003000000
7000000003000000
7000000003000000
00000070c0000000
7000000003000000
7000000003000000
00000070c0000000
7000000003000000
00000070c0000000
=
struct mixed {
  int a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
};
-
{e=>0,c=>-1,a=>122,b=>0,d=>1}
7a00000006000000
7a00000006000000
7a00000006000000
0000007a60000000
7a00000006000000
7a00000006000000
0000007a60000000
7a00000006000000
0000007a60000000
-
{e=>-1,c=>-1,a=>-41,b=>1,d=>0}
d7ffffff0b000000
d7ffffff0b000000
d7ffffff0b000000
ffffffd7d0000000
d7ffffff0b000000
d7ffffff0b000000
ffffffd7d0000000
d7ffffff0b000000
ffffffd7d0000000
-
{e=>-1,c=>-1,a=>67,b=>0,d=>0}
430000000a000000
430000000a000000
430000000a000000
0000004350000000
430000000a000000
430000000a000000
0000004350000000
430000000a000000
0000004350000000
-
{e=>0,c=>0,a=>-109,b=>0,d=>1}
93ffffff04000000
93ffffff04000000
93ffffff04000000
ffffff9320000000
93ffffff04000000
93ffffff04000000
ffffff9320000000
93ffffff04000000
ffffff9320000000
-
{e=>0,c=>0,a=>-80,b=>1,d=>0}
b0ffffff01000000
b0ffffff01000000
b0ffffff01000000
ffffffb080000000
b0ffffff01000000
b0ffffff01000000
ffffffb080000000
b0ffffff01000000
ffffffb080000000
=
struct mixed {
  int a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
};
-
{e=>0,c=>-1,a=>-35,b=>1,d=>0,f=>0}
ddffffff03000000
ddffffff03000000
ddffffff03000000
ffffffddc0000000
ddffffff03000000
ddffffff03000000
ffffffddc0000000
ddffffff03000000
ffffffddc0000000
-
{e=>-1,c=>-1,a=>-61,b=>0,d=>0,f=>0}
c3ffffff0a000000
c3ffffff0a000000
c3ffffff0a000000
ffffffc350000000
c3ffffff0a000000
c3ffffff0a000000
ffffffc350000000
c3ffffff0a000000
ffffffc350000000
-
{e=>0,c=>0,a=>94,b=>0,d=>0,f=>1}
5e00000010000000
5e00000010000000
5e00000010000000
0000005e08000000
5e00000010000000
5e00000010000000
0000005e08000000
5e00000010000000
0000005e08000000
-
{e=>0,c=>-1,a=>-17,b=>0,d=>0,f=>0}
efffffff02000000
efffffff02000000
efffffff02000000
ffffffef40000000
efffffff02000000
efffffff02000000
ffffffef40000000
efffffff02000000
ffffffef40000000
-
{e=>-1,c=>-1,a=>-4,b=>0,d=>1,f=>0}
fcffffff0e000000
fcffffff0e000000
fcffffff0e000000
fffffffc70000000
fcffffff0e000000
fcffffff0e000000
fffffffc70000000
fcffffff0e000000
fffffffc70000000
=
struct mixed {
  int a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
};
-
{e=>-1,c=>-1,a=>66,g=>0,b=>0,d=>0,f=>1}
420000001a000000
420000001a000000
420000001a000000
0000004258000000
420000001a000000
420000001a000000
0000004258000000
420000001a000000
0000004258000000
-
{e=>0,c=>-1,a=>88,g=>-1,b=>0,d=>1,f=>1}
5800000036000000
5800000036000000
5800000036000000
000000586c000000
5800000036000000
5800000036000000
000000586c000000
5800000036000000
000000586c000000
-
{e=>-1,c=>0,a=>22,g=>0,b=>0,d=>0,f=>0}
1600000008000000
1600000008000000
1600000008000000
0000001610000000
1600000008000000
1600000008000000
0000001610000000
1600000008000000
0000001610000000
-
{e=>0,c=>-1,a=>54,g=>-1,b=>0,d=>0,f=>1}
3600000032000000
3600000032000000
3600000032000000
000000364c000000
3600000032000000
3600000032000000
000000364c000000
3600000032000000
000000364c000000
-
{e=>-1,c=>-1,a=>98,g=>-1,b=>0,d=>0,f=>0}
620000002a000000
620000002a000000
620000002a000000
0000006254000000
620000002a000000
620000002a000000
0000006254000000
620000002a000000
0000006254000000
=
struct mixed {
  int a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
  unsigned long  h:1;
};
-
{e=>-1,a=>-102,d=>1,c=>0,h=>0,b=>1,g=>-1,f=>0}
9affffff2d000000
9affffff2d000000
9affffff2d000000
ffffff9ab4000000
9affffff2d000000
9affffff2d000000
ffffff9ab4000000
9affffff2d000000
ffffff9ab4000000
-
{e=>-1,a=>84,d=>1,c=>0,h=>0,b=>0,g=>0,f=>0}
540000000c000000
540000000c000000
540000000c000000
0000005430000000
540000000c000000
540000000c000000
0000005430000000
540000000c000000
0000005430000000
-
{e=>-1,a=>-63,d=>1,c=>-1,h=>0,b=>1,g=>0,f=>0}
c1ffffff0f000000
c1ffffff0f000000
c1ffffff0f000000
ffffffc1f0000000
c1ffffff0f000000
c1ffffff0f000000
ffffffc1f0000000
c1ffffff0f000000
ffffffc1f0000000
-
{e=>0,a=>-36,d=>0,c=>0,h=>0,b=>1,g=>-1,f=>1}
dcffffff31000000
dcffffff31000000
dcffffff31000000
ffffffdc8c000000
dcffffff31000000
dcffffff31000000
ffffffdc8c000000
dcffffff31000000
ffffffdc8c000000
-
{e=>0,a=>17,d=>0,c=>0,h=>0,b=>1,g=>-1,f=>0}
1100000021000000
1100000021000000
1100000021000000
0000001184000000
1100000021000000
1100000021000000
0000001184000000
1100000021000000
0000001184000000
=
struct mixed {
  int a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
  unsigned long  h:1;
  signed   long  i:1;
};
-
{e=>0,a=>98,d=>1,c=>0,h=>1,b=>0,g=>-1,f=>0,i=>-1}
62000000e4000000
62000000e4000000
62000000e4000000
0000006227000000
62000000e4000000
62000000e4000000
0000006227000000
62000000e4000000
0000006227000000
-
{e=>0,a=>-97,d=>0,c=>-1,h=>0,b=>1,g=>0,f=>1,i=>-1}
9fffffff93000000
9fffffff93000000
9fffffff93000000
ffffff9fc9000000
9fffffff93000000
9fffffff93000000
ffffff9fc9000000
9fffffff93000000
ffffff9fc9000000
-
{e=>-1,a=>15,d=>1,c=>-1,h=>0,b=>0,g=>0,f=>1,i=>0}
0f0000001e000000
0f0000001e000000
0f0000001e000000
0000000f78000000
0f0000001e000000
0f0000001e000000
0000000f78000000
0f0000001e000000
0000000f78000000
-
{e=>-1,a=>-3,d=>0,c=>-1,h=>0,b=>1,g=>0,f=>1,i=>0}
fdffffff1b000000
fdffffff1b000000
fdffffff1b000000
fffffffdd8000000
fdffffff1b000000
fdffffff1b000000
fffffffdd8000000
fdffffff1b000000
fffffffdd8000000
-
{e=>0,a=>101,d=>1,c=>0,h=>0,b=>0,g=>-1,f=>1,i=>-1}
65000000b4000000
65000000b4000000
65000000b4000000
000000652d000000
65000000b4000000
65000000b4000000
000000652d000000
65000000b4000000
000000652d000000
=
struct mixed {
  int a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
  unsigned long  h:1;
  signed   long  i:1;
  unsigned char  j;
};
-
{e=>-1,a=>-121,d=>1,j=>162,c=>0,h=>1,b=>0,g=>-1,f=>0,i=>0}
87ffffff6ca20000
87ffffff6ca20000
87ffffff6ca20000
ffffff8736a20000
87ffffff6ca20000
87ffffff6ca20000
ffffff8736a20000
87ffffff6ca20000
ffffff8736a20000
-
{e=>0,a=>-14,d=>1,j=>104,c=>-1,h=>0,b=>0,g=>0,f=>1,i=>-1}
f2ffffff96680000
f2ffffff96680000
f2ffffff96680000
fffffff269680000
f2ffffff96680000
f2ffffff96680000
fffffff269680000
f2ffffff96680000
fffffff269680000
-
{e=>-1,a=>4,d=>0,j=>93,c=>-1,h=>0,b=>0,g=>0,f=>1,i=>0}
040000001a5d0000
040000001a5d0000
040000001a5d0000
00000004585d0000
040000001a5d0000
040000001a5d0000
00000004585d0000
040000001a5d0000
00000004585d0000
-
{e=>-1,a=>17,d=>0,j=>133,c=>0,h=>0,b=>1,g=>0,f=>0,i=>0}
1100000009850000
1100000009850000
1100000009850000
0000001190850000
1100000009850000
1100000009850000
0000001190850000
1100000009850000
0000001190850000
-
{e=>0,a=>56,d=>0,j=>65,c=>-1,h=>0,b=>0,g=>-1,f=>0,i=>-1}
38000000a2410000
38000000a2410000
38000000a2410000
0000003845410000
38000000a2410000
38000000a2410000
0000003845410000
38000000a2410000
0000003845410000
=
struct mixed {
  long a;
  unsigned char  b:1;
};
-
{a=>99,b=>1}
6300000001000000
63000000000000000100000000000000
63000000000000000100000000000000
0000006380000000
6300000001000000
6300000001000000
00000000000000638000000000000000
6300000001000000
0000006380000000
-
{a=>8,b=>0}
0800000000000000
08000000000000000000000000000000
08000000000000000000000000000000
0000000800000000
0800000000000000
0800000000000000
00000000000000080000000000000000
0800000000000000
0000000800000000
-
{a=>-122,b=>0}
86ffffff00000000
86ffffffffffffff0000000000000000
86ffffffffffffff0000000000000000
ffffff8600000000
86ffffff00000000
86ffffff00000000
ffffffffffffff860000000000000000
86ffffff00000000
ffffff8600000000
-
{a=>-2,b=>1}
feffffff01000000
feffffffffffffff0100000000000000
feffffffffffffff0100000000000000
fffffffe80000000
feffffff01000000
feffffff01000000
fffffffffffffffe8000000000000000
feffffff01000000
fffffffe80000000
-
{a=>102,b=>0}
6600000000000000
66000000000000000000000000000000
66000000000000000000000000000000
0000006600000000
6600000000000000
6600000000000000
00000000000000660000000000000000
6600000000000000
0000006600000000
=
struct mixed {
  long a;
  unsigned char  b:1;
  signed   char  c:1;
};
-
{c=>-1,a=>96,b=>0}
6000000002000000
60000000000000000200000000000000
60000000000000000200000000000000
0000006040000000
6000000002000000
6000000002000000
00000000000000604000000000000000
6000000002000000
0000006040000000
-
{c=>-1,a=>59,b=>0}
3b00000002000000
3b000000000000000200000000000000
3b000000000000000200000000000000
0000003b40000000
3b00000002000000
3b00000002000000
000000000000003b4000000000000000
3b00000002000000
0000003b40000000
-
{c=>-1,a=>120,b=>1}
7800000003000000
78000000000000000300000000000000
78000000000000000300000000000000
00000078c0000000
7800000003000000
7800000003000000
0000000000000078c000000000000000
7800000003000000
00000078c0000000
-
{c=>0,a=>-13,b=>1}
f3ffffff01000000
f3ffffffffffffff0100000000000000
f3ffffffffffffff0100000000000000
fffffff380000000
f3ffffff01000000
f3ffffff01000000
fffffffffffffff38000000000000000
f3ffffff01000000
fffffff380000000
-
{c=>0,a=>-28,b=>0}
e4ffffff00000000
e4ffffffffffffff0000000000000000
e4ffffffffffffff0000000000000000
ffffffe400000000
e4ffffff00000000
e4ffffff00000000
ffffffffffffffe40000000000000000
e4ffffff00000000
ffffffe400000000
=
struct mixed {
  long a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
};
-
{c=>0,a=>109,b=>1,d=>0}
6d00000001000000
6d000000000000000100000000000000
6d000000000000000100000000000000
0000006d80000000
6d00000001000000
6d00000001000000
000000000000006d8000000000000000
6d00000001000000
0000006d80000000
-
{c=>0,a=>107,b=>0,d=>0}
6b00000000000000
6b000000000000000000000000000000
6b000000000000000000000000000000
0000006b00000000
6b00000000000000
6b00000000000000
000000000000006b0000000000000000
6b00000000000000
0000006b00000000
-
{c=>0,a=>28,b=>1,d=>1}
1c00000005000000
1c000000000000000500000000000000
1c000000000000000500000000000000
0000001ca0000000
1c00000005000000
1c00000005000000
000000000000001ca000000000000000
1c00000005000000
0000001ca0000000
-
{c=>0,a=>72,b=>0,d=>1}
4800000004000000
48000000000000000400000000000000
48000000000000000400000000000000
0000004820000000
4800000004000000
4800000004000000
00000000000000482000000000000000
4800000004000000
0000004820000000
-
{c=>0,a=>-52,b=>0,d=>1}
ccffffff04000000
ccffffffffffffff0400000000000000
ccffffffffffffff0400000000000000
ffffffcc20000000
ccffffff04000000
ccffffff04000000
ffffffffffffffcc2000000000000000
ccffffff04000000
ffffffcc20000000
=
struct mixed {
  long a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
};
-
{e=>0,c=>0,a=>25,b=>0,d=>1}
1900000004000000
19000000000000000400000000000000
19000000000000000400000000000000
0000001920000000
1900000004000000
1900000004000000
00000000000000192000000000000000
1900000004000000
0000001920000000
-
{e=>-1,c=>-1,a=>59,b=>1,d=>1}
3b0000000f000000
3b000000000000000f00000000000000
3b000000000000000f00000000000000
0000003bf0000000
3b0000000f000000
3b0000000f000000
000000000000003bf000000000000000
3b0000000f000000
0000003bf0000000
-
{e=>-1,c=>0,a=>124,b=>0,d=>1}
7c0000000c000000
7c000000000000000c00000000000000
7c000000000000000c00000000000000
0000007c30000000
7c0000000c000000
7c0000000c000000
000000000000007c3000000000000000
7c0000000c000000
0000007c30000000
-
{e=>-1,c=>0,a=>74,b=>0,d=>0}
4a00000008000000
4a000000000000000800000000000000
4a000000000000000800000000000000
0000004a10000000
4a00000008000000
4a00000008000000
000000000000004a1000000000000000
4a00000008000000
0000004a10000000
-
{e=>-1,c=>0,a=>-39,b=>0,d=>1}
d9ffffff0c000000
d9ffffffffffffff0c00000000000000
d9ffffffffffffff0c00000000000000
ffffffd930000000
d9ffffff0c000000
d9ffffff0c000000
ffffffffffffffd93000000000000000
d9ffffff0c000000
ffffffd930000000
=
struct mixed {
  long a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
};
-
{e=>-1,c=>-1,a=>-33,b=>0,d=>0,f=>0}
dfffffff0a000000
dfffffffffffffff0a00000000000000
dfffffffffffffff0a00000000000000
ffffffdf50000000
dfffffff0a000000
dfffffff0a000000
ffffffffffffffdf5000000000000000
dfffffff0a000000
ffffffdf50000000
-
{e=>0,c=>0,a=>-57,b=>1,d=>0,f=>0}
c7ffffff01000000
c7ffffffffffffff0100000000000000
c7ffffffffffffff0100000000000000
ffffffc780000000
c7ffffff01000000
c7ffffff01000000
ffffffffffffffc78000000000000000
c7ffffff01000000
ffffffc780000000
-
{e=>0,c=>-1,a=>-10,b=>0,d=>1,f=>0}
f6ffffff06000000
f6ffffffffffffff0600000000000000
f6ffffffffffffff0600000000000000
fffffff660000000
f6ffffff06000000
f6ffffff06000000
fffffffffffffff66000000000000000
f6ffffff06000000
fffffff660000000
-
{e=>0,c=>-1,a=>52,b=>0,d=>0,f=>1}
3400000012000000
34000000000000001200000000000000
34000000000000001200000000000000
0000003448000000
3400000012000000
3400000012000000
00000000000000344800000000000000
3400000012000000
0000003448000000
-
{e=>-1,c=>0,a=>127,b=>0,d=>0,f=>0}
7f00000008000000
7f000000000000000800000000000000
7f000000000000000800000000000000
0000007f10000000
7f00000008000000
7f00000008000000
000000000000007f1000000000000000
7f00000008000000
0000007f10000000
=
struct mixed {
  long a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
};
-
{e=>0,c=>-1,a=>-7,g=>0,b=>0,d=>0,f=>1}
f9ffffff12000000
f9ffffffffffffff1200000000000000
f9ffffffffffffff1200000000000000
fffffff948000000
f9ffffff12000000
f9ffffff12000000
fffffffffffffff94800000000000000
f9ffffff12000000
fffffff948000000
-
{e=>0,c=>0,a=>18,g=>-1,b=>1,d=>0,f=>1}
1200000031000000
12000000000000003100000000000000
12000000000000003100000000000000
000000128c000000
1200000031000000
1200000031000000
00000000000000128c00000000000000
1200000031000000
000000128c000000
-
{e=>-1,c=>-1,a=>84,g=>0,b=>0,d=>1,f=>1}
540000001e000000
54000000000000001e00000000000000
54000000000000001e00000000000000
0000005478000000
540000001e000000
540000001e000000
00000000000000547800000000000000
540000001e000000
0000005478000000
-
{e=>0,c=>-1,a=>21,g=>0,b=>0,d=>1,f=>0}
1500000006000000
15000000000000000600000000000000
15000000000000000600000000000000
0000001560000000
1500000006000000
1500000006000000
00000000000000156000000000000000
1500000006000000
0000001560000000
-
{e=>-1,c=>-1,a=>-2,g=>-1,b=>1,d=>0,f=>1}
feffffff3b000000
feffffffffffffff3b00000000000000
feffffffffffffff3b00000000000000
fffffffedc000000
feffffff3b000000
feffffff3b000000
fffffffffffffffedc00000000000000
feffffff3b000000
fffffffedc000000
=
struct mixed {
  long a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
  unsigned long  h:1;
};
-
{e=>-1,a=>11,d=>0,c=>0,h=>1,b=>1,g=>0,f=>1}
0b00000059000000
0b000000000000005900000000000000
0b000000000000005900000000000000
0000000b9a000000
0b00000059000000
0b00000059000000
000000000000000b9a00000000000000
0b00000059000000
0000000b9a000000
-
{e=>0,a=>-17,d=>0,c=>0,h=>1,b=>0,g=>0,f=>0}
efffffff40000000
efffffffffffffff4000000000000000
efffffffffffffff4000000000000000
ffffffef02000000
efffffff40000000
efffffff40000000
ffffffffffffffef0200000000000000
efffffff40000000
ffffffef02000000
-
{e=>-1,a=>2,d=>1,c=>-1,h=>0,b=>1,g=>0,f=>0}
020000000f000000
02000000000000000f00000000000000
02000000000000000f00000000000000
00000002f0000000
020000000f000000
020000000f000000
0000000000000002f000000000000000
020000000f000000
00000002f0000000
-
{e=>0,a=>6,d=>1,c=>-1,h=>0,b=>1,g=>-1,f=>1}
0600000037000000
06000000000000003700000000000000
06000000000000003700000000000000
00000006ec000000
0600000037000000
0600000037000000
0000000000000006ec00000000000000
0600000037000000
00000006ec000000
-
{e=>0,a=>103,d=>0,c=>0,h=>0,b=>1,g=>-1,f=>0}
6700000021000000
67000000000000002100000000000000
67000000000000002100000000000000
0000006784000000
6700000021000000
6700000021000000
00000000000000678400000000000000
6700000021000000
0000006784000000
=
struct mixed {
  long a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
  unsigned long  h:1;
  signed   long  i:1;
};
-
{e=>-1,a=>-66,d=>0,c=>0,h=>0,b=>1,g=>0,f=>1,i=>-1}
beffffff99000000
beffffffffffffff9900000000000000
beffffffffffffff9900000000000000
ffffffbe99000000
beffffff99000000
beffffff99000000
ffffffffffffffbe9900000000000000
beffffff99000000
ffffffbe99000000
-
{e=>0,a=>-106,d=>0,c=>0,h=>1,b=>0,g=>-1,f=>0,i=>0}
96ffffff60000000
96ffffffffffffff6000000000000000
96ffffffffffffff6000000000000000
ffffff9606000000
96ffffff60000000
96ffffff60000000
ffffffffffffff960600000000000000
96ffffff60000000
ffffff9606000000
-
{e=>-1,a=>-86,d=>0,c=>0,h=>0,b=>1,g=>0,f=>0,i=>0}
aaffffff09000000
aaffffffffffffff0900000000000000
aaffffffffffffff0900000000000000
ffffffaa90000000
aaffffff09000000
aaffffff09000000
ffffffffffffffaa9000000000000000
aaffffff09000000
ffffffaa90000000
-
{e=>-1,a=>-98,d=>0,c=>0,h=>0,b=>0,g=>0,f=>1,i=>0}
9effffff18000000
9effffffffffffff1800000000000000
9effffffffffffff1800000000000000
ffffff9e18000000
9effffff18000000
9effffff18000000
ffffffffffffff9e1800000000000000
9effffff18000000
ffffff9e18000000
-
{e=>0,a=>40,d=>0,c=>0,h=>1,b=>1,g=>0,f=>1,i=>0}
2800000051000000
28000000000000005100000000000000
28000000000000005100000000000000
000000288a000000
2800000051000000
2800000051000000
00000000000000288a00000000000000
2800000051000000
000000288a000000
=
struct mixed {
  long a;
  unsigned char  b:1;
  signed   char  c:1;
  unsigned short d:1;
  signed   short e:1;
  unsigned int   f:1;
  signed   int   g:1;
  unsigned long  h:1;
  signed   long  i:1;
  unsigned char  j;
};
-
{e=>-1,a=>-49,d=>1,j=>205,c=>0,h=>0,b=>1,g=>0,f=>1,i=>-1}
cfffffff9dcd0000
cfffffffffffffff9dcd000000000000
cfffffffffffffff9dcd000000000000
ffffffcfb9cd0000
cfffffff9dcd0000
cfffffff9dcd0000
ffffffffffffffcfb9cd000000000000
cfffffff9dcd0000
ffffffcfb9cd0000
-
{e=>-1,a=>126,d=>0,j=>0,c=>-1,h=>1,b=>1,g=>-1,f=>0,i=>0}
7e0000006b000000
7e000000000000006b00000000000000
7e000000000000006b00000000000000
0000007ed6000000
7e0000006b000000
7e0000006b000000
000000000000007ed600000000000000
7e0000006b000000
0000007ed6000000
-
{e=>0,a=>-31,d=>0,j=>105,c=>-1,h=>0,b=>1,g=>0,f=>0,i=>-1}
e1ffffff83690000
e1ffffffffffffff8369000000000000
e1ffffffffffffff8369000000000000
ffffffe1c1690000
e1ffffff83690000
e1ffffff83690000
ffffffffffffffe1c169000000000000
e1ffffff83690000
ffffffe1c1690000
-
{e=>-1,a=>-1,d=>1,j=>21,c=>-1,h=>0,b=>1,g=>-1,f=>0,i=>0}
ffffffff2f150000
ffffffffffffffff2f15000000000000
ffffffffffffffff2f15000000000000
fffffffff4150000
ffffffff2f150000
ffffffff2f150000
fffffffffffffffff415000000000000
ffffffff2f150000
fffffffff4150000
-
{e=>-1,a=>99,d=>0,j=>132,c=>0,h=>0,b=>0,g=>0,f=>1,i=>0}
6300000018840000
63000000000000001884000000000000
63000000000000001884000000000000
0000006318840000
6300000018840000
6300000018840000
00000000000000631884000000000000
6300000018840000
0000006318840000
=
struct force_align1 {
  unsigned char a:1;
};
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>1}
01
01
01
80
01000000
01
80
01
80
-
{a=>1}
01
01
01
80
01000000
01
80
01
80
-
{a=>1}
01
01
01
80
01000000
01
80
01
80
-
{a=>1}
01
01
01
80
01000000
01
80
01
80
=
struct force_align1 {
  unsigned char a:1;
  unsigned char b:1;
};
-
{a=>1,b=>1}
03
03
03
c0
03000000
03
c0
03
c0
-
{a=>1,b=>1}
03
03
03
c0
03000000
03
c0
03
c0
-
{a=>0,b=>1}
02
02
02
40
02000000
02
40
02
40
-
{a=>0,b=>1}
02
02
02
40
02000000
02
40
02
40
-
{a=>1,b=>1}
03
03
03
c0
03000000
03
c0
03
c0
=
struct force_align1 {
  unsigned char a:1;
  unsigned char b:1;
  unsigned char  :0;
};
-
{a=>0,b=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>0,b=>1}
02
02
02
40
02000000
02
40
02
40
-
{a=>0,b=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>1,b=>1}
03
03
03
c0
03000000
03
c0
03
c0
-
{a=>1,b=>0}
01
01
01
80
01000000
01
80
01
80
=
struct force_align1 {
  unsigned char a:1;
  unsigned char b:1;
  unsigned char  :0;
  unsigned char c:1;
};
-
{c=>1,a=>1,b=>0}
0101
0101
0101
8080
01010000
0101
8080
0101
8080
-
{c=>1,a=>1,b=>1}
0301
0301
0301
c080
03010000
0301
c080
0301
c080
-
{c=>0,a=>1,b=>1}
0300
0300
0300
c000
03000000
0300
c000
0300
c000
-
{c=>0,a=>0,b=>0}
0000
0000
0000
0000
00000000
0000
0000
0000
0000
-
{c=>0,a=>1,b=>0}
0100
0100
0100
8000
01000000
0100
8000
0100
8000
=
struct force_align1 {
  unsigned char a:1;
  unsigned char b:1;
  unsigned char  :0;
  unsigned char c:1;
  unsigned int  d;
};
-
{c=>0,a=>0,b=>1,d=>114}
0200000072000000
0200000072000000
0200000072000000
4000000000000072
0200000072000000
0200000072000000
4000000000000072
0200000072000000
4000000000000072
-
{c=>0,a=>1,b=>0,d=>177}
01000000b1000000
01000000b1000000
01000000b1000000
80000000000000b1
01000000b1000000
01000000b1000000
80000000000000b1
01000000b1000000
80000000000000b1
-
{c=>1,a=>1,b=>1,d=>163}
03010000a3000000
03010000a3000000
03010000a3000000
c0800000000000a3
03010000a3000000
03010000a3000000
c0800000000000a3
03010000a3000000
c0800000000000a3
-
{c=>0,a=>0,b=>1,d=>180}
02000000b4000000
02000000b4000000
02000000b4000000
40000000000000b4
02000000b4000000
02000000b4000000
40000000000000b4
02000000b4000000
40000000000000b4
-
{c=>0,a=>1,b=>0,d=>131}
0100000083000000
0100000083000000
0100000083000000
8000000000000083
0100000083000000
0100000083000000
8000000000000083
0100000083000000
8000000000000083
=
struct force_align1 {
  char a;
  unsigned char b:1;
};
-
{a=>105,b=>1}
6901
6901
6901
6980
69010000
6901
6980
6901
6980
-
{a=>-17,b=>1}
ef01
ef01
ef01
ef80
ef010000
ef01
ef80
ef01
ef80
-
{a=>-128,b=>1}
8001
8001
8001
8080
80010000
8001
8080
8001
8080
-
{a=>35,b=>0}
2300
2300
2300
2300
23000000
2300
2300
2300
2300
-
{a=>-120,b=>0}
8800
8800
8800
8800
88000000
8800
8800
8800
8800
=
struct force_align1 {
  char a;
  unsigned char b:1;
  unsigned char c:1;
};
-
{c=>0,a=>87,b=>0}
5700
5700
5700
5700
57000000
5700
5700
5700
5700
-
{c=>0,a=>12,b=>1}
0c01
0c01
0c01
0c80
0c010000
0c01
0c80
0c01
0c80
-
{c=>0,a=>107,b=>0}
6b00
6b00
6b00
6b00
6b000000
6b00
6b00
6b00
6b00
-
{c=>1,a=>-100,b=>0}
9c02
9c02
9c02
9c40
9c020000
9c02
9c40
9c02
9c40
-
{c=>1,a=>-61,b=>0}
c302
c302
c302
c340
c3020000
c302
c340
c302
c340
=
struct force_align1 {
  char a;
  unsigned char b:1;
  unsigned char c:1;
  unsigned char  :0;
};
-
{c=>0,a=>-59,b=>0}
c500
c500
c500
c500
c5000000
c500
c500
c500
c500
-
{c=>0,a=>-128,b=>0}
8000
8000
8000
8000
80000000
8000
8000
8000
8000
-
{c=>0,a=>-43,b=>1}
d501
d501
d501
d580
d5010000
d501
d580
d501
d580
-
{c=>0,a=>55,b=>0}
3700
3700
3700
3700
37000000
3700
3700
3700
3700
-
{c=>0,a=>-27,b=>1}
e501
e501
e501
e580
e5010000
e501
e580
e501
e580
=
struct force_align1 {
  char a;
  unsigned char b:1;
  unsigned char c:1;
  unsigned char  :0;
  unsigned char d:1;
};
-
{c=>1,a=>-22,b=>1,d=>0}
ea0300
ea0300
ea0300
eac000
ea030000
ea0300
eac000
ea0300
eac000
-
{c=>1,a=>115,b=>1,d=>0}
730300
730300
730300
73c000
73030000
730300
73c000
730300
73c000
-
{c=>1,a=>-2,b=>0,d=>0}
fe0200
fe0200
fe0200
fe4000
fe020000
fe0200
fe4000
fe0200
fe4000
-
{c=>0,a=>-40,b=>1,d=>0}
d80100
d80100
d80100
d88000
d8010000
d80100
d88000
d80100
d88000
-
{c=>1,a=>52,b=>0,d=>0}
340200
340200
340200
344000
34020000
340200
344000
340200
344000
=
struct force_align1 {
  char a;
  unsigned char b:1;
  unsigned char c:1;
  unsigned char  :0;
  unsigned char d:1;
  unsigned int  e;
};
-
{e=>84,c=>0,a=>-2,b=>1,d=>1}
fe01010054000000
fe01010054000000
fe01010054000000
fe80800000000054
fe01010054000000
fe01010054000000
fe80800000000054
fe01010054000000
fe80800000000054
-
{e=>26,c=>1,a=>-22,b=>0,d=>1}
ea0201001a000000
ea0201001a000000
ea0201001a000000
ea4080000000001a
ea0201001a000000
ea0201001a000000
ea4080000000001a
ea0201001a000000
ea4080000000001a
-
{e=>229,c=>0,a=>-4,b=>1,d=>0}
fc010000e5000000
fc010000e5000000
fc010000e5000000
fc800000000000e5
fc010000e5000000
fc010000e5000000
fc800000000000e5
fc010000e5000000
fc800000000000e5
-
{e=>140,c=>0,a=>-121,b=>0,d=>1}
870001008c000000
870001008c000000
870001008c000000
870080000000008c
870001008c000000
870001008c000000
870080000000008c
870001008c000000
870080000000008c
-
{e=>135,c=>0,a=>23,b=>0,d=>0}
1700000087000000
1700000087000000
1700000087000000
1700000000000087
1700000087000000
1700000087000000
1700000000000087
1700000087000000
1700000000000087
=
struct force_align1 {
  short a;
  unsigned char b:1;
};
-
{a=>108,b=>1}
6c000100
6c000100
6c000100
006c8000
6c000100
6c000100
006c8000
6c000100
006c8000
-
{a=>-114,b=>0}
8eff0000
8eff0000
8eff0000
ff8e0000
8eff0000
8eff0000
ff8e0000
8eff0000
ff8e0000
-
{a=>64,b=>1}
40000100
40000100
40000100
00408000
40000100
40000100
00408000
40000100
00408000
-
{a=>19,b=>1}
13000100
13000100
13000100
00138000
13000100
13000100
00138000
13000100
00138000
-
{a=>-123,b=>0}
85ff0000
85ff0000
85ff0000
ff850000
85ff0000
85ff0000
ff850000
85ff0000
ff850000
=
struct force_align1 {
  short a;
  unsigned char b:1;
  unsigned char c:1;
};
-
{c=>0,a=>-11,b=>1}
f5ff0100
f5ff0100
f5ff0100
fff58000
f5ff0100
f5ff0100
fff58000
f5ff0100
fff58000
-
{c=>1,a=>90,b=>0}
5a000200
5a000200
5a000200
005a4000
5a000200
5a000200
005a4000
5a000200
005a4000
-
{c=>0,a=>107,b=>0}
6b000000
6b000000
6b000000
006b0000
6b000000
6b000000
006b0000
6b000000
006b0000
-
{c=>0,a=>-75,b=>1}
b5ff0100
b5ff0100
b5ff0100
ffb58000
b5ff0100
b5ff0100
ffb58000
b5ff0100
ffb58000
-
{c=>1,a=>-80,b=>0}
b0ff0200
b0ff0200
b0ff0200
ffb04000
b0ff0200
b0ff0200
ffb04000
b0ff0200
ffb04000
=
struct force_align1 {
  short a;
  unsigned char b:1;
  unsigned char c:1;
  unsigned char  :0;
};
-
{c=>1,a=>105,b=>1}
69000300
69000300
69000300
0069c000
69000300
69000300
0069c000
69000300
0069c000
-
{c=>0,a=>49,b=>1}
31000100
31000100
31000100
00318000
31000100
31000100
00318000
31000100
00318000
-
{c=>1,a=>37,b=>0}
25000200
25000200
25000200
00254000
25000200
25000200
00254000
25000200
00254000
-
{c=>0,a=>-82,b=>0}
aeff0000
aeff0000
aeff0000
ffae0000
aeff0000
aeff0000
ffae0000
aeff0000
ffae0000
-
{c=>1,a=>-88,b=>1}
a8ff0300
a8ff0300
a8ff0300
ffa8c000
a8ff0300
a8ff0300
ffa8c000
a8ff0300
ffa8c000
=
struct force_align1 {
  short a;
  unsigned char b:1;
  unsigned char c:1;
  unsigned char  :0;
  unsigned char d:1;
};
-
{c=>0,a=>-121,b=>1,d=>0}
87ff0100
87ff0100
87ff0100
ff878000
87ff0100
87ff0100
ff878000
87ff0100
ff878000
-
{c=>1,a=>80,b=>0,d=>1}
50000201
50000201
50000201
00504080
50000201
50000201
00504080
50000201
00504080
-
{c=>0,a=>-79,b=>1,d=>1}
b1ff0101
b1ff0101
b1ff0101
ffb18080
b1ff0101
b1ff0101
ffb18080
b1ff0101
ffb18080
-
{c=>0,a=>106,b=>1,d=>0}
6a000100
6a000100
6a000100
006a8000
6a000100
6a000100
006a8000
6a000100
006a8000
-
{c=>1,a=>113,b=>0,d=>1}
71000201
71000201
71000201
00714080
71000201
71000201
00714080
71000201
00714080
=
struct force_align1 {
  short a;
  unsigned char b:1;
  unsigned char c:1;
  unsigned char  :0;
  unsigned char d:1;
  unsigned int  e;
};
-
{e=>56,c=>0,a=>80,b=>0,d=>0}
5000000038000000
5000000038000000
5000000038000000
0050000000000038
5000000038000000
5000000038000000
0050000000000038
5000000038000000
0050000000000038
-
{e=>189,c=>1,a=>6,b=>1,d=>1}
06000301bd000000
06000301bd000000
06000301bd000000
0006c080000000bd
06000301bd000000
06000301bd000000
0006c080000000bd
06000301bd000000
0006c080000000bd
-
{e=>198,c=>1,a=>-106,b=>0,d=>0}
96ff0200c6000000
96ff0200c6000000
96ff0200c6000000
ff964000000000c6
96ff0200c6000000
96ff0200c6000000
ff964000000000c6
96ff0200c6000000
ff964000000000c6
-
{e=>167,c=>1,a=>-17,b=>1,d=>0}
efff0300a7000000
efff0300a7000000
efff0300a7000000
ffefc000000000a7
efff0300a7000000
efff0300a7000000
ffefc000000000a7
efff0300a7000000
ffefc000000000a7
-
{e=>89,c=>0,a=>-78,b=>1,d=>0}
b2ff010059000000
b2ff010059000000
b2ff010059000000
ffb2800000000059
b2ff010059000000
b2ff010059000000
ffb2800000000059
b2ff010059000000
ffb2800000000059
=
struct force_align1 {
  int a;
  unsigned char b:1;
};
-
{a=>19,b=>1}
1300000001000000
1300000001000000
1300000001000000
0000001380000000
1300000001000000
1300000001000000
0000001380000000
1300000001000000
0000001380000000
-
{a=>79,b=>0}
4f00000000000000
4f00000000000000
4f00000000000000
0000004f00000000
4f00000000000000
4f00000000000000
0000004f00000000
4f00000000000000
0000004f00000000
-
{a=>-101,b=>1}
9bffffff01000000
9bffffff01000000
9bffffff01000000
ffffff9b80000000
9bffffff01000000
9bffffff01000000
ffffff9b80000000
9bffffff01000000
ffffff9b80000000
-
{a=>11,b=>1}
0b00000001000000
0b00000001000000
0b00000001000000
0000000b80000000
0b00000001000000
0b00000001000000
0000000b80000000
0b00000001000000
0000000b80000000
-
{a=>79,b=>0}
4f00000000000000
4f00000000000000
4f00000000000000
0000004f00000000
4f00000000000000
4f00000000000000
0000004f00000000
4f00000000000000
0000004f00000000
=
struct force_align1 {
  int a;
  unsigned char b:1;
  unsigned char c:1;
};
-
{c=>1,a=>-25,b=>0}
e7ffffff02000000
e7ffffff02000000
e7ffffff02000000
ffffffe740000000
e7ffffff02000000
e7ffffff02000000
ffffffe740000000
e7ffffff02000000
ffffffe740000000
-
{c=>1,a=>-98,b=>0}
9effffff02000000
9effffff02000000
9effffff02000000
ffffff9e40000000
9effffff02000000
9effffff02000000
ffffff9e40000000
9effffff02000000
ffffff9e40000000
-
{c=>0,a=>-118,b=>0}
8affffff00000000
8affffff00000000
8affffff00000000
ffffff8a00000000
8affffff00000000
8affffff00000000
ffffff8a00000000
8affffff00000000
ffffff8a00000000
-
{c=>1,a=>-46,b=>1}
d2ffffff03000000
d2ffffff03000000
d2ffffff03000000
ffffffd2c0000000
d2ffffff03000000
d2ffffff03000000
ffffffd2c0000000
d2ffffff03000000
ffffffd2c0000000
-
{c=>0,a=>92,b=>0}
5c00000000000000
5c00000000000000
5c00000000000000
0000005c00000000
5c00000000000000
5c00000000000000
0000005c00000000
5c00000000000000
0000005c00000000
=
struct force_align1 {
  int a;
  unsigned char b:1;
  unsigned char c:1;
  unsigned char  :0;
};
-
{c=>0,a=>27,b=>1}
1b00000001000000
1b00000001000000
1b00000001000000
0000001b80000000
1b00000001000000
1b00000001000000
0000001b80000000
1b00000001000000
0000001b80000000
-
{c=>1,a=>71,b=>1}
4700000003000000
4700000003000000
4700000003000000
00000047c0000000
4700000003000000
4700000003000000
00000047c0000000
4700000003000000
00000047c0000000
-
{c=>0,a=>53,b=>0}
3500000000000000
3500000000000000
3500000000000000
0000003500000000
3500000000000000
3500000000000000
0000003500000000
3500000000000000
0000003500000000
-
{c=>0,a=>-126,b=>1}
82ffffff01000000
82ffffff01000000
82ffffff01000000
ffffff8280000000
82ffffff01000000
82ffffff01000000
ffffff8280000000
82ffffff01000000
ffffff8280000000
-
{c=>0,a=>-59,b=>1}
c5ffffff01000000
c5ffffff01000000
c5ffffff01000000
ffffffc580000000
c5ffffff01000000
c5ffffff01000000
ffffffc580000000
c5ffffff01000000
ffffffc580000000
=
struct force_align1 {
  int a;
  unsigned char b:1;
  unsigned char c:1;
  unsigned char  :0;
  unsigned char d:1;
};
-
{c=>1,a=>49,b=>1,d=>0}
3100000003000000
3100000003000000
3100000003000000
00000031c0000000
3100000003000000
3100000003000000
00000031c0000000
3100000003000000
00000031c0000000
-
{c=>1,a=>-97,b=>0,d=>0}
9fffffff02000000
9fffffff02000000
9fffffff02000000
ffffff9f40000000
9fffffff02000000
9fffffff02000000
ffffff9f40000000
9fffffff02000000
ffffff9f40000000
-
{c=>1,a=>114,b=>1,d=>1}
7200000003010000
7200000003010000
7200000003010000
00000072c0800000
7200000003010000
7200000003010000
00000072c0800000
7200000003010000
00000072c0800000
-
{c=>0,a=>-38,b=>1,d=>0}
daffffff01000000
daffffff01000000
daffffff01000000
ffffffda80000000
daffffff01000000
daffffff01000000
ffffffda80000000
daffffff01000000
ffffffda80000000
-
{c=>0,a=>-74,b=>0,d=>0}
b6ffffff00000000
b6ffffff00000000
b6ffffff00000000
ffffffb600000000
b6ffffff00000000
b6ffffff00000000
ffffffb600000000
b6ffffff00000000
ffffffb600000000
=
struct force_align1 {
  int a;
  unsigned char b:1;
  unsigned char c:1;
  unsigned char  :0;
  unsigned char d:1;
  unsigned int  e;
};
-
{e=>174,c=>0,a=>102,b=>0,d=>1}
6600000000010000ae000000
6600000000010000ae000000
6600000000010000ae000000
0000006600800000000000ae
6600000000010000ae000000
6600000000010000ae000000
0000006600800000000000ae
6600000000010000ae000000
0000006600800000000000ae
-
{e=>77,c=>1,a=>85,b=>0,d=>0}
55000000020000004d000000
55000000020000004d000000
55000000020000004d000000
00000055400000000000004d
55000000020000004d000000
55000000020000004d000000
00000055400000000000004d
55000000020000004d000000
00000055400000000000004d
-
{e=>97,c=>1,a=>-95,b=>0,d=>1}
a1ffffff0201000061000000
a1ffffff0201000061000000
a1ffffff0201000061000000
ffffffa14080000000000061
a1ffffff0201000061000000
a1ffffff0201000061000000
ffffffa14080000000000061
a1ffffff0201000061000000
ffffffa14080000000000061
-
{e=>21,c=>1,a=>-30,b=>0,d=>1}
e2ffffff0201000015000000
e2ffffff0201000015000000
e2ffffff0201000015000000
ffffffe24080000000000015
e2ffffff0201000015000000
e2ffffff0201000015000000
ffffffe24080000000000015
e2ffffff0201000015000000
ffffffe24080000000000015
-
{e=>169,c=>0,a=>-9,b=>1,d=>0}
f7ffffff01000000a9000000
f7ffffff01000000a9000000
f7ffffff01000000a9000000
fffffff780000000000000a9
f7ffffff01000000a9000000
f7ffffff01000000a9000000
fffffff780000000000000a9
f7ffffff01000000a9000000
fffffff780000000000000a9
=
struct force_align1 {
  long a;
  unsigned char b:1;
};
-
{a=>67,b=>0}
4300000000000000
43000000000000000000000000000000
43000000000000000000000000000000
0000004300000000
4300000000000000
4300000000000000
00000000000000430000000000000000
4300000000000000
0000004300000000
-
{a=>122,b=>0}
7a00000000000000
7a000000000000000000000000000000
7a000000000000000000000000000000
0000007a00000000
7a00000000000000
7a00000000000000
000000000000007a0000000000000000
7a00000000000000
0000007a00000000
-
{a=>104,b=>0}
6800000000000000
68000000000000000000000000000000
68000000000000000000000000000000
0000006800000000
6800000000000000
6800000000000000
00000000000000680000000000000000
6800000000000000
0000006800000000
-
{a=>-99,b=>0}
9dffffff00000000
9dffffffffffffff0000000000000000
9dffffffffffffff0000000000000000
ffffff9d00000000
9dffffff00000000
9dffffff00000000
ffffffffffffff9d0000000000000000
9dffffff00000000
ffffff9d00000000
-
{a=>-11,b=>1}
f5ffffff01000000
f5ffffffffffffff0100000000000000
f5ffffffffffffff0100000000000000
fffffff580000000
f5ffffff01000000
f5ffffff01000000
fffffffffffffff58000000000000000
f5ffffff01000000
fffffff580000000
=
struct force_align1 {
  long a;
  unsigned char b:1;
  unsigned char c:1;
};
-
{c=>1,a=>-95,b=>0}
a1ffffff02000000
a1ffffffffffffff0200000000000000
a1ffffffffffffff0200000000000000
ffffffa140000000
a1ffffff02000000
a1ffffff02000000
ffffffffffffffa14000000000000000
a1ffffff02000000
ffffffa140000000
-
{c=>0,a=>74,b=>1}
4a00000001000000
4a000000000000000100000000000000
4a000000000000000100000000000000
0000004a80000000
4a00000001000000
4a00000001000000
000000000000004a8000000000000000
4a00000001000000
0000004a80000000
-
{c=>0,a=>31,b=>1}
1f00000001000000
1f000000000000000100000000000000
1f000000000000000100000000000000
0000001f80000000
1f00000001000000
1f00000001000000
000000000000001f8000000000000000
1f00000001000000
0000001f80000000
-
{c=>0,a=>-31,b=>1}
e1ffffff01000000
e1ffffffffffffff0100000000000000
e1ffffffffffffff0100000000000000
ffffffe180000000
e1ffffff01000000
e1ffffff01000000
ffffffffffffffe18000000000000000
e1ffffff01000000
ffffffe180000000
-
{c=>0,a=>47,b=>1}
2f00000001000000
2f000000000000000100000000000000
2f000000000000000100000000000000
0000002f80000000
2f00000001000000
2f00000001000000
000000000000002f8000000000000000
2f00000001000000
0000002f80000000
=
struct force_align1 {
  long a;
  unsigned char b:1;
  unsigned char c:1;
  unsigned char  :0;
};
-
{c=>1,a=>-52,b=>0}
ccffffff02000000
ccffffffffffffff0200000000000000
ccffffffffffffff0200000000000000
ffffffcc40000000
ccffffff02000000
ccffffff02000000
ffffffffffffffcc4000000000000000
ccffffff02000000
ffffffcc40000000
-
{c=>1,a=>9,b=>0}
0900000002000000
09000000000000000200000000000000
09000000000000000200000000000000
0000000940000000
0900000002000000
0900000002000000
00000000000000094000000000000000
0900000002000000
0000000940000000
-
{c=>1,a=>9,b=>1}
0900000003000000
09000000000000000300000000000000
09000000000000000300000000000000
00000009c0000000
0900000003000000
0900000003000000
0000000000000009c000000000000000
0900000003000000
00000009c0000000
-
{c=>1,a=>32,b=>1}
2000000003000000
20000000000000000300000000000000
20000000000000000300000000000000
00000020c0000000
2000000003000000
2000000003000000
0000000000000020c000000000000000
2000000003000000
00000020c0000000
-
{c=>1,a=>-30,b=>0}
e2ffffff02000000
e2ffffffffffffff0200000000000000
e2ffffffffffffff0200000000000000
ffffffe240000000
e2ffffff02000000
e2ffffff02000000
ffffffffffffffe24000000000000000
e2ffffff02000000
ffffffe240000000
=
struct force_align1 {
  long a;
  unsigned char b:1;
  unsigned char c:1;
  unsigned char  :0;
  unsigned char d:1;
};
-
{c=>1,a=>-45,b=>1,d=>0}
d3ffffff03000000
d3ffffffffffffff0300000000000000
d3ffffffffffffff0300000000000000
ffffffd3c0000000
d3ffffff03000000
d3ffffff03000000
ffffffffffffffd3c000000000000000
d3ffffff03000000
ffffffd3c0000000
-
{c=>0,a=>44,b=>0,d=>0}
2c00000000000000
2c000000000000000000000000000000
2c000000000000000000000000000000
0000002c00000000
2c00000000000000
2c00000000000000
000000000000002c0000000000000000
2c00000000000000
0000002c00000000
-
{c=>1,a=>88,b=>1,d=>1}
5800000003010000
58000000000000000301000000000000
58000000000000000301000000000000
00000058c0800000
5800000003010000
5800000003010000
0000000000000058c080000000000000
5800000003010000
00000058c0800000
-
{c=>1,a=>99,b=>0,d=>0}
6300000002000000
63000000000000000200000000000000
63000000000000000200000000000000
0000006340000000
6300000002000000
6300000002000000
00000000000000634000000000000000
6300000002000000
0000006340000000
-
{c=>1,a=>94,b=>1,d=>0}
5e00000003000000
5e000000000000000300000000000000
5e000000000000000300000000000000
0000005ec0000000
5e00000003000000
5e00000003000000
000000000000005ec000000000000000
5e00000003000000
0000005ec0000000
=
struct force_align1 {
  long a;
  unsigned char b:1;
  unsigned char c:1;
  unsigned char  :0;
  unsigned char d:1;
  unsigned int  e;
};
-
{e=>84,c=>1,a=>-57,b=>0,d=>1}
c7ffffff0201000054000000
c7ffffffffffffff0201000054000000
c7ffffffffffffff0201000054000000
ffffffc74080000000000054
c7ffffff0201000054000000
c7ffffff0201000054000000
ffffffffffffffc74080000000000054
c7ffffff0201000054000000
ffffffc74080000000000054
-
{e=>202,c=>0,a=>-67,b=>0,d=>1}
bdffffff00010000ca000000
bdffffffffffffff00010000ca000000
bdffffffffffffff00010000ca000000
ffffffbd00800000000000ca
bdffffff00010000ca000000
bdffffff00010000ca000000
ffffffffffffffbd00800000000000ca
bdffffff00010000ca000000
ffffffbd00800000000000ca
-
{e=>108,c=>0,a=>108,b=>1,d=>0}
6c000000010000006c000000
6c00000000000000010000006c000000
6c00000000000000010000006c000000
0000006c800000000000006c
6c000000010000006c000000
6c000000010000006c000000
000000000000006c800000000000006c
6c000000010000006c000000
0000006c800000000000006c
-
{e=>5,c=>0,a=>51,b=>1,d=>0}
330000000100000005000000
33000000000000000100000005000000
33000000000000000100000005000000
000000338000000000000005
330000000100000005000000
330000000100000005000000
00000000000000338000000000000005
330000000100000005000000
000000338000000000000005
-
{e=>228,c=>0,a=>-15,b=>0,d=>0}
f1ffffff00000000e4000000
f1ffffffffffffff00000000e4000000
f1ffffffffffffff00000000e4000000
fffffff100000000000000e4
f1ffffff00000000e4000000
f1ffffff00000000e4000000
fffffffffffffff100000000000000e4
f1ffffff00000000e4000000
fffffff100000000000000e4
=
struct force_align2 {
  unsigned char  a:2;
};
-
{a=>2}
02
02
02
80
02000000
02
80
02
80
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>3}
03
03
03
c0
03000000
03
c0
03
c0
-
{a=>3}
03
03
03
c0
03000000
03
c0
03
c0
=
struct force_align2 {
  unsigned char  a:2;
  unsigned char  b:2;
};
-
{a=>0,b=>3}
0c
0c
0c
30
0c000000
0c
30
0c
30
-
{a=>0,b=>1}
04
04
04
10
04000000
04
10
04
10
-
{a=>2,b=>3}
0e
0e
0e
b0
0e000000
0e
b0
0e
b0
-
{a=>2,b=>1}
06
06
06
90
06000000
06
90
06
90
-
{a=>3,b=>3}
0f
0f
0f
f0
0f000000
0f
f0
0f
f0
=
struct force_align2 {
  unsigned char  a:2;
  unsigned char  b:2;
  unsigned char   :0;
};
-
{a=>0,b=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>0,b=>1}
04
04
04
10
04000000
04
10
04
10
-
{a=>1,b=>3}
0d
0d
0d
70
0d000000
0d
70
0d
70
-
{a=>2,b=>0}
02
02
02
80
02000000
02
80
02
80
-
{a=>0,b=>2}
08
08
08
20
08000000
08
20
08
20
=
struct force_align2 {
  unsigned char  a:2;
  unsigned char  b:2;
  unsigned char   :0;
  unsigned char  c:2;
};
-
{c=>1,a=>1,b=>3}
0d01
0d01
0d01
7040
0d010000
0d01
7040
0d01
7040
-
{c=>2,a=>2,b=>1}
0602
0602
0602
9080
06020000
0602
9080
0602
9080
-
{c=>1,a=>2,b=>0}
0201
0201
0201
8040
02010000
0201
8040
0201
8040
-
{c=>2,a=>3,b=>3}
0f02
0f02
0f02
f080
0f020000
0f02
f080
0f02
f080
-
{c=>0,a=>1,b=>3}
0d00
0d00
0d00
7000
0d000000
0d00
7000
0d00
7000
=
struct force_align2 {
  unsigned char  a:2;
  unsigned char  b:2;
  unsigned char   :0;
  unsigned char  c:2;
  unsigned short d;
};
-
{c=>0,a=>1,b=>0,d=>112}
01007000
01007000
01007000
40000070
01007000
01007000
40000070
01007000
40000070
-
{c=>0,a=>3,b=>3,d=>128}
0f008000
0f008000
0f008000
f0000080
0f008000
0f008000
f0000080
0f008000
f0000080
-
{c=>1,a=>2,b=>0,d=>190}
0201be00
0201be00
0201be00
804000be
0201be00
0201be00
804000be
0201be00
804000be
-
{c=>0,a=>3,b=>2,d=>63}
0b003f00
0b003f00
0b003f00
e000003f
0b003f00
0b003f00
e000003f
0b003f00
e000003f
-
{c=>2,a=>2,b=>2,d=>241}
0a02f100
0a02f100
0a02f100
a08000f1
0a02f100
0a02f100
a08000f1
0a02f100
a08000f1
=
struct force_align2 {
  char a;
  unsigned char  b:2;
};
-
{a=>74,b=>1}
4a01
4a01
4a01
4a40
4a010000
4a01
4a40
4a01
4a40
-
{a=>-7,b=>1}
f901
f901
f901
f940
f9010000
f901
f940
f901
f940
-
{a=>102,b=>1}
6601
6601
6601
6640
66010000
6601
6640
6601
6640
-
{a=>10,b=>3}
0a03
0a03
0a03
0ac0
0a030000
0a03
0ac0
0a03
0ac0
-
{a=>-7,b=>2}
f902
f902
f902
f980
f9020000
f902
f980
f902
f980
=
struct force_align2 {
  char a;
  unsigned char  b:2;
  unsigned char  c:2;
};
-
{c=>3,a=>7,b=>1}
070d
070d
070d
0770
070d0000
070d
0770
070d
0770
-
{c=>3,a=>50,b=>0}
320c
320c
320c
3230
320c0000
320c
3230
320c
3230
-
{c=>2,a=>-125,b=>0}
8308
8308
8308
8320
83080000
8308
8320
8308
8320
-
{c=>2,a=>-32,b=>0}
e008
e008
e008
e020
e0080000
e008
e020
e008
e020
-
{c=>1,a=>68,b=>0}
4404
4404
4404
4410
44040000
4404
4410
4404
4410
=
struct force_align2 {
  char a;
  unsigned char  b:2;
  unsigned char  c:2;
  unsigned char   :0;
};
-
{c=>2,a=>-127,b=>0}
8108
8108
8108
8120
81080000
8108
8120
8108
8120
-
{c=>1,a=>-27,b=>0}
e504
e504
e504
e510
e5040000
e504
e510
e504
e510
-
{c=>2,a=>30,b=>1}
1e09
1e09
1e09
1e60
1e090000
1e09
1e60
1e09
1e60
-
{c=>0,a=>-25,b=>1}
e701
e701
e701
e740
e7010000
e701
e740
e701
e740
-
{c=>2,a=>-15,b=>1}
f109
f109
f109
f160
f1090000
f109
f160
f109
f160
=
struct force_align2 {
  char a;
  unsigned char  b:2;
  unsigned char  c:2;
  unsigned char   :0;
  unsigned char  d:2;
};
-
{c=>1,a=>75,b=>1,d=>2}
4b0502
4b0502
4b0502
4b5080
4b050200
4b0502
4b5080
4b0502
4b5080
-
{c=>1,a=>18,b=>1,d=>3}
120503
120503
120503
1250c0
12050300
120503
1250c0
120503
1250c0
-
{c=>2,a=>-39,b=>2,d=>0}
d90a00
d90a00
d90a00
d9a000
d90a0000
d90a00
d9a000
d90a00
d9a000
-
{c=>3,a=>-91,b=>2,d=>0}
a50e00
a50e00
a50e00
a5b000
a50e0000
a50e00
a5b000
a50e00
a5b000
-
{c=>1,a=>60,b=>1,d=>0}
3c0500
3c0500
3c0500
3c5000
3c050000
3c0500
3c5000
3c0500
3c5000
=
struct force_align2 {
  char a;
  unsigned char  b:2;
  unsigned char  c:2;
  unsigned char   :0;
  unsigned char  d:2;
  unsigned short e;
};
-
{e=>11,c=>2,a=>39,b=>0,d=>2}
270802000b00
270802000b00
270802000b00
27208000000b
270802000b000000
270802000b00
27208000000b
270802000b00
27208000000b
-
{e=>219,c=>0,a=>42,b=>3,d=>1}
2a030100db00
2a030100db00
2a030100db00
2ac0400000db
2a030100db000000
2a030100db00
2ac0400000db
2a030100db00
2ac0400000db
-
{e=>154,c=>0,a=>-14,b=>1,d=>1}
f20101009a00
f20101009a00
f20101009a00
f2404000009a
f20101009a000000
f20101009a00
f2404000009a
f20101009a00
f2404000009a
-
{e=>86,c=>1,a=>20,b=>3,d=>1}
140701005600
140701005600
140701005600
14d040000056
1407010056000000
140701005600
14d040000056
140701005600
14d040000056
-
{e=>7,c=>0,a=>-109,b=>1,d=>1}
930101000700
930101000700
930101000700
934040000007
9301010007000000
930101000700
934040000007
930101000700
934040000007
=
struct force_align2 {
  short a;
  unsigned char  b:2;
};
-
{a=>-77,b=>0}
b3ff0000
b3ff0000
b3ff0000
ffb30000
b3ff0000
b3ff0000
ffb30000
b3ff0000
ffb30000
-
{a=>32,b=>1}
20000100
20000100
20000100
00204000
20000100
20000100
00204000
20000100
00204000
-
{a=>-116,b=>3}
8cff0300
8cff0300
8cff0300
ff8cc000
8cff0300
8cff0300
ff8cc000
8cff0300
ff8cc000
-
{a=>127,b=>2}
7f000200
7f000200
7f000200
007f8000
7f000200
7f000200
007f8000
7f000200
007f8000
-
{a=>47,b=>2}
2f000200
2f000200
2f000200
002f8000
2f000200
2f000200
002f8000
2f000200
002f8000
=
struct force_align2 {
  short a;
  unsigned char  b:2;
  unsigned char  c:2;
};
-
{c=>1,a=>-56,b=>2}
c8ff0600
c8ff0600
c8ff0600
ffc89000
c8ff0600
c8ff0600
ffc89000
c8ff0600
ffc89000
-
{c=>1,a=>96,b=>0}
60000400
60000400
60000400
00601000
60000400
60000400
00601000
60000400
00601000
-
{c=>1,a=>-89,b=>1}
a7ff0500
a7ff0500
a7ff0500
ffa75000
a7ff0500
a7ff0500
ffa75000
a7ff0500
ffa75000
-
{c=>1,a=>-121,b=>1}
87ff0500
87ff0500
87ff0500
ff875000
87ff0500
87ff0500
ff875000
87ff0500
ff875000
-
{c=>2,a=>80,b=>3}
50000b00
50000b00
50000b00
0050e000
50000b00
50000b00
0050e000
50000b00
0050e000
=
struct force_align2 {
  short a;
  unsigned char  b:2;
  unsigned char  c:2;
  unsigned char   :0;
};
-
{c=>0,a=>-50,b=>1}
ceff0100
ceff0100
ceff0100
ffce4000
ceff0100
ceff0100
ffce4000
ceff0100
ffce4000
-
{c=>3,a=>26,b=>0}
1a000c00
1a000c00
1a000c00
001a3000
1a000c00
1a000c00
001a3000
1a000c00
001a3000
-
{c=>2,a=>-116,b=>2}
8cff0a00
8cff0a00
8cff0a00
ff8ca000
8cff0a00
8cff0a00
ff8ca000
8cff0a00
ff8ca000
-
{c=>3,a=>-72,b=>2}
b8ff0e00
b8ff0e00
b8ff0e00
ffb8b000
b8ff0e00
b8ff0e00
ffb8b000
b8ff0e00
ffb8b000
-
{c=>1,a=>87,b=>2}
57000600
57000600
57000600
00579000
57000600
57000600
00579000
57000600
00579000
=
struct force_align2 {
  short a;
  unsigned char  b:2;
  unsigned char  c:2;
  unsigned char   :0;
  unsigned char  d:2;
};
-
{c=>0,a=>-94,b=>1,d=>3}
a2ff0103
a2ff0103
a2ff0103
ffa240c0
a2ff0103
a2ff0103
ffa240c0
a2ff0103
ffa240c0
-
{c=>0,a=>-117,b=>0,d=>1}
8bff0001
8bff0001
8bff0001
ff8b0040
8bff0001
8bff0001
ff8b0040
8bff0001
ff8b0040
-
{c=>2,a=>18,b=>2,d=>2}
12000a02
12000a02
12000a02
0012a080
12000a02
12000a02
0012a080
12000a02
0012a080
-
{c=>3,a=>-15,b=>0,d=>0}
f1ff0c00
f1ff0c00
f1ff0c00
fff13000
f1ff0c00
f1ff0c00
fff13000
f1ff0c00
fff13000
-
{c=>0,a=>-39,b=>2,d=>3}
d9ff0203
d9ff0203
d9ff0203
ffd980c0
d9ff0203
d9ff0203
ffd980c0
d9ff0203
ffd980c0
=
struct force_align2 {
  short a;
  unsigned char  b:2;
  unsigned char  c:2;
  unsigned char   :0;
  unsigned char  d:2;
  unsigned short e;
};
-
{e=>213,c=>2,a=>98,b=>3,d=>0}
62000b00d500
62000b00d500
62000b00d500
0062e00000d5
62000b00d5000000
62000b00d500
0062e00000d5
62000b00d500
0062e00000d5
-
{e=>183,c=>3,a=>104,b=>2,d=>0}
68000e00b700
68000e00b700
68000e00b700
0068b00000b7
68000e00b7000000
68000e00b700
0068b00000b7
68000e00b700
0068b00000b7
-
{e=>152,c=>3,a=>68,b=>3,d=>1}
44000f019800
44000f019800
44000f019800
0044f0400098
44000f0198000000
44000f019800
0044f0400098
44000f019800
0044f0400098
-
{e=>117,c=>0,a=>83,b=>2,d=>1}
530002017500
530002017500
530002017500
005380400075
5300020175000000
530002017500
005380400075
530002017500
005380400075
-
{e=>183,c=>0,a=>-82,b=>3,d=>3}
aeff0303b700
aeff0303b700
aeff0303b700
ffaec0c000b7
aeff0303b7000000
aeff0303b700
ffaec0c000b7
aeff0303b700
ffaec0c000b7
=
struct force_align2 {
  int a;
  unsigned char  b:2;
};
-
{a=>-20,b=>3}
ecffffff03000000
ecffffff03000000
ecffffff03000000
ffffffecc0000000
ecffffff03000000
ecffffff03000000
ffffffecc0000000
ecffffff03000000
ffffffecc0000000
-
{a=>123,b=>1}
7b00000001000000
7b00000001000000
7b00000001000000
0000007b40000000
7b00000001000000
7b00000001000000
0000007b40000000
7b00000001000000
0000007b40000000
-
{a=>-106,b=>0}
96ffffff00000000
96ffffff00000000
96ffffff00000000
ffffff9600000000
96ffffff00000000
96ffffff00000000
ffffff9600000000
96ffffff00000000
ffffff9600000000
-
{a=>6,b=>3}
0600000003000000
0600000003000000
0600000003000000
00000006c0000000
0600000003000000
0600000003000000
00000006c0000000
0600000003000000
00000006c0000000
-
{a=>60,b=>0}
3c00000000000000
3c00000000000000
3c00000000000000
0000003c00000000
3c00000000000000
3c00000000000000
0000003c00000000
3c00000000000000
0000003c00000000
=
struct force_align2 {
  int a;
  unsigned char  b:2;
  unsigned char  c:2;
};
-
{c=>2,a=>55,b=>0}
3700000008000000
3700000008000000
3700000008000000
0000003720000000
3700000008000000
3700000008000000
0000003720000000
3700000008000000
0000003720000000
-
{c=>2,a=>-128,b=>3}
80ffffff0b000000
80ffffff0b000000
80ffffff0b000000
ffffff80e0000000
80ffffff0b000000
80ffffff0b000000
ffffff80e0000000
80ffffff0b000000
ffffff80e0000000
-
{c=>3,a=>-119,b=>3}
89ffffff0f000000
89ffffff0f000000
89ffffff0f000000
ffffff89f0000000
89ffffff0f000000
89ffffff0f000000
ffffff89f0000000
89ffffff0f000000
ffffff89f0000000
-
{c=>2,a=>46,b=>0}
2e00000008000000
2e00000008000000
2e00000008000000
0000002e20000000
2e00000008000000
2e00000008000000
0000002e20000000
2e00000008000000
0000002e20000000
-
{c=>2,a=>-13,b=>2}
f3ffffff0a000000
f3ffffff0a000000
f3ffffff0a000000
fffffff3a0000000
f3ffffff0a000000
f3ffffff0a000000
fffffff3a0000000
f3ffffff0a000000
fffffff3a0000000
=
struct force_align2 {
  int a;
  unsigned char  b:2;
  unsigned char  c:2;
  unsigned char   :0;
};
-
{c=>3,a=>-72,b=>3}
b8ffffff0f000000
b8ffffff0f000000
b8ffffff0f000000
ffffffb8f0000000
b8ffffff0f000000
b8ffffff0f000000
ffffffb8f0000000
b8ffffff0f000000
ffffffb8f0000000
-
{c=>3,a=>31,b=>0}
1f0000000c000000
1f0000000c000000
1f0000000c000000
0000001f30000000
1f0000000c000000
1f0000000c000000
0000001f30000000
1f0000000c000000
0000001f30000000
-
{c=>0,a=>105,b=>1}
6900000001000000
6900000001000000
6900000001000000
0000006940000000
6900000001000000
6900000001000000
0000006940000000
6900000001000000
0000006940000000
-
{c=>2,a=>74,b=>1}
4a00000009000000
4a00000009000000
4a00000009000000
0000004a60000000
4a00000009000000
4a00000009000000
0000004a60000000
4a00000009000000
0000004a60000000
-
{c=>0,a=>12,b=>1}
0c00000001000000
0c00000001000000
0c00000001000000
0000000c40000000
0c00000001000000
0c00000001000000
0000000c40000000
0c00000001000000
0000000c40000000
=
struct force_align2 {
  int a;
  unsigned char  b:2;
  unsigned char  c:2;
  unsigned char   :0;
  unsigned char  d:2;
};
-
{c=>2,a=>-93,b=>0,d=>3}
a3ffffff08030000
a3ffffff08030000
a3ffffff08030000
ffffffa320c00000
a3ffffff08030000
a3ffffff08030000
ffffffa320c00000
a3ffffff08030000
ffffffa320c00000
-
{c=>0,a=>-88,b=>2,d=>0}
a8ffffff02000000
a8ffffff02000000
a8ffffff02000000
ffffffa880000000
a8ffffff02000000
a8ffffff02000000
ffffffa880000000
a8ffffff02000000
ffffffa880000000
-
{c=>0,a=>89,b=>3,d=>0}
5900000003000000
5900000003000000
5900000003000000
00000059c0000000
5900000003000000
5900000003000000
00000059c0000000
5900000003000000
00000059c0000000
-
{c=>1,a=>-61,b=>2,d=>1}
c3ffffff06010000
c3ffffff06010000
c3ffffff06010000
ffffffc390400000
c3ffffff06010000
c3ffffff06010000
ffffffc390400000
c3ffffff06010000
ffffffc390400000
-
{c=>0,a=>-21,b=>0,d=>1}
ebffffff00010000
ebffffff00010000
ebffffff00010000
ffffffeb00400000
ebffffff00010000
ebffffff00010000
ffffffeb00400000
ebffffff00010000
ffffffeb00400000
=
struct force_align2 {
  int a;
  unsigned char  b:2;
  unsigned char  c:2;
  unsigned char   :0;
  unsigned char  d:2;
  unsigned short e;
};
-
{e=>23,c=>0,a=>-79,b=>1,d=>3}
b1ffffff01031700
b1ffffff01031700
b1ffffff01031700
ffffffb140c00017
b1ffffff01031700
b1ffffff01031700
ffffffb140c00017
b1ffffff01031700
ffffffb140c00017
-
{e=>106,c=>2,a=>-36,b=>0,d=>0}
dcffffff08006a00
dcffffff08006a00
dcffffff08006a00
ffffffdc2000006a
dcffffff08006a00
dcffffff08006a00
ffffffdc2000006a
dcffffff08006a00
ffffffdc2000006a
-
{e=>139,c=>3,a=>114,b=>3,d=>3}
720000000f038b00
720000000f038b00
720000000f038b00
00000072f0c0008b
720000000f038b00
720000000f038b00
00000072f0c0008b
720000000f038b00
00000072f0c0008b
-
{e=>151,c=>2,a=>-110,b=>0,d=>3}
92ffffff08039700
92ffffff08039700
92ffffff08039700
ffffff9220c00097
92ffffff08039700
92ffffff08039700
ffffff9220c00097
92ffffff08039700
ffffff9220c00097
-
{e=>15,c=>1,a=>-72,b=>0,d=>3}
b8ffffff04030f00
b8ffffff04030f00
b8ffffff04030f00
ffffffb810c0000f
b8ffffff04030f00
b8ffffff04030f00
ffffffb810c0000f
b8ffffff04030f00
ffffffb810c0000f
=
struct force_align2 {
  long a;
  unsigned char  b:2;
};
-
{a=>-86,b=>1}
aaffffff01000000
aaffffffffffffff0100000000000000
aaffffffffffffff0100000000000000
ffffffaa40000000
aaffffff01000000
aaffffff01000000
ffffffffffffffaa4000000000000000
aaffffff01000000
ffffffaa40000000
-
{a=>-16,b=>0}
f0ffffff00000000
f0ffffffffffffff0000000000000000
f0ffffffffffffff0000000000000000
fffffff000000000
f0ffffff00000000
f0ffffff00000000
fffffffffffffff00000000000000000
f0ffffff00000000
fffffff000000000
-
{a=>-65,b=>2}
bfffffff02000000
bfffffffffffffff0200000000000000
bfffffffffffffff0200000000000000
ffffffbf80000000
bfffffff02000000
bfffffff02000000
ffffffffffffffbf8000000000000000
bfffffff02000000
ffffffbf80000000
-
{a=>2,b=>2}
0200000002000000
02000000000000000200000000000000
02000000000000000200000000000000
0000000280000000
0200000002000000
0200000002000000
00000000000000028000000000000000
0200000002000000
0000000280000000
-
{a=>-85,b=>2}
abffffff02000000
abffffffffffffff0200000000000000
abffffffffffffff0200000000000000
ffffffab80000000
abffffff02000000
abffffff02000000
ffffffffffffffab8000000000000000
abffffff02000000
ffffffab80000000
=
struct force_align2 {
  long a;
  unsigned char  b:2;
  unsigned char  c:2;
};
-
{c=>3,a=>-105,b=>2}
97ffffff0e000000
97ffffffffffffff0e00000000000000
97ffffffffffffff0e00000000000000
ffffff97b0000000
97ffffff0e000000
97ffffff0e000000
ffffffffffffff97b000000000000000
97ffffff0e000000
ffffff97b0000000
-
{c=>1,a=>14,b=>1}
0e00000005000000
0e000000000000000500000000000000
0e000000000000000500000000000000
0000000e50000000
0e00000005000000
0e00000005000000
000000000000000e5000000000000000
0e00000005000000
0000000e50000000
-
{c=>1,a=>-120,b=>2}
88ffffff06000000
88ffffffffffffff0600000000000000
88ffffffffffffff0600000000000000
ffffff8890000000
88ffffff06000000
88ffffff06000000
ffffffffffffff889000000000000000
88ffffff06000000
ffffff8890000000
-
{c=>2,a=>67,b=>3}
430000000b000000
43000000000000000b00000000000000
43000000000000000b00000000000000
00000043e0000000
430000000b000000
430000000b000000
0000000000000043e000000000000000
430000000b000000
00000043e0000000
-
{c=>1,a=>85,b=>0}
5500000004000000
55000000000000000400000000000000
55000000000000000400000000000000
0000005510000000
5500000004000000
5500000004000000
00000000000000551000000000000000
5500000004000000
0000005510000000
=
struct force_align2 {
  long a;
  unsigned char  b:2;
  unsigned char  c:2;
  unsigned char   :0;
};
-
{c=>1,a=>113,b=>1}
7100000005000000
71000000000000000500000000000000
71000000000000000500000000000000
0000007150000000
7100000005000000
7100000005000000
00000000000000715000000000000000
7100000005000000
0000007150000000
-
{c=>0,a=>-59,b=>2}
c5ffffff02000000
c5ffffffffffffff0200000000000000
c5ffffffffffffff0200000000000000
ffffffc580000000
c5ffffff02000000
c5ffffff02000000
ffffffffffffffc58000000000000000
c5ffffff02000000
ffffffc580000000
-
{c=>2,a=>115,b=>1}
7300000009000000
73000000000000000900000000000000
73000000000000000900000000000000
0000007360000000
7300000009000000
7300000009000000
00000000000000736000000000000000
7300000009000000
0000007360000000
-
{c=>1,a=>-97,b=>3}
9fffffff07000000
9fffffffffffffff0700000000000000
9fffffffffffffff0700000000000000
ffffff9fd0000000
9fffffff07000000
9fffffff07000000
ffffffffffffff9fd000000000000000
9fffffff07000000
ffffff9fd0000000
-
{c=>2,a=>38,b=>2}
260000000a000000
26000000000000000a00000000000000
26000000000000000a00000000000000
00000026a0000000
260000000a000000
260000000a000000
0000000000000026a000000000000000
260000000a000000
00000026a0000000
=
struct force_align2 {
  long a;
  unsigned char  b:2;
  unsigned char  c:2;
  unsigned char   :0;
  unsigned char  d:2;
};
-
{c=>2,a=>14,b=>0,d=>0}
0e00000008000000
0e000000000000000800000000000000
0e000000000000000800000000000000
0000000e20000000
0e00000008000000
0e00000008000000
000000000000000e2000000000000000
0e00000008000000
0000000e20000000
-
{c=>3,a=>-56,b=>0,d=>3}
c8ffffff0c030000
c8ffffffffffffff0c03000000000000
c8ffffffffffffff0c03000000000000
ffffffc830c00000
c8ffffff0c030000
c8ffffff0c030000
ffffffffffffffc830c0000000000000
c8ffffff0c030000
ffffffc830c00000
-
{c=>1,a=>84,b=>0,d=>2}
5400000004020000
54000000000000000402000000000000
54000000000000000402000000000000
0000005410800000
5400000004020000
5400000004020000
00000000000000541080000000000000
5400000004020000
0000005410800000
-
{c=>1,a=>-54,b=>2,d=>0}
caffffff06000000
caffffffffffffff0600000000000000
caffffffffffffff0600000000000000
ffffffca90000000
caffffff06000000
caffffff06000000
ffffffffffffffca9000000000000000
caffffff06000000
ffffffca90000000
-
{c=>0,a=>61,b=>2,d=>0}
3d00000002000000
3d000000000000000200000000000000
3d000000000000000200000000000000
0000003d80000000
3d00000002000000
3d00000002000000
000000000000003d8000000000000000
3d00000002000000
0000003d80000000
=
struct force_align2 {
  long a;
  unsigned char  b:2;
  unsigned char  c:2;
  unsigned char   :0;
  unsigned char  d:2;
  unsigned short e;
};
-
{e=>109,c=>0,a=>66,b=>0,d=>1}
4200000000016d00
420000000000000000016d0000000000
420000000000000000016d0000000000
000000420040006d
4200000000016d00
4200000000016d00
00000000000000420040006d00000000
4200000000016d00
000000420040006d
-
{e=>167,c=>2,a=>-15,b=>2,d=>0}
f1ffffff0a00a700
f1ffffffffffffff0a00a70000000000
f1ffffffffffffff0a00a70000000000
fffffff1a00000a7
f1ffffff0a00a700
f1ffffff0a00a700
fffffffffffffff1a00000a700000000
f1ffffff0a00a700
fffffff1a00000a7
-
{e=>39,c=>1,a=>92,b=>1,d=>3}
5c00000005032700
5c000000000000000503270000000000
5c000000000000000503270000000000
0000005c50c00027
5c00000005032700
5c00000005032700
000000000000005c50c0002700000000
5c00000005032700
0000005c50c00027
-
{e=>135,c=>3,a=>-67,b=>0,d=>2}
bdffffff0c028700
bdffffffffffffff0c02870000000000
bdffffffffffffff0c02870000000000
ffffffbd30800087
bdffffff0c028700
bdffffff0c028700
ffffffffffffffbd3080008700000000
bdffffff0c028700
ffffffbd30800087
-
{e=>180,c=>1,a=>38,b=>0,d=>0}
260000000400b400
26000000000000000400b40000000000
26000000000000000400b40000000000
00000026100000b4
260000000400b400
260000000400b400
0000000000000026100000b400000000
260000000400b400
00000026100000b4
=
struct mixed1 {
  unsigned int a:1;
};
-
{a=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
-
{a=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
-
{a=>1}
01000000
01000000
01000000
80000000
01000000
01000000
80000000
01000000
80000000
-
{a=>1}
01000000
01000000
01000000
80000000
01000000
01000000
80000000
01000000
80000000
-
{a=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
=
struct mixed1 {
  unsigned int a:1;
  unsigned int b:1;
};
-
{a=>1,b=>0}
01000000
01000000
01000000
80000000
01000000
01000000
80000000
01000000
80000000
-
{a=>1,b=>0}
01000000
01000000
01000000
80000000
01000000
01000000
80000000
01000000
80000000
-
{a=>1,b=>0}
01000000
01000000
01000000
80000000
01000000
01000000
80000000
01000000
80000000
-
{a=>1,b=>1}
03000000
03000000
03000000
c0000000
03000000
03000000
c0000000
03000000
c0000000
-
{a=>1,b=>0}
01000000
01000000
01000000
80000000
01000000
01000000
80000000
01000000
80000000
=
struct mixed1 {
  unsigned int a:1;
  unsigned int b:1;
  unsigned int  :0;
};
-
{a=>0,b=>1}
02000000
02000000
02000000
40000000
02000000
02000000
40000000
02000000
40000000
-
{a=>1,b=>0}
01000000
01000000
01000000
80000000
01000000
01000000
80000000
01000000
80000000
-
{a=>0,b=>1}
02000000
02000000
02000000
40000000
02000000
02000000
40000000
02000000
40000000
-
{a=>0,b=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
-
{a=>1,b=>1}
03000000
03000000
03000000
c0000000
03000000
03000000
c0000000
03000000
c0000000
=
struct mixed1 {
  unsigned int a:1;
  unsigned int b:1;
  unsigned int  :0;
  unsigned int c:1;
};
-
{c=>1,a=>0,b=>0}
0000000001000000
0000000001000000
0000000001000000
0000000080000000
0000000001000000
0000000001000000
0000000080000000
0000000001000000
0000000080000000
-
{c=>1,a=>1,b=>1}
0300000001000000
0300000001000000
0300000001000000
c000000080000000
0300000001000000
0300000001000000
c000000080000000
0300000001000000
c000000080000000
-
{c=>0,a=>1,b=>0}
0100000000000000
0100000000000000
0100000000000000
8000000000000000
0100000000000000
0100000000000000
8000000000000000
0100000000000000
8000000000000000
-
{c=>0,a=>0,b=>1}
0200000000000000
0200000000000000
0200000000000000
4000000000000000
0200000000000000
0200000000000000
4000000000000000
0200000000000000
4000000000000000
-
{c=>0,a=>1,b=>0}
0100000000000000
0100000000000000
0100000000000000
8000000000000000
0100000000000000
0100000000000000
8000000000000000
0100000000000000
8000000000000000
=
struct mixed1 {
  unsigned int a:1;
  unsigned int b:1;
  unsigned int  :0;
  unsigned int c:1;
  signed   int d:1;
};
-
{c=>0,a=>1,b=>1,d=>0}
0300000000000000
0300000000000000
0300000000000000
c000000000000000
0300000000000000
0300000000000000
c000000000000000
0300000000000000
c000000000000000
-
{c=>0,a=>1,b=>1,d=>-1}
0300000002000000
0300000002000000
0300000002000000
c000000040000000
0300000002000000
0300000002000000
c000000040000000
0300000002000000
c000000040000000
-
{c=>1,a=>0,b=>0,d=>0}
0000000001000000
0000000001000000
0000000001000000
0000000080000000
0000000001000000
0000000001000000
0000000080000000
0000000001000000
0000000080000000
-
{c=>0,a=>1,b=>1,d=>-1}
0300000002000000
0300000002000000
0300000002000000
c000000040000000
0300000002000000
0300000002000000
c000000040000000
0300000002000000
c000000040000000
-
{c=>0,a=>1,b=>0,d=>0}
0100000000000000
0100000000000000
0100000000000000
8000000000000000
0100000000000000
0100000000000000
8000000000000000
0100000000000000
8000000000000000
=
struct mixed1 {
  unsigned int a:1;
  unsigned int b:1;
  unsigned int  :0;
  unsigned int c:1;
  signed   int d:1;
  signed   int e:1;
};
-
{e=>0,c=>0,a=>0,b=>1,d=>0}
0200000000000000
0200000000000000
0200000000000000
4000000000000000
0200000000000000
0200000000000000
4000000000000000
0200000000000000
4000000000000000
-
{e=>-1,c=>0,a=>0,b=>1,d=>-1}
0200000006000000
0200000006000000
0200000006000000
4000000060000000
0200000006000000
0200000006000000
4000000060000000
0200000006000000
4000000060000000
-
{e=>0,c=>0,a=>1,b=>1,d=>-1}
0300000002000000
0300000002000000
0300000002000000
c000000040000000
0300000002000000
0300000002000000
c000000040000000
0300000002000000
c000000040000000
-
{e=>-1,c=>1,a=>1,b=>0,d=>-1}
0100000007000000
0100000007000000
0100000007000000
80000000e0000000
0100000007000000
0100000007000000
80000000e0000000
0100000007000000
80000000e0000000
-
{e=>0,c=>0,a=>0,b=>0,d=>0}
0000000000000000
0000000000000000
0000000000000000
0000000000000000
0000000000000000
0000000000000000
0000000000000000
0000000000000000
0000000000000000
=
struct mixed1 {
  unsigned int a:1;
  unsigned int b:1;
  unsigned int  :0;
  unsigned int c:1;
  signed   int d:1;
  signed   int e:1;
  signed   int  :0;
};
-
{e=>-1,c=>0,a=>1,b=>0,d=>-1}
0100000006000000
0100000006000000
0100000006000000
8000000060000000
0100000006000000
0100000006000000
8000000060000000
0100000006000000
8000000060000000
-
{e=>0,c=>1,a=>1,b=>0,d=>0}
0100000001000000
0100000001000000
0100000001000000
8000000080000000
0100000001000000
0100000001000000
8000000080000000
0100000001000000
8000000080000000
-
{e=>-1,c=>0,a=>1,b=>0,d=>0}
0100000004000000
0100000004000000
0100000004000000
8000000020000000
0100000004000000
0100000004000000
8000000020000000
0100000004000000
8000000020000000
-
{e=>0,c=>1,a=>0,b=>1,d=>-1}
0200000003000000
0200000003000000
0200000003000000
40000000c0000000
0200000003000000
0200000003000000
40000000c0000000
0200000003000000
40000000c0000000
-
{e=>-1,c=>1,a=>1,b=>1,d=>-1}
0300000007000000
0300000007000000
0300000007000000
c0000000e0000000
0300000007000000
0300000007000000
c0000000e0000000
0300000007000000
c0000000e0000000
=
struct mixed1 {
  unsigned int a:1;
  unsigned int b:1;
  unsigned int  :0;
  unsigned int c:1;
  signed   int d:1;
  signed   int e:1;
  signed   int  :0;
  signed   int f:1;
};
-
{e=>-1,c=>1,a=>0,b=>1,d=>-1,f=>-1}
020000000700000001000000
020000000700000001000000
020000000700000001000000
40000000e000000080000000
020000000700000001000000
020000000700000001000000
40000000e000000080000000
020000000700000001000000
40000000e000000080000000
-
{e=>-1,c=>0,a=>0,b=>1,d=>0,f=>-1}
020000000400000001000000
020000000400000001000000
020000000400000001000000
400000002000000080000000
020000000400000001000000
020000000400000001000000
400000002000000080000000
020000000400000001000000
400000002000000080000000
-
{e=>-1,c=>1,a=>0,b=>1,d=>-1,f=>-1}
020000000700000001000000
020000000700000001000000
020000000700000001000000
40000000e000000080000000
020000000700000001000000
020000000700000001000000
40000000e000000080000000
020000000700000001000000
40000000e000000080000000
-
{e=>0,c=>1,a=>0,b=>0,d=>0,f=>-1}
000000000100000001000000
000000000100000001000000
000000000100000001000000
000000008000000080000000
000000000100000001000000
000000000100000001000000
000000008000000080000000
000000000100000001000000
000000008000000080000000
-
{e=>-1,c=>1,a=>0,b=>1,d=>-1,f=>-1}
020000000700000001000000
020000000700000001000000
020000000700000001000000
40000000e000000080000000
020000000700000001000000
020000000700000001000000
40000000e000000080000000
020000000700000001000000
40000000e000000080000000
=
struct mixed1 {
  unsigned int a:1;
  unsigned int b:1;
  unsigned int  :0;
  unsigned int c:1;
  signed   int d:1;
  signed   int e:1;
  signed   int  :0;
  signed   int f:1;
  int          g:1;
};
-
{e=>0,c=>1,a=>1,g=>-1,b=>1,d=>-1,f=>-1}
030000000300000003000000
030000000300000003000000
030000000300000003000000
c0000000c0000000c0000000
030000000300000003000000
030000000300000003000000
c0000000c0000000c0000000
030000000300000003000000
c0000000c0000000c0000000
-
{e=>0,c=>0,a=>1,g=>-1,b=>1,d=>0,f=>-1}
030000000000000003000000
030000000000000003000000
030000000000000003000000
c000000000000000c0000000
030000000000000003000000
030000000000000003000000
c000000000000000c0000000
030000000000000003000000
c000000000000000c0000000
-
{e=>0,c=>0,a=>0,g=>-1,b=>0,d=>0,f=>-1}
000000000000000003000000
000000000000000003000000
000000000000000003000000
0000000000000000c0000000
000000000000000003000000
000000000000000003000000
0000000000000000c0000000
000000000000000003000000
0000000000000000c0000000
-
{e=>0,c=>1,a=>1,g=>0,b=>1,d=>0,f=>0}
030000000100000000000000
030000000100000000000000
030000000100000000000000
c00000008000000000000000
030000000100000000000000
030000000100000000000000
c00000008000000000000000
030000000100000000000000
c00000008000000000000000
-
{e=>0,c=>1,a=>0,g=>-1,b=>1,d=>0,f=>0}
020000000100000002000000
020000000100000002000000
020000000100000002000000
400000008000000040000000
020000000100000002000000
020000000100000002000000
400000008000000040000000
020000000100000002000000
400000008000000040000000
=
struct mixed1 {
  unsigned int a:1;
  unsigned int b:1;
  unsigned int  :0;
  unsigned int c:1;
  signed   int d:1;
  signed   int e:1;
  signed   int  :0;
  signed   int f:1;
  int          g:1;
  int          h:1;
};
-
{e=>0,a=>1,d=>-1,c=>0,h=>0,b=>1,g=>-1,f=>-1}
030000000200000003000000
030000000200000003000000
030000000200000003000000
c000000040000000c0000000
030000000200000003000000
030000000200000003000000
c000000040000000c0000000
030000000200000003000000
c000000040000000c0000000
-
{e=>0,a=>0,d=>0,c=>0,h=>-1,b=>1,g=>-1,f=>-1}
020000000000000007000000
020000000000000007000000
020000000000000007000000
4000000000000000e0000000
020000000000000007000000
020000000000000007000000
4000000000000000e0000000
020000000000000007000000
4000000000000000e0000000
-
{e=>0,a=>0,d=>-1,c=>1,h=>0,b=>1,g=>-1,f=>0}
020000000300000002000000
020000000300000002000000
020000000300000002000000
40000000c000000040000000
020000000300000002000000
020000000300000002000000
40000000c000000040000000
020000000300000002000000
40000000c000000040000000
-
{e=>0,a=>0,d=>-1,c=>1,h=>-1,b=>0,g=>-1,f=>0}
000000000300000006000000
000000000300000006000000
000000000300000006000000
00000000c000000060000000
000000000300000006000000
000000000300000006000000
00000000c000000060000000
000000000300000006000000
00000000c000000060000000
-
{e=>0,a=>1,d=>-1,c=>0,h=>-1,b=>1,g=>0,f=>-1}
030000000200000005000000
030000000200000005000000
030000000200000005000000
c000000040000000a0000000
030000000200000005000000
030000000200000005000000
c000000040000000a0000000
030000000200000005000000
c000000040000000a0000000
=
struct mixed1 {
  unsigned int a:1;
  unsigned int b:1;
  unsigned int  :0;
  unsigned int c:1;
  signed   int d:1;
  signed   int e:1;
  signed   int  :0;
  signed   int f:1;
  int          g:1;
  int          h:1;
  int           :0;
};
-
{e=>0,a=>1,d=>0,c=>0,h=>-1,b=>0,g=>0,f=>-1}
010000000000000005000000
010000000000000005000000
010000000000000005000000
8000000000000000a0000000
010000000000000005000000
010000000000000005000000
8000000000000000a0000000
010000000000000005000000
8000000000000000a0000000
-
{e=>0,a=>1,d=>-1,c=>0,h=>-1,b=>0,g=>0,f=>-1}
010000000200000005000000
010000000200000005000000
010000000200000005000000
8000000040000000a0000000
010000000200000005000000
010000000200000005000000
8000000040000000a0000000
010000000200000005000000
8000000040000000a0000000
-
{e=>-1,a=>0,d=>0,c=>0,h=>0,b=>1,g=>0,f=>-1}
020000000400000001000000
020000000400000001000000
020000000400000001000000
400000002000000080000000
020000000400000001000000
020000000400000001000000
400000002000000080000000
020000000400000001000000
400000002000000080000000
-
{e=>0,a=>1,d=>-1,c=>0,h=>-1,b=>1,g=>0,f=>-1}
030000000200000005000000
030000000200000005000000
030000000200000005000000
c000000040000000a0000000
030000000200000005000000
030000000200000005000000
c000000040000000a0000000
030000000200000005000000
c000000040000000a0000000
-
{e=>-1,a=>1,d=>0,c=>0,h=>0,b=>0,g=>-1,f=>-1}
010000000400000003000000
010000000400000003000000
010000000400000003000000
8000000020000000c0000000
010000000400000003000000
010000000400000003000000
8000000020000000c0000000
010000000400000003000000
8000000020000000c0000000
=
struct mixed1 {
  unsigned int a:1;
  unsigned int b:1;
  unsigned int  :0;
  unsigned int c:1;
  signed   int d:1;
  signed   int e:1;
  signed   int  :0;
  signed   int f:1;
  int          g:1;
  int          h:1;
  int           :0;
  int          i:1;
};
-
{e=>-1,a=>1,d=>0,c=>1,h=>-1,b=>0,g=>-1,f=>-1,i=>0}
01000000050000000700000000000000
01000000050000000700000000000000
01000000050000000700000000000000
80000000a0000000e000000000000000
01000000050000000700000000000000
01000000050000000700000000000000
80000000a0000000e000000000000000
01000000050000000700000000000000
80000000a0000000e000000000000000
-
{e=>0,a=>1,d=>0,c=>0,h=>-1,b=>0,g=>0,f=>-1,i=>0}
01000000000000000500000000000000
01000000000000000500000000000000
01000000000000000500000000000000
8000000000000000a000000000000000
01000000000000000500000000000000
01000000000000000500000000000000
8000000000000000a000000000000000
01000000000000000500000000000000
8000000000000000a000000000000000
-
{e=>0,a=>1,d=>-1,c=>1,h=>-1,b=>0,g=>0,f=>-1,i=>0}
01000000030000000500000000000000
01000000030000000500000000000000
01000000030000000500000000000000
80000000c0000000a000000000000000
01000000030000000500000000000000
01000000030000000500000000000000
80000000c0000000a000000000000000
01000000030000000500000000000000
80000000c0000000a000000000000000
-
{e=>0,a=>1,d=>-1,c=>1,h=>-1,b=>1,g=>0,f=>-1,i=>0}
03000000030000000500000000000000
03000000030000000500000000000000
03000000030000000500000000000000
c0000000c0000000a000000000000000
03000000030000000500000000000000
03000000030000000500000000000000
c0000000c0000000a000000000000000
03000000030000000500000000000000
c0000000c0000000a000000000000000
-
{e=>-1,a=>1,d=>-1,c=>0,h=>-1,b=>0,g=>-1,f=>0,i=>-1}
01000000060000000600000001000000
01000000060000000600000001000000
01000000060000000600000001000000
80000000600000006000000080000000
01000000060000000600000001000000
01000000060000000600000001000000
80000000600000006000000080000000
01000000060000000600000001000000
80000000600000006000000080000000
=
struct mixed1 {
  unsigned int a:1;
  unsigned int b:1;
  unsigned int  :0;
  unsigned int c:1;
  signed   int d:1;
  signed   int e:1;
  signed   int  :0;
  signed   int f:1;
  int          g:1;
  int          h:1;
  int           :0;
  int          i:1;
  long         j;
};
-
{e=>-1,a=>0,d=>-1,j=>95,c=>0,h=>-1,b=>0,g=>-1,f=>0,i=>-1}
000000000600000006000000010000005f000000
000000000600000006000000010000005f00000000000000
000000000600000006000000010000005f00000000000000
000000006000000060000000800000000000005f
000000000600000006000000010000005f000000
000000000600000006000000010000005f000000
00000000600000006000000080000000000000000000005f
000000000600000006000000010000005f000000
000000006000000060000000800000000000005f
-
{e=>-1,a=>0,d=>0,j=>6,c=>1,h=>-1,b=>1,g=>0,f=>-1,i=>0}
0200000005000000050000000000000006000000
020000000500000005000000000000000600000000000000
020000000500000005000000000000000600000000000000
40000000a0000000a00000000000000000000006
0200000005000000050000000000000006000000
0200000005000000050000000000000006000000
40000000a0000000a0000000000000000000000000000006
0200000005000000050000000000000006000000
40000000a0000000a00000000000000000000006
-
{e=>0,a=>1,d=>-1,j=>2,c=>1,h=>0,b=>1,g=>0,f=>-1,i=>-1}
0300000003000000010000000100000002000000
030000000300000001000000010000000200000000000000
030000000300000001000000010000000200000000000000
c0000000c0000000800000008000000000000002
0300000003000000010000000100000002000000
0300000003000000010000000100000002000000
c0000000c000000080000000800000000000000000000002
0300000003000000010000000100000002000000
c0000000c0000000800000008000000000000002
-
{e=>0,a=>1,d=>0,j=>29,c=>0,h=>0,b=>1,g=>0,f=>0,i=>-1}
030000000000000000000000010000001d000000
030000000000000000000000010000001d00000000000000
030000000000000000000000010000001d00000000000000
c00000000000000000000000800000000000001d
030000000000000000000000010000001d000000
030000000000000000000000010000001d000000
c0000000000000000000000080000000000000000000001d
030000000000000000000000010000001d000000
c00000000000000000000000800000000000001d
-
{e=>0,a=>0,d=>-1,j=>-28,c=>0,h=>-1,b=>1,g=>-1,f=>-1,i=>0}
02000000020000000700000000000000e4ffffff
02000000020000000700000000000000e4ffffffffffffff
02000000020000000700000000000000e4ffffffffffffff
4000000040000000e000000000000000ffffffe4
02000000020000000700000000000000e4ffffff
02000000020000000700000000000000e4ffffff
4000000040000000e000000000000000ffffffffffffffe4
02000000020000000700000000000000e4ffffff
4000000040000000e000000000000000ffffffe4
=
struct mixed1 {
  char a;
  unsigned int b:1;
};
-
{a=>110,b=>1}
6e010000
6e010000
6e010000
6e800000
6e010000
6e010000
6e800000
6e010000
6e800000
-
{a=>-117,b=>1}
8b010000
8b010000
8b010000
8b800000
8b010000
8b010000
8b800000
8b010000
8b800000
-
{a=>-103,b=>0}
99000000
99000000
99000000
99000000
99000000
99000000
99000000
99000000
99000000
-
{a=>-42,b=>0}
d6000000
d6000000
d6000000
d6000000
d6000000
d6000000
d6000000
d6000000
d6000000
-
{a=>71,b=>1}
47010000
47010000
47010000
47800000
47010000
47010000
47800000
47010000
47800000
=
struct mixed1 {
  char a;
  unsigned int b:1;
  unsigned int c:1;
};
-
{c=>0,a=>53,b=>0}
35000000
35000000
35000000
35000000
35000000
35000000
35000000
35000000
35000000
-
{c=>1,a=>5,b=>1}
05030000
05030000
05030000
05c00000
05030000
05030000
05c00000
05030000
05c00000
-
{c=>0,a=>-80,b=>0}
b0000000
b0000000
b0000000
b0000000
b0000000
b0000000
b0000000
b0000000
b0000000
-
{c=>1,a=>100,b=>0}
64020000
64020000
64020000
64400000
64020000
64020000
64400000
64020000
64400000
-
{c=>1,a=>-94,b=>1}
a2030000
a2030000
a2030000
a2c00000
a2030000
a2030000
a2c00000
a2030000
a2c00000
=
struct mixed1 {
  char a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
};
-
{c=>0,a=>-121,b=>1}
87010000
87010000
87010000
87800000
87010000
87010000
87800000
87010000
87800000
-
{c=>0,a=>-57,b=>1}
c7010000
c7010000
c7010000
c7800000
c7010000
c7010000
c7800000
c7010000
c7800000
-
{c=>0,a=>37,b=>1}
25010000
25010000
25010000
25800000
25010000
25010000
25800000
25010000
25800000
-
{c=>1,a=>37,b=>1}
25030000
25030000
25030000
25c00000
25030000
25030000
25c00000
25030000
25c00000
-
{c=>0,a=>-110,b=>0}
92000000
92000000
92000000
92000000
92000000
92000000
92000000
92000000
92000000
=
struct mixed1 {
  char a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
};
-
{c=>0,a=>43,b=>0,d=>0}
2b00000000000000
2b00000000000000
2b00000000000000
2b00000000000000
2b00000000000000
2b00000000000000
2b00000000000000
2b00000000000000
2b00000000000000
-
{c=>1,a=>72,b=>1,d=>0}
4803000000000000
4803000000000000
4803000000000000
48c0000000000000
4803000000000000
4803000000000000
48c0000000000000
4803000000000000
48c0000000000000
-
{c=>1,a=>70,b=>0,d=>0}
4602000000000000
4602000000000000
4602000000000000
4640000000000000
4602000000000000
4602000000000000
4640000000000000
4602000000000000
4640000000000000
-
{c=>1,a=>50,b=>1,d=>0}
3203000000000000
3203000000000000
3203000000000000
32c0000000000000
3203000000000000
3203000000000000
32c0000000000000
3203000000000000
32c0000000000000
-
{c=>0,a=>104,b=>0,d=>0}
6800000000000000
6800000000000000
6800000000000000
6800000000000000
6800000000000000
6800000000000000
6800000000000000
6800000000000000
6800000000000000
=
struct mixed1 {
  char a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
};
-
{e=>0,c=>0,a=>48,b=>1,d=>1}
3001000001000000
3001000001000000
3001000001000000
3080000080000000
3001000001000000
3001000001000000
3080000080000000
3001000001000000
3080000080000000
-
{e=>-1,c=>0,a=>-115,b=>1,d=>0}
8d01000002000000
8d01000002000000
8d01000002000000
8d80000040000000
8d01000002000000
8d01000002000000
8d80000040000000
8d01000002000000
8d80000040000000
-
{e=>-1,c=>1,a=>-71,b=>0,d=>1}
b902000003000000
b902000003000000
b902000003000000
b9400000c0000000
b902000003000000
b902000003000000
b9400000c0000000
b902000003000000
b9400000c0000000
-
{e=>-1,c=>0,a=>38,b=>0,d=>0}
2600000002000000
2600000002000000
2600000002000000
2600000040000000
2600000002000000
2600000002000000
2600000040000000
2600000002000000
2600000040000000
-
{e=>-1,c=>1,a=>110,b=>0,d=>0}
6e02000002000000
6e02000002000000
6e02000002000000
6e40000040000000
6e02000002000000
6e02000002000000
6e40000040000000
6e02000002000000
6e40000040000000
=
struct mixed1 {
  char a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
};
-
{e=>0,c=>0,a=>-12,b=>0,d=>1,f=>0}
f400000001000000
f400000001000000
f400000001000000
f400000080000000
f400000001000000
f400000001000000
f400000080000000
f400000001000000
f400000080000000
-
{e=>0,c=>0,a=>5,b=>0,d=>1,f=>0}
0500000001000000
0500000001000000
0500000001000000
0500000080000000
0500000001000000
0500000001000000
0500000080000000
0500000001000000
0500000080000000
-
{e=>-1,c=>1,a=>47,b=>0,d=>0,f=>0}
2f02000002000000
2f02000002000000
2f02000002000000
2f40000040000000
2f02000002000000
2f02000002000000
2f40000040000000
2f02000002000000
2f40000040000000
-
{e=>-1,c=>1,a=>87,b=>0,d=>0,f=>-1}
5702000006000000
5702000006000000
5702000006000000
5740000060000000
5702000006000000
5702000006000000
5740000060000000
5702000006000000
5740000060000000
-
{e=>0,c=>0,a=>-26,b=>1,d=>1,f=>0}
e601000001000000
e601000001000000
e601000001000000
e680000080000000
e601000001000000
e601000001000000
e680000080000000
e601000001000000
e680000080000000
=
struct mixed1 {
  char a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
};
-
{e=>0,c=>0,a=>-46,b=>1,d=>1,f=>0}
d201000001000000
d201000001000000
d201000001000000
d280000080000000
d201000001000000
d201000001000000
d280000080000000
d201000001000000
d280000080000000
-
{e=>-1,c=>0,a=>-8,b=>1,d=>1,f=>0}
f801000003000000
f801000003000000
f801000003000000
f8800000c0000000
f801000003000000
f801000003000000
f8800000c0000000
f801000003000000
f8800000c0000000
-
{e=>-1,c=>1,a=>-104,b=>1,d=>0,f=>-1}
9803000006000000
9803000006000000
9803000006000000
98c0000060000000
9803000006000000
9803000006000000
98c0000060000000
9803000006000000
98c0000060000000
-
{e=>0,c=>1,a=>111,b=>1,d=>1,f=>0}
6f03000001000000
6f03000001000000
6f03000001000000
6fc0000080000000
6f03000001000000
6f03000001000000
6fc0000080000000
6f03000001000000
6fc0000080000000
-
{e=>-1,c=>1,a=>66,b=>1,d=>0,f=>-1}
4203000006000000
4203000006000000
4203000006000000
42c0000060000000
4203000006000000
4203000006000000
42c0000060000000
4203000006000000
42c0000060000000
=
struct mixed1 {
  char a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
};
-
{e=>0,c=>0,a=>33,g=>0,b=>1,d=>1,f=>-1}
210100000500000000000000
210100000500000000000000
210100000500000000000000
21800000a000000000000000
210100000500000000000000
210100000500000000000000
21800000a000000000000000
210100000500000000000000
21800000a000000000000000
-
{e=>0,c=>1,a=>-26,g=>0,b=>1,d=>1,f=>-1}
e60300000500000000000000
e60300000500000000000000
e60300000500000000000000
e6c00000a000000000000000
e60300000500000000000000
e60300000500000000000000
e6c00000a000000000000000
e60300000500000000000000
e6c00000a000000000000000
-
{e=>-1,c=>1,a=>-58,g=>0,b=>0,d=>1,f=>-1}
c60200000700000000000000
c60200000700000000000000
c60200000700000000000000
c6400000e000000000000000
c60200000700000000000000
c60200000700000000000000
c6400000e000000000000000
c60200000700000000000000
c6400000e000000000000000
-
{e=>0,c=>1,a=>-27,g=>-1,b=>0,d=>0,f=>-1}
e50200000400000001000000
e50200000400000001000000
e50200000400000001000000
e54000002000000080000000
e50200000400000001000000
e50200000400000001000000
e54000002000000080000000
e50200000400000001000000
e54000002000000080000000
-
{e=>-1,c=>1,a=>-33,g=>0,b=>0,d=>1,f=>0}
df0200000300000000000000
df0200000300000000000000
df0200000300000000000000
df400000c000000000000000
df0200000300000000000000
df0200000300000000000000
df400000c000000000000000
df0200000300000000000000
df400000c000000000000000
=
struct mixed1 {
  char a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
};
-
{e=>-1,a=>40,d=>0,c=>1,h=>0,b=>1,g=>0,f=>0}
280300000200000000000000
280300000200000000000000
280300000200000000000000
28c000004000000000000000
280300000200000000000000
280300000200000000000000
28c000004000000000000000
280300000200000000000000
28c000004000000000000000
-
{e=>-1,a=>123,d=>0,c=>0,h=>0,b=>1,g=>-1,f=>-1}
7b0100000600000001000000
7b0100000600000001000000
7b0100000600000001000000
7b8000006000000080000000
7b0100000600000001000000
7b0100000600000001000000
7b8000006000000080000000
7b0100000600000001000000
7b8000006000000080000000
-
{e=>-1,a=>102,d=>0,c=>1,h=>0,b=>0,g=>-1,f=>-1}
660200000600000001000000
660200000600000001000000
660200000600000001000000
664000006000000080000000
660200000600000001000000
660200000600000001000000
664000006000000080000000
660200000600000001000000
664000006000000080000000
-
{e=>0,a=>-10,d=>1,c=>1,h=>-1,b=>1,g=>0,f=>-1}
f60300000500000002000000
f60300000500000002000000
f60300000500000002000000
f6c00000a000000040000000
f60300000500000002000000
f60300000500000002000000
f6c00000a000000040000000
f60300000500000002000000
f6c00000a000000040000000
-
{e=>0,a=>49,d=>1,c=>0,h=>0,b=>0,g=>-1,f=>-1}
310000000500000001000000
310000000500000001000000
310000000500000001000000
31000000a000000080000000
310000000500000001000000
310000000500000001000000
31000000a000000080000000
310000000500000001000000
31000000a000000080000000
=
struct mixed1 {
  char a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
};
-
{e=>-1,a=>-11,d=>1,c=>1,h=>-1,b=>1,g=>-1,f=>0,i=>-1}
f50300000300000007000000
f50300000300000007000000
f50300000300000007000000
f5c00000c0000000e0000000
f50300000300000007000000
f50300000300000007000000
f5c00000c0000000e0000000
f50300000300000007000000
f5c00000c0000000e0000000
-
{e=>0,a=>-102,d=>0,c=>0,h=>0,b=>0,g=>-1,f=>-1,i=>0}
9a0000000400000001000000
9a0000000400000001000000
9a0000000400000001000000
9a0000002000000080000000
9a0000000400000001000000
9a0000000400000001000000
9a0000002000000080000000
9a0000000400000001000000
9a0000002000000080000000
-
{e=>0,a=>-33,d=>1,c=>0,h=>-1,b=>0,g=>0,f=>0,i=>0}
df0000000100000002000000
df0000000100000002000000
df0000000100000002000000
df0000008000000040000000
df0000000100000002000000
df0000000100000002000000
df0000008000000040000000
df0000000100000002000000
df0000008000000040000000
-
{e=>-1,a=>-96,d=>1,c=>0,h=>0,b=>1,g=>0,f=>0,i=>0}
a00100000300000000000000
a00100000300000000000000
a00100000300000000000000
a0800000c000000000000000
a00100000300000000000000
a00100000300000000000000
a0800000c000000000000000
a00100000300000000000000
a0800000c000000000000000
-
{e=>-1,a=>125,d=>1,c=>1,h=>-1,b=>0,g=>0,f=>-1,i=>-1}
7d0200000700000006000000
7d0200000700000006000000
7d0200000700000006000000
7d400000e000000060000000
7d0200000700000006000000
7d0200000700000006000000
7d400000e000000060000000
7d0200000700000006000000
7d400000e000000060000000
=
struct mixed1 {
  char a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
  int           :0;
};
-
{e=>-1,a=>-41,d=>0,c=>0,h=>-1,b=>1,g=>-1,f=>-1,i=>-1}
d70100000600000007000000
d70100000600000007000000
d70100000600000007000000
d780000060000000e0000000
d70100000600000007000000
d70100000600000007000000
d780000060000000e0000000
d70100000600000007000000
d780000060000000e0000000
-
{e=>-1,a=>51,d=>1,c=>0,h=>-1,b=>1,g=>-1,f=>-1,i=>0}
330100000700000003000000
330100000700000003000000
330100000700000003000000
33800000e0000000c0000000
330100000700000003000000
330100000700000003000000
33800000e0000000c0000000
330100000700000003000000
33800000e0000000c0000000
-
{e=>0,a=>43,d=>0,c=>0,h=>0,b=>1,g=>0,f=>-1,i=>-1}
2b0100000400000004000000
2b0100000400000004000000
2b0100000400000004000000
2b8000002000000020000000
2b0100000400000004000000
2b0100000400000004000000
2b8000002000000020000000
2b0100000400000004000000
2b8000002000000020000000
-
{e=>0,a=>33,d=>0,c=>1,h=>-1,b=>0,g=>0,f=>0,i=>-1}
210200000000000006000000
210200000000000006000000
210200000000000006000000
214000000000000060000000
210200000000000006000000
210200000000000006000000
214000000000000060000000
210200000000000006000000
214000000000000060000000
-
{e=>-1,a=>-111,d=>1,c=>1,h=>0,b=>0,g=>0,f=>-1,i=>0}
910200000700000000000000
910200000700000000000000
910200000700000000000000
91400000e000000000000000
910200000700000000000000
910200000700000000000000
91400000e000000000000000
910200000700000000000000
91400000e000000000000000
=
struct mixed1 {
  char a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
  int           :0;
  int          j:1;
};
-
{e=>-1,a=>-32,d=>0,j=>-1,c=>1,h=>-1,b=>0,g=>-1,f=>0,i=>0}
e0020000020000000300000001000000
e0020000020000000300000001000000
e0020000020000000300000001000000
e040000040000000c000000080000000
e0020000020000000300000001000000
e0020000020000000300000001000000
e040000040000000c000000080000000
e0020000020000000300000001000000
e040000040000000c000000080000000
-
{e=>0,a=>-11,d=>0,j=>0,c=>1,h=>0,b=>1,g=>-1,f=>-1,i=>-1}
f5030000040000000500000000000000
f5030000040000000500000000000000
f5030000040000000500000000000000
f5c0000020000000a000000000000000
f5030000040000000500000000000000
f5030000040000000500000000000000
f5c0000020000000a000000000000000
f5030000040000000500000000000000
f5c0000020000000a000000000000000
-
{e=>0,a=>-110,d=>1,j=>-1,c=>1,h=>-1,b=>1,g=>-1,f=>0,i=>-1}
92030000010000000700000001000000
92030000010000000700000001000000
92030000010000000700000001000000
92c0000080000000e000000080000000
92030000010000000700000001000000
92030000010000000700000001000000
92c0000080000000e000000080000000
92030000010000000700000001000000
92c0000080000000e000000080000000
-
{e=>-1,a=>-1,d=>0,j=>-1,c=>1,h=>-1,b=>0,g=>-1,f=>0,i=>-1}
ff020000020000000700000001000000
ff020000020000000700000001000000
ff020000020000000700000001000000
ff40000040000000e000000080000000
ff020000020000000700000001000000
ff020000020000000700000001000000
ff40000040000000e000000080000000
ff020000020000000700000001000000
ff40000040000000e000000080000000
-
{e=>0,a=>-47,d=>0,j=>-1,c=>1,h=>0,b=>1,g=>0,f=>0,i=>-1}
d1030000000000000400000001000000
d1030000000000000400000001000000
d1030000000000000400000001000000
d1c00000000000002000000080000000
d1030000000000000400000001000000
d1030000000000000400000001000000
d1c00000000000002000000080000000
d1030000000000000400000001000000
d1c00000000000002000000080000000
=
struct mixed1 {
  char a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
  int           :0;
  int          j:1;
  long         k;
};
-
{e=>0,a=>-103,d=>1,j=>0,c=>1,k=>81,h=>0,b=>1,g=>0,f=>0,i=>0}
9903000001000000000000000000000051000000
990300000100000000000000000000005100000000000000
990300000100000000000000000000005100000000000000
99c0000080000000000000000000000000000051
9903000001000000000000000000000051000000
9903000001000000000000000000000051000000
99c000008000000000000000000000000000000000000051
9903000001000000000000000000000051000000
99c0000080000000000000000000000000000051
-
{e=>0,a=>5,d=>0,j=>0,c=>1,k=>-43,h=>0,b=>0,g=>0,f=>-1,i=>-1}
05020000040000000400000000000000d5ffffff
05020000040000000400000000000000d5ffffffffffffff
05020000040000000400000000000000d5ffffffffffffff
05400000200000002000000000000000ffffffd5
05020000040000000400000000000000d5ffffff
05020000040000000400000000000000d5ffffff
05400000200000002000000000000000ffffffffffffffd5
05020000040000000400000000000000d5ffffff
05400000200000002000000000000000ffffffd5
-
{e=>0,a=>48,d=>0,j=>0,c=>1,k=>-96,h=>0,b=>0,g=>0,f=>-1,i=>0}
30020000040000000000000000000000a0ffffff
30020000040000000000000000000000a0ffffffffffffff
30020000040000000000000000000000a0ffffffffffffff
30400000200000000000000000000000ffffffa0
30020000040000000000000000000000a0ffffff
30020000040000000000000000000000a0ffffff
30400000200000000000000000000000ffffffffffffffa0
30020000040000000000000000000000a0ffffff
30400000200000000000000000000000ffffffa0
-
{e=>-1,a=>113,d=>0,j=>-1,c=>1,k=>-112,h=>-1,b=>1,g=>0,f=>-1,i=>0}
7103000006000000020000000100000090ffffff
7103000006000000020000000100000090ffffffffffffff
7103000006000000020000000100000090ffffffffffffff
71c00000600000004000000080000000ffffff90
7103000006000000020000000100000090ffffff
7103000006000000020000000100000090ffffff
71c00000600000004000000080000000ffffffffffffff90
7103000006000000020000000100000090ffffff
71c00000600000004000000080000000ffffff90
-
{e=>0,a=>124,d=>1,j=>-1,c=>1,k=>62,h=>0,b=>0,g=>0,f=>-1,i=>0}
7c0200000500000000000000010000003e000000
7c0200000500000000000000010000003e00000000000000
7c0200000500000000000000010000003e00000000000000
7c400000a000000000000000800000000000003e
7c0200000500000000000000010000003e000000
7c0200000500000000000000010000003e000000
7c400000a00000000000000080000000000000000000003e
7c0200000500000000000000010000003e000000
7c400000a000000000000000800000000000003e
=
struct mixed1 {
  short a;
  unsigned int b:1;
};
-
{a=>110,b=>1}
6e000100
6e000100
6e000100
006e8000
6e000100
6e000100
006e8000
6e000100
006e8000
-
{a=>-33,b=>1}
dfff0100
dfff0100
dfff0100
ffdf8000
dfff0100
dfff0100
ffdf8000
dfff0100
ffdf8000
-
{a=>-68,b=>0}
bcff0000
bcff0000
bcff0000
ffbc0000
bcff0000
bcff0000
ffbc0000
bcff0000
ffbc0000
-
{a=>-44,b=>1}
d4ff0100
d4ff0100
d4ff0100
ffd48000
d4ff0100
d4ff0100
ffd48000
d4ff0100
ffd48000
-
{a=>94,b=>0}
5e000000
5e000000
5e000000
005e0000
5e000000
5e000000
005e0000
5e000000
005e0000
=
struct mixed1 {
  short a;
  unsigned int b:1;
  unsigned int c:1;
};
-
{c=>1,a=>-20,b=>1}
ecff0300
ecff0300
ecff0300
ffecc000
ecff0300
ecff0300
ffecc000
ecff0300
ffecc000
-
{c=>1,a=>-53,b=>1}
cbff0300
cbff0300
cbff0300
ffcbc000
cbff0300
cbff0300
ffcbc000
cbff0300
ffcbc000
-
{c=>1,a=>123,b=>0}
7b000200
7b000200
7b000200
007b4000
7b000200
7b000200
007b4000
7b000200
007b4000
-
{c=>1,a=>-52,b=>0}
ccff0200
ccff0200
ccff0200
ffcc4000
ccff0200
ccff0200
ffcc4000
ccff0200
ffcc4000
-
{c=>1,a=>93,b=>0}
5d000200
5d000200
5d000200
005d4000
5d000200
5d000200
005d4000
5d000200
005d4000
=
struct mixed1 {
  short a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
};
-
{c=>1,a=>110,b=>0}
6e000200
6e000200
6e000200
006e4000
6e000200
6e000200
006e4000
6e000200
006e4000
-
{c=>0,a=>51,b=>0}
33000000
33000000
33000000
00330000
33000000
33000000
00330000
33000000
00330000
-
{c=>0,a=>118,b=>0}
76000000
76000000
76000000
00760000
76000000
76000000
00760000
76000000
00760000
-
{c=>1,a=>27,b=>1}
1b000300
1b000300
1b000300
001bc000
1b000300
1b000300
001bc000
1b000300
001bc000
-
{c=>0,a=>-97,b=>1}
9fff0100
9fff0100
9fff0100
ff9f8000
9fff0100
9fff0100
ff9f8000
9fff0100
ff9f8000
=
struct mixed1 {
  short a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
};
-
{c=>1,a=>102,b=>1,d=>0}
6600030000000000
6600030000000000
6600030000000000
0066c00000000000
6600030000000000
6600030000000000
0066c00000000000
6600030000000000
0066c00000000000
-
{c=>0,a=>-89,b=>1,d=>0}
a7ff010000000000
a7ff010000000000
a7ff010000000000
ffa7800000000000
a7ff010000000000
a7ff010000000000
ffa7800000000000
a7ff010000000000
ffa7800000000000
-
{c=>1,a=>37,b=>0,d=>0}
2500020000000000
2500020000000000
2500020000000000
0025400000000000
2500020000000000
2500020000000000
0025400000000000
2500020000000000
0025400000000000
-
{c=>1,a=>111,b=>1,d=>0}
6f00030000000000
6f00030000000000
6f00030000000000
006fc00000000000
6f00030000000000
6f00030000000000
006fc00000000000
6f00030000000000
006fc00000000000
-
{c=>0,a=>33,b=>0,d=>0}
2100000000000000
2100000000000000
2100000000000000
0021000000000000
2100000000000000
2100000000000000
0021000000000000
2100000000000000
0021000000000000
=
struct mixed1 {
  short a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
};
-
{e=>0,c=>1,a=>-77,b=>0,d=>0}
b3ff020000000000
b3ff020000000000
b3ff020000000000
ffb3400000000000
b3ff020000000000
b3ff020000000000
ffb3400000000000
b3ff020000000000
ffb3400000000000
-
{e=>-1,c=>0,a=>73,b=>1,d=>1}
4900010003000000
4900010003000000
4900010003000000
00498000c0000000
4900010003000000
4900010003000000
00498000c0000000
4900010003000000
00498000c0000000
-
{e=>-1,c=>0,a=>50,b=>1,d=>0}
3200010002000000
3200010002000000
3200010002000000
0032800040000000
3200010002000000
3200010002000000
0032800040000000
3200010002000000
0032800040000000
-
{e=>0,c=>1,a=>-125,b=>0,d=>1}
83ff020001000000
83ff020001000000
83ff020001000000
ff83400080000000
83ff020001000000
83ff020001000000
ff83400080000000
83ff020001000000
ff83400080000000
-
{e=>0,c=>0,a=>55,b=>1,d=>0}
3700010000000000
3700010000000000
3700010000000000
0037800000000000
3700010000000000
3700010000000000
0037800000000000
3700010000000000
0037800000000000
=
struct mixed1 {
  short a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
};
-
{e=>0,c=>1,a=>-25,b=>1,d=>1,f=>-1}
e7ff030005000000
e7ff030005000000
e7ff030005000000
ffe7c000a0000000
e7ff030005000000
e7ff030005000000
ffe7c000a0000000
e7ff030005000000
ffe7c000a0000000
-
{e=>0,c=>0,a=>110,b=>0,d=>0,f=>-1}
6e00000004000000
6e00000004000000
6e00000004000000
006e000020000000
6e00000004000000
6e00000004000000
006e000020000000
6e00000004000000
006e000020000000
-
{e=>0,c=>0,a=>-28,b=>1,d=>0,f=>0}
e4ff010000000000
e4ff010000000000
e4ff010000000000
ffe4800000000000
e4ff010000000000
e4ff010000000000
ffe4800000000000
e4ff010000000000
ffe4800000000000
-
{e=>0,c=>1,a=>38,b=>1,d=>1,f=>0}
2600030001000000
2600030001000000
2600030001000000
0026c00080000000
2600030001000000
2600030001000000
0026c00080000000
2600030001000000
0026c00080000000
-
{e=>-1,c=>0,a=>38,b=>0,d=>1,f=>-1}
2600000007000000
2600000007000000
2600000007000000
00260000e0000000
2600000007000000
2600000007000000
00260000e0000000
2600000007000000
00260000e0000000
=
struct mixed1 {
  short a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
};
-
{e=>0,c=>0,a=>-35,b=>1,d=>1,f=>-1}
ddff010005000000
ddff010005000000
ddff010005000000
ffdd8000a0000000
ddff010005000000
ddff010005000000
ffdd8000a0000000
ddff010005000000
ffdd8000a0000000
-
{e=>0,c=>0,a=>-82,b=>0,d=>0,f=>0}
aeff000000000000
aeff000000000000
aeff000000000000
ffae000000000000
aeff000000000000
aeff000000000000
ffae000000000000
aeff000000000000
ffae000000000000
-
{e=>0,c=>0,a=>-124,b=>1,d=>0,f=>0}
84ff010000000000
84ff010000000000
84ff010000000000
ff84800000000000
84ff010000000000
84ff010000000000
ff84800000000000
84ff010000000000
ff84800000000000
-
{e=>0,c=>0,a=>-50,b=>0,d=>1,f=>0}
ceff000001000000
ceff000001000000
ceff000001000000
ffce000080000000
ceff000001000000
ceff000001000000
ffce000080000000
ceff000001000000
ffce000080000000
-
{e=>-1,c=>1,a=>-121,b=>0,d=>0,f=>-1}
87ff020006000000
87ff020006000000
87ff020006000000
ff87400060000000
87ff020006000000
87ff020006000000
ff87400060000000
87ff020006000000
ff87400060000000
=
struct mixed1 {
  short a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
};
-
{e=>-1,c=>1,a=>39,g=>0,b=>1,d=>1,f=>0}
270003000300000000000000
270003000300000000000000
270003000300000000000000
0027c000c000000000000000
270003000300000000000000
270003000300000000000000
0027c000c000000000000000
270003000300000000000000
0027c000c000000000000000
-
{e=>-1,c=>0,a=>-21,g=>0,b=>0,d=>0,f=>0}
ebff00000200000000000000
ebff00000200000000000000
ebff00000200000000000000
ffeb00004000000000000000
ebff00000200000000000000
ebff00000200000000000000
ffeb00004000000000000000
ebff00000200000000000000
ffeb00004000000000000000
-
{e=>-1,c=>1,a=>-9,g=>-1,b=>1,d=>0,f=>0}
f7ff03000200000001000000
f7ff03000200000001000000
f7ff03000200000001000000
fff7c0004000000080000000
f7ff03000200000001000000
f7ff03000200000001000000
fff7c0004000000080000000
f7ff03000200000001000000
fff7c0004000000080000000
-
{e=>0,c=>0,a=>39,g=>-1,b=>0,d=>1,f=>0}
270000000100000001000000
270000000100000001000000
270000000100000001000000
002700008000000080000000
270000000100000001000000
270000000100000001000000
002700008000000080000000
270000000100000001000000
002700008000000080000000
-
{e=>0,c=>0,a=>-23,g=>0,b=>1,d=>1,f=>0}
e9ff01000100000000000000
e9ff01000100000000000000
e9ff01000100000000000000
ffe980008000000000000000
e9ff01000100000000000000
e9ff01000100000000000000
ffe980008000000000000000
e9ff01000100000000000000
ffe980008000000000000000
=
struct mixed1 {
  short a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
};
-
{e=>-1,a=>-109,d=>1,c=>1,h=>0,b=>0,g=>0,f=>-1}
93ff02000700000000000000
93ff02000700000000000000
93ff02000700000000000000
ff934000e000000000000000
93ff02000700000000000000
93ff02000700000000000000
ff934000e000000000000000
93ff02000700000000000000
ff934000e000000000000000
-
{e=>0,a=>113,d=>1,c=>0,h=>-1,b=>0,g=>0,f=>-1}
710000000500000002000000
710000000500000002000000
710000000500000002000000
00710000a000000040000000
710000000500000002000000
710000000500000002000000
00710000a000000040000000
710000000500000002000000
00710000a000000040000000
-
{e=>-1,a=>115,d=>1,c=>0,h=>-1,b=>1,g=>-1,f=>0}
730001000300000003000000
730001000300000003000000
730001000300000003000000
00738000c0000000c0000000
730001000300000003000000
730001000300000003000000
00738000c0000000c0000000
730001000300000003000000
00738000c0000000c0000000
-
{e=>0,a=>86,d=>1,c=>0,h=>0,b=>0,g=>0,f=>0}
560000000100000000000000
560000000100000000000000
560000000100000000000000
005600008000000000000000
560000000100000000000000
560000000100000000000000
005600008000000000000000
560000000100000000000000
005600008000000000000000
-
{e=>-1,a=>-14,d=>1,c=>1,h=>-1,b=>1,g=>-1,f=>0}
f2ff03000300000003000000
f2ff03000300000003000000
f2ff03000300000003000000
fff2c000c0000000c0000000
f2ff03000300000003000000
f2ff03000300000003000000
fff2c000c0000000c0000000
f2ff03000300000003000000
fff2c000c0000000c0000000
=
struct mixed1 {
  short a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
};
-
{e=>-1,a=>97,d=>1,c=>0,h=>-1,b=>0,g=>-1,f=>0,i=>0}
610000000300000003000000
610000000300000003000000
610000000300000003000000
00610000c0000000c0000000
610000000300000003000000
610000000300000003000000
00610000c0000000c0000000
610000000300000003000000
00610000c0000000c0000000
-
{e=>0,a=>-1,d=>0,c=>0,h=>-1,b=>1,g=>0,f=>0,i=>0}
ffff01000000000002000000
ffff01000000000002000000
ffff01000000000002000000
ffff80000000000040000000
ffff01000000000002000000
ffff01000000000002000000
ffff80000000000040000000
ffff01000000000002000000
ffff80000000000040000000
-
{e=>-1,a=>62,d=>1,c=>0,h=>0,b=>0,g=>-1,f=>0,i=>-1}
3e0000000300000005000000
3e0000000300000005000000
3e0000000300000005000000
003e0000c0000000a0000000
3e0000000300000005000000
3e0000000300000005000000
003e0000c0000000a0000000
3e0000000300000005000000
003e0000c0000000a0000000
-
{e=>0,a=>-110,d=>0,c=>0,h=>-1,b=>1,g=>0,f=>0,i=>-1}
92ff01000000000006000000
92ff01000000000006000000
92ff01000000000006000000
ff9280000000000060000000
92ff01000000000006000000
92ff01000000000006000000
ff9280000000000060000000
92ff01000000000006000000
ff9280000000000060000000
-
{e=>0,a=>-40,d=>1,c=>0,h=>-1,b=>0,g=>0,f=>-1,i=>0}
d8ff00000500000002000000
d8ff00000500000002000000
d8ff00000500000002000000
ffd80000a000000040000000
d8ff00000500000002000000
d8ff00000500000002000000
ffd80000a000000040000000
d8ff00000500000002000000
ffd80000a000000040000000
=
struct mixed1 {
  short a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
  int           :0;
};
-
{e=>-1,a=>-48,d=>0,c=>1,h=>0,b=>0,g=>0,f=>0,i=>0}
d0ff02000200000000000000
d0ff02000200000000000000
d0ff02000200000000000000
ffd040004000000000000000
d0ff02000200000000000000
d0ff02000200000000000000
ffd040004000000000000000
d0ff02000200000000000000
ffd040004000000000000000
-
{e=>0,a=>27,d=>1,c=>0,h=>0,b=>0,g=>-1,f=>-1,i=>-1}
1b0000000500000005000000
1b0000000500000005000000
1b0000000500000005000000
001b0000a0000000a0000000
1b0000000500000005000000
1b0000000500000005000000
001b0000a0000000a0000000
1b0000000500000005000000
001b0000a0000000a0000000
-
{e=>0,a=>47,d=>1,c=>0,h=>-1,b=>1,g=>0,f=>0,i=>-1}
2f0001000100000006000000
2f0001000100000006000000
2f0001000100000006000000
002f80008000000060000000
2f0001000100000006000000
2f0001000100000006000000
002f80008000000060000000
2f0001000100000006000000
002f80008000000060000000
-
{e=>-1,a=>24,d=>0,c=>1,h=>-1,b=>1,g=>-1,f=>-1,i=>-1}
180003000600000007000000
180003000600000007000000
180003000600000007000000
0018c00060000000e0000000
180003000600000007000000
180003000600000007000000
0018c00060000000e0000000
180003000600000007000000
0018c00060000000e0000000
-
{e=>0,a=>-105,d=>1,c=>1,h=>-1,b=>0,g=>-1,f=>0,i=>0}
97ff02000100000003000000
97ff02000100000003000000
97ff02000100000003000000
ff97400080000000c0000000
97ff02000100000003000000
97ff02000100000003000000
ff97400080000000c0000000
97ff02000100000003000000
ff97400080000000c0000000
=
struct mixed1 {
  short a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
  int           :0;
  int          j:1;
};
-
{e=>-1,a=>-24,d=>0,j=>0,c=>1,h=>0,b=>0,g=>0,f=>0,i=>0}
e8ff0200020000000000000000000000
e8ff0200020000000000000000000000
e8ff0200020000000000000000000000
ffe84000400000000000000000000000
e8ff0200020000000000000000000000
e8ff0200020000000000000000000000
ffe84000400000000000000000000000
e8ff0200020000000000000000000000
ffe84000400000000000000000000000
-
{e=>-1,a=>-22,d=>0,j=>0,c=>1,h=>0,b=>0,g=>-1,f=>0,i=>0}
eaff0200020000000100000000000000
eaff0200020000000100000000000000
eaff0200020000000100000000000000
ffea4000400000008000000000000000
eaff0200020000000100000000000000
eaff0200020000000100000000000000
ffea4000400000008000000000000000
eaff0200020000000100000000000000
ffea4000400000008000000000000000
-
{e=>0,a=>-38,d=>0,j=>-1,c=>0,h=>-1,b=>1,g=>-1,f=>-1,i=>0}
daff0100040000000300000001000000
daff0100040000000300000001000000
daff0100040000000300000001000000
ffda800020000000c000000080000000
daff0100040000000300000001000000
daff0100040000000300000001000000
ffda800020000000c000000080000000
daff0100040000000300000001000000
ffda800020000000c000000080000000
-
{e=>0,a=>72,d=>1,j=>0,c=>1,h=>-1,b=>1,g=>0,f=>-1,i=>0}
48000300050000000200000000000000
48000300050000000200000000000000
48000300050000000200000000000000
0048c000a00000004000000000000000
48000300050000000200000000000000
48000300050000000200000000000000
0048c000a00000004000000000000000
48000300050000000200000000000000
0048c000a00000004000000000000000
-
{e=>0,a=>-62,d=>0,j=>0,c=>0,h=>0,b=>1,g=>-1,f=>-1,i=>0}
c2ff0100040000000100000000000000
c2ff0100040000000100000000000000
c2ff0100040000000100000000000000
ffc28000200000008000000000000000
c2ff0100040000000100000000000000
c2ff0100040000000100000000000000
ffc28000200000008000000000000000
c2ff0100040000000100000000000000
ffc28000200000008000000000000000
=
struct mixed1 {
  short a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
  int           :0;
  int          j:1;
  long         k;
};
-
{e=>-1,a=>29,d=>0,j=>-1,c=>1,k=>-52,h=>-1,b=>1,g=>0,f=>0,i=>0}
1d000300020000000200000001000000ccffffff
1d000300020000000200000001000000ccffffffffffffff
1d000300020000000200000001000000ccffffffffffffff
001dc000400000004000000080000000ffffffcc
1d000300020000000200000001000000ccffffff
1d000300020000000200000001000000ccffffff
001dc000400000004000000080000000ffffffffffffffcc
1d000300020000000200000001000000ccffffff
001dc000400000004000000080000000ffffffcc
-
{e=>0,a=>71,d=>0,j=>-1,c=>0,k=>11,h=>0,b=>0,g=>0,f=>0,i=>-1}
470000000000000004000000010000000b000000
470000000000000004000000010000000b00000000000000
470000000000000004000000010000000b00000000000000
004700000000000020000000800000000000000b
470000000000000004000000010000000b000000
470000000000000004000000010000000b000000
00470000000000002000000080000000000000000000000b
470000000000000004000000010000000b000000
004700000000000020000000800000000000000b
-
{e=>-1,a=>7,d=>0,j=>0,c=>0,k=>101,h=>-1,b=>0,g=>-1,f=>0,i=>-1}
0700000002000000070000000000000065000000
070000000200000007000000000000006500000000000000
070000000200000007000000000000006500000000000000
0007000040000000e00000000000000000000065
0700000002000000070000000000000065000000
0700000002000000070000000000000065000000
0007000040000000e0000000000000000000000000000065
0700000002000000070000000000000065000000
0007000040000000e00000000000000000000065
-
{e=>-1,a=>-19,d=>1,j=>0,c=>0,k=>8,h=>-1,b=>1,g=>0,f=>0,i=>-1}
edff010003000000060000000000000008000000
edff01000300000006000000000000000800000000000000
edff01000300000006000000000000000800000000000000
ffed8000c0000000600000000000000000000008
edff010003000000060000000000000008000000
edff010003000000060000000000000008000000
ffed8000c000000060000000000000000000000000000008
edff010003000000060000000000000008000000
ffed8000c0000000600000000000000000000008
-
{e=>-1,a=>71,d=>1,j=>0,c=>0,k=>-64,h=>0,b=>1,g=>-1,f=>-1,i=>-1}
47000100070000000500000000000000c0ffffff
47000100070000000500000000000000c0ffffffffffffff
47000100070000000500000000000000c0ffffffffffffff
00478000e0000000a000000000000000ffffffc0
47000100070000000500000000000000c0ffffff
47000100070000000500000000000000c0ffffff
00478000e0000000a000000000000000ffffffffffffffc0
47000100070000000500000000000000c0ffffff
00478000e0000000a000000000000000ffffffc0
=
struct mixed1 {
  int a;
  unsigned int b:1;
};
-
{a=>-120,b=>0}
88ffffff00000000
88ffffff00000000
88ffffff00000000
ffffff8800000000
88ffffff00000000
88ffffff00000000
ffffff8800000000
88ffffff00000000
ffffff8800000000
-
{a=>-74,b=>1}
b6ffffff01000000
b6ffffff01000000
b6ffffff01000000
ffffffb680000000
b6ffffff01000000
b6ffffff01000000
ffffffb680000000
b6ffffff01000000
ffffffb680000000
-
{a=>-4,b=>1}
fcffffff01000000
fcffffff01000000
fcffffff01000000
fffffffc80000000
fcffffff01000000
fcffffff01000000
fffffffc80000000
fcffffff01000000
fffffffc80000000
-
{a=>-89,b=>0}
a7ffffff00000000
a7ffffff00000000
a7ffffff00000000
ffffffa700000000
a7ffffff00000000
a7ffffff00000000
ffffffa700000000
a7ffffff00000000
ffffffa700000000
-
{a=>95,b=>0}
5f00000000000000
5f00000000000000
5f00000000000000
0000005f00000000
5f00000000000000
5f00000000000000
0000005f00000000
5f00000000000000
0000005f00000000
=
struct mixed1 {
  int a;
  unsigned int b:1;
  unsigned int c:1;
};
-
{c=>0,a=>124,b=>1}
7c00000001000000
7c00000001000000
7c00000001000000
0000007c80000000
7c00000001000000
7c00000001000000
0000007c80000000
7c00000001000000
0000007c80000000
-
{c=>0,a=>97,b=>1}
6100000001000000
6100000001000000
6100000001000000
0000006180000000
6100000001000000
6100000001000000
0000006180000000
6100000001000000
0000006180000000
-
{c=>0,a=>-1,b=>0}
ffffffff00000000
ffffffff00000000
ffffffff00000000
ffffffff00000000
ffffffff00000000
ffffffff00000000
ffffffff00000000
ffffffff00000000
ffffffff00000000
-
{c=>0,a=>-59,b=>0}
c5ffffff00000000
c5ffffff00000000
c5ffffff00000000
ffffffc500000000
c5ffffff00000000
c5ffffff00000000
ffffffc500000000
c5ffffff00000000
ffffffc500000000
-
{c=>1,a=>23,b=>1}
1700000003000000
1700000003000000
1700000003000000
00000017c0000000
1700000003000000
1700000003000000
00000017c0000000
1700000003000000
00000017c0000000
=
struct mixed1 {
  int a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
};
-
{c=>0,a=>1,b=>0}
0100000000000000
0100000000000000
0100000000000000
0000000100000000
0100000000000000
0100000000000000
0000000100000000
0100000000000000
0000000100000000
-
{c=>0,a=>-43,b=>1}
d5ffffff01000000
d5ffffff01000000
d5ffffff01000000
ffffffd580000000
d5ffffff01000000
d5ffffff01000000
ffffffd580000000
d5ffffff01000000
ffffffd580000000
-
{c=>0,a=>-32,b=>1}
e0ffffff01000000
e0ffffff01000000
e0ffffff01000000
ffffffe080000000
e0ffffff01000000
e0ffffff01000000
ffffffe080000000
e0ffffff01000000
ffffffe080000000
-
{c=>0,a=>-65,b=>1}
bfffffff01000000
bfffffff01000000
bfffffff01000000
ffffffbf80000000
bfffffff01000000
bfffffff01000000
ffffffbf80000000
bfffffff01000000
ffffffbf80000000
-
{c=>0,a=>-14,b=>0}
f2ffffff00000000
f2ffffff00000000
f2ffffff00000000
fffffff200000000
f2ffffff00000000
f2ffffff00000000
fffffff200000000
f2ffffff00000000
fffffff200000000
=
struct mixed1 {
  int a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
};
-
{c=>0,a=>89,b=>0,d=>0}
590000000000000000000000
590000000000000000000000
590000000000000000000000
000000590000000000000000
590000000000000000000000
590000000000000000000000
000000590000000000000000
590000000000000000000000
000000590000000000000000
-
{c=>0,a=>-30,b=>0,d=>1}
e2ffffff0000000001000000
e2ffffff0000000001000000
e2ffffff0000000001000000
ffffffe20000000080000000
e2ffffff0000000001000000
e2ffffff0000000001000000
ffffffe20000000080000000
e2ffffff0000000001000000
ffffffe20000000080000000
-
{c=>1,a=>-6,b=>0,d=>0}
faffffff0200000000000000
faffffff0200000000000000
faffffff0200000000000000
fffffffa4000000000000000
faffffff0200000000000000
faffffff0200000000000000
fffffffa4000000000000000
faffffff0200000000000000
fffffffa4000000000000000
-
{c=>1,a=>-16,b=>1,d=>0}
f0ffffff0300000000000000
f0ffffff0300000000000000
f0ffffff0300000000000000
fffffff0c000000000000000
f0ffffff0300000000000000
f0ffffff0300000000000000
fffffff0c000000000000000
f0ffffff0300000000000000
fffffff0c000000000000000
-
{c=>0,a=>94,b=>1,d=>1}
5e0000000100000001000000
5e0000000100000001000000
5e0000000100000001000000
0000005e8000000080000000
5e0000000100000001000000
5e0000000100000001000000
0000005e8000000080000000
5e0000000100000001000000
0000005e8000000080000000
=
struct mixed1 {
  int a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
};
-
{e=>-1,c=>0,a=>-26,b=>1,d=>1}
e6ffffff0100000003000000
e6ffffff0100000003000000
e6ffffff0100000003000000
ffffffe680000000c0000000
e6ffffff0100000003000000
e6ffffff0100000003000000
ffffffe680000000c0000000
e6ffffff0100000003000000
ffffffe680000000c0000000
-
{e=>0,c=>0,a=>-38,b=>1,d=>0}
daffffff0100000000000000
daffffff0100000000000000
daffffff0100000000000000
ffffffda8000000000000000
daffffff0100000000000000
daffffff0100000000000000
ffffffda8000000000000000
daffffff0100000000000000
ffffffda8000000000000000
-
{e=>-1,c=>1,a=>82,b=>1,d=>1}
520000000300000003000000
520000000300000003000000
520000000300000003000000
00000052c0000000c0000000
520000000300000003000000
520000000300000003000000
00000052c0000000c0000000
520000000300000003000000
00000052c0000000c0000000
-
{e=>-1,c=>1,a=>-3,b=>1,d=>0}
fdffffff0300000002000000
fdffffff0300000002000000
fdffffff0300000002000000
fffffffdc000000040000000
fdffffff0300000002000000
fdffffff0300000002000000
fffffffdc000000040000000
fdffffff0300000002000000
fffffffdc000000040000000
-
{e=>-1,c=>1,a=>104,b=>0,d=>1}
680000000200000003000000
680000000200000003000000
680000000200000003000000
0000006840000000c0000000
680000000200000003000000
680000000200000003000000
0000006840000000c0000000
680000000200000003000000
0000006840000000c0000000
=
struct mixed1 {
  int a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
};
-
{e=>-1,c=>0,a=>-49,b=>0,d=>1,f=>0}
cfffffff0000000003000000
cfffffff0000000003000000
cfffffff0000000003000000
ffffffcf00000000c0000000
cfffffff0000000003000000
cfffffff0000000003000000
ffffffcf00000000c0000000
cfffffff0000000003000000
ffffffcf00000000c0000000
-
{e=>-1,c=>1,a=>-85,b=>0,d=>1,f=>-1}
abffffff0200000007000000
abffffff0200000007000000
abffffff0200000007000000
ffffffab40000000e0000000
abffffff0200000007000000
abffffff0200000007000000
ffffffab40000000e0000000
abffffff0200000007000000
ffffffab40000000e0000000
-
{e=>0,c=>1,a=>-109,b=>0,d=>0,f=>0}
93ffffff0200000000000000
93ffffff0200000000000000
93ffffff0200000000000000
ffffff934000000000000000
93ffffff0200000000000000
93ffffff0200000000000000
ffffff934000000000000000
93ffffff0200000000000000
ffffff934000000000000000
-
{e=>0,c=>0,a=>109,b=>0,d=>0,f=>0}
6d0000000000000000000000
6d0000000000000000000000
6d0000000000000000000000
0000006d0000000000000000
6d0000000000000000000000
6d0000000000000000000000
0000006d0000000000000000
6d0000000000000000000000
0000006d0000000000000000
-
{e=>0,c=>1,a=>-3,b=>0,d=>0,f=>0}
fdffffff0200000000000000
fdffffff0200000000000000
fdffffff0200000000000000
fffffffd4000000000000000
fdffffff0200000000000000
fdffffff0200000000000000
fffffffd4000000000000000
fdffffff0200000000000000
fffffffd4000000000000000
=
struct mixed1 {
  int a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
};
-
{e=>0,c=>0,a=>-89,b=>0,d=>0,f=>-1}
a7ffffff0000000004000000
a7ffffff0000000004000000
a7ffffff0000000004000000
ffffffa70000000020000000
a7ffffff0000000004000000
a7ffffff0000000004000000
ffffffa70000000020000000
a7ffffff0000000004000000
ffffffa70000000020000000
-
{e=>-1,c=>0,a=>-6,b=>1,d=>1,f=>0}
faffffff0100000003000000
faffffff0100000003000000
faffffff0100000003000000
fffffffa80000000c0000000
faffffff0100000003000000
faffffff0100000003000000
fffffffa80000000c0000000
faffffff0100000003000000
fffffffa80000000c0000000
-
{e=>0,c=>0,a=>-60,b=>0,d=>1,f=>0}
c4ffffff0000000001000000
c4ffffff0000000001000000
c4ffffff0000000001000000
ffffffc40000000080000000
c4ffffff0000000001000000
c4ffffff0000000001000000
ffffffc40000000080000000
c4ffffff0000000001000000
ffffffc40000000080000000
-
{e=>-1,c=>1,a=>-65,b=>0,d=>1,f=>0}
bfffffff0200000003000000
bfffffff0200000003000000
bfffffff0200000003000000
ffffffbf40000000c0000000
bfffffff0200000003000000
bfffffff0200000003000000
ffffffbf40000000c0000000
bfffffff0200000003000000
ffffffbf40000000c0000000
-
{e=>0,c=>0,a=>-92,b=>0,d=>0,f=>-1}
a4ffffff0000000004000000
a4ffffff0000000004000000
a4ffffff0000000004000000
ffffffa40000000020000000
a4ffffff0000000004000000
a4ffffff0000000004000000
ffffffa40000000020000000
a4ffffff0000000004000000
ffffffa40000000020000000
=
struct mixed1 {
  int a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
};
-
{e=>0,c=>1,a=>23,g=>0,b=>0,d=>0,f=>0}
17000000020000000000000000000000
17000000020000000000000000000000
17000000020000000000000000000000
00000017400000000000000000000000
17000000020000000000000000000000
17000000020000000000000000000000
00000017400000000000000000000000
17000000020000000000000000000000
00000017400000000000000000000000
-
{e=>0,c=>0,a=>-110,g=>-1,b=>1,d=>1,f=>0}
92ffffff010000000100000001000000
92ffffff010000000100000001000000
92ffffff010000000100000001000000
ffffff92800000008000000080000000
92ffffff010000000100000001000000
92ffffff010000000100000001000000
ffffff92800000008000000080000000
92ffffff010000000100000001000000
ffffff92800000008000000080000000
-
{e=>0,c=>1,a=>6,g=>0,b=>0,d=>1,f=>-1}
06000000020000000500000000000000
06000000020000000500000000000000
06000000020000000500000000000000
0000000640000000a000000000000000
06000000020000000500000000000000
06000000020000000500000000000000
0000000640000000a000000000000000
06000000020000000500000000000000
0000000640000000a000000000000000
-
{e=>-1,c=>0,a=>-15,g=>-1,b=>0,d=>1,f=>0}
f1ffffff000000000300000001000000
f1ffffff000000000300000001000000
f1ffffff000000000300000001000000
fffffff100000000c000000080000000
f1ffffff000000000300000001000000
f1ffffff000000000300000001000000
fffffff100000000c000000080000000
f1ffffff000000000300000001000000
fffffff100000000c000000080000000
-
{e=>-1,c=>1,a=>-105,g=>-1,b=>1,d=>1,f=>-1}
97ffffff030000000700000001000000
97ffffff030000000700000001000000
97ffffff030000000700000001000000
ffffff97c0000000e000000080000000
97ffffff030000000700000001000000
97ffffff030000000700000001000000
ffffff97c0000000e000000080000000
97ffffff030000000700000001000000
ffffff97c0000000e000000080000000
=
struct mixed1 {
  int a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
};
-
{e=>-1,a=>-67,d=>0,c=>1,h=>-1,b=>1,g=>-1,f=>-1}
bdffffff030000000600000003000000
bdffffff030000000600000003000000
bdffffff030000000600000003000000
ffffffbdc000000060000000c0000000
bdffffff030000000600000003000000
bdffffff030000000600000003000000
ffffffbdc000000060000000c0000000
bdffffff030000000600000003000000
ffffffbdc000000060000000c0000000
-
{e=>0,a=>16,d=>0,c=>1,h=>0,b=>0,g=>-1,f=>-1}
10000000020000000400000001000000
10000000020000000400000001000000
10000000020000000400000001000000
00000010400000002000000080000000
10000000020000000400000001000000
10000000020000000400000001000000
00000010400000002000000080000000
10000000020000000400000001000000
00000010400000002000000080000000
-
{e=>0,a=>75,d=>0,c=>0,h=>0,b=>0,g=>0,f=>-1}
4b000000000000000400000000000000
4b000000000000000400000000000000
4b000000000000000400000000000000
0000004b000000002000000000000000
4b000000000000000400000000000000
4b000000000000000400000000000000
0000004b000000002000000000000000
4b000000000000000400000000000000
0000004b000000002000000000000000
-
{e=>-1,a=>-78,d=>0,c=>1,h=>0,b=>1,g=>-1,f=>0}
b2ffffff030000000200000001000000
b2ffffff030000000200000001000000
b2ffffff030000000200000001000000
ffffffb2c00000004000000080000000
b2ffffff030000000200000001000000
b2ffffff030000000200000001000000
ffffffb2c00000004000000080000000
b2ffffff030000000200000001000000
ffffffb2c00000004000000080000000
-
{e=>0,a=>50,d=>1,c=>1,h=>0,b=>1,g=>0,f=>0}
32000000030000000100000000000000
32000000030000000100000000000000
32000000030000000100000000000000
00000032c00000008000000000000000
32000000030000000100000000000000
32000000030000000100000000000000
00000032c00000008000000000000000
32000000030000000100000000000000
00000032c00000008000000000000000
=
struct mixed1 {
  int a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
};
-
{e=>0,a=>45,d=>0,c=>1,h=>0,b=>0,g=>-1,f=>-1,i=>-1}
2d000000020000000400000005000000
2d000000020000000400000005000000
2d000000020000000400000005000000
0000002d4000000020000000a0000000
2d000000020000000400000005000000
2d000000020000000400000005000000
0000002d4000000020000000a0000000
2d000000020000000400000005000000
0000002d4000000020000000a0000000
-
{e=>0,a=>-65,d=>1,c=>1,h=>-1,b=>0,g=>-1,f=>-1,i=>0}
bfffffff020000000500000003000000
bfffffff020000000500000003000000
bfffffff020000000500000003000000
ffffffbf40000000a0000000c0000000
bfffffff020000000500000003000000
bfffffff020000000500000003000000
ffffffbf40000000a0000000c0000000
bfffffff020000000500000003000000
ffffffbf40000000a0000000c0000000
-
{e=>-1,a=>5,d=>0,c=>1,h=>0,b=>1,g=>0,f=>-1,i=>0}
05000000030000000600000000000000
05000000030000000600000000000000
05000000030000000600000000000000
00000005c00000006000000000000000
05000000030000000600000000000000
05000000030000000600000000000000
00000005c00000006000000000000000
05000000030000000600000000000000
00000005c00000006000000000000000
-
{e=>-1,a=>53,d=>1,c=>0,h=>-1,b=>1,g=>0,f=>-1,i=>-1}
35000000010000000700000006000000
35000000010000000700000006000000
35000000010000000700000006000000
0000003580000000e000000060000000
35000000010000000700000006000000
35000000010000000700000006000000
0000003580000000e000000060000000
35000000010000000700000006000000
0000003580000000e000000060000000
-
{e=>-1,a=>-98,d=>0,c=>1,h=>-1,b=>1,g=>0,f=>0,i=>-1}
9effffff030000000200000006000000
9effffff030000000200000006000000
9effffff030000000200000006000000
ffffff9ec00000004000000060000000
9effffff030000000200000006000000
9effffff030000000200000006000000
ffffff9ec00000004000000060000000
9effffff030000000200000006000000
ffffff9ec00000004000000060000000
=
struct mixed1 {
  int a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
  int           :0;
};
-
{e=>0,a=>79,d=>0,c=>0,h=>-1,b=>1,g=>-1,f=>0,i=>0}
4f000000010000000000000003000000
4f000000010000000000000003000000
4f000000010000000000000003000000
0000004f8000000000000000c0000000
4f000000010000000000000003000000
4f000000010000000000000003000000
0000004f8000000000000000c0000000
4f000000010000000000000003000000
0000004f8000000000000000c0000000
-
{e=>0,a=>-115,d=>1,c=>0,h=>0,b=>1,g=>0,f=>-1,i=>-1}
8dffffff010000000500000004000000
8dffffff010000000500000004000000
8dffffff010000000500000004000000
ffffff8d80000000a000000020000000
8dffffff010000000500000004000000
8dffffff010000000500000004000000
ffffff8d80000000a000000020000000
8dffffff010000000500000004000000
ffffff8d80000000a000000020000000
-
{e=>-1,a=>-69,d=>0,c=>1,h=>-1,b=>1,g=>-1,f=>0,i=>0}
bbffffff030000000200000003000000
bbffffff030000000200000003000000
bbffffff030000000200000003000000
ffffffbbc000000040000000c0000000
bbffffff030000000200000003000000
bbffffff030000000200000003000000
ffffffbbc000000040000000c0000000
bbffffff030000000200000003000000
ffffffbbc000000040000000c0000000
-
{e=>-1,a=>0,d=>0,c=>1,h=>0,b=>1,g=>-1,f=>0,i=>-1}
00000000030000000200000005000000
00000000030000000200000005000000
00000000030000000200000005000000
00000000c000000040000000a0000000
00000000030000000200000005000000
00000000030000000200000005000000
00000000c000000040000000a0000000
00000000030000000200000005000000
00000000c000000040000000a0000000
-
{e=>-1,a=>34,d=>1,c=>1,h=>0,b=>1,g=>0,f=>-1,i=>-1}
22000000030000000700000004000000
22000000030000000700000004000000
22000000030000000700000004000000
00000022c0000000e000000020000000
22000000030000000700000004000000
22000000030000000700000004000000
00000022c0000000e000000020000000
22000000030000000700000004000000
00000022c0000000e000000020000000
=
struct mixed1 {
  int a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
  int           :0;
  int          j:1;
};
-
{e=>0,a=>67,d=>0,j=>0,c=>1,h=>0,b=>1,g=>0,f=>-1,i=>0}
4300000003000000040000000000000000000000
4300000003000000040000000000000000000000
4300000003000000040000000000000000000000
00000043c0000000200000000000000000000000
4300000003000000040000000000000000000000
4300000003000000040000000000000000000000
00000043c0000000200000000000000000000000
4300000003000000040000000000000000000000
00000043c0000000200000000000000000000000
-
{e=>0,a=>23,d=>0,j=>-1,c=>1,h=>0,b=>0,g=>-1,f=>-1,i=>-1}
1700000002000000040000000500000001000000
1700000002000000040000000500000001000000
1700000002000000040000000500000001000000
000000174000000020000000a000000080000000
1700000002000000040000000500000001000000
1700000002000000040000000500000001000000
000000174000000020000000a000000080000000
1700000002000000040000000500000001000000
000000174000000020000000a000000080000000
-
{e=>0,a=>89,d=>0,j=>0,c=>0,h=>-1,b=>0,g=>-1,f=>-1,i=>0}
5900000000000000040000000300000000000000
5900000000000000040000000300000000000000
5900000000000000040000000300000000000000
000000590000000020000000c000000000000000
5900000000000000040000000300000000000000
5900000000000000040000000300000000000000
000000590000000020000000c000000000000000
5900000000000000040000000300000000000000
000000590000000020000000c000000000000000
-
{e=>0,a=>-97,d=>0,j=>0,c=>1,h=>-1,b=>0,g=>-1,f=>0,i=>-1}
9fffffff02000000000000000700000000000000
9fffffff02000000000000000700000000000000
9fffffff02000000000000000700000000000000
ffffff9f4000000000000000e000000000000000
9fffffff02000000000000000700000000000000
9fffffff02000000000000000700000000000000
ffffff9f4000000000000000e000000000000000
9fffffff02000000000000000700000000000000
ffffff9f4000000000000000e000000000000000
-
{e=>0,a=>-76,d=>1,j=>-1,c=>0,h=>-1,b=>1,g=>-1,f=>0,i=>0}
b4ffffff01000000010000000300000001000000
b4ffffff01000000010000000300000001000000
b4ffffff01000000010000000300000001000000
ffffffb48000000080000000c000000080000000
b4ffffff01000000010000000300000001000000
b4ffffff01000000010000000300000001000000
ffffffb48000000080000000c000000080000000
b4ffffff01000000010000000300000001000000
ffffffb48000000080000000c000000080000000
=
struct mixed1 {
  int a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
  int           :0;
  int          j:1;
  long         k;
};
-
{e=>0,a=>-74,d=>1,j=>0,c=>1,k=>96,h=>0,b=>1,g=>-1,f=>0,i=>0}
b6ffffff0300000001000000010000000000000060000000
b6ffffff03000000010000000100000000000000000000006000000000000000
b6ffffff03000000010000000100000000000000000000006000000000000000
ffffffb6c000000080000000800000000000000000000060
b6ffffff0300000001000000010000000000000060000000
b6ffffff0300000001000000010000000000000060000000
ffffffb6c0000000800000008000000000000000000000000000000000000060
b6ffffff0300000001000000010000000000000060000000
ffffffb6c000000080000000800000000000000000000060
-
{e=>0,a=>89,d=>1,j=>0,c=>0,k=>-51,h=>0,b=>0,g=>-1,f=>0,i=>-1}
5900000000000000010000000500000000000000cdffffff
590000000000000001000000050000000000000000000000cdffffffffffffff
590000000000000001000000050000000000000000000000cdffffffffffffff
000000590000000080000000a000000000000000ffffffcd
5900000000000000010000000500000000000000cdffffff
5900000000000000010000000500000000000000cdffffff
000000590000000080000000a00000000000000000000000ffffffffffffffcd
5900000000000000010000000500000000000000cdffffff
000000590000000080000000a000000000000000ffffffcd
-
{e=>-1,a=>48,d=>0,j=>0,c=>0,k=>116,h=>-1,b=>0,g=>-1,f=>0,i=>-1}
300000000000000002000000070000000000000074000000
3000000000000000020000000700000000000000000000007400000000000000
3000000000000000020000000700000000000000000000007400000000000000
000000300000000040000000e00000000000000000000074
300000000000000002000000070000000000000074000000
300000000000000002000000070000000000000074000000
000000300000000040000000e000000000000000000000000000000000000074
300000000000000002000000070000000000000074000000
000000300000000040000000e00000000000000000000074
-
{e=>0,a=>-74,d=>0,j=>0,c=>1,k=>59,h=>0,b=>1,g=>0,f=>-1,i=>0}
b6ffffff030000000400000000000000000000003b000000
b6ffffff03000000040000000000000000000000000000003b00000000000000
b6ffffff03000000040000000000000000000000000000003b00000000000000
ffffffb6c00000002000000000000000000000000000003b
b6ffffff030000000400000000000000000000003b000000
b6ffffff030000000400000000000000000000003b000000
ffffffb6c000000020000000000000000000000000000000000000000000003b
b6ffffff030000000400000000000000000000003b000000
ffffffb6c00000002000000000000000000000000000003b
-
{e=>-1,a=>63,d=>1,j=>-1,c=>0,k=>49,h=>0,b=>0,g=>-1,f=>0,i=>0}
3f0000000000000003000000010000000100000031000000
3f00000000000000030000000100000001000000000000003100000000000000
3f00000000000000030000000100000001000000000000003100000000000000
0000003f00000000c0000000800000008000000000000031
3f0000000000000003000000010000000100000031000000
3f0000000000000003000000010000000100000031000000
0000003f00000000c00000008000000080000000000000000000000000000031
3f0000000000000003000000010000000100000031000000
0000003f00000000c0000000800000008000000000000031
=
struct mixed1 {
  long a;
  unsigned int b:1;
};
-
{a=>-77,b=>1}
b3ffffff01000000
b3ffffffffffffff0100000000000000
b3ffffffffffffff0100000000000000
ffffffb380000000
b3ffffff01000000
b3ffffff01000000
ffffffffffffffb38000000000000000
b3ffffff01000000
ffffffb380000000
-
{a=>-4,b=>0}
fcffffff00000000
fcffffffffffffff0000000000000000
fcffffffffffffff0000000000000000
fffffffc00000000
fcffffff00000000
fcffffff00000000
fffffffffffffffc0000000000000000
fcffffff00000000
fffffffc00000000
-
{a=>106,b=>1}
6a00000001000000
6a000000000000000100000000000000
6a000000000000000100000000000000
0000006a80000000
6a00000001000000
6a00000001000000
000000000000006a8000000000000000
6a00000001000000
0000006a80000000
-
{a=>-44,b=>1}
d4ffffff01000000
d4ffffffffffffff0100000000000000
d4ffffffffffffff0100000000000000
ffffffd480000000
d4ffffff01000000
d4ffffff01000000
ffffffffffffffd48000000000000000
d4ffffff01000000
ffffffd480000000
-
{a=>-88,b=>1}
a8ffffff01000000
a8ffffffffffffff0100000000000000
a8ffffffffffffff0100000000000000
ffffffa880000000
a8ffffff01000000
a8ffffff01000000
ffffffffffffffa88000000000000000
a8ffffff01000000
ffffffa880000000
=
struct mixed1 {
  long a;
  unsigned int b:1;
  unsigned int c:1;
};
-
{c=>0,a=>-69,b=>1}
bbffffff01000000
bbffffffffffffff0100000000000000
bbffffffffffffff0100000000000000
ffffffbb80000000
bbffffff01000000
bbffffff01000000
ffffffffffffffbb8000000000000000
bbffffff01000000
ffffffbb80000000
-
{c=>0,a=>-85,b=>1}
abffffff01000000
abffffffffffffff0100000000000000
abffffffffffffff0100000000000000
ffffffab80000000
abffffff01000000
abffffff01000000
ffffffffffffffab8000000000000000
abffffff01000000
ffffffab80000000
-
{c=>0,a=>33,b=>1}
2100000001000000
21000000000000000100000000000000
21000000000000000100000000000000
0000002180000000
2100000001000000
2100000001000000
00000000000000218000000000000000
2100000001000000
0000002180000000
-
{c=>1,a=>40,b=>1}
2800000003000000
28000000000000000300000000000000
28000000000000000300000000000000
00000028c0000000
2800000003000000
2800000003000000
0000000000000028c000000000000000
2800000003000000
00000028c0000000
-
{c=>0,a=>-14,b=>1}
f2ffffff01000000
f2ffffffffffffff0100000000000000
f2ffffffffffffff0100000000000000
fffffff280000000
f2ffffff01000000
f2ffffff01000000
fffffffffffffff28000000000000000
f2ffffff01000000
fffffff280000000
=
struct mixed1 {
  long a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
};
-
{c=>0,a=>-30,b=>0}
e2ffffff00000000
e2ffffffffffffff0000000000000000
e2ffffffffffffff0000000000000000
ffffffe200000000
e2ffffff00000000
e2ffffff00000000
ffffffffffffffe20000000000000000
e2ffffff00000000
ffffffe200000000
-
{c=>0,a=>-60,b=>0}
c4ffffff00000000
c4ffffffffffffff0000000000000000
c4ffffffffffffff0000000000000000
ffffffc400000000
c4ffffff00000000
c4ffffff00000000
ffffffffffffffc40000000000000000
c4ffffff00000000
ffffffc400000000
-
{c=>1,a=>57,b=>0}
3900000002000000
39000000000000000200000000000000
39000000000000000200000000000000
0000003940000000
3900000002000000
3900000002000000
00000000000000394000000000000000
3900000002000000
0000003940000000
-
{c=>1,a=>11,b=>0}
0b00000002000000
0b000000000000000200000000000000
0b000000000000000200000000000000
0000000b40000000
0b00000002000000
0b00000002000000
000000000000000b4000000000000000
0b00000002000000
0000000b40000000
-
{c=>1,a=>-73,b=>1}
b7ffffff03000000
b7ffffffffffffff0300000000000000
b7ffffffffffffff0300000000000000
ffffffb7c0000000
b7ffffff03000000
b7ffffff03000000
ffffffffffffffb7c000000000000000
b7ffffff03000000
ffffffb7c0000000
=
struct mixed1 {
  long a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
};
-
{c=>0,a=>-46,b=>0,d=>1}
d2ffffff0000000001000000
d2ffffffffffffff0000000001000000
d2ffffffffffffff0000000001000000
ffffffd20000000080000000
d2ffffff0000000001000000
d2ffffff0000000001000000
ffffffffffffffd20000000080000000
d2ffffff0000000001000000
ffffffd20000000080000000
-
{c=>0,a=>27,b=>0,d=>0}
1b0000000000000000000000
1b000000000000000000000000000000
1b000000000000000000000000000000
0000001b0000000000000000
1b0000000000000000000000
1b0000000000000000000000
000000000000001b0000000000000000
1b0000000000000000000000
0000001b0000000000000000
-
{c=>1,a=>1,b=>1,d=>0}
010000000300000000000000
01000000000000000300000000000000
01000000000000000300000000000000
00000001c000000000000000
010000000300000000000000
010000000300000000000000
0000000000000001c000000000000000
010000000300000000000000
00000001c000000000000000
-
{c=>1,a=>71,b=>0,d=>0}
470000000200000000000000
47000000000000000200000000000000
47000000000000000200000000000000
000000474000000000000000
470000000200000000000000
470000000200000000000000
00000000000000474000000000000000
470000000200000000000000
000000474000000000000000
-
{c=>0,a=>-14,b=>1,d=>1}
f2ffffff0100000001000000
f2ffffffffffffff0100000001000000
f2ffffffffffffff0100000001000000
fffffff28000000080000000
f2ffffff0100000001000000
f2ffffff0100000001000000
fffffffffffffff28000000080000000
f2ffffff0100000001000000
fffffff28000000080000000
=
struct mixed1 {
  long a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
};
-
{e=>-1,c=>1,a=>19,b=>0,d=>0}
130000000200000002000000
13000000000000000200000002000000
13000000000000000200000002000000
000000134000000040000000
130000000200000002000000
130000000200000002000000
00000000000000134000000040000000
130000000200000002000000
000000134000000040000000
-
{e=>-1,c=>1,a=>70,b=>0,d=>1}
460000000200000003000000
46000000000000000200000003000000
46000000000000000200000003000000
0000004640000000c0000000
460000000200000003000000
460000000200000003000000
000000000000004640000000c0000000
460000000200000003000000
0000004640000000c0000000
-
{e=>-1,c=>1,a=>-112,b=>1,d=>0}
90ffffff0300000002000000
90ffffffffffffff0300000002000000
90ffffffffffffff0300000002000000
ffffff90c000000040000000
90ffffff0300000002000000
90ffffff0300000002000000
ffffffffffffff90c000000040000000
90ffffff0300000002000000
ffffff90c000000040000000
-
{e=>0,c=>0,a=>90,b=>0,d=>1}
5a0000000000000001000000
5a000000000000000000000001000000
5a000000000000000000000001000000
0000005a0000000080000000
5a0000000000000001000000
5a0000000000000001000000
000000000000005a0000000080000000
5a0000000000000001000000
0000005a0000000080000000
-
{e=>-1,c=>1,a=>-16,b=>1,d=>0}
f0ffffff0300000002000000
f0ffffffffffffff0300000002000000
f0ffffffffffffff0300000002000000
fffffff0c000000040000000
f0ffffff0300000002000000
f0ffffff0300000002000000
fffffffffffffff0c000000040000000
f0ffffff0300000002000000
fffffff0c000000040000000
=
struct mixed1 {
  long a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
};
-
{e=>-1,c=>1,a=>92,b=>0,d=>0,f=>-1}
5c0000000200000006000000
5c000000000000000200000006000000
5c000000000000000200000006000000
0000005c4000000060000000
5c0000000200000006000000
5c0000000200000006000000
000000000000005c4000000060000000
5c0000000200000006000000
0000005c4000000060000000
-
{e=>0,c=>1,a=>-112,b=>1,d=>0,f=>0}
90ffffff0300000000000000
90ffffffffffffff0300000000000000
90ffffffffffffff0300000000000000
ffffff90c000000000000000
90ffffff0300000000000000
90ffffff0300000000000000
ffffffffffffff90c000000000000000
90ffffff0300000000000000
ffffff90c000000000000000
-
{e=>-1,c=>0,a=>-75,b=>1,d=>1,f=>0}
b5ffffff0100000003000000
b5ffffffffffffff0100000003000000
b5ffffffffffffff0100000003000000
ffffffb580000000c0000000
b5ffffff0100000003000000
b5ffffff0100000003000000
ffffffffffffffb580000000c0000000
b5ffffff0100000003000000
ffffffb580000000c0000000
-
{e=>0,c=>0,a=>-54,b=>1,d=>1,f=>-1}
caffffff0100000005000000
caffffffffffffff0100000005000000
caffffffffffffff0100000005000000
ffffffca80000000a0000000
caffffff0100000005000000
caffffff0100000005000000
ffffffffffffffca80000000a0000000
caffffff0100000005000000
ffffffca80000000a0000000
-
{e=>0,c=>0,a=>-3,b=>0,d=>0,f=>-1}
fdffffff0000000004000000
fdffffffffffffff0000000004000000
fdffffffffffffff0000000004000000
fffffffd0000000020000000
fdffffff0000000004000000
fdffffff0000000004000000
fffffffffffffffd0000000020000000
fdffffff0000000004000000
fffffffd0000000020000000
=
struct mixed1 {
  long a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
};
-
{e=>0,c=>1,a=>99,b=>1,d=>0,f=>0}
630000000300000000000000
63000000000000000300000000000000
63000000000000000300000000000000
00000063c000000000000000
630000000300000000000000
630000000300000000000000
0000000000000063c000000000000000
630000000300000000000000
00000063c000000000000000
-
{e=>0,c=>1,a=>121,b=>1,d=>1,f=>0}
790000000300000001000000
79000000000000000300000001000000
79000000000000000300000001000000
00000079c000000080000000
790000000300000001000000
790000000300000001000000
0000000000000079c000000080000000
790000000300000001000000
00000079c000000080000000
-
{e=>0,c=>1,a=>101,b=>0,d=>0,f=>-1}
650000000200000004000000
65000000000000000200000004000000
65000000000000000200000004000000
000000654000000020000000
650000000200000004000000
650000000200000004000000
00000000000000654000000020000000
650000000200000004000000
000000654000000020000000
-
{e=>0,c=>1,a=>-100,b=>0,d=>0,f=>0}
9cffffff0200000000000000
9cffffffffffffff0200000000000000
9cffffffffffffff0200000000000000
ffffff9c4000000000000000
9cffffff0200000000000000
9cffffff0200000000000000
ffffffffffffff9c4000000000000000
9cffffff0200000000000000
ffffff9c4000000000000000
-
{e=>0,c=>1,a=>-59,b=>0,d=>1,f=>0}
c5ffffff0200000001000000
c5ffffffffffffff0200000001000000
c5ffffffffffffff0200000001000000
ffffffc54000000080000000
c5ffffff0200000001000000
c5ffffff0200000001000000
ffffffffffffffc54000000080000000
c5ffffff0200000001000000
ffffffc54000000080000000
=
struct mixed1 {
  long a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
};
-
{e=>0,c=>0,a=>73,g=>-1,b=>1,d=>1,f=>-1}
49000000010000000500000001000000
490000000000000001000000050000000100000000000000
490000000000000001000000050000000100000000000000
0000004980000000a000000080000000
49000000010000000500000001000000
49000000010000000500000001000000
000000000000004980000000a00000008000000000000000
49000000010000000500000001000000
0000004980000000a000000080000000
-
{e=>0,c=>0,a=>11,g=>0,b=>1,d=>0,f=>0}
0b000000010000000000000000000000
0b0000000000000001000000000000000000000000000000
0b0000000000000001000000000000000000000000000000
0000000b800000000000000000000000
0b000000010000000000000000000000
0b000000010000000000000000000000
000000000000000b80000000000000000000000000000000
0b000000010000000000000000000000
0000000b800000000000000000000000
-
{e=>-1,c=>0,a=>-31,g=>-1,b=>1,d=>1,f=>0}
e1ffffff010000000300000001000000
e1ffffffffffffff01000000030000000100000000000000
e1ffffffffffffff01000000030000000100000000000000
ffffffe180000000c000000080000000
e1ffffff010000000300000001000000
e1ffffff010000000300000001000000
ffffffffffffffe180000000c00000008000000000000000
e1ffffff010000000300000001000000
ffffffe180000000c000000080000000
-
{e=>-1,c=>0,a=>-124,g=>-1,b=>1,d=>1,f=>-1}
84ffffff010000000700000001000000
84ffffffffffffff01000000070000000100000000000000
84ffffffffffffff01000000070000000100000000000000
ffffff8480000000e000000080000000
84ffffff010000000700000001000000
84ffffff010000000700000001000000
ffffffffffffff8480000000e00000008000000000000000
84ffffff010000000700000001000000
ffffff8480000000e000000080000000
-
{e=>-1,c=>0,a=>-42,g=>0,b=>1,d=>0,f=>-1}
d6ffffff010000000600000000000000
d6ffffffffffffff01000000060000000000000000000000
d6ffffffffffffff01000000060000000000000000000000
ffffffd6800000006000000000000000
d6ffffff010000000600000000000000
d6ffffff010000000600000000000000
ffffffffffffffd680000000600000000000000000000000
d6ffffff010000000600000000000000
ffffffd6800000006000000000000000
=
struct mixed1 {
  long a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
};
-
{e=>-1,a=>86,d=>0,c=>0,h=>0,b=>0,g=>0,f=>-1}
56000000000000000600000000000000
560000000000000000000000060000000000000000000000
560000000000000000000000060000000000000000000000
00000056000000006000000000000000
56000000000000000600000000000000
56000000000000000600000000000000
000000000000005600000000600000000000000000000000
56000000000000000600000000000000
00000056000000006000000000000000
-
{e=>-1,a=>-97,d=>1,c=>0,h=>0,b=>0,g=>-1,f=>-1}
9fffffff000000000700000001000000
9fffffffffffffff00000000070000000100000000000000
9fffffffffffffff00000000070000000100000000000000
ffffff9f00000000e000000080000000
9fffffff000000000700000001000000
9fffffff000000000700000001000000
ffffffffffffff9f00000000e00000008000000000000000
9fffffff000000000700000001000000
ffffff9f00000000e000000080000000
-
{e=>0,a=>18,d=>0,c=>1,h=>-1,b=>0,g=>0,f=>0}
12000000020000000000000002000000
120000000000000002000000000000000200000000000000
120000000000000002000000000000000200000000000000
00000012400000000000000040000000
12000000020000000000000002000000
12000000020000000000000002000000
000000000000001240000000000000004000000000000000
12000000020000000000000002000000
00000012400000000000000040000000
-
{e=>0,a=>-102,d=>0,c=>0,h=>-1,b=>1,g=>-1,f=>0}
9affffff010000000000000003000000
9affffffffffffff01000000000000000300000000000000
9affffffffffffff01000000000000000300000000000000
ffffff9a8000000000000000c0000000
9affffff010000000000000003000000
9affffff010000000000000003000000
ffffffffffffff9a8000000000000000c000000000000000
9affffff010000000000000003000000
ffffff9a8000000000000000c0000000
-
{e=>0,a=>-36,d=>0,c=>0,h=>-1,b=>1,g=>0,f=>0}
dcffffff010000000000000002000000
dcffffffffffffff01000000000000000200000000000000
dcffffffffffffff01000000000000000200000000000000
ffffffdc800000000000000040000000
dcffffff010000000000000002000000
dcffffff010000000000000002000000
ffffffffffffffdc80000000000000004000000000000000
dcffffff010000000000000002000000
ffffffdc800000000000000040000000
=
struct mixed1 {
  long a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
};
-
{e=>-1,a=>83,d=>1,c=>1,h=>-1,b=>1,g=>-1,f=>-1,i=>0}
53000000030000000700000003000000
530000000000000003000000070000000300000000000000
530000000000000003000000070000000300000000000000
00000053c0000000e0000000c0000000
53000000030000000700000003000000
53000000030000000700000003000000
0000000000000053c0000000e0000000c000000000000000
53000000030000000700000003000000
00000053c0000000e0000000c0000000
-
{e=>0,a=>35,d=>1,c=>0,h=>0,b=>1,g=>-1,f=>0,i=>0}
23000000010000000100000001000000
230000000000000001000000010000000100000000000000
230000000000000001000000010000000100000000000000
00000023800000008000000080000000
23000000010000000100000001000000
23000000010000000100000001000000
000000000000002380000000800000008000000000000000
23000000010000000100000001000000
00000023800000008000000080000000
-
{e=>-1,a=>-48,d=>1,c=>1,h=>-1,b=>0,g=>0,f=>-1,i=>0}
d0ffffff020000000700000002000000
d0ffffffffffffff02000000070000000200000000000000
d0ffffffffffffff02000000070000000200000000000000
ffffffd040000000e000000040000000
d0ffffff020000000700000002000000
d0ffffff020000000700000002000000
ffffffffffffffd040000000e00000004000000000000000
d0ffffff020000000700000002000000
ffffffd040000000e000000040000000
-
{e=>-1,a=>47,d=>1,c=>1,h=>-1,b=>0,g=>0,f=>0,i=>0}
2f000000020000000300000002000000
2f0000000000000002000000030000000200000000000000
2f0000000000000002000000030000000200000000000000
0000002f40000000c000000040000000
2f000000020000000300000002000000
2f000000020000000300000002000000
000000000000002f40000000c00000004000000000000000
2f000000020000000300000002000000
0000002f40000000c000000040000000
-
{e=>-1,a=>-92,d=>1,c=>0,h=>-1,b=>1,g=>-1,f=>0,i=>0}
a4ffffff010000000300000003000000
a4ffffffffffffff01000000030000000300000000000000
a4ffffffffffffff01000000030000000300000000000000
ffffffa480000000c0000000c0000000
a4ffffff010000000300000003000000
a4ffffff010000000300000003000000
ffffffffffffffa480000000c0000000c000000000000000
a4ffffff010000000300000003000000
ffffffa480000000c0000000c0000000
=
struct mixed1 {
  long a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
  int           :0;
};
-
{e=>0,a=>-32,d=>0,c=>0,h=>-1,b=>1,g=>-1,f=>-1,i=>0}
e0ffffff010000000400000003000000
e0ffffffffffffff01000000040000000300000000000000
e0ffffffffffffff01000000040000000300000000000000
ffffffe08000000020000000c0000000
e0ffffff010000000400000003000000
e0ffffff010000000400000003000000
ffffffffffffffe08000000020000000c000000000000000
e0ffffff010000000400000003000000
ffffffe08000000020000000c0000000
-
{e=>0,a=>-105,d=>1,c=>1,h=>0,b=>0,g=>-1,f=>-1,i=>-1}
97ffffff020000000500000005000000
97ffffffffffffff02000000050000000500000000000000
97ffffffffffffff02000000050000000500000000000000
ffffff9740000000a0000000a0000000
97ffffff020000000500000005000000
97ffffff020000000500000005000000
ffffffffffffff9740000000a0000000a000000000000000
97ffffff020000000500000005000000
ffffff9740000000a0000000a0000000
-
{e=>0,a=>95,d=>1,c=>1,h=>-1,b=>1,g=>-1,f=>-1,i=>-1}
5f000000030000000500000007000000
5f0000000000000003000000050000000700000000000000
5f0000000000000003000000050000000700000000000000
0000005fc0000000a0000000e0000000
5f000000030000000500000007000000
5f000000030000000500000007000000
000000000000005fc0000000a0000000e000000000000000
5f000000030000000500000007000000
0000005fc0000000a0000000e0000000
-
{e=>-1,a=>-81,d=>0,c=>0,h=>0,b=>1,g=>0,f=>0,i=>0}
afffffff010000000200000000000000
afffffffffffffff01000000020000000000000000000000
afffffffffffffff01000000020000000000000000000000
ffffffaf800000004000000000000000
afffffff010000000200000000000000
afffffff010000000200000000000000
ffffffffffffffaf80000000400000000000000000000000
afffffff010000000200000000000000
ffffffaf800000004000000000000000
-
{e=>-1,a=>54,d=>0,c=>0,h=>-1,b=>0,g=>-1,f=>0,i=>-1}
36000000000000000200000007000000
360000000000000000000000020000000700000000000000
360000000000000000000000020000000700000000000000
000000360000000040000000e0000000
36000000000000000200000007000000
36000000000000000200000007000000
00000000000000360000000040000000e000000000000000
36000000000000000200000007000000
000000360000000040000000e0000000
=
struct mixed1 {
  long a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
  int           :0;
  int          j:1;
};
-
{e=>0,a=>-112,d=>0,j=>0,c=>1,h=>0,b=>1,g=>-1,f=>0,i=>-1}
90ffffff03000000000000000500000000000000
90ffffffffffffff03000000000000000500000000000000
90ffffffffffffff03000000000000000500000000000000
ffffff90c000000000000000a000000000000000
90ffffff03000000000000000500000000000000
90ffffff03000000000000000500000000000000
ffffffffffffff90c000000000000000a000000000000000
90ffffff03000000000000000500000000000000
ffffff90c000000000000000a000000000000000
-
{e=>0,a=>39,d=>0,j=>0,c=>1,h=>-1,b=>1,g=>-1,f=>-1,i=>0}
2700000003000000040000000300000000000000
270000000000000003000000040000000300000000000000
270000000000000003000000040000000300000000000000
00000027c000000020000000c000000000000000
2700000003000000040000000300000000000000
2700000003000000040000000300000000000000
0000000000000027c000000020000000c000000000000000
2700000003000000040000000300000000000000
00000027c000000020000000c000000000000000
-
{e=>-1,a=>113,d=>1,j=>-1,c=>1,h=>-1,b=>0,g=>0,f=>-1,i=>0}
7100000002000000070000000200000001000000
710000000000000002000000070000000200000001000000
710000000000000002000000070000000200000001000000
0000007140000000e00000004000000080000000
7100000002000000070000000200000001000000
7100000002000000070000000200000001000000
000000000000007140000000e00000004000000080000000
7100000002000000070000000200000001000000
0000007140000000e00000004000000080000000
-
{e=>0,a=>118,d=>1,j=>0,c=>1,h=>0,b=>0,g=>0,f=>0,i=>-1}
7600000002000000010000000400000000000000
760000000000000002000000010000000400000000000000
760000000000000002000000010000000400000000000000
0000007640000000800000002000000000000000
7600000002000000010000000400000000000000
7600000002000000010000000400000000000000
000000000000007640000000800000002000000000000000
7600000002000000010000000400000000000000
0000007640000000800000002000000000000000
-
{e=>-1,a=>80,d=>0,j=>-1,c=>1,h=>0,b=>0,g=>-1,f=>-1,i=>0}
5000000002000000060000000100000001000000
500000000000000002000000060000000100000001000000
500000000000000002000000060000000100000001000000
0000005040000000600000008000000080000000
5000000002000000060000000100000001000000
5000000002000000060000000100000001000000
000000000000005040000000600000008000000080000000
5000000002000000060000000100000001000000
0000005040000000600000008000000080000000
=
struct mixed1 {
  long a;
  unsigned int b:1;
  unsigned int c:1;
  unsigned int  :0;
  unsigned int d:1;
  signed   int e:1;
  signed   int f:1;
  signed   int  :0;
  signed   int g:1;
  int          h:1;
  int          i:1;
  int           :0;
  int          j:1;
  long         k;
};
-
{e=>-1,a=>2,d=>0,j=>0,c=>1,k=>-79,h=>0,b=>1,g=>0,f=>0,i=>0}
0200000003000000020000000000000000000000b1ffffff
020000000000000003000000020000000000000000000000b1ffffffffffffff
020000000000000003000000020000000000000000000000b1ffffffffffffff
00000002c0000000400000000000000000000000ffffffb1
0200000003000000020000000000000000000000b1ffffff
0200000003000000020000000000000000000000b1ffffff
0000000000000002c0000000400000000000000000000000ffffffffffffffb1
0200000003000000020000000000000000000000b1ffffff
00000002c0000000400000000000000000000000ffffffb1
-
{e=>0,a=>-88,d=>1,j=>0,c=>1,k=>-90,h=>0,b=>0,g=>-1,f=>0,i=>0}
a8ffffff02000000010000000100000000000000a6ffffff
a8ffffffffffffff02000000010000000100000000000000a6ffffffffffffff
a8ffffffffffffff02000000010000000100000000000000a6ffffffffffffff
ffffffa840000000800000008000000000000000ffffffa6
a8ffffff02000000010000000100000000000000a6ffffff
a8ffffff02000000010000000100000000000000a6ffffff
ffffffffffffffa840000000800000008000000000000000ffffffffffffffa6
a8ffffff02000000010000000100000000000000a6ffffff
ffffffa840000000800000008000000000000000ffffffa6
-
{e=>0,a=>-63,d=>0,j=>-1,c=>1,k=>22,h=>-1,b=>0,g=>0,f=>-1,i=>0}
c1ffffff0200000004000000020000000100000016000000
c1ffffffffffffff020000000400000002000000010000001600000000000000
c1ffffffffffffff020000000400000002000000010000001600000000000000
ffffffc14000000020000000400000008000000000000016
c1ffffff0200000004000000020000000100000016000000
c1ffffff0200000004000000020000000100000016000000
ffffffffffffffc1400000002000000040000000800000000000000000000016
c1ffffff0200000004000000020000000100000016000000
ffffffc14000000020000000400000008000000000000016
-
{e=>0,a=>23,d=>1,j=>0,c=>1,k=>21,h=>0,b=>1,g=>-1,f=>-1,i=>0}
170000000300000005000000010000000000000015000000
1700000000000000030000000500000001000000000000001500000000000000
1700000000000000030000000500000001000000000000001500000000000000
00000017c0000000a0000000800000000000000000000015
170000000300000005000000010000000000000015000000
170000000300000005000000010000000000000015000000
0000000000000017c0000000a000000080000000000000000000000000000015
170000000300000005000000010000000000000015000000
00000017c0000000a0000000800000000000000000000015
-
{e=>-1,a=>84,d=>1,j=>-1,c=>1,k=>47,h=>0,b=>1,g=>-1,f=>0,i=>-1}
54000000030000000300000005000000010000002f000000
5400000000000000030000000300000005000000010000002f00000000000000
5400000000000000030000000300000005000000010000002f00000000000000
00000054c0000000c0000000a0000000800000000000002f
54000000030000000300000005000000010000002f000000
54000000030000000300000005000000010000002f000000
0000000000000054c0000000c0000000a000000080000000000000000000002f
54000000030000000300000005000000010000002f000000
00000054c0000000c0000000a0000000800000000000002f
=
struct mixed2 {
  unsigned int a:2;
};
-
{a=>1}
01000000
01000000
01000000
40000000
01000000
01000000
40000000
01000000
40000000
-
{a=>2}
02000000
02000000
02000000
80000000
02000000
02000000
80000000
02000000
80000000
-
{a=>2}
02000000
02000000
02000000
80000000
02000000
02000000
80000000
02000000
80000000
-
{a=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
-
{a=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
=
struct mixed2 {
  unsigned int a:2;
  unsigned int b:2;
};
-
{a=>0,b=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
-
{a=>0,b=>2}
08000000
08000000
08000000
20000000
08000000
08000000
20000000
08000000
20000000
-
{a=>3,b=>3}
0f000000
0f000000
0f000000
f0000000
0f000000
0f000000
f0000000
0f000000
f0000000
-
{a=>2,b=>1}
06000000
06000000
06000000
90000000
06000000
06000000
90000000
06000000
90000000
-
{a=>0,b=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
=
struct mixed2 {
  unsigned int a:2;
  unsigned int b:2;
  unsigned int  :0;
};
-
{a=>2,b=>1}
06000000
06000000
06000000
90000000
06000000
06000000
90000000
06000000
90000000
-
{a=>0,b=>3}
0c000000
0c000000
0c000000
30000000
0c000000
0c000000
30000000
0c000000
30000000
-
{a=>2,b=>2}
0a000000
0a000000
0a000000
a0000000
0a000000
0a000000
a0000000
0a000000
a0000000
-
{a=>3,b=>0}
03000000
03000000
03000000
c0000000
03000000
03000000
c0000000
03000000
c0000000
-
{a=>3,b=>1}
07000000
07000000
07000000
d0000000
07000000
07000000
d0000000
07000000
d0000000
=
struct mixed2 {
  unsigned int a:2;
  unsigned int b:2;
  unsigned int  :0;
  unsigned int c:2;
};
-
{c=>0,a=>3,b=>2}
0b00000000000000
0b00000000000000
0b00000000000000
e000000000000000
0b00000000000000
0b00000000000000
e000000000000000
0b00000000000000
e000000000000000
-
{c=>2,a=>2,b=>3}
0e00000002000000
0e00000002000000
0e00000002000000
b000000080000000
0e00000002000000
0e00000002000000
b000000080000000
0e00000002000000
b000000080000000
-
{c=>3,a=>2,b=>2}
0a00000003000000
0a00000003000000
0a00000003000000
a0000000c0000000
0a00000003000000
0a00000003000000
a0000000c0000000
0a00000003000000
a0000000c0000000
-
{c=>1,a=>2,b=>3}
0e00000001000000
0e00000001000000
0e00000001000000
b000000040000000
0e00000001000000
0e00000001000000
b000000040000000
0e00000001000000
b000000040000000
-
{c=>1,a=>0,b=>1}
0400000001000000
0400000001000000
0400000001000000
1000000040000000
0400000001000000
0400000001000000
1000000040000000
0400000001000000
1000000040000000
=
struct mixed2 {
  unsigned int a:2;
  unsigned int b:2;
  unsigned int  :0;
  unsigned int c:2;
  signed   int d:2;
};
-
{c=>0,a=>2,b=>2,d=>-1}
0a0000000c000000
0a0000000c000000
0a0000000c000000
a000000030000000
0a0000000c000000
0a0000000c000000
a000000030000000
0a0000000c000000
a000000030000000
-
{c=>1,a=>0,b=>1,d=>0}
0400000001000000
0400000001000000
0400000001000000
1000000040000000
0400000001000000
0400000001000000
1000000040000000
0400000001000000
1000000040000000
-
{c=>2,a=>2,b=>1,d=>0}
0600000002000000
0600000002000000
0600000002000000
9000000080000000
0600000002000000
0600000002000000
9000000080000000
0600000002000000
9000000080000000
-
{c=>2,a=>0,b=>2,d=>0}
0800000002000000
0800000002000000
0800000002000000
2000000080000000
0800000002000000
0800000002000000
2000000080000000
0800000002000000
2000000080000000
-
{c=>1,a=>1,b=>3,d=>0}
0d00000001000000
0d00000001000000
0d00000001000000
7000000040000000
0d00000001000000
0d00000001000000
7000000040000000
0d00000001000000
7000000040000000
=
struct mixed2 {
  unsigned int a:2;
  unsigned int b:2;
  unsigned int  :0;
  unsigned int c:2;
  signed   int d:2;
  signed   int e:2;
};
-
{e=>1,c=>0,a=>1,b=>2,d=>-2}
0900000018000000
0900000018000000
0900000018000000
6000000024000000
0900000018000000
0900000018000000
6000000024000000
0900000018000000
6000000024000000
-
{e=>0,c=>1,a=>0,b=>2,d=>-1}
080000000d000000
080000000d000000
080000000d000000
2000000070000000
080000000d000000
080000000d000000
2000000070000000
080000000d000000
2000000070000000
-
{e=>-2,c=>3,a=>3,b=>1,d=>1}
0700000027000000
0700000027000000
0700000027000000
d0000000d8000000
0700000027000000
0700000027000000
d0000000d8000000
0700000027000000
d0000000d8000000
-
{e=>1,c=>3,a=>0,b=>1,d=>-1}
040000001f000000
040000001f000000
040000001f000000
10000000f4000000
040000001f000000
040000001f000000
10000000f4000000
040000001f000000
10000000f4000000
-
{e=>-2,c=>0,a=>0,b=>3,d=>-2}
0c00000028000000
0c00000028000000
0c00000028000000
3000000028000000
0c00000028000000
0c00000028000000
3000000028000000
0c00000028000000
3000000028000000
=
struct mixed2 {
  unsigned int a:2;
  unsigned int b:2;
  unsigned int  :0;
  unsigned int c:2;
  signed   int d:2;
  signed   int e:2;
  signed   int  :0;
};
-
{e=>-1,c=>3,a=>2,b=>1,d=>1}
0600000037000000
0600000037000000
0600000037000000
90000000dc000000
0600000037000000
0600000037000000
90000000dc000000
0600000037000000
90000000dc000000
-
{e=>-2,c=>0,a=>1,b=>2,d=>-2}
0900000028000000
0900000028000000
0900000028000000
6000000028000000
0900000028000000
0900000028000000
6000000028000000
0900000028000000
6000000028000000
-
{e=>0,c=>3,a=>2,b=>2,d=>0}
0a00000003000000
0a00000003000000
0a00000003000000
a0000000c0000000
0a00000003000000
0a00000003000000
a0000000c0000000
0a00000003000000
a0000000c0000000
-
{e=>1,c=>2,a=>1,b=>2,d=>-2}
090000001a000000
090000001a000000
090000001a000000
60000000a4000000
090000001a000000
090000001a000000
60000000a4000000
090000001a000000
60000000a4000000
-
{e=>1,c=>2,a=>2,b=>3,d=>0}
0e00000012000000
0e00000012000000
0e00000012000000
b000000084000000
0e00000012000000
0e00000012000000
b000000084000000
0e00000012000000
b000000084000000
=
struct mixed2 {
  unsigned int a:2;
  unsigned int b:2;
  unsigned int  :0;
  unsigned int c:2;
  signed   int d:2;
  signed   int e:2;
  signed   int  :0;
  signed   int f:2;
};
-
{e=>0,c=>1,a=>2,b=>3,d=>0,f=>-1}
0e0000000100000003000000
0e0000000100000003000000
0e0000000100000003000000
b000000040000000c0000000
0e0000000100000003000000
0e0000000100000003000000
b000000040000000c0000000
0e0000000100000003000000
b000000040000000c0000000
-
{e=>0,c=>0,a=>0,b=>2,d=>-1,f=>1}
080000000c00000001000000
080000000c00000001000000
080000000c00000001000000
200000003000000040000000
080000000c00000001000000
080000000c00000001000000
200000003000000040000000
080000000c00000001000000
200000003000000040000000
-
{e=>0,c=>2,a=>0,b=>0,d=>0,f=>-2}
000000000200000002000000
000000000200000002000000
000000000200000002000000
000000008000000080000000
000000000200000002000000
000000000200000002000000
000000008000000080000000
000000000200000002000000
000000008000000080000000
-
{e=>-2,c=>3,a=>2,b=>1,d=>-2,f=>-2}
060000002b00000002000000
060000002b00000002000000
060000002b00000002000000
90000000e800000080000000
060000002b00000002000000
060000002b00000002000000
90000000e800000080000000
060000002b00000002000000
90000000e800000080000000
-
{e=>-2,c=>2,a=>0,b=>3,d=>-2,f=>-1}
0c0000002a00000003000000
0c0000002a00000003000000
0c0000002a00000003000000
30000000a8000000c0000000
0c0000002a00000003000000
0c0000002a00000003000000
30000000a8000000c0000000
0c0000002a00000003000000
30000000a8000000c0000000
=
struct mixed2 {
  unsigned int a:2;
  unsigned int b:2;
  unsigned int  :0;
  unsigned int c:2;
  signed   int d:2;
  signed   int e:2;
  signed   int  :0;
  signed   int f:2;
  int          g:2;
};
-
{e=>0,c=>2,a=>1,g=>-1,b=>3,d=>1,f=>-1}
0d000000060000000f000000
0d000000060000000f000000
0d000000060000000f000000
7000000090000000f0000000
0d000000060000000f000000
0d000000060000000f000000
7000000090000000f0000000
0d000000060000000f000000
7000000090000000f0000000
-
{e=>1,c=>2,a=>2,g=>1,b=>2,d=>1,f=>1}
0a0000001600000005000000
0a0000001600000005000000
0a0000001600000005000000
a00000009400000050000000
0a0000001600000005000000
0a0000001600000005000000
a00000009400000050000000
0a0000001600000005000000
a00000009400000050000000
-
{e=>0,c=>2,a=>2,g=>-1,b=>2,d=>-2,f=>-1}
0a0000000a0000000f000000
0a0000000a0000000f000000
0a0000000a0000000f000000
a0000000a0000000f0000000
0a0000000a0000000f000000
0a0000000a0000000f000000
a0000000a0000000f0000000
0a0000000a0000000f000000
a0000000a0000000f0000000
-
{e=>-2,c=>0,a=>2,g=>-2,b=>1,d=>-1,f=>1}
060000002c00000009000000
060000002c00000009000000
060000002c00000009000000
900000003800000060000000
060000002c00000009000000
060000002c00000009000000
900000003800000060000000
060000002c00000009000000
900000003800000060000000
-
{e=>-1,c=>3,a=>1,g=>-1,b=>0,d=>0,f=>0}
01000000330000000c000000
01000000330000000c000000
01000000330000000c000000
40000000cc00000030000000
01000000330000000c000000
01000000330000000c000000
40000000cc00000030000000
01000000330000000c000000
40000000cc00000030000000
=
struct mixed2 {
  unsigned int a:2;
  unsigned int b:2;
  unsigned int  :0;
  unsigned int c:2;
  signed   int d:2;
  signed   int e:2;
  signed   int  :0;
  signed   int f:2;
  int          g:2;
  int          h:2;
};
-
{e=>-2,a=>0,d=>1,c=>2,h=>-1,b=>1,g=>-2,f=>-2}
04000000260000003a000000
04000000260000003a000000
04000000260000003a000000
1000000098000000ac000000
04000000260000003a000000
04000000260000003a000000
1000000098000000ac000000
04000000260000003a000000
1000000098000000ac000000
-
{e=>-2,a=>0,d=>1,c=>0,h=>0,b=>0,g=>1,f=>0}
000000002400000004000000
000000002400000004000000
000000002400000004000000
000000001800000010000000
000000002400000004000000
000000002400000004000000
000000001800000010000000
000000002400000004000000
000000001800000010000000
-
{e=>1,a=>1,d=>1,c=>1,h=>0,b=>0,g=>-1,f=>-2}
01000000150000000e000000
01000000150000000e000000
01000000150000000e000000
4000000054000000b0000000
01000000150000000e000000
01000000150000000e000000
4000000054000000b0000000
01000000150000000e000000
4000000054000000b0000000
-
{e=>0,a=>3,d=>0,c=>0,h=>1,b=>2,g=>0,f=>1}
0b0000000000000011000000
0b0000000000000011000000
0b0000000000000011000000
e00000000000000044000000
0b0000000000000011000000
0b0000000000000011000000
e00000000000000044000000
0b0000000000000011000000
e00000000000000044000000
-
{e=>-1,a=>1,d=>0,c=>1,h=>0,b=>0,g=>0,f=>0}
010000003100000000000000
010000003100000000000000
010000003100000000000000
400000004c00000000000000
010000003100000000000000
010000003100000000000000
400000004c00000000000000
010000003100000000000000
400000004c00000000000000
=
struct mixed2 {
  unsigned int a:2;
  unsigned int b:2;
  unsigned int  :0;
  unsigned int c:2;
  signed   int d:2;
  signed   int e:2;
  signed   int  :0;
  signed   int f:2;
  int          g:2;
  int          h:2;
  int           :0;
};
-
{e=>-2,a=>0,d=>0,c=>0,h=>-1,b=>1,g=>0,f=>-2}
040000002000000032000000
040000002000000032000000
040000002000000032000000
10000000080000008c000000
040000002000000032000000
040000002000000032000000
10000000080000008c000000
040000002000000032000000
10000000080000008c000000
-
{e=>0,a=>3,d=>-2,c=>2,h=>-1,b=>3,g=>-1,f=>-2}
0f0000000a0000003e000000
0f0000000a0000003e000000
0f0000000a0000003e000000
f0000000a0000000bc000000
0f0000000a0000003e000000
0f0000000a0000003e000000
f0000000a0000000bc000000
0f0000000a0000003e000000
f0000000a0000000bc000000
-
{e=>-1,a=>0,d=>0,c=>1,h=>-1,b=>0,g=>-1,f=>0}
00000000310000003c000000
00000000310000003c000000
00000000310000003c000000
000000004c0000003c000000
00000000310000003c000000
00000000310000003c000000
000000004c0000003c000000
00000000310000003c000000
000000004c0000003c000000
-
{e=>0,a=>3,d=>-2,c=>0,h=>1,b=>2,g=>-2,f=>1}
0b0000000800000019000000
0b0000000800000019000000
0b0000000800000019000000
e00000002000000064000000
0b0000000800000019000000
0b0000000800000019000000
e00000002000000064000000
0b0000000800000019000000
e00000002000000064000000
-
{e=>-1,a=>2,d=>0,c=>1,h=>1,b=>0,g=>0,f=>1}
020000003100000011000000
020000003100000011000000
020000003100000011000000
800000004c00000044000000
020000003100000011000000
020000003100000011000000
800000004c00000044000000
020000003100000011000000
800000004c00000044000000
=
struct mixed2 {
  unsigned int a:2;
  unsigned int b:2;
  unsigned int  :0;
  unsigned int c:2;
  signed   int d:2;
  signed   int e:2;
  signed   int  :0;
  signed   int f:2;
  int          g:2;
  int          h:2;
  int           :0;
  int          i:2;
};
-
{e=>0,a=>0,d=>0,c=>2,h=>-1,b=>2,g=>1,f=>0,i=>1}
08000000020000003400000001000000
08000000020000003400000001000000
08000000020000003400000001000000
20000000800000001c00000040000000
08000000020000003400000001000000
08000000020000003400000001000000
20000000800000001c00000040000000
08000000020000003400000001000000
20000000800000001c00000040000000
-
{e=>0,a=>0,d=>-2,c=>0,h=>-1,b=>0,g=>-2,f=>1,i=>1}
00000000080000003900000001000000
00000000080000003900000001000000
00000000080000003900000001000000
00000000200000006c00000040000000
00000000080000003900000001000000
00000000080000003900000001000000
00000000200000006c00000040000000
00000000080000003900000001000000
00000000200000006c00000040000000
-
{e=>-1,a=>2,d=>0,c=>0,h=>0,b=>1,g=>-2,f=>0,i=>-1}
06000000300000000800000003000000
06000000300000000800000003000000
06000000300000000800000003000000
900000000c00000020000000c0000000
06000000300000000800000003000000
06000000300000000800000003000000
900000000c00000020000000c0000000
06000000300000000800000003000000
900000000c00000020000000c0000000
-
{e=>1,a=>0,d=>0,c=>2,h=>0,b=>2,g=>1,f=>0,i=>1}
08000000120000000400000001000000
08000000120000000400000001000000
08000000120000000400000001000000
20000000840000001000000040000000
08000000120000000400000001000000
08000000120000000400000001000000
20000000840000001000000040000000
08000000120000000400000001000000
20000000840000001000000040000000
-
{e=>0,a=>3,d=>-1,c=>0,h=>-1,b=>2,g=>-2,f=>0,i=>-2}
0b0000000c0000003800000002000000
0b0000000c0000003800000002000000
0b0000000c0000003800000002000000
e0000000300000002c00000080000000
0b0000000c0000003800000002000000
0b0000000c0000003800000002000000
e0000000300000002c00000080000000
0b0000000c0000003800000002000000
e0000000300000002c00000080000000
=
struct mixed2 {
  unsigned int a:2;
  unsigned int b:2;
  unsigned int  :0;
  unsigned int c:2;
  signed   int d:2;
  signed   int e:2;
  signed   int  :0;
  signed   int f:2;
  int          g:2;
  int          h:2;
  int           :0;
  int          i:2;
  int          j;
};
-
{e=>-2,a=>1,d=>0,j=>11,c=>0,h=>-2,b=>1,g=>1,f=>-1,i=>-1}
050000002000000027000000030000000b000000
050000002000000027000000030000000b000000
050000002000000027000000030000000b000000
5000000008000000d8000000c00000000000000b
050000002000000027000000030000000b000000
050000002000000027000000030000000b000000
5000000008000000d8000000c00000000000000b
050000002000000027000000030000000b000000
5000000008000000d8000000c00000000000000b
-
{e=>1,a=>2,d=>-2,j=>76,c=>3,h=>-1,b=>1,g=>0,f=>-1,i=>1}
060000001b00000033000000010000004c000000
060000001b00000033000000010000004c000000
060000001b00000033000000010000004c000000
90000000e4000000cc000000400000000000004c
060000001b00000033000000010000004c000000
060000001b00000033000000010000004c000000
90000000e4000000cc000000400000000000004c
060000001b00000033000000010000004c000000
90000000e4000000cc000000400000000000004c
-
{e=>1,a=>3,d=>0,j=>-66,c=>0,h=>-2,b=>3,g=>-2,f=>-1,i=>-2}
0f000000100000002b00000002000000beffffff
0f000000100000002b00000002000000beffffff
0f000000100000002b00000002000000beffffff
f000000004000000e800000080000000ffffffbe
0f000000100000002b00000002000000beffffff
0f000000100000002b00000002000000beffffff
f000000004000000e800000080000000ffffffbe
0f000000100000002b00000002000000beffffff
f000000004000000e800000080000000ffffffbe
-
{e=>-1,a=>0,d=>0,j=>-99,c=>1,h=>0,b=>1,g=>-2,f=>0,i=>1}
040000003100000008000000010000009dffffff
040000003100000008000000010000009dffffff
040000003100000008000000010000009dffffff
100000004c0000002000000040000000ffffff9d
040000003100000008000000010000009dffffff
040000003100000008000000010000009dffffff
100000004c0000002000000040000000ffffff9d
040000003100000008000000010000009dffffff
100000004c0000002000000040000000ffffff9d
-
{e=>-1,a=>2,d=>1,j=>94,c=>3,h=>-2,b=>3,g=>1,f=>-2,i=>-2}
0e0000003700000026000000020000005e000000
0e0000003700000026000000020000005e000000
0e0000003700000026000000020000005e000000
b0000000dc00000098000000800000000000005e
0e0000003700000026000000020000005e000000
0e0000003700000026000000020000005e000000
b0000000dc00000098000000800000000000005e
0e0000003700000026000000020000005e000000
b0000000dc00000098000000800000000000005e
=
struct mixed2 {
  char a;
  unsigned int b:2;
};
-
{a=>-56,b=>3}
c8030000
c8030000
c8030000
c8c00000
c8030000
c8030000
c8c00000
c8030000
c8c00000
-
{a=>127,b=>0}
7f000000
7f000000
7f000000
7f000000
7f000000
7f000000
7f000000
7f000000
7f000000
-
{a=>43,b=>2}
2b020000
2b020000
2b020000
2b800000
2b020000
2b020000
2b800000
2b020000
2b800000
-
{a=>-28,b=>1}
e4010000
e4010000
e4010000
e4400000
e4010000
e4010000
e4400000
e4010000
e4400000
-
{a=>38,b=>0}
26000000
26000000
26000000
26000000
26000000
26000000
26000000
26000000
26000000
=
struct mixed2 {
  char a;
  unsigned int b:2;
  unsigned int c:2;
};
-
{c=>0,a=>35,b=>1}
23010000
23010000
23010000
23400000
23010000
23010000
23400000
23010000
23400000
-
{c=>0,a=>53,b=>3}
35030000
35030000
35030000
35c00000
35030000
35030000
35c00000
35030000
35c00000
-
{c=>3,a=>120,b=>0}
780c0000
780c0000
780c0000
78300000
780c0000
780c0000
78300000
780c0000
78300000
-
{c=>3,a=>-123,b=>1}
850d0000
850d0000
850d0000
85700000
850d0000
850d0000
85700000
850d0000
85700000
-
{c=>1,a=>29,b=>3}
1d070000
1d070000
1d070000
1dd00000
1d070000
1d070000
1dd00000
1d070000
1dd00000
=
struct mixed2 {
  char a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
};
-
{c=>2,a=>79,b=>2}
4f0a0000
4f0a0000
4f0a0000
4fa00000
4f0a0000
4f0a0000
4fa00000
4f0a0000
4fa00000
-
{c=>1,a=>-102,b=>2}
9a060000
9a060000
9a060000
9a900000
9a060000
9a060000
9a900000
9a060000
9a900000
-
{c=>0,a=>-112,b=>1}
90010000
90010000
90010000
90400000
90010000
90010000
90400000
90010000
90400000
-
{c=>0,a=>86,b=>0}
56000000
56000000
56000000
56000000
56000000
56000000
56000000
56000000
56000000
-
{c=>2,a=>-112,b=>2}
900a0000
900a0000
900a0000
90a00000
900a0000
900a0000
90a00000
900a0000
90a00000
=
struct mixed2 {
  char a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
};
-
{c=>1,a=>9,b=>1,d=>2}
0905000002000000
0905000002000000
0905000002000000
0950000080000000
0905000002000000
0905000002000000
0950000080000000
0905000002000000
0950000080000000
-
{c=>2,a=>-42,b=>0,d=>3}
d608000003000000
d608000003000000
d608000003000000
d6200000c0000000
d608000003000000
d608000003000000
d6200000c0000000
d608000003000000
d6200000c0000000
-
{c=>2,a=>65,b=>2,d=>2}
410a000002000000
410a000002000000
410a000002000000
41a0000080000000
410a000002000000
410a000002000000
41a0000080000000
410a000002000000
41a0000080000000
-
{c=>1,a=>-14,b=>2,d=>0}
f206000000000000
f206000000000000
f206000000000000
f290000000000000
f206000000000000
f206000000000000
f290000000000000
f206000000000000
f290000000000000
-
{c=>3,a=>-69,b=>1,d=>1}
bb0d000001000000
bb0d000001000000
bb0d000001000000
bb70000040000000
bb0d000001000000
bb0d000001000000
bb70000040000000
bb0d000001000000
bb70000040000000
=
struct mixed2 {
  char a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
};
-
{e=>0,c=>1,a=>-38,b=>2,d=>1}
da06000001000000
da06000001000000
da06000001000000
da90000040000000
da06000001000000
da06000001000000
da90000040000000
da06000001000000
da90000040000000
-
{e=>0,c=>0,a=>66,b=>2,d=>1}
4202000001000000
4202000001000000
4202000001000000
4280000040000000
4202000001000000
4202000001000000
4280000040000000
4202000001000000
4280000040000000
-
{e=>1,c=>2,a=>-56,b=>1,d=>2}
c809000006000000
c809000006000000
c809000006000000
c860000090000000
c809000006000000
c809000006000000
c860000090000000
c809000006000000
c860000090000000
-
{e=>-1,c=>1,a=>120,b=>1,d=>2}
780500000e000000
780500000e000000
780500000e000000
78500000b0000000
780500000e000000
780500000e000000
78500000b0000000
780500000e000000
78500000b0000000
-
{e=>0,c=>2,a=>62,b=>0,d=>3}
3e08000003000000
3e08000003000000
3e08000003000000
3e200000c0000000
3e08000003000000
3e08000003000000
3e200000c0000000
3e08000003000000
3e200000c0000000
=
struct mixed2 {
  char a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
};
-
{e=>1,c=>3,a=>-41,b=>1,d=>2,f=>0}
d70d000006000000
d70d000006000000
d70d000006000000
d770000090000000
d70d000006000000
d70d000006000000
d770000090000000
d70d000006000000
d770000090000000
-
{e=>-2,c=>2,a=>100,b=>2,d=>1,f=>1}
640a000019000000
640a000019000000
640a000019000000
64a0000064000000
640a000019000000
640a000019000000
64a0000064000000
640a000019000000
64a0000064000000
-
{e=>1,c=>0,a=>86,b=>0,d=>3,f=>1}
5600000017000000
5600000017000000
5600000017000000
56000000d4000000
5600000017000000
5600000017000000
56000000d4000000
5600000017000000
56000000d4000000
-
{e=>1,c=>3,a=>-89,b=>3,d=>2,f=>-2}
a70f000026000000
a70f000026000000
a70f000026000000
a7f0000098000000
a70f000026000000
a70f000026000000
a7f0000098000000
a70f000026000000
a7f0000098000000
-
{e=>-1,c=>3,a=>-109,b=>3,d=>0,f=>1}
930f00001c000000
930f00001c000000
930f00001c000000
93f0000034000000
930f00001c000000
930f00001c000000
93f0000034000000
930f00001c000000
93f0000034000000
=
struct mixed2 {
  char a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
};
-
{e=>-2,c=>0,a=>-11,b=>1,d=>3,f=>1}
f50100001b000000
f50100001b000000
f50100001b000000
f5400000e4000000
f50100001b000000
f50100001b000000
f5400000e4000000
f50100001b000000
f5400000e4000000
-
{e=>-2,c=>0,a=>11,b=>0,d=>0,f=>1}
0b00000018000000
0b00000018000000
0b00000018000000
0b00000024000000
0b00000018000000
0b00000018000000
0b00000024000000
0b00000018000000
0b00000024000000
-
{e=>0,c=>3,a=>100,b=>1,d=>3,f=>0}
640d000003000000
640d000003000000
640d000003000000
64700000c0000000
640d000003000000
640d000003000000
64700000c0000000
640d000003000000
64700000c0000000
-
{e=>0,c=>3,a=>-21,b=>2,d=>0,f=>-2}
eb0e000020000000
eb0e000020000000
eb0e000020000000
ebb0000008000000
eb0e000020000000
eb0e000020000000
ebb0000008000000
eb0e000020000000
ebb0000008000000
-
{e=>1,c=>0,a=>-82,b=>1,d=>1,f=>-1}
ae01000035000000
ae01000035000000
ae01000035000000
ae4000005c000000
ae01000035000000
ae01000035000000
ae4000005c000000
ae01000035000000
ae4000005c000000
=
struct mixed2 {
  char a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
};
-
{e=>1,c=>1,a=>-87,g=>-2,b=>0,d=>0,f=>0}
a90400000400000002000000
a90400000400000002000000
a90400000400000002000000
a91000001000000080000000
a90400000400000002000000
a90400000400000002000000
a91000001000000080000000
a90400000400000002000000
a91000001000000080000000
-
{e=>-2,c=>1,a=>1,g=>-2,b=>0,d=>0,f=>-2}
010400002800000002000000
010400002800000002000000
010400002800000002000000
011000002800000080000000
010400002800000002000000
010400002800000002000000
011000002800000080000000
010400002800000002000000
011000002800000080000000
-
{e=>-1,c=>2,a=>107,g=>-2,b=>3,d=>3,f=>-1}
6b0b00003f00000002000000
6b0b00003f00000002000000
6b0b00003f00000002000000
6be00000fc00000080000000
6b0b00003f00000002000000
6b0b00003f00000002000000
6be00000fc00000080000000
6b0b00003f00000002000000
6be00000fc00000080000000
-
{e=>-1,c=>1,a=>-44,g=>0,b=>0,d=>0,f=>-1}
d40400003c00000000000000
d40400003c00000000000000
d40400003c00000000000000
d41000003c00000000000000
d40400003c00000000000000
d40400003c00000000000000
d41000003c00000000000000
d40400003c00000000000000
d41000003c00000000000000
-
{e=>-1,c=>2,a=>-40,g=>-1,b=>0,d=>3,f=>0}
d80800000f00000003000000
d80800000f00000003000000
d80800000f00000003000000
d8200000f0000000c0000000
d80800000f00000003000000
d80800000f00000003000000
d8200000f0000000c0000000
d80800000f00000003000000
d8200000f0000000c0000000
=
struct mixed2 {
  char a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
};
-
{e=>-2,a=>30,d=>2,c=>0,h=>-1,b=>1,g=>-2,f=>-1}
1e0100003a0000000e000000
1e0100003a0000000e000000
1e0100003a0000000e000000
1e400000ac000000b0000000
1e0100003a0000000e000000
1e0100003a0000000e000000
1e400000ac000000b0000000
1e0100003a0000000e000000
1e400000ac000000b0000000
-
{e=>1,a=>52,d=>3,c=>0,h=>-2,b=>2,g=>0,f=>0}
340200000700000008000000
340200000700000008000000
340200000700000008000000
34800000d000000020000000
340200000700000008000000
340200000700000008000000
34800000d000000020000000
340200000700000008000000
34800000d000000020000000
-
{e=>1,a=>-125,d=>2,c=>2,h=>1,b=>0,g=>1,f=>-1}
830800003600000005000000
830800003600000005000000
830800003600000005000000
832000009c00000050000000
830800003600000005000000
830800003600000005000000
832000009c00000050000000
830800003600000005000000
832000009c00000050000000
-
{e=>-1,a=>70,d=>0,c=>3,h=>-1,b=>3,g=>1,f=>-1}
460f00003c0000000d000000
460f00003c0000000d000000
460f00003c0000000d000000
46f000003c00000070000000
460f00003c0000000d000000
460f00003c0000000d000000
46f000003c00000070000000
460f00003c0000000d000000
46f000003c00000070000000
-
{e=>0,a=>-57,d=>2,c=>3,h=>1,b=>0,g=>-1,f=>-1}
c70c00003200000007000000
c70c00003200000007000000
c70c00003200000007000000
c73000008c000000d0000000
c70c00003200000007000000
c70c00003200000007000000
c73000008c000000d0000000
c70c00003200000007000000
c73000008c000000d0000000
=
struct mixed2 {
  char a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
};
-
{e=>-2,a=>122,d=>0,c=>1,h=>0,b=>1,g=>0,f=>0,i=>-2}
7a0500000800000020000000
7a0500000800000020000000
7a0500000800000020000000
7a5000002000000008000000
7a0500000800000020000000
7a0500000800000020000000
7a5000002000000008000000
7a0500000800000020000000
7a5000002000000008000000
-
{e=>-2,a=>76,d=>3,c=>3,h=>-1,b=>2,g=>0,f=>-1,i=>-1}
4c0e00003b0000003c000000
4c0e00003b0000003c000000
4c0e00003b0000003c000000
4cb00000ec0000003c000000
4c0e00003b0000003c000000
4c0e00003b0000003c000000
4cb00000ec0000003c000000
4c0e00003b0000003c000000
4cb00000ec0000003c000000
-
{e=>1,a=>56,d=>3,c=>2,h=>-1,b=>3,g=>-1,f=>1,i=>0}
380b0000170000000f000000
380b0000170000000f000000
380b0000170000000f000000
38e00000d4000000f0000000
380b0000170000000f000000
380b0000170000000f000000
38e00000d4000000f0000000
380b0000170000000f000000
38e00000d4000000f0000000
-
{e=>-2,a=>79,d=>0,c=>1,h=>1,b=>2,g=>-2,f=>0,i=>1}
4f0600000800000016000000
4f0600000800000016000000
4f0600000800000016000000
4f9000002000000094000000
4f0600000800000016000000
4f0600000800000016000000
4f9000002000000094000000
4f0600000800000016000000
4f9000002000000094000000
-
{e=>1,a=>-87,d=>2,c=>1,h=>-1,b=>1,g=>0,f=>0,i=>0}
a9050000060000000c000000
a9050000060000000c000000
a9050000060000000c000000
a95000009000000030000000
a9050000060000000c000000
a9050000060000000c000000
a95000009000000030000000
a9050000060000000c000000
a95000009000000030000000
=
struct mixed2 {
  char a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
  int           :0;
};
-
{e=>-1,a=>-90,d=>0,c=>2,h=>1,b=>2,g=>0,f=>-2,i=>-2}
a60a00002c00000024000000
a60a00002c00000024000000
a60a00002c00000024000000
a6a000003800000018000000
a60a00002c00000024000000
a60a00002c00000024000000
a6a000003800000018000000
a60a00002c00000024000000
a6a000003800000018000000
-
{e=>-2,a=>-119,d=>1,c=>0,h=>0,b=>2,g=>-2,f=>-1,i=>1}
890200003900000012000000
890200003900000012000000
890200003900000012000000
898000006c00000084000000
890200003900000012000000
890200003900000012000000
898000006c00000084000000
890200003900000012000000
898000006c00000084000000
-
{e=>1,a=>108,d=>3,c=>3,h=>0,b=>3,g=>-1,f=>-1,i=>1}
6c0f00003700000013000000
6c0f00003700000013000000
6c0f00003700000013000000
6cf00000dc000000c4000000
6c0f00003700000013000000
6c0f00003700000013000000
6cf00000dc000000c4000000
6c0f00003700000013000000
6cf00000dc000000c4000000
-
{e=>0,a=>-126,d=>0,c=>3,h=>1,b=>2,g=>-2,f=>0,i=>-1}
820e00000000000036000000
820e00000000000036000000
820e00000000000036000000
82b00000000000009c000000
820e00000000000036000000
820e00000000000036000000
82b00000000000009c000000
820e00000000000036000000
82b00000000000009c000000
-
{e=>1,a=>-120,d=>2,c=>2,h=>0,b=>1,g=>-2,f=>0,i=>-1}
880900000600000032000000
880900000600000032000000
880900000600000032000000
88600000900000008c000000
880900000600000032000000
880900000600000032000000
88600000900000008c000000
880900000600000032000000
88600000900000008c000000
=
struct mixed2 {
  char a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
  int           :0;
  int          j:2;
};
-
{e=>1,a=>-105,d=>3,j=>1,c=>3,h=>0,b=>1,g=>-2,f=>-2,i=>0}
970d0000270000000200000001000000
970d0000270000000200000001000000
970d0000270000000200000001000000
97700000d80000008000000040000000
970d0000270000000200000001000000
970d0000270000000200000001000000
97700000d80000008000000040000000
970d0000270000000200000001000000
97700000d80000008000000040000000
-
{e=>0,a=>32,d=>0,j=>0,c=>2,h=>1,b=>2,g=>1,f=>-1,i=>-1}
200a0000300000003500000000000000
200a0000300000003500000000000000
200a0000300000003500000000000000
20a000000c0000005c00000000000000
200a0000300000003500000000000000
200a0000300000003500000000000000
20a000000c0000005c00000000000000
200a0000300000003500000000000000
20a000000c0000005c00000000000000
-
{e=>1,a=>57,d=>1,j=>-2,c=>2,h=>-1,b=>1,g=>-2,f=>-2,i=>1}
39090000250000001e00000002000000
39090000250000001e00000002000000
39090000250000001e00000002000000
3960000058000000b400000080000000
39090000250000001e00000002000000
39090000250000001e00000002000000
3960000058000000b400000080000000
39090000250000001e00000002000000
3960000058000000b400000080000000
-
{e=>0,a=>59,d=>3,j=>-1,c=>0,h=>-2,b=>1,g=>0,f=>1,i=>-2}
3b010000130000002800000003000000
3b010000130000002800000003000000
3b010000130000002800000003000000
3b400000c400000028000000c0000000
3b010000130000002800000003000000
3b010000130000002800000003000000
3b400000c400000028000000c0000000
3b010000130000002800000003000000
3b400000c400000028000000c0000000
-
{e=>-2,a=>68,d=>0,j=>1,c=>0,h=>1,b=>3,g=>0,f=>-2,i=>0}
44030000280000000400000001000000
44030000280000000400000001000000
44030000280000000400000001000000
44c00000280000001000000040000000
44030000280000000400000001000000
44030000280000000400000001000000
44c00000280000001000000040000000
44030000280000000400000001000000
44c00000280000001000000040000000
=
struct mixed2 {
  char a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
  int           :0;
  int          j:2;
  int          k;
};
-
{e=>1,a=>-55,d=>1,j=>-2,c=>3,k=>111,h=>-1,b=>1,g=>-1,f=>0,i=>-1}
c90d0000050000003f000000020000006f000000
c90d0000050000003f000000020000006f000000
c90d0000050000003f000000020000006f000000
c970000050000000fc000000800000000000006f
c90d0000050000003f000000020000006f000000
c90d0000050000003f000000020000006f000000
c970000050000000fc000000800000000000006f
c90d0000050000003f000000020000006f000000
c970000050000000fc000000800000000000006f
-
{e=>-2,a=>-69,d=>3,j=>0,c=>0,k=>-83,h=>0,b=>3,g=>0,f=>-1,i=>1}
bb0300003b0000001000000000000000adffffff
bb0300003b0000001000000000000000adffffff
bb0300003b0000001000000000000000adffffff
bbc00000ec0000000400000000000000ffffffad
bb0300003b0000001000000000000000adffffff
bb0300003b0000001000000000000000adffffff
bbc00000ec0000000400000000000000ffffffad
bb0300003b0000001000000000000000adffffff
bbc00000ec0000000400000000000000ffffffad
-
{e=>0,a=>110,d=>0,j=>0,c=>3,k=>116,h=>-1,b=>3,g=>-2,f=>1,i=>-1}
6e0f0000100000003e0000000000000074000000
6e0f0000100000003e0000000000000074000000
6e0f0000100000003e0000000000000074000000
6ef0000004000000bc0000000000000000000074
6e0f0000100000003e0000000000000074000000
6e0f0000100000003e0000000000000074000000
6ef0000004000000bc0000000000000000000074
6e0f0000100000003e0000000000000074000000
6ef0000004000000bc0000000000000000000074
-
{e=>0,a=>-42,d=>1,j=>-1,c=>0,k=>92,h=>-1,b=>2,g=>1,f=>-2,i=>-2}
d6020000210000002d000000030000005c000000
d6020000210000002d000000030000005c000000
d6020000210000002d000000030000005c000000
d68000004800000078000000c00000000000005c
d6020000210000002d000000030000005c000000
d6020000210000002d000000030000005c000000
d68000004800000078000000c00000000000005c
d6020000210000002d000000030000005c000000
d68000004800000078000000c00000000000005c
-
{e=>-1,a=>-34,d=>0,j=>-2,c=>3,k=>22,h=>-2,b=>2,g=>-1,f=>0,i=>0}
de0e00000c0000000b0000000200000016000000
de0e00000c0000000b0000000200000016000000
de0e00000c0000000b0000000200000016000000
deb0000030000000e00000008000000000000016
de0e00000c0000000b0000000200000016000000
de0e00000c0000000b0000000200000016000000
deb0000030000000e00000008000000000000016
de0e00000c0000000b0000000200000016000000
deb0000030000000e00000008000000000000016
=
struct mixed2 {
  short a;
  unsigned int b:2;
};
-
{a=>-36,b=>3}
dcff0300
dcff0300
dcff0300
ffdcc000
dcff0300
dcff0300
ffdcc000
dcff0300
ffdcc000
-
{a=>77,b=>0}
4d000000
4d000000
4d000000
004d0000
4d000000
4d000000
004d0000
4d000000
004d0000
-
{a=>-125,b=>0}
83ff0000
83ff0000
83ff0000
ff830000
83ff0000
83ff0000
ff830000
83ff0000
ff830000
-
{a=>33,b=>0}
21000000
21000000
21000000
00210000
21000000
21000000
00210000
21000000
00210000
-
{a=>18,b=>3}
12000300
12000300
12000300
0012c000
12000300
12000300
0012c000
12000300
0012c000
=
struct mixed2 {
  short a;
  unsigned int b:2;
  unsigned int c:2;
};
-
{c=>2,a=>39,b=>2}
27000a00
27000a00
27000a00
0027a000
27000a00
27000a00
0027a000
27000a00
0027a000
-
{c=>2,a=>-73,b=>3}
b7ff0b00
b7ff0b00
b7ff0b00
ffb7e000
b7ff0b00
b7ff0b00
ffb7e000
b7ff0b00
ffb7e000
-
{c=>2,a=>12,b=>1}
0c000900
0c000900
0c000900
000c6000
0c000900
0c000900
000c6000
0c000900
000c6000
-
{c=>1,a=>107,b=>2}
6b000600
6b000600
6b000600
006b9000
6b000600
6b000600
006b9000
6b000600
006b9000
-
{c=>0,a=>-10,b=>2}
f6ff0200
f6ff0200
f6ff0200
fff68000
f6ff0200
f6ff0200
fff68000
f6ff0200
fff68000
=
struct mixed2 {
  short a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
};
-
{c=>0,a=>-15,b=>0}
f1ff0000
f1ff0000
f1ff0000
fff10000
f1ff0000
f1ff0000
fff10000
f1ff0000
fff10000
-
{c=>2,a=>-103,b=>1}
99ff0900
99ff0900
99ff0900
ff996000
99ff0900
99ff0900
ff996000
99ff0900
ff996000
-
{c=>0,a=>106,b=>3}
6a000300
6a000300
6a000300
006ac000
6a000300
6a000300
006ac000
6a000300
006ac000
-
{c=>0,a=>77,b=>3}
4d000300
4d000300
4d000300
004dc000
4d000300
4d000300
004dc000
4d000300
004dc000
-
{c=>0,a=>-60,b=>2}
c4ff0200
c4ff0200
c4ff0200
ffc48000
c4ff0200
c4ff0200
ffc48000
c4ff0200
ffc48000
=
struct mixed2 {
  short a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
};
-
{c=>3,a=>-90,b=>2,d=>1}
a6ff0e0001000000
a6ff0e0001000000
a6ff0e0001000000
ffa6b00040000000
a6ff0e0001000000
a6ff0e0001000000
ffa6b00040000000
a6ff0e0001000000
ffa6b00040000000
-
{c=>1,a=>-112,b=>3,d=>1}
90ff070001000000
90ff070001000000
90ff070001000000
ff90d00040000000
90ff070001000000
90ff070001000000
ff90d00040000000
90ff070001000000
ff90d00040000000
-
{c=>3,a=>-67,b=>0,d=>1}
bdff0c0001000000
bdff0c0001000000
bdff0c0001000000
ffbd300040000000
bdff0c0001000000
bdff0c0001000000
ffbd300040000000
bdff0c0001000000
ffbd300040000000
-
{c=>1,a=>-2,b=>0,d=>3}
feff040003000000
feff040003000000
feff040003000000
fffe1000c0000000
feff040003000000
feff040003000000
fffe1000c0000000
feff040003000000
fffe1000c0000000
-
{c=>0,a=>-45,b=>1,d=>1}
d3ff010001000000
d3ff010001000000
d3ff010001000000
ffd3400040000000
d3ff010001000000
d3ff010001000000
ffd3400040000000
d3ff010001000000
ffd3400040000000
=
struct mixed2 {
  short a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
};
-
{e=>-1,c=>2,a=>-104,b=>2,d=>0}
98ff0a000c000000
98ff0a000c000000
98ff0a000c000000
ff98a00030000000
98ff0a000c000000
98ff0a000c000000
ff98a00030000000
98ff0a000c000000
ff98a00030000000
-
{e=>-2,c=>1,a=>-128,b=>3,d=>2}
80ff07000a000000
80ff07000a000000
80ff07000a000000
ff80d000a0000000
80ff07000a000000
80ff07000a000000
ff80d000a0000000
80ff07000a000000
ff80d000a0000000
-
{e=>1,c=>3,a=>-119,b=>2,d=>1}
89ff0e0005000000
89ff0e0005000000
89ff0e0005000000
ff89b00050000000
89ff0e0005000000
89ff0e0005000000
ff89b00050000000
89ff0e0005000000
ff89b00050000000
-
{e=>-1,c=>3,a=>31,b=>1,d=>0}
1f000d000c000000
1f000d000c000000
1f000d000c000000
001f700030000000
1f000d000c000000
1f000d000c000000
001f700030000000
1f000d000c000000
001f700030000000
-
{e=>-1,c=>0,a=>-28,b=>1,d=>0}
e4ff01000c000000
e4ff01000c000000
e4ff01000c000000
ffe4400030000000
e4ff01000c000000
e4ff01000c000000
ffe4400030000000
e4ff01000c000000
ffe4400030000000
=
struct mixed2 {
  short a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
};
-
{e=>-1,c=>0,a=>15,b=>3,d=>0,f=>-2}
0f0003002c000000
0f0003002c000000
0f0003002c000000
000fc00038000000
0f0003002c000000
0f0003002c000000
000fc00038000000
0f0003002c000000
000fc00038000000
-
{e=>-1,c=>2,a=>-51,b=>3,d=>1,f=>0}
cdff0b000d000000
cdff0b000d000000
cdff0b000d000000
ffcde00070000000
cdff0b000d000000
cdff0b000d000000
ffcde00070000000
cdff0b000d000000
ffcde00070000000
-
{e=>-1,c=>2,a=>-69,b=>1,d=>3,f=>1}
bbff09001f000000
bbff09001f000000
bbff09001f000000
ffbb6000f4000000
bbff09001f000000
bbff09001f000000
ffbb6000f4000000
bbff09001f000000
ffbb6000f4000000
-
{e=>1,c=>3,a=>121,b=>2,d=>1,f=>0}
79000e0005000000
79000e0005000000
79000e0005000000
0079b00050000000
79000e0005000000
79000e0005000000
0079b00050000000
79000e0005000000
0079b00050000000
-
{e=>0,c=>2,a=>17,b=>3,d=>3,f=>-1}
11000b0033000000
11000b0033000000
11000b0033000000
0011e000cc000000
11000b0033000000
11000b0033000000
0011e000cc000000
11000b0033000000
0011e000cc000000
=
struct mixed2 {
  short a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
};
-
{e=>0,c=>1,a=>-102,b=>2,d=>2,f=>-1}
9aff060032000000
9aff060032000000
9aff060032000000
ff9a90008c000000
9aff060032000000
9aff060032000000
ff9a90008c000000
9aff060032000000
ff9a90008c000000
-
{e=>-2,c=>2,a=>-45,b=>2,d=>2,f=>-2}
d3ff0a002a000000
d3ff0a002a000000
d3ff0a002a000000
ffd3a000a8000000
d3ff0a002a000000
d3ff0a002a000000
ffd3a000a8000000
d3ff0a002a000000
ffd3a000a8000000
-
{e=>-2,c=>3,a=>1,b=>0,d=>1,f=>-1}
01000c0039000000
01000c0039000000
01000c0039000000
000130006c000000
01000c0039000000
01000c0039000000
000130006c000000
01000c0039000000
000130006c000000
-
{e=>1,c=>1,a=>-70,b=>0,d=>1,f=>0}
baff040005000000
baff040005000000
baff040005000000
ffba100050000000
baff040005000000
baff040005000000
ffba100050000000
baff040005000000
ffba100050000000
-
{e=>0,c=>3,a=>-67,b=>3,d=>2,f=>-2}
bdff0f0022000000
bdff0f0022000000
bdff0f0022000000
ffbdf00088000000
bdff0f0022000000
bdff0f0022000000
ffbdf00088000000
bdff0f0022000000
ffbdf00088000000
=
struct mixed2 {
  short a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
};
-
{e=>-1,c=>1,a=>-14,g=>-2,b=>2,d=>3,f=>0}
f2ff06000f00000002000000
f2ff06000f00000002000000
f2ff06000f00000002000000
fff29000f000000080000000
f2ff06000f00000002000000
f2ff06000f00000002000000
fff29000f000000080000000
f2ff06000f00000002000000
fff29000f000000080000000
-
{e=>0,c=>2,a=>-82,g=>-2,b=>2,d=>0,f=>0}
aeff0a000000000002000000
aeff0a000000000002000000
aeff0a000000000002000000
ffaea0000000000080000000
aeff0a000000000002000000
aeff0a000000000002000000
ffaea0000000000080000000
aeff0a000000000002000000
ffaea0000000000080000000
-
{e=>1,c=>1,a=>-117,g=>-1,b=>0,d=>3,f=>0}
8bff04000700000003000000
8bff04000700000003000000
8bff04000700000003000000
ff8b1000d0000000c0000000
8bff04000700000003000000
8bff04000700000003000000
ff8b1000d0000000c0000000
8bff04000700000003000000
ff8b1000d0000000c0000000
-
{e=>1,c=>3,a=>-88,g=>1,b=>3,d=>0,f=>0}
a8ff0f000400000001000000
a8ff0f000400000001000000
a8ff0f000400000001000000
ffa8f0001000000040000000
a8ff0f000400000001000000
a8ff0f000400000001000000
ffa8f0001000000040000000
a8ff0f000400000001000000
ffa8f0001000000040000000
-
{e=>0,c=>3,a=>38,g=>0,b=>3,d=>1,f=>-1}
26000f003100000000000000
26000f003100000000000000
26000f003100000000000000
0026f0004c00000000000000
26000f003100000000000000
26000f003100000000000000
0026f0004c00000000000000
26000f003100000000000000
0026f0004c00000000000000
=
struct mixed2 {
  short a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
};
-
{e=>0,a=>14,d=>3,c=>1,h=>-2,b=>2,g=>-2,f=>-2}
0e000600230000000a000000
0e000600230000000a000000
0e000600230000000a000000
000e9000c8000000a0000000
0e000600230000000a000000
0e000600230000000a000000
000e9000c8000000a0000000
0e000600230000000a000000
000e9000c8000000a0000000
-
{e=>1,a=>73,d=>0,c=>0,h=>-1,b=>3,g=>0,f=>0}
49000300040000000c000000
49000300040000000c000000
49000300040000000c000000
0049c0001000000030000000
49000300040000000c000000
49000300040000000c000000
0049c0001000000030000000
49000300040000000c000000
0049c0001000000030000000
-
{e=>-2,a=>5,d=>2,c=>1,h=>-1,b=>2,g=>1,f=>-2}
050006002a0000000d000000
050006002a0000000d000000
050006002a0000000d000000
00059000a800000070000000
050006002a0000000d000000
050006002a0000000d000000
00059000a800000070000000
050006002a0000000d000000
00059000a800000070000000
-
{e=>0,a=>-57,d=>2,c=>0,h=>-1,b=>0,g=>0,f=>1}
c7ff0000120000000c000000
c7ff0000120000000c000000
c7ff0000120000000c000000
ffc700008400000030000000
c7ff0000120000000c000000
c7ff0000120000000c000000
ffc700008400000030000000
c7ff0000120000000c000000
ffc700008400000030000000
-
{e=>-1,a=>-21,d=>0,c=>3,h=>-1,b=>0,g=>-1,f=>1}
ebff0c001c0000000f000000
ebff0c001c0000000f000000
ebff0c001c0000000f000000
ffeb300034000000f0000000
ebff0c001c0000000f000000
ebff0c001c0000000f000000
ffeb300034000000f0000000
ebff0c001c0000000f000000
ffeb300034000000f0000000
=
struct mixed2 {
  short a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
};
-
{e=>-2,a=>64,d=>3,c=>1,h=>1,b=>0,g=>1,f=>0,i=>-2}
400004000b00000025000000
400004000b00000025000000
400004000b00000025000000
00401000e000000058000000
400004000b00000025000000
400004000b00000025000000
00401000e000000058000000
400004000b00000025000000
00401000e000000058000000
-
{e=>-1,a=>-28,d=>2,c=>0,h=>-2,b=>3,g=>-1,f=>-1,i=>-1}
e4ff03003e0000003b000000
e4ff03003e0000003b000000
e4ff03003e0000003b000000
ffe4c000bc000000ec000000
e4ff03003e0000003b000000
e4ff03003e0000003b000000
ffe4c000bc000000ec000000
e4ff03003e0000003b000000
ffe4c000bc000000ec000000
-
{e=>-1,a=>16,d=>0,c=>1,h=>0,b=>2,g=>-1,f=>1,i=>-1}
100006001c00000033000000
100006001c00000033000000
100006001c00000033000000
0010900034000000cc000000
100006001c00000033000000
100006001c00000033000000
0010900034000000cc000000
100006001c00000033000000
0010900034000000cc000000
-
{e=>1,a=>-116,d=>0,c=>2,h=>-1,b=>3,g=>0,f=>-2,i=>0}
8cff0b00240000000c000000
8cff0b00240000000c000000
8cff0b00240000000c000000
ff8ce0001800000030000000
8cff0b00240000000c000000
8cff0b00240000000c000000
ff8ce0001800000030000000
8cff0b00240000000c000000
ff8ce0001800000030000000
-
{e=>0,a=>-24,d=>0,c=>0,h=>-1,b=>1,g=>1,f=>-2,i=>0}
e8ff0100200000000d000000
e8ff0100200000000d000000
e8ff0100200000000d000000
ffe840000800000070000000
e8ff0100200000000d000000
e8ff0100200000000d000000
ffe840000800000070000000
e8ff0100200000000d000000
ffe840000800000070000000
=
struct mixed2 {
  short a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
  int           :0;
};
-
{e=>0,a=>-98,d=>3,c=>1,h=>-2,b=>3,g=>-2,f=>1,i=>-1}
9eff0700130000003a000000
9eff0700130000003a000000
9eff0700130000003a000000
ff9ed000c4000000ac000000
9eff0700130000003a000000
9eff0700130000003a000000
ff9ed000c4000000ac000000
9eff0700130000003a000000
ff9ed000c4000000ac000000
-
{e=>1,a=>87,d=>3,c=>2,h=>-1,b=>2,g=>-1,f=>-2,i=>-1}
57000a00270000003f000000
57000a00270000003f000000
57000a00270000003f000000
0057a000d8000000fc000000
57000a00270000003f000000
57000a00270000003f000000
0057a000d8000000fc000000
57000a00270000003f000000
0057a000d8000000fc000000
-
{e=>1,a=>-69,d=>2,c=>1,h=>0,b=>3,g=>0,f=>-2,i=>-1}
bbff07002600000030000000
bbff07002600000030000000
bbff07002600000030000000
ffbbd000980000000c000000
bbff07002600000030000000
bbff07002600000030000000
ffbbd000980000000c000000
bbff07002600000030000000
ffbbd000980000000c000000
-
{e=>-1,a=>-28,d=>3,c=>0,h=>-1,b=>1,g=>-1,f=>0,i=>-2}
e4ff01000f0000002f000000
e4ff01000f0000002f000000
e4ff01000f0000002f000000
ffe44000f0000000f8000000
e4ff01000f0000002f000000
e4ff01000f0000002f000000
ffe44000f0000000f8000000
e4ff01000f0000002f000000
ffe44000f0000000f8000000
-
{e=>0,a=>58,d=>3,c=>3,h=>0,b=>3,g=>-2,f=>-1,i=>0}
3a000f003300000002000000
3a000f003300000002000000
3a000f003300000002000000
003af000cc00000080000000
3a000f003300000002000000
3a000f003300000002000000
003af000cc00000080000000
3a000f003300000002000000
003af000cc00000080000000
=
struct mixed2 {
  short a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
  int           :0;
  int          j:2;
};
-
{e=>0,a=>-102,d=>3,j=>-2,c=>1,h=>0,b=>2,g=>0,f=>0,i=>-1}
9aff0600030000003000000002000000
9aff0600030000003000000002000000
9aff0600030000003000000002000000
ff9a9000c00000000c00000080000000
9aff0600030000003000000002000000
9aff0600030000003000000002000000
ff9a9000c00000000c00000080000000
9aff0600030000003000000002000000
ff9a9000c00000000c00000080000000
-
{e=>-1,a=>-12,d=>1,j=>1,c=>1,h=>-2,b=>0,g=>-2,f=>1,i=>-2}
f4ff04001d0000002a00000001000000
f4ff04001d0000002a00000001000000
f4ff04001d0000002a00000001000000
fff4100074000000a800000040000000
f4ff04001d0000002a00000001000000
f4ff04001d0000002a00000001000000
fff4100074000000a800000040000000
f4ff04001d0000002a00000001000000
fff4100074000000a800000040000000
-
{e=>-2,a=>98,d=>3,j=>1,c=>0,h=>0,b=>0,g=>-1,f=>-2,i=>-2}
620000002b0000002300000001000000
620000002b0000002300000001000000
620000002b0000002300000001000000
00620000e8000000c800000040000000
620000002b0000002300000001000000
620000002b0000002300000001000000
00620000e8000000c800000040000000
620000002b0000002300000001000000
00620000e8000000c800000040000000
-
{e=>-1,a=>-38,d=>3,j=>-1,c=>1,h=>-1,b=>1,g=>-2,f=>0,i=>1}
daff05000f0000001e00000003000000
daff05000f0000001e00000003000000
daff05000f0000001e00000003000000
ffda5000f0000000b4000000c0000000
daff05000f0000001e00000003000000
daff05000f0000001e00000003000000
ffda5000f0000000b4000000c0000000
daff05000f0000001e00000003000000
ffda5000f0000000b4000000c0000000
-
{e=>1,a=>0,d=>2,j=>-2,c=>1,h=>0,b=>2,g=>1,f=>-2,i=>0}
00000600260000000100000002000000
00000600260000000100000002000000
00000600260000000100000002000000
00009000980000004000000080000000
00000600260000000100000002000000
00000600260000000100000002000000
00009000980000004000000080000000
00000600260000000100000002000000
00009000980000004000000080000000
=
struct mixed2 {
  short a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
  int           :0;
  int          j:2;
  int          k;
};
-
{e=>-1,a=>-67,d=>0,j=>-2,c=>2,k=>-19,h=>1,b=>0,g=>0,f=>-1,i=>1}
bdff08003c0000001400000002000000edffffff
bdff08003c0000001400000002000000edffffff
bdff08003c0000001400000002000000edffffff
ffbd20003c0000001400000080000000ffffffed
bdff08003c0000001400000002000000edffffff
bdff08003c0000001400000002000000edffffff
ffbd20003c0000001400000080000000ffffffed
bdff08003c0000001400000002000000edffffff
ffbd20003c0000001400000080000000ffffffed
-
{e=>0,a=>-109,d=>2,j=>0,c=>1,k=>116,h=>0,b=>0,g=>1,f=>1,i=>-1}
93ff040012000000310000000000000074000000
93ff040012000000310000000000000074000000
93ff040012000000310000000000000074000000
ff931000840000004c0000000000000000000074
93ff040012000000310000000000000074000000
93ff040012000000310000000000000074000000
ff931000840000004c0000000000000000000074
93ff040012000000310000000000000074000000
ff931000840000004c0000000000000000000074
-
{e=>0,a=>102,d=>0,j=>1,c=>3,k=>116,h=>1,b=>2,g=>0,f=>1,i=>1}
66000e0010000000140000000100000074000000
66000e0010000000140000000100000074000000
66000e0010000000140000000100000074000000
0066b00004000000140000004000000000000074
66000e0010000000140000000100000074000000
66000e0010000000140000000100000074000000
0066b00004000000140000004000000000000074
66000e0010000000140000000100000074000000
0066b00004000000140000004000000000000074
-
{e=>0,a=>27,d=>1,j=>-1,c=>0,k=>-116,h=>-2,b=>2,g=>1,f=>-1,i=>-1}
1b0002003100000039000000030000008cffffff
1b0002003100000039000000030000008cffffff
1b0002003100000039000000030000008cffffff
001b80004c0000006c000000c0000000ffffff8c
1b0002003100000039000000030000008cffffff
1b0002003100000039000000030000008cffffff
001b80004c0000006c000000c0000000ffffff8c
1b0002003100000039000000030000008cffffff
001b80004c0000006c000000c0000000ffffff8c
-
{e=>1,a=>-68,d=>0,j=>-1,c=>3,k=>-47,h=>-1,b=>1,g=>0,f=>0,i=>-2}
bcff0d00040000002c00000003000000d1ffffff
bcff0d00040000002c00000003000000d1ffffff
bcff0d00040000002c00000003000000d1ffffff
ffbc70001000000038000000c0000000ffffffd1
bcff0d00040000002c00000003000000d1ffffff
bcff0d00040000002c00000003000000d1ffffff
ffbc70001000000038000000c0000000ffffffd1
bcff0d00040000002c00000003000000d1ffffff
ffbc70001000000038000000c0000000ffffffd1
=
struct mixed2 {
  int a;
  unsigned int b:2;
};
-
{a=>-99,b=>3}
9dffffff03000000
9dffffff03000000
9dffffff03000000
ffffff9dc0000000
9dffffff03000000
9dffffff03000000
ffffff9dc0000000
9dffffff03000000
ffffff9dc0000000
-
{a=>-83,b=>3}
adffffff03000000
adffffff03000000
adffffff03000000
ffffffadc0000000
adffffff03000000
adffffff03000000
ffffffadc0000000
adffffff03000000
ffffffadc0000000
-
{a=>15,b=>2}
0f00000002000000
0f00000002000000
0f00000002000000
0000000f80000000
0f00000002000000
0f00000002000000
0000000f80000000
0f00000002000000
0000000f80000000
-
{a=>60,b=>1}
3c00000001000000
3c00000001000000
3c00000001000000
0000003c40000000
3c00000001000000
3c00000001000000
0000003c40000000
3c00000001000000
0000003c40000000
-
{a=>15,b=>2}
0f00000002000000
0f00000002000000
0f00000002000000
0000000f80000000
0f00000002000000
0f00000002000000
0000000f80000000
0f00000002000000
0000000f80000000
=
struct mixed2 {
  int a;
  unsigned int b:2;
  unsigned int c:2;
};
-
{c=>2,a=>64,b=>2}
400000000a000000
400000000a000000
400000000a000000
00000040a0000000
400000000a000000
400000000a000000
00000040a0000000
400000000a000000
00000040a0000000
-
{c=>3,a=>21,b=>3}
150000000f000000
150000000f000000
150000000f000000
00000015f0000000
150000000f000000
150000000f000000
00000015f0000000
150000000f000000
00000015f0000000
-
{c=>1,a=>88,b=>1}
5800000005000000
5800000005000000
5800000005000000
0000005850000000
5800000005000000
5800000005000000
0000005850000000
5800000005000000
0000005850000000
-
{c=>2,a=>-84,b=>2}
acffffff0a000000
acffffff0a000000
acffffff0a000000
ffffffaca0000000
acffffff0a000000
acffffff0a000000
ffffffaca0000000
acffffff0a000000
ffffffaca0000000
-
{c=>3,a=>127,b=>2}
7f0000000e000000
7f0000000e000000
7f0000000e000000
0000007fb0000000
7f0000000e000000
7f0000000e000000
0000007fb0000000
7f0000000e000000
0000007fb0000000
=
struct mixed2 {
  int a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
};
-
{c=>0,a=>-11,b=>2}
f5ffffff02000000
f5ffffff02000000
f5ffffff02000000
fffffff580000000
f5ffffff02000000
f5ffffff02000000
fffffff580000000
f5ffffff02000000
fffffff580000000
-
{c=>1,a=>-114,b=>1}
8effffff05000000
8effffff05000000
8effffff05000000
ffffff8e50000000
8effffff05000000
8effffff05000000
ffffff8e50000000
8effffff05000000
ffffff8e50000000
-
{c=>3,a=>-66,b=>1}
beffffff0d000000
beffffff0d000000
beffffff0d000000
ffffffbe70000000
beffffff0d000000
beffffff0d000000
ffffffbe70000000
beffffff0d000000
ffffffbe70000000
-
{c=>2,a=>-101,b=>1}
9bffffff09000000
9bffffff09000000
9bffffff09000000
ffffff9b60000000
9bffffff09000000
9bffffff09000000
ffffff9b60000000
9bffffff09000000
ffffff9b60000000
-
{c=>2,a=>51,b=>3}
330000000b000000
330000000b000000
330000000b000000
00000033e0000000
330000000b000000
330000000b000000
00000033e0000000
330000000b000000
00000033e0000000
=
struct mixed2 {
  int a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
};
-
{c=>3,a=>71,b=>3,d=>2}
470000000f00000002000000
470000000f00000002000000
470000000f00000002000000
00000047f000000080000000
470000000f00000002000000
470000000f00000002000000
00000047f000000080000000
470000000f00000002000000
00000047f000000080000000
-
{c=>0,a=>-59,b=>3,d=>2}
c5ffffff0300000002000000
c5ffffff0300000002000000
c5ffffff0300000002000000
ffffffc5c000000080000000
c5ffffff0300000002000000
c5ffffff0300000002000000
ffffffc5c000000080000000
c5ffffff0300000002000000
ffffffc5c000000080000000
-
{c=>1,a=>-34,b=>1,d=>2}
deffffff0500000002000000
deffffff0500000002000000
deffffff0500000002000000
ffffffde5000000080000000
deffffff0500000002000000
deffffff0500000002000000
ffffffde5000000080000000
deffffff0500000002000000
ffffffde5000000080000000
-
{c=>1,a=>-50,b=>0,d=>2}
ceffffff0400000002000000
ceffffff0400000002000000
ceffffff0400000002000000
ffffffce1000000080000000
ceffffff0400000002000000
ceffffff0400000002000000
ffffffce1000000080000000
ceffffff0400000002000000
ffffffce1000000080000000
-
{c=>2,a=>98,b=>3,d=>1}
620000000b00000001000000
620000000b00000001000000
620000000b00000001000000
00000062e000000040000000
620000000b00000001000000
620000000b00000001000000
00000062e000000040000000
620000000b00000001000000
00000062e000000040000000
=
struct mixed2 {
  int a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
};
-
{e=>0,c=>2,a=>-115,b=>0,d=>3}
8dffffff0800000003000000
8dffffff0800000003000000
8dffffff0800000003000000
ffffff8d20000000c0000000
8dffffff0800000003000000
8dffffff0800000003000000
ffffff8d20000000c0000000
8dffffff0800000003000000
ffffff8d20000000c0000000
-
{e=>0,c=>2,a=>120,b=>0,d=>1}
780000000800000001000000
780000000800000001000000
780000000800000001000000
000000782000000040000000
780000000800000001000000
780000000800000001000000
000000782000000040000000
780000000800000001000000
000000782000000040000000
-
{e=>-1,c=>3,a=>-67,b=>0,d=>1}
bdffffff0c0000000d000000
bdffffff0c0000000d000000
bdffffff0c0000000d000000
ffffffbd3000000070000000
bdffffff0c0000000d000000
bdffffff0c0000000d000000
ffffffbd3000000070000000
bdffffff0c0000000d000000
ffffffbd3000000070000000
-
{e=>-2,c=>2,a=>52,b=>2,d=>0}
340000000a00000008000000
340000000a00000008000000
340000000a00000008000000
00000034a000000020000000
340000000a00000008000000
340000000a00000008000000
00000034a000000020000000
340000000a00000008000000
00000034a000000020000000
-
{e=>-1,c=>2,a=>94,b=>3,d=>2}
5e0000000b0000000e000000
5e0000000b0000000e000000
5e0000000b0000000e000000
0000005ee0000000b0000000
5e0000000b0000000e000000
5e0000000b0000000e000000
0000005ee0000000b0000000
5e0000000b0000000e000000
0000005ee0000000b0000000
=
struct mixed2 {
  int a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
};
-
{e=>0,c=>3,a=>-74,b=>1,d=>1,f=>1}
b6ffffff0d00000011000000
b6ffffff0d00000011000000
b6ffffff0d00000011000000
ffffffb67000000044000000
b6ffffff0d00000011000000
b6ffffff0d00000011000000
ffffffb67000000044000000
b6ffffff0d00000011000000
ffffffb67000000044000000
-
{e=>-1,c=>3,a=>117,b=>2,d=>1,f=>1}
750000000e0000001d000000
750000000e0000001d000000
750000000e0000001d000000
00000075b000000074000000
750000000e0000001d000000
750000000e0000001d000000
00000075b000000074000000
750000000e0000001d000000
00000075b000000074000000
-
{e=>1,c=>1,a=>-117,b=>0,d=>2,f=>-2}
8bffffff0400000026000000
8bffffff0400000026000000
8bffffff0400000026000000
ffffff8b1000000098000000
8bffffff0400000026000000
8bffffff0400000026000000
ffffff8b1000000098000000
8bffffff0400000026000000
ffffff8b1000000098000000
-
{e=>-2,c=>1,a=>-90,b=>1,d=>0,f=>-2}
a6ffffff0500000028000000
a6ffffff0500000028000000
a6ffffff0500000028000000
ffffffa65000000028000000
a6ffffff0500000028000000
a6ffffff0500000028000000
ffffffa65000000028000000
a6ffffff0500000028000000
ffffffa65000000028000000
-
{e=>-1,c=>2,a=>41,b=>0,d=>3,f=>0}
29000000080000000f000000
29000000080000000f000000
29000000080000000f000000
0000002920000000f0000000
29000000080000000f000000
29000000080000000f000000
0000002920000000f0000000
29000000080000000f000000
0000002920000000f0000000
=
struct mixed2 {
  int a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
};
-
{e=>0,c=>3,a=>-75,b=>1,d=>1,f=>0}
b5ffffff0d00000001000000
b5ffffff0d00000001000000
b5ffffff0d00000001000000
ffffffb57000000040000000
b5ffffff0d00000001000000
b5ffffff0d00000001000000
ffffffb57000000040000000
b5ffffff0d00000001000000
ffffffb57000000040000000
-
{e=>1,c=>3,a=>-74,b=>1,d=>1,f=>0}
b6ffffff0d00000005000000
b6ffffff0d00000005000000
b6ffffff0d00000005000000
ffffffb67000000050000000
b6ffffff0d00000005000000
b6ffffff0d00000005000000
ffffffb67000000050000000
b6ffffff0d00000005000000
ffffffb67000000050000000
-
{e=>-2,c=>0,a=>7,b=>2,d=>2,f=>0}
07000000020000000a000000
07000000020000000a000000
07000000020000000a000000
0000000780000000a0000000
07000000020000000a000000
07000000020000000a000000
0000000780000000a0000000
07000000020000000a000000
0000000780000000a0000000
-
{e=>-1,c=>0,a=>-14,b=>3,d=>2,f=>-1}
f2ffffff030000003e000000
f2ffffff030000003e000000
f2ffffff030000003e000000
fffffff2c0000000bc000000
f2ffffff030000003e000000
f2ffffff030000003e000000
fffffff2c0000000bc000000
f2ffffff030000003e000000
fffffff2c0000000bc000000
-
{e=>0,c=>2,a=>-68,b=>1,d=>3,f=>-2}
bcffffff0900000023000000
bcffffff0900000023000000
bcffffff0900000023000000
ffffffbc60000000c8000000
bcffffff0900000023000000
bcffffff0900000023000000
ffffffbc60000000c8000000
bcffffff0900000023000000
ffffffbc60000000c8000000
=
struct mixed2 {
  int a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
};
-
{e=>-1,c=>0,a=>-121,g=>-2,b=>1,d=>0,f=>-2}
87ffffff010000002c00000002000000
87ffffff010000002c00000002000000
87ffffff010000002c00000002000000
ffffff87400000003800000080000000
87ffffff010000002c00000002000000
87ffffff010000002c00000002000000
ffffff87400000003800000080000000
87ffffff010000002c00000002000000
ffffff87400000003800000080000000
-
{e=>-2,c=>2,a=>125,g=>-2,b=>3,d=>3,f=>-2}
7d0000000b0000002b00000002000000
7d0000000b0000002b00000002000000
7d0000000b0000002b00000002000000
0000007de0000000e800000080000000
7d0000000b0000002b00000002000000
7d0000000b0000002b00000002000000
0000007de0000000e800000080000000
7d0000000b0000002b00000002000000
0000007de0000000e800000080000000
-
{e=>-2,c=>0,a=>23,g=>-2,b=>0,d=>0,f=>1}
17000000000000001800000002000000
17000000000000001800000002000000
17000000000000001800000002000000
00000017000000002400000080000000
17000000000000001800000002000000
17000000000000001800000002000000
00000017000000002400000080000000
17000000000000001800000002000000
00000017000000002400000080000000
-
{e=>-2,c=>0,a=>-89,g=>1,b=>2,d=>2,f=>-1}
a7ffffff020000003a00000001000000
a7ffffff020000003a00000001000000
a7ffffff020000003a00000001000000
ffffffa780000000ac00000040000000
a7ffffff020000003a00000001000000
a7ffffff020000003a00000001000000
ffffffa780000000ac00000040000000
a7ffffff020000003a00000001000000
ffffffa780000000ac00000040000000
-
{e=>-1,c=>3,a=>46,g=>1,b=>1,d=>1,f=>0}
2e0000000d0000000d00000001000000
2e0000000d0000000d00000001000000
2e0000000d0000000d00000001000000
0000002e700000007000000040000000
2e0000000d0000000d00000001000000
2e0000000d0000000d00000001000000
0000002e700000007000000040000000
2e0000000d0000000d00000001000000
0000002e700000007000000040000000
=
struct mixed2 {
  int a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
};
-
{e=>-2,a=>-37,d=>1,c=>1,h=>0,b=>0,g=>1,f=>-1}
dbffffff040000003900000001000000
dbffffff040000003900000001000000
dbffffff040000003900000001000000
ffffffdb100000006c00000040000000
dbffffff040000003900000001000000
dbffffff040000003900000001000000
ffffffdb100000006c00000040000000
dbffffff040000003900000001000000
ffffffdb100000006c00000040000000
-
{e=>0,a=>-96,d=>3,c=>3,h=>1,b=>0,g=>-2,f=>1}
a0ffffff0c0000001300000006000000
a0ffffff0c0000001300000006000000
a0ffffff0c0000001300000006000000
ffffffa030000000c400000090000000
a0ffffff0c0000001300000006000000
a0ffffff0c0000001300000006000000
ffffffa030000000c400000090000000
a0ffffff0c0000001300000006000000
ffffffa030000000c400000090000000
-
{e=>-1,a=>-27,d=>1,c=>3,h=>-1,b=>1,g=>1,f=>-1}
e5ffffff0d0000003d0000000d000000
e5ffffff0d0000003d0000000d000000
e5ffffff0d0000003d0000000d000000
ffffffe5700000007c00000070000000
e5ffffff0d0000003d0000000d000000
e5ffffff0d0000003d0000000d000000
ffffffe5700000007c00000070000000
e5ffffff0d0000003d0000000d000000
ffffffe5700000007c00000070000000
-
{e=>-2,a=>-117,d=>3,c=>2,h=>-2,b=>1,g=>-1,f=>-2}
8bffffff090000002b0000000b000000
8bffffff090000002b0000000b000000
8bffffff090000002b0000000b000000
ffffff8b60000000e8000000e0000000
8bffffff090000002b0000000b000000
8bffffff090000002b0000000b000000
ffffff8b60000000e8000000e0000000
8bffffff090000002b0000000b000000
ffffff8b60000000e8000000e0000000
-
{e=>1,a=>-10,d=>0,c=>0,h=>-2,b=>0,g=>1,f=>1}
f6ffffff000000001400000009000000
f6ffffff000000001400000009000000
f6ffffff000000001400000009000000
fffffff6000000001400000060000000
f6ffffff000000001400000009000000
f6ffffff000000001400000009000000
fffffff6000000001400000060000000
f6ffffff000000001400000009000000
fffffff6000000001400000060000000
=
struct mixed2 {
  int a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
};
-
{e=>1,a=>-4,d=>3,c=>3,h=>-2,b=>0,g=>1,f=>-1,i=>-1}
fcffffff0c0000003700000039000000
fcffffff0c0000003700000039000000
fcffffff0c0000003700000039000000
fffffffc30000000dc0000006c000000
fcffffff0c0000003700000039000000
fcffffff0c0000003700000039000000
fffffffc30000000dc0000006c000000
fcffffff0c0000003700000039000000
fffffffc30000000dc0000006c000000
-
{e=>0,a=>98,d=>2,c=>2,h=>0,b=>2,g=>0,f=>1,i=>-2}
620000000a0000001200000020000000
620000000a0000001200000020000000
620000000a0000001200000020000000
00000062a00000008400000008000000
620000000a0000001200000020000000
620000000a0000001200000020000000
00000062a00000008400000008000000
620000000a0000001200000020000000
00000062a00000008400000008000000
-
{e=>1,a=>40,d=>3,c=>2,h=>1,b=>3,g=>0,f=>-1,i=>1}
280000000b0000003700000014000000
280000000b0000003700000014000000
280000000b0000003700000014000000
00000028e0000000dc00000014000000
280000000b0000003700000014000000
280000000b0000003700000014000000
00000028e0000000dc00000014000000
280000000b0000003700000014000000
00000028e0000000dc00000014000000
-
{e=>0,a=>-91,d=>0,c=>3,h=>0,b=>2,g=>-1,f=>-1,i=>-1}
a5ffffff0e0000003000000033000000
a5ffffff0e0000003000000033000000
a5ffffff0e0000003000000033000000
ffffffa5b00000000c000000cc000000
a5ffffff0e0000003000000033000000
a5ffffff0e0000003000000033000000
ffffffa5b00000000c000000cc000000
a5ffffff0e0000003000000033000000
ffffffa5b00000000c000000cc000000
-
{e=>0,a=>111,d=>2,c=>1,h=>-1,b=>0,g=>-2,f=>-2,i=>-1}
6f00000004000000220000003e000000
6f00000004000000220000003e000000
6f00000004000000220000003e000000
0000006f1000000088000000bc000000
6f00000004000000220000003e000000
6f00000004000000220000003e000000
0000006f1000000088000000bc000000
6f00000004000000220000003e000000
0000006f1000000088000000bc000000
=
struct mixed2 {
  int a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
  int           :0;
};
-
{e=>0,a=>-110,d=>2,c=>3,h=>-1,b=>1,g=>0,f=>-2,i=>0}
92ffffff0d000000220000000c000000
92ffffff0d000000220000000c000000
92ffffff0d000000220000000c000000
ffffff92700000008800000030000000
92ffffff0d000000220000000c000000
92ffffff0d000000220000000c000000
ffffff92700000008800000030000000
92ffffff0d000000220000000c000000
ffffff92700000008800000030000000
-
{e=>-2,a=>-48,d=>1,c=>0,h=>-2,b=>3,g=>1,f=>0,i=>1}
d0ffffff030000000900000019000000
d0ffffff030000000900000019000000
d0ffffff030000000900000019000000
ffffffd0c00000006000000064000000
d0ffffff030000000900000019000000
d0ffffff030000000900000019000000
ffffffd0c00000006000000064000000
d0ffffff030000000900000019000000
ffffffd0c00000006000000064000000
-
{e=>-1,a=>107,d=>3,c=>3,h=>0,b=>3,g=>1,f=>1,i=>0}
6b0000000f0000001f00000001000000
6b0000000f0000001f00000001000000
6b0000000f0000001f00000001000000
0000006bf0000000f400000040000000
6b0000000f0000001f00000001000000
6b0000000f0000001f00000001000000
0000006bf0000000f400000040000000
6b0000000f0000001f00000001000000
0000006bf0000000f400000040000000
-
{e=>-1,a=>23,d=>3,c=>0,h=>-2,b=>0,g=>0,f=>0,i=>1}
17000000000000000f00000018000000
17000000000000000f00000018000000
17000000000000000f00000018000000
0000001700000000f000000024000000
17000000000000000f00000018000000
17000000000000000f00000018000000
0000001700000000f000000024000000
17000000000000000f00000018000000
0000001700000000f000000024000000
-
{e=>-2,a=>-85,d=>3,c=>2,h=>0,b=>1,g=>0,f=>-1,i=>1}
abffffff090000003b00000010000000
abffffff090000003b00000010000000
abffffff090000003b00000010000000
ffffffab60000000ec00000004000000
abffffff090000003b00000010000000
abffffff090000003b00000010000000
ffffffab60000000ec00000004000000
abffffff090000003b00000010000000
ffffffab60000000ec00000004000000
=
struct mixed2 {
  int a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
  int           :0;
  int          j:2;
};
-
{e=>0,a=>-100,d=>3,j=>-1,c=>2,h=>-1,b=>1,g=>-1,f=>-1,i=>-1}
9cffffff09000000330000003f00000003000000
9cffffff09000000330000003f00000003000000
9cffffff09000000330000003f00000003000000
ffffff9c60000000cc000000fc000000c0000000
9cffffff09000000330000003f00000003000000
9cffffff09000000330000003f00000003000000
ffffff9c60000000cc000000fc000000c0000000
9cffffff09000000330000003f00000003000000
ffffff9c60000000cc000000fc000000c0000000
-
{e=>1,a=>18,d=>0,j=>1,c=>2,h=>-2,b=>2,g=>1,f=>-2,i=>0}
120000000a000000240000000900000001000000
120000000a000000240000000900000001000000
120000000a000000240000000900000001000000
00000012a0000000180000006000000040000000
120000000a000000240000000900000001000000
120000000a000000240000000900000001000000
00000012a0000000180000006000000040000000
120000000a000000240000000900000001000000
00000012a0000000180000006000000040000000
-
{e=>-2,a=>-36,d=>1,j=>0,c=>0,h=>-2,b=>2,g=>-1,f=>0,i=>-1}
dcffffff02000000090000003b00000000000000
dcffffff02000000090000003b00000000000000
dcffffff02000000090000003b00000000000000
ffffffdc8000000060000000ec00000000000000
dcffffff02000000090000003b00000000000000
dcffffff02000000090000003b00000000000000
ffffffdc8000000060000000ec00000000000000
dcffffff02000000090000003b00000000000000
ffffffdc8000000060000000ec00000000000000
-
{e=>1,a=>-45,d=>0,j=>0,c=>0,h=>0,b=>0,g=>1,f=>0,i=>-1}
d3ffffff00000000040000003100000000000000
d3ffffff00000000040000003100000000000000
d3ffffff00000000040000003100000000000000
ffffffd300000000100000004c00000000000000
d3ffffff00000000040000003100000000000000
d3ffffff00000000040000003100000000000000
ffffffd300000000100000004c00000000000000
d3ffffff00000000040000003100000000000000
ffffffd300000000100000004c00000000000000
-
{e=>-2,a=>103,d=>3,j=>-2,c=>0,h=>1,b=>0,g=>1,f=>0,i=>1}
67000000000000000b0000001500000002000000
67000000000000000b0000001500000002000000
67000000000000000b0000001500000002000000
0000006700000000e00000005400000080000000
67000000000000000b0000001500000002000000
67000000000000000b0000001500000002000000
0000006700000000e00000005400000080000000
67000000000000000b0000001500000002000000
0000006700000000e00000005400000080000000
=
struct mixed2 {
  int a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
  int           :0;
  int          j:2;
  int          k;
};
-
{e=>-2,a=>108,d=>3,j=>-2,c=>0,k=>-117,h=>1,b=>0,g=>1,f=>-1,i=>-1}
6c000000000000003b00000035000000020000008bffffff
6c000000000000003b00000035000000020000008bffffff
6c000000000000003b00000035000000020000008bffffff
0000006c00000000ec0000005c00000080000000ffffff8b
6c000000000000003b00000035000000020000008bffffff
6c000000000000003b00000035000000020000008bffffff
0000006c00000000ec0000005c00000080000000ffffff8b
6c000000000000003b00000035000000020000008bffffff
0000006c00000000ec0000005c00000080000000ffffff8b
-
{e=>-1,a=>43,d=>1,j=>-1,c=>1,k=>16,h=>-2,b=>2,g=>-2,f=>-2,i=>1}
2b000000060000002d0000001a0000000300000010000000
2b000000060000002d0000001a0000000300000010000000
2b000000060000002d0000001a0000000300000010000000
0000002b9000000078000000a4000000c000000000000010
2b000000060000002d0000001a0000000300000010000000
2b000000060000002d0000001a0000000300000010000000
0000002b9000000078000000a4000000c000000000000010
2b000000060000002d0000001a0000000300000010000000
0000002b9000000078000000a4000000c000000000000010
-
{e=>1,a=>-38,d=>0,j=>0,c=>3,k=>-25,h=>-1,b=>0,g=>-1,f=>0,i=>1}
daffffff0c000000040000001f00000000000000e7ffffff
daffffff0c000000040000001f00000000000000e7ffffff
daffffff0c000000040000001f00000000000000e7ffffff
ffffffda3000000010000000f400000000000000ffffffe7
daffffff0c000000040000001f00000000000000e7ffffff
daffffff0c000000040000001f00000000000000e7ffffff
ffffffda3000000010000000f400000000000000ffffffe7
daffffff0c000000040000001f00000000000000e7ffffff
ffffffda3000000010000000f400000000000000ffffffe7
-
{e=>0,a=>-93,d=>3,j=>0,c=>1,k=>23,h=>-2,b=>1,g=>-1,f=>0,i=>0}
a3ffffff05000000030000000b0000000000000017000000
a3ffffff05000000030000000b0000000000000017000000
a3ffffff05000000030000000b0000000000000017000000
ffffffa350000000c0000000e00000000000000000000017
a3ffffff05000000030000000b0000000000000017000000
a3ffffff05000000030000000b0000000000000017000000
ffffffa350000000c0000000e00000000000000000000017
a3ffffff05000000030000000b0000000000000017000000
ffffffa350000000c0000000e00000000000000000000017
-
{e=>0,a=>108,d=>2,j=>-1,c=>1,k=>90,h=>-2,b=>0,g=>-2,f=>0,i=>1}
6c00000004000000020000001a000000030000005a000000
6c00000004000000020000001a000000030000005a000000
6c00000004000000020000001a000000030000005a000000
0000006c1000000080000000a4000000c00000000000005a
6c00000004000000020000001a000000030000005a000000
6c00000004000000020000001a000000030000005a000000
0000006c1000000080000000a4000000c00000000000005a
6c00000004000000020000001a000000030000005a000000
0000006c1000000080000000a4000000c00000000000005a
=
struct mixed2 {
  long a;
  unsigned int b:2;
};
-
{a=>25,b=>0}
1900000000000000
19000000000000000000000000000000
19000000000000000000000000000000
0000001900000000
1900000000000000
1900000000000000
00000000000000190000000000000000
1900000000000000
0000001900000000
-
{a=>-13,b=>2}
f3ffffff02000000
f3ffffffffffffff0200000000000000
f3ffffffffffffff0200000000000000
fffffff380000000
f3ffffff02000000
f3ffffff02000000
fffffffffffffff38000000000000000
f3ffffff02000000
fffffff380000000
-
{a=>-45,b=>3}
d3ffffff03000000
d3ffffffffffffff0300000000000000
d3ffffffffffffff0300000000000000
ffffffd3c0000000
d3ffffff03000000
d3ffffff03000000
ffffffffffffffd3c000000000000000
d3ffffff03000000
ffffffd3c0000000
-
{a=>-4,b=>0}
fcffffff00000000
fcffffffffffffff0000000000000000
fcffffffffffffff0000000000000000
fffffffc00000000
fcffffff00000000
fcffffff00000000
fffffffffffffffc0000000000000000
fcffffff00000000
fffffffc00000000
-
{a=>121,b=>3}
7900000003000000
79000000000000000300000000000000
79000000000000000300000000000000
00000079c0000000
7900000003000000
7900000003000000
0000000000000079c000000000000000
7900000003000000
00000079c0000000
=
struct mixed2 {
  long a;
  unsigned int b:2;
  unsigned int c:2;
};
-
{c=>2,a=>-103,b=>2}
99ffffff0a000000
99ffffffffffffff0a00000000000000
99ffffffffffffff0a00000000000000
ffffff99a0000000
99ffffff0a000000
99ffffff0a000000
ffffffffffffff99a000000000000000
99ffffff0a000000
ffffff99a0000000
-
{c=>1,a=>15,b=>2}
0f00000006000000
0f000000000000000600000000000000
0f000000000000000600000000000000
0000000f90000000
0f00000006000000
0f00000006000000
000000000000000f9000000000000000
0f00000006000000
0000000f90000000
-
{c=>2,a=>30,b=>1}
1e00000009000000
1e000000000000000900000000000000
1e000000000000000900000000000000
0000001e60000000
1e00000009000000
1e00000009000000
000000000000001e6000000000000000
1e00000009000000
0000001e60000000
-
{c=>0,a=>77,b=>1}
4d00000001000000
4d000000000000000100000000000000
4d000000000000000100000000000000
0000004d40000000
4d00000001000000
4d00000001000000
000000000000004d4000000000000000
4d00000001000000
0000004d40000000
-
{c=>0,a=>35,b=>3}
2300000003000000
23000000000000000300000000000000
23000000000000000300000000000000
00000023c0000000
2300000003000000
2300000003000000
0000000000000023c000000000000000
2300000003000000
00000023c0000000
=
struct mixed2 {
  long a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
};
-
{c=>3,a=>24,b=>2}
180000000e000000
18000000000000000e00000000000000
18000000000000000e00000000000000
00000018b0000000
180000000e000000
180000000e000000
0000000000000018b000000000000000
180000000e000000
00000018b0000000
-
{c=>1,a=>20,b=>0}
1400000004000000
14000000000000000400000000000000
14000000000000000400000000000000
0000001410000000
1400000004000000
1400000004000000
00000000000000141000000000000000
1400000004000000
0000001410000000
-
{c=>3,a=>-15,b=>2}
f1ffffff0e000000
f1ffffffffffffff0e00000000000000
f1ffffffffffffff0e00000000000000
fffffff1b0000000
f1ffffff0e000000
f1ffffff0e000000
fffffffffffffff1b000000000000000
f1ffffff0e000000
fffffff1b0000000
-
{c=>1,a=>8,b=>1}
0800000005000000
08000000000000000500000000000000
08000000000000000500000000000000
0000000850000000
0800000005000000
0800000005000000
00000000000000085000000000000000
0800000005000000
0000000850000000
-
{c=>3,a=>79,b=>3}
4f0000000f000000
4f000000000000000f00000000000000
4f000000000000000f00000000000000
0000004ff0000000
4f0000000f000000
4f0000000f000000
000000000000004ff000000000000000
4f0000000f000000
0000004ff0000000
=
struct mixed2 {
  long a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
};
-
{c=>1,a=>-41,b=>3,d=>0}
d7ffffff0700000000000000
d7ffffffffffffff0700000000000000
d7ffffffffffffff0700000000000000
ffffffd7d000000000000000
d7ffffff0700000000000000
d7ffffff0700000000000000
ffffffffffffffd7d000000000000000
d7ffffff0700000000000000
ffffffd7d000000000000000
-
{c=>0,a=>89,b=>3,d=>2}
590000000300000002000000
59000000000000000300000002000000
59000000000000000300000002000000
00000059c000000080000000
590000000300000002000000
590000000300000002000000
0000000000000059c000000080000000
590000000300000002000000
00000059c000000080000000
-
{c=>1,a=>72,b=>2,d=>1}
480000000600000001000000
48000000000000000600000001000000
48000000000000000600000001000000
000000489000000040000000
480000000600000001000000
480000000600000001000000
00000000000000489000000040000000
480000000600000001000000
000000489000000040000000
-
{c=>3,a=>-32,b=>1,d=>2}
e0ffffff0d00000002000000
e0ffffffffffffff0d00000002000000
e0ffffffffffffff0d00000002000000
ffffffe07000000080000000
e0ffffff0d00000002000000
e0ffffff0d00000002000000
ffffffffffffffe07000000080000000
e0ffffff0d00000002000000
ffffffe07000000080000000
-
{c=>1,a=>96,b=>0,d=>0}
600000000400000000000000
60000000000000000400000000000000
60000000000000000400000000000000
000000601000000000000000
600000000400000000000000
600000000400000000000000
00000000000000601000000000000000
600000000400000000000000
000000601000000000000000
=
struct mixed2 {
  long a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
};
-
{e=>-2,c=>1,a=>52,b=>3,d=>1}
340000000700000009000000
34000000000000000700000009000000
34000000000000000700000009000000
00000034d000000060000000
340000000700000009000000
340000000700000009000000
0000000000000034d000000060000000
340000000700000009000000
00000034d000000060000000
-
{e=>-1,c=>2,a=>-124,b=>2,d=>3}
84ffffff0a0000000f000000
84ffffffffffffff0a0000000f000000
84ffffffffffffff0a0000000f000000
ffffff84a0000000f0000000
84ffffff0a0000000f000000
84ffffff0a0000000f000000
ffffffffffffff84a0000000f0000000
84ffffff0a0000000f000000
ffffff84a0000000f0000000
-
{e=>-1,c=>1,a=>-79,b=>2,d=>1}
b1ffffff060000000d000000
b1ffffffffffffff060000000d000000
b1ffffffffffffff060000000d000000
ffffffb19000000070000000
b1ffffff060000000d000000
b1ffffff060000000d000000
ffffffffffffffb19000000070000000
b1ffffff060000000d000000
ffffffb19000000070000000
-
{e=>0,c=>0,a=>-70,b=>2,d=>2}
baffffff0200000002000000
baffffffffffffff0200000002000000
baffffffffffffff0200000002000000
ffffffba8000000080000000
baffffff0200000002000000
baffffff0200000002000000
ffffffffffffffba8000000080000000
baffffff0200000002000000
ffffffba8000000080000000
-
{e=>-1,c=>0,a=>-18,b=>2,d=>1}
eeffffff020000000d000000
eeffffffffffffff020000000d000000
eeffffffffffffff020000000d000000
ffffffee8000000070000000
eeffffff020000000d000000
eeffffff020000000d000000
ffffffffffffffee8000000070000000
eeffffff020000000d000000
ffffffee8000000070000000
=
struct mixed2 {
  long a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
};
-
{e=>-1,c=>2,a=>-31,b=>0,d=>2,f=>1}
e1ffffff080000001e000000
e1ffffffffffffff080000001e000000
e1ffffffffffffff080000001e000000
ffffffe120000000b4000000
e1ffffff080000001e000000
e1ffffff080000001e000000
ffffffffffffffe120000000b4000000
e1ffffff080000001e000000
ffffffe120000000b4000000
-
{e=>0,c=>2,a=>-103,b=>2,d=>1,f=>0}
99ffffff0a00000001000000
99ffffffffffffff0a00000001000000
99ffffffffffffff0a00000001000000
ffffff99a000000040000000
99ffffff0a00000001000000
99ffffff0a00000001000000
ffffffffffffff99a000000040000000
99ffffff0a00000001000000
ffffff99a000000040000000
-
{e=>-1,c=>2,a=>51,b=>3,d=>1,f=>-1}
330000000b0000003d000000
33000000000000000b0000003d000000
33000000000000000b0000003d000000
00000033e00000007c000000
330000000b0000003d000000
330000000b0000003d000000
0000000000000033e00000007c000000
330000000b0000003d000000
00000033e00000007c000000
-
{e=>1,c=>3,a=>-94,b=>0,d=>0,f=>-1}
a2ffffff0c00000034000000
a2ffffffffffffff0c00000034000000
a2ffffffffffffff0c00000034000000
ffffffa2300000001c000000
a2ffffff0c00000034000000
a2ffffff0c00000034000000
ffffffffffffffa2300000001c000000
a2ffffff0c00000034000000
ffffffa2300000001c000000
-
{e=>-1,c=>3,a=>-14,b=>0,d=>2,f=>-2}
f2ffffff0c0000002e000000
f2ffffffffffffff0c0000002e000000
f2ffffffffffffff0c0000002e000000
fffffff230000000b8000000
f2ffffff0c0000002e000000
f2ffffff0c0000002e000000
fffffffffffffff230000000b8000000
f2ffffff0c0000002e000000
fffffff230000000b8000000
=
struct mixed2 {
  long a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
};
-
{e=>-2,c=>0,a=>80,b=>1,d=>0,f=>0}
500000000100000008000000
50000000000000000100000008000000
50000000000000000100000008000000
000000504000000020000000
500000000100000008000000
500000000100000008000000
00000000000000504000000020000000
500000000100000008000000
000000504000000020000000
-
{e=>1,c=>2,a=>12,b=>1,d=>1,f=>-2}
0c0000000900000025000000
0c000000000000000900000025000000
0c000000000000000900000025000000
0000000c6000000058000000
0c0000000900000025000000
0c0000000900000025000000
000000000000000c6000000058000000
0c0000000900000025000000
0000000c6000000058000000
-
{e=>-2,c=>0,a=>-50,b=>2,d=>3,f=>-1}
ceffffff020000003b000000
ceffffffffffffff020000003b000000
ceffffffffffffff020000003b000000
ffffffce80000000ec000000
ceffffff020000003b000000
ceffffff020000003b000000
ffffffffffffffce80000000ec000000
ceffffff020000003b000000
ffffffce80000000ec000000
-
{e=>-1,c=>1,a=>95,b=>3,d=>2,f=>-1}
5f000000070000003e000000
5f00000000000000070000003e000000
5f00000000000000070000003e000000
0000005fd0000000bc000000
5f000000070000003e000000
5f000000070000003e000000
000000000000005fd0000000bc000000
5f000000070000003e000000
0000005fd0000000bc000000
-
{e=>1,c=>2,a=>99,b=>0,d=>3,f=>0}
630000000800000007000000
63000000000000000800000007000000
63000000000000000800000007000000
0000006320000000d0000000
630000000800000007000000
630000000800000007000000
000000000000006320000000d0000000
630000000800000007000000
0000006320000000d0000000
=
struct mixed2 {
  long a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
};
-
{e=>1,c=>2,a=>-83,g=>-2,b=>3,d=>2,f=>1}
adffffff0b0000001600000002000000
adffffffffffffff0b000000160000000200000000000000
adffffffffffffff0b000000160000000200000000000000
ffffffade00000009400000080000000
adffffff0b0000001600000002000000
adffffff0b0000001600000002000000
ffffffffffffffade0000000940000008000000000000000
adffffff0b0000001600000002000000
ffffffade00000009400000080000000
-
{e=>1,c=>2,a=>21,g=>-2,b=>3,d=>1,f=>1}
150000000b0000001500000002000000
15000000000000000b000000150000000200000000000000
15000000000000000b000000150000000200000000000000
00000015e00000005400000080000000
150000000b0000001500000002000000
150000000b0000001500000002000000
0000000000000015e0000000540000008000000000000000
150000000b0000001500000002000000
00000015e00000005400000080000000
-
{e=>0,c=>2,a=>90,g=>0,b=>0,d=>2,f=>1}
5a000000080000001200000000000000
5a0000000000000008000000120000000000000000000000
5a0000000000000008000000120000000000000000000000
0000005a200000008400000000000000
5a000000080000001200000000000000
5a000000080000001200000000000000
000000000000005a20000000840000000000000000000000
5a000000080000001200000000000000
0000005a200000008400000000000000
-
{e=>-2,c=>3,a=>-13,g=>-2,b=>2,d=>2,f=>-2}
f3ffffff0e0000002a00000002000000
f3ffffffffffffff0e0000002a0000000200000000000000
f3ffffffffffffff0e0000002a0000000200000000000000
fffffff3b0000000a800000080000000
f3ffffff0e0000002a00000002000000
f3ffffff0e0000002a00000002000000
fffffffffffffff3b0000000a80000008000000000000000
f3ffffff0e0000002a00000002000000
fffffff3b0000000a800000080000000
-
{e=>-2,c=>0,a=>125,g=>-1,b=>1,d=>1,f=>-2}
7d000000010000002900000003000000
7d0000000000000001000000290000000300000000000000
7d0000000000000001000000290000000300000000000000
0000007d4000000068000000c0000000
7d000000010000002900000003000000
7d000000010000002900000003000000
000000000000007d4000000068000000c000000000000000
7d000000010000002900000003000000
0000007d4000000068000000c0000000
=
struct mixed2 {
  long a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
};
-
{e=>1,a=>-118,d=>0,c=>1,h=>0,b=>2,g=>0,f=>1}
8affffff060000001400000000000000
8affffffffffffff06000000140000000000000000000000
8affffffffffffff06000000140000000000000000000000
ffffff8a900000001400000000000000
8affffff060000001400000000000000
8affffff060000001400000000000000
ffffffffffffff8a90000000140000000000000000000000
8affffff060000001400000000000000
ffffff8a900000001400000000000000
-
{e=>-1,a=>-22,d=>2,c=>1,h=>-2,b=>0,g=>-2,f=>-1}
eaffffff040000003e0000000a000000
eaffffffffffffff040000003e0000000a00000000000000
eaffffffffffffff040000003e0000000a00000000000000
ffffffea10000000bc000000a0000000
eaffffff040000003e0000000a000000
eaffffff040000003e0000000a000000
ffffffffffffffea10000000bc000000a000000000000000
eaffffff040000003e0000000a000000
ffffffea10000000bc000000a0000000
-
{e=>0,a=>35,d=>2,c=>2,h=>1,b=>0,g=>-1,f=>0}
23000000080000000200000007000000
230000000000000008000000020000000700000000000000
230000000000000008000000020000000700000000000000
000000232000000080000000d0000000
23000000080000000200000007000000
23000000080000000200000007000000
00000000000000232000000080000000d000000000000000
23000000080000000200000007000000
000000232000000080000000d0000000
-
{e=>1,a=>109,d=>0,c=>0,h=>0,b=>0,g=>1,f=>0}
6d000000000000000400000001000000
6d0000000000000000000000040000000100000000000000
6d0000000000000000000000040000000100000000000000
0000006d000000001000000040000000
6d000000000000000400000001000000
6d000000000000000400000001000000
000000000000006d00000000100000004000000000000000
6d000000000000000400000001000000
0000006d000000001000000040000000
-
{e=>1,a=>67,d=>1,c=>1,h=>0,b=>0,g=>-2,f=>0}
43000000040000000500000002000000
430000000000000004000000050000000200000000000000
430000000000000004000000050000000200000000000000
00000043100000005000000080000000
43000000040000000500000002000000
43000000040000000500000002000000
000000000000004310000000500000008000000000000000
43000000040000000500000002000000
00000043100000005000000080000000
=
struct mixed2 {
  long a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
};
-
{e=>-1,a=>-88,d=>2,c=>3,h=>-1,b=>3,g=>-2,f=>0,i=>-1}
a8ffffff0f0000000e0000003e000000
a8ffffffffffffff0f0000000e0000003e00000000000000
a8ffffffffffffff0f0000000e0000003e00000000000000
ffffffa8f0000000b0000000bc000000
a8ffffff0f0000000e0000003e000000
a8ffffff0f0000000e0000003e000000
ffffffffffffffa8f0000000b0000000bc00000000000000
a8ffffff0f0000000e0000003e000000
ffffffa8f0000000b0000000bc000000
-
{e=>-1,a=>117,d=>0,c=>2,h=>-1,b=>2,g=>-1,f=>0,i=>0}
750000000a0000000c0000000f000000
75000000000000000a0000000c0000000f00000000000000
75000000000000000a0000000c0000000f00000000000000
00000075a000000030000000f0000000
750000000a0000000c0000000f000000
750000000a0000000c0000000f000000
0000000000000075a000000030000000f000000000000000
750000000a0000000c0000000f000000
00000075a000000030000000f0000000
-
{e=>-1,a=>119,d=>1,c=>0,h=>-1,b=>2,g=>1,f=>-2,i=>1}
77000000020000002d0000001d000000
7700000000000000020000002d0000001d00000000000000
7700000000000000020000002d0000001d00000000000000
00000077800000007800000074000000
77000000020000002d0000001d000000
77000000020000002d0000001d000000
000000000000007780000000780000007400000000000000
77000000020000002d0000001d000000
00000077800000007800000074000000
-
{e=>0,a=>-126,d=>1,c=>2,h=>1,b=>2,g=>0,f=>0,i=>-2}
82ffffff0a0000000100000024000000
82ffffffffffffff0a000000010000002400000000000000
82ffffffffffffff0a000000010000002400000000000000
ffffff82a00000004000000018000000
82ffffff0a0000000100000024000000
82ffffff0a0000000100000024000000
ffffffffffffff82a0000000400000001800000000000000
82ffffff0a0000000100000024000000
ffffff82a00000004000000018000000
-
{e=>-1,a=>-78,d=>3,c=>2,h=>-2,b=>2,g=>-2,f=>-1,i=>1}
b2ffffff0a0000003f0000001a000000
b2ffffffffffffff0a0000003f0000001a00000000000000
b2ffffffffffffff0a0000003f0000001a00000000000000
ffffffb2a0000000fc000000a4000000
b2ffffff0a0000003f0000001a000000
b2ffffff0a0000003f0000001a000000
ffffffffffffffb2a0000000fc000000a400000000000000
b2ffffff0a0000003f0000001a000000
ffffffb2a0000000fc000000a4000000
=
struct mixed2 {
  long a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
  int           :0;
};
-
{e=>0,a=>-53,d=>0,c=>3,h=>-1,b=>1,g=>1,f=>1,i=>0}
cbffffff0d000000100000000d000000
cbffffffffffffff0d000000100000000d00000000000000
cbffffffffffffff0d000000100000000d00000000000000
ffffffcb700000000400000070000000
cbffffff0d000000100000000d000000
cbffffff0d000000100000000d000000
ffffffffffffffcb70000000040000007000000000000000
cbffffff0d000000100000000d000000
ffffffcb700000000400000070000000
-
{e=>-2,a=>-108,d=>2,c=>0,h=>-1,b=>2,g=>-1,f=>0,i=>-2}
94ffffff020000000a0000002f000000
94ffffffffffffff020000000a0000002f00000000000000
94ffffffffffffff020000000a0000002f00000000000000
ffffff9480000000a0000000f8000000
94ffffff020000000a0000002f000000
94ffffff020000000a0000002f000000
ffffffffffffff9480000000a0000000f800000000000000
94ffffff020000000a0000002f000000
ffffff9480000000a0000000f8000000
-
{e=>1,a=>-117,d=>1,c=>1,h=>0,b=>1,g=>-2,f=>0,i=>-1}
8bffffff050000000500000032000000
8bffffffffffffff05000000050000003200000000000000
8bffffffffffffff05000000050000003200000000000000
ffffff8b50000000500000008c000000
8bffffff050000000500000032000000
8bffffff050000000500000032000000
ffffffffffffff8b50000000500000008c00000000000000
8bffffff050000000500000032000000
ffffff8b50000000500000008c000000
-
{e=>1,a=>121,d=>1,c=>1,h=>-2,b=>0,g=>1,f=>0,i=>1}
79000000040000000500000019000000
790000000000000004000000050000001900000000000000
790000000000000004000000050000001900000000000000
00000079100000005000000064000000
79000000040000000500000019000000
79000000040000000500000019000000
000000000000007910000000500000006400000000000000
79000000040000000500000019000000
00000079100000005000000064000000
-
{e=>-2,a=>-2,d=>1,c=>3,h=>-2,b=>0,g=>-1,f=>-2,i=>-2}
feffffff0c000000290000002b000000
feffffffffffffff0c000000290000002b00000000000000
feffffffffffffff0c000000290000002b00000000000000
fffffffe3000000068000000e8000000
feffffff0c000000290000002b000000
feffffff0c000000290000002b000000
fffffffffffffffe3000000068000000e800000000000000
feffffff0c000000290000002b000000
fffffffe3000000068000000e8000000
=
struct mixed2 {
  long a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
  int           :0;
  int          j:2;
};
-
{e=>-1,a=>65,d=>2,j=>-1,c=>3,h=>0,b=>0,g=>1,f=>0,i=>0}
410000000c0000000e0000000100000003000000
41000000000000000c0000000e0000000100000003000000
41000000000000000c0000000e0000000100000003000000
0000004130000000b000000040000000c0000000
410000000c0000000e0000000100000003000000
410000000c0000000e0000000100000003000000
000000000000004130000000b000000040000000c0000000
410000000c0000000e0000000100000003000000
0000004130000000b000000040000000c0000000
-
{e=>-1,a=>68,d=>0,j=>1,c=>0,h=>-2,b=>2,g=>-1,f=>-2,i=>-1}
44000000020000002c0000003b00000001000000
4400000000000000020000002c0000003b00000001000000
4400000000000000020000002c0000003b00000001000000
000000448000000038000000ec00000040000000
44000000020000002c0000003b00000001000000
44000000020000002c0000003b00000001000000
00000000000000448000000038000000ec00000040000000
44000000020000002c0000003b00000001000000
000000448000000038000000ec00000040000000
-
{e=>1,a=>15,d=>3,j=>0,c=>0,h=>-1,b=>3,g=>1,f=>-2,i=>-1}
0f00000003000000270000003d00000000000000
0f0000000000000003000000270000003d00000000000000
0f0000000000000003000000270000003d00000000000000
0000000fc0000000d80000007c00000000000000
0f00000003000000270000003d00000000000000
0f00000003000000270000003d00000000000000
000000000000000fc0000000d80000007c00000000000000
0f00000003000000270000003d00000000000000
0000000fc0000000d80000007c00000000000000
-
{e=>-1,a=>-76,d=>3,j=>-2,c=>3,h=>1,b=>2,g=>1,f=>-2,i=>1}
b4ffffff0e0000002f0000001500000002000000
b4ffffffffffffff0e0000002f0000001500000002000000
b4ffffffffffffff0e0000002f0000001500000002000000
ffffffb4b0000000f80000005400000080000000
b4ffffff0e0000002f0000001500000002000000
b4ffffff0e0000002f0000001500000002000000
ffffffffffffffb4b0000000f80000005400000080000000
b4ffffff0e0000002f0000001500000002000000
ffffffb4b0000000f80000005400000080000000
-
{e=>-1,a=>65,d=>3,j=>1,c=>1,h=>0,b=>2,g=>0,f=>0,i=>0}
41000000060000000f0000000000000001000000
4100000000000000060000000f0000000000000001000000
4100000000000000060000000f0000000000000001000000
0000004190000000f00000000000000040000000
41000000060000000f0000000000000001000000
41000000060000000f0000000000000001000000
000000000000004190000000f00000000000000040000000
41000000060000000f0000000000000001000000
0000004190000000f00000000000000040000000
=
struct mixed2 {
  long a;
  unsigned int b:2;
  unsigned int c:2;
  unsigned int  :0;
  unsigned int d:2;
  signed   int e:2;
  signed   int f:2;
  signed   int  :0;
  signed   int g:2;
  int          h:2;
  int          i:2;
  int           :0;
  int          j:2;
  int          k;
};
-
{e=>1,a=>-49,d=>0,j=>-2,c=>3,k=>-42,h=>1,b=>0,g=>-2,f=>1,i=>-2}
cfffffff0c000000140000002600000002000000d6ffffff
cfffffffffffffff0c000000140000002600000002000000d6ffffff00000000
cfffffffffffffff0c000000140000002600000002000000d6ffffff00000000
ffffffcf30000000140000009800000080000000ffffffd6
cfffffff0c000000140000002600000002000000d6ffffff
cfffffff0c000000140000002600000002000000d6ffffff
ffffffffffffffcf30000000140000009800000080000000ffffffd600000000
cfffffff0c000000140000002600000002000000d6ffffff
ffffffcf30000000140000009800000080000000ffffffd6
-
{e=>0,a=>91,d=>3,j=>-2,c=>2,k=>-107,h=>0,b=>3,g=>-2,f=>-2,i=>0}
5b0000000b00000023000000020000000200000095ffffff
5b000000000000000b00000023000000020000000200000095ffffff00000000
5b000000000000000b00000023000000020000000200000095ffffff00000000
0000005be0000000c80000008000000080000000ffffff95
5b0000000b00000023000000020000000200000095ffffff
5b0000000b00000023000000020000000200000095ffffff
000000000000005be0000000c80000008000000080000000ffffff9500000000
5b0000000b00000023000000020000000200000095ffffff
0000005be0000000c80000008000000080000000ffffff95
-
{e=>-1,a=>119,d=>0,j=>-1,c=>2,k=>-75,h=>0,b=>0,g=>0,f=>0,i=>1}
77000000080000000c0000001000000003000000b5ffffff
7700000000000000080000000c0000001000000003000000b5ffffff00000000
7700000000000000080000000c0000001000000003000000b5ffffff00000000
00000077200000003000000004000000c0000000ffffffb5
77000000080000000c0000001000000003000000b5ffffff
77000000080000000c0000001000000003000000b5ffffff
0000000000000077200000003000000004000000c0000000ffffffb500000000
77000000080000000c0000001000000003000000b5ffffff
00000077200000003000000004000000c0000000ffffffb5
-
{e=>1,a=>56,d=>2,j=>-2,c=>1,k=>-42,h=>-2,b=>2,g=>0,f=>-1,i=>0}
3800000006000000360000000800000002000000d6ffffff
380000000000000006000000360000000800000002000000d6ffffff00000000
380000000000000006000000360000000800000002000000d6ffffff00000000
00000038900000009c0000002000000080000000ffffffd6
3800000006000000360000000800000002000000d6ffffff
3800000006000000360000000800000002000000d6ffffff
0000000000000038900000009c0000002000000080000000ffffffd600000000
3800000006000000360000000800000002000000d6ffffff
00000038900000009c0000002000000080000000ffffffd6
-
{e=>0,a=>47,d=>2,j=>1,c=>3,k=>-15,h=>-1,b=>0,g=>-1,f=>0,i=>1}
2f0000000c000000020000001f00000001000000f1ffffff
2f000000000000000c000000020000001f00000001000000f1ffffff00000000
2f000000000000000c000000020000001f00000001000000f1ffffff00000000
0000002f3000000080000000f400000040000000fffffff1
2f0000000c000000020000001f00000001000000f1ffffff
2f0000000c000000020000001f00000001000000f1ffffff
000000000000002f3000000080000000f400000040000000fffffff100000000
2f0000000c000000020000001f00000001000000f1ffffff
0000002f3000000080000000f400000040000000fffffff1
=
struct uch_wrap {
  unsigned char a:3;
};
-
{a=>1}
01
01
01
20
01000000
01
20
01
20
-
{a=>4}
04
04
04
80
04000000
04
80
04
80
-
{a=>3}
03
03
03
60
03000000
03
60
03
60
-
{a=>1}
01
01
01
20
01000000
01
20
01
20
-
{a=>7}
07
07
07
e0
07000000
07
e0
07
e0
=
struct uch_wrap {
  unsigned char a:3;
  unsigned char b:3;
};
-
{a=>1,b=>3}
19
19
19
2c
19000000
19
2c
19
2c
-
{a=>0,b=>4}
20
20
20
10
20000000
20
10
20
10
-
{a=>1,b=>6}
31
31
31
38
31000000
31
38
31
38
-
{a=>5,b=>4}
25
25
25
b0
25000000
25
b0
25
b0
-
{a=>0,b=>4}
20
20
20
10
20000000
20
10
20
10
=
struct uch_wrap {
  unsigned char a:3;
  unsigned char b:3;
  unsigned char c:3;
};
-
{c=>4,a=>7,b=>7}
3f04
3f04
3f04
fc80
3f040000
3f04
fc80
3f04
fc80
-
{c=>7,a=>3,b=>3}
1b07
1b07
1b07
6ce0
1b070000
1b07
6ce0
1b07
6ce0
-
{c=>0,a=>6,b=>5}
2e00
2e00
2e00
d400
2e000000
2e00
d400
2e00
d400
-
{c=>3,a=>5,b=>3}
1d03
1d03
1d03
ac60
1d030000
1d03
ac60
1d03
ac60
-
{c=>5,a=>6,b=>1}
0e05
0e05
0e05
c4a0
0e050000
0e05
c4a0
0e05
c4a0
=
struct uch_wrap {
  unsigned char a:3;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
};
-
{c=>2,a=>2,b=>6,d=>2}
3212
3212
3212
5848
32120000
3212
5848
3212
5848
-
{c=>3,a=>2,b=>5,d=>7}
2a3b
2a3b
2a3b
547c
2a3b0000
2a3b
547c
2a3b
547c
-
{c=>2,a=>6,b=>7,d=>2}
3e12
3e12
3e12
dc48
3e120000
3e12
dc48
3e12
dc48
-
{c=>7,a=>6,b=>6,d=>4}
3627
3627
3627
d8f0
36270000
3627
d8f0
3627
d8f0
-
{c=>7,a=>2,b=>2,d=>7}
123f
123f
123f
48fc
123f0000
123f
48fc
123f
48fc
=
struct uch_wrap {
  unsigned char a:3;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
};
-
{e=>6,c=>0,a=>7,b=>2,d=>5}
172806
172806
172806
e814c0
17280600
172806
e814c0
172806
e814c0
-
{e=>0,c=>7,a=>1,b=>5,d=>5}
292f00
292f00
292f00
34f400
292f0000
292f00
34f400
292f00
34f400
-
{e=>7,c=>4,a=>7,b=>7,d=>7}
3f3c07
3f3c07
3f3c07
fc9ce0
3f3c0700
3f3c07
fc9ce0
3f3c07
fc9ce0
-
{e=>2,c=>2,a=>2,b=>6,d=>6}
323202
323202
323202
585840
32320200
323202
585840
323202
585840
-
{e=>0,c=>5,a=>6,b=>6,d=>5}
362d00
362d00
362d00
d8b400
362d0000
362d00
d8b400
362d00
d8b400
=
struct uch_wrap {
  unsigned char a:3;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
};
-
{e=>2,c=>2,a=>0,b=>7,d=>5,f=>4}
382a22
382a22
382a22
1c5450
382a2200
382a22
1c5450
382a22
1c5450
-
{e=>1,c=>5,a=>1,b=>5,d=>5,f=>5}
292d29
292d29
292d29
34b434
292d2900
292d29
34b434
292d29
34b434
-
{e=>5,c=>7,a=>1,b=>7,d=>6,f=>4}
393725
393725
393725
3cf8b0
39372500
393725
3cf8b0
393725
3cf8b0
-
{e=>5,c=>6,a=>6,b=>1,d=>4,f=>1}
0e260d
0e260d
0e260d
c4d0a4
0e260d00
0e260d
c4d0a4
0e260d
c4d0a4
-
{e=>6,c=>2,a=>7,b=>1,d=>6,f=>3}
0f321e
0f321e
0f321e
e458cc
0f321e00
0f321e
e458cc
0f321e
e458cc
=
struct uch_wrap {
  unsigned char a:3;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
};
-
{e=>7,c=>4,a=>5,g=>0,b=>1,d=>1,f=>1}
0d0c0f00
0d0c0f00
0d0c0f00
a484e400
0d0c0f00
0d0c0f00
a484e400
0d0c0f00
a484e400
-
{e=>3,c=>4,a=>6,g=>2,b=>4,d=>2,f=>0}
26140302
26140302
26140302
d0886040
26140302
26140302
d0886040
26140302
d0886040
-
{e=>2,c=>4,a=>7,g=>6,b=>6,d=>4,f=>6}
37243206
37243206
37243206
f89058c0
37243206
37243206
f89058c0
37243206
f89058c0
-
{e=>0,c=>6,a=>3,g=>0,b=>1,d=>6,f=>1}
0b360800
0b360800
0b360800
64d80400
0b360800
0b360800
64d80400
0b360800
64d80400
-
{e=>3,c=>7,a=>0,g=>4,b=>4,d=>1,f=>4}
200f2304
200f2304
200f2304
10e47080
200f2304
200f2304
10e47080
200f2304
10e47080
=
struct uch_wrap {
  unsigned char a:3;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
};
-
{e=>1,a=>1,d=>4,c=>6,h=>5,b=>3,g=>5,f=>5}
1926292d
1926292d
1926292d
2cd034b4
1926292d
1926292d
2cd034b4
1926292d
2cd034b4
-
{e=>7,a=>4,d=>6,c=>1,h=>0,b=>0,g=>0,f=>3}
04311f00
04311f00
04311f00
8038ec00
04311f00
04311f00
8038ec00
04311f00
8038ec00
-
{e=>2,a=>6,d=>4,c=>1,h=>5,b=>4,g=>6,f=>3}
26211a2e
26211a2e
26211a2e
d0304cd4
26211a2e
26211a2e
d0304cd4
26211a2e
d0304cd4
-
{e=>1,a=>2,d=>6,c=>2,h=>6,b=>4,g=>3,f=>0}
22320133
22320133
22320133
50582078
22320133
22320133
50582078
22320133
50582078
-
{e=>0,a=>1,d=>0,c=>3,h=>5,b=>3,g=>4,f=>5}
1903282c
1903282c
1903282c
2c601494
1903282c
1903282c
2c601494
1903282c
2c601494
=
struct uch_wrap {
  unsigned char a:3;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
};
-
{e=>4,a=>6,d=>7,c=>0,h=>5,b=>3,g=>6,f=>2,i=>5}
1e38142e05
1e38142e05
1e38142e05
cc1c88d4a0
1e38142e05000000
1e38142e05
cc1c88d4a0
1e38142e05
cc1c88d4a0
-
{e=>7,a=>3,d=>1,c=>0,h=>0,b=>2,g=>5,f=>6,i=>6}
1308370506
1308370506
1308370506
6804f8a0c0
1308370506000000
1308370506
6804f8a0c0
1308370506
6804f8a0c0
-
{e=>3,a=>2,d=>4,c=>3,h=>6,b=>2,g=>7,f=>7,i=>6}
12233b3706
12233b3706
12233b3706
48707cf8c0
12233b3706000000
12233b3706
48707cf8c0
12233b3706
48707cf8c0
-
{e=>0,a=>3,d=>7,c=>1,h=>7,b=>7,g=>0,f=>4,i=>0}
3b39203800
3b39203800
3b39203800
7c3c101c00
3b39203800000000
3b39203800
7c3c101c00
3b39203800
7c3c101c00
-
{e=>5,a=>7,d=>0,c=>1,h=>3,b=>7,g=>3,f=>6,i=>1}
3f01351b01
3f01351b01
3f01351b01
fc20b86c20
3f01351b01000000
3f01351b01
fc20b86c20
3f01351b01
fc20b86c20
=
struct uch_wrap {
  unsigned char a:3;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
};
-
{e=>3,a=>6,d=>1,j=>4,c=>0,h=>4,b=>1,g=>5,f=>4,i=>1}
0e08232521
0e08232521
0e08232521
c40470b030
0e08232521000000
0e08232521
c40470b030
0e08232521
c40470b030
-
{e=>6,a=>1,d=>1,j=>1,c=>2,h=>3,b=>4,g=>0,f=>5,i=>1}
210a2e1809
210a2e1809
210a2e1809
3044d40c24
210a2e1809000000
210a2e1809
3044d40c24
210a2e1809
3044d40c24
-
{e=>5,a=>2,d=>6,j=>3,c=>7,h=>0,b=>7,g=>1,f=>7,i=>3}
3a373d011b
3a373d011b
3a373d011b
5cf8bc206c
3a373d011b000000
3a373d011b
5cf8bc206c
3a373d011b
5cf8bc206c
-
{e=>6,a=>1,d=>3,j=>3,c=>5,h=>6,b=>1,g=>5,f=>3,i=>7}
091d1e351f
091d1e351f
091d1e351f
24acccb8ec
091d1e351f000000
091d1e351f
24acccb8ec
091d1e351f
24acccb8ec
-
{e=>4,a=>0,d=>5,j=>4,c=>5,h=>2,b=>1,g=>1,f=>1,i=>2}
082d0c1122
082d0c1122
082d0c1122
04b4842850
082d0c1122000000
082d0c1122
04b4842850
082d0c1122
04b4842850
=
struct uch_wrap {
  unsigned char a:3;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
};
-
{e=>0,a=>4,d=>4,j=>1,c=>3,k=>2,h=>3,b=>4,g=>2,f=>6,i=>2}
2423301a0a02
2423301a0a02
2423301a0a02
9070184c4440
2423301a0a020000
2423301a0a02
9070184c4440
2423301a0a02
9070184c4440
-
{e=>1,a=>6,d=>5,j=>4,c=>0,k=>1,h=>7,b=>1,g=>4,f=>7,i=>2}
0e28393c2201
0e28393c2201
0e28393c2201
c4143c9c5020
0e28393c22010000
0e28393c2201
c4143c9c5020
0e28393c2201
c4143c9c5020
-
{e=>6,a=>3,d=>6,j=>5,c=>4,k=>1,h=>2,b=>1,g=>2,f=>2,i=>7}
0b3416122f01
0b3416122f01
0b3416122f01
6498c848f420
0b3416122f010000
0b3416122f01
6498c848f420
0b3416122f01
6498c848f420
-
{e=>4,a=>2,d=>5,j=>1,c=>2,k=>7,h=>0,b=>0,g=>1,f=>0,i=>4}
022a04010c07
022a04010c07
022a04010c07
4054802084e0
022a04010c070000
022a04010c07
4054802084e0
022a04010c07
4054802084e0
-
{e=>5,a=>0,d=>0,j=>4,c=>6,k=>4,h=>1,b=>3,g=>4,f=>2,i=>2}
1806150c2204
1806150c2204
1806150c2204
0cc0a8845080
1806150c22040000
1806150c2204
0cc0a8845080
1806150c2204
0cc0a8845080
=
struct uch_wrap {
  unsigned char a:3;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
};
-
{e=>1,a=>4,d=>2,j=>3,l=>2,c=>1,k=>0,h=>2,b=>4,g=>2,f=>4,i=>7}
241121121f10
241121121f10
241121121f10
90283048ec08
241121121f100000
241121121f10
90283048ec08
241121121f10
90283048ec08
-
{e=>3,a=>2,d=>1,j=>0,l=>7,c=>0,k=>0,h=>5,b=>2,g=>6,f=>1,i=>0}
12080b2e0038
12080b2e0038
12080b2e0038
480464d4001c
12080b2e00380000
12080b2e0038
480464d4001c
12080b2e0038
480464d4001c
-
{e=>7,a=>6,d=>5,j=>3,l=>2,c=>7,k=>0,h=>4,b=>0,g=>7,f=>1,i=>5}
062f0f271d10
062f0f271d10
062f0f271d10
c0f4e4f0ac08
062f0f271d100000
062f0f271d10
c0f4e4f0ac08
062f0f271d10
c0f4e4f0ac08
-
{e=>0,a=>3,d=>3,j=>3,l=>1,c=>5,k=>4,h=>3,b=>4,g=>3,f=>5,i=>7}
231d281b1f0c
231d281b1f0c
231d281b1f0c
70ac146cec84
231d281b1f0c0000
231d281b1f0c
70ac146cec84
231d281b1f0c
70ac146cec84
-
{e=>2,a=>2,d=>6,j=>1,l=>1,c=>6,k=>7,h=>3,b=>7,g=>5,f=>4,i=>0}
3a36221d080f
3a36221d080f
3a36221d080f
5cd850ac04e4
3a36221d080f0000
3a36221d080f
5cd850ac04e4
3a36221d080f
5cd850ac04e4
=
struct uch_wrap {
  unsigned char a:3;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
};
-
{e=>3,a=>6,m=>7,d=>3,j=>4,l=>4,c=>2,k=>2,h=>5,b=>7,g=>6,f=>2,i=>3}
3e1a132e232207
3e1a132e232207
3e1a132e232207
dc4c68d47050e0
3e1a132e23220700
3e1a132e232207
dc4c68d47050e0
3e1a132e232207
dc4c68d47050e0
-
{e=>2,a=>3,m=>0,d=>7,j=>7,l=>0,c=>2,k=>3,h=>1,b=>2,g=>1,f=>7,i=>7}
133a3a093f0300
133a3a093f0300
133a3a093f0300
685c5c24fc6000
133a3a093f030000
133a3a093f0300
685c5c24fc6000
133a3a093f0300
685c5c24fc6000
-
{e=>3,a=>7,m=>0,d=>4,j=>6,l=>5,c=>1,k=>6,h=>2,b=>5,g=>7,f=>5,i=>1}
2f212b17312e00
2f212b17312e00
2f212b17312e00
f43074e838d400
2f212b17312e0000
2f212b17312e00
f43074e838d400
2f212b17312e00
f43074e838d400
-
{e=>6,a=>5,m=>3,d=>0,j=>1,l=>5,c=>1,k=>3,h=>0,b=>6,g=>4,f=>4,i=>2}
350126040a2b03
350126040a2b03
350126040a2b03
b820d080447460
350126040a2b0300
350126040a2b03
b820d080447460
350126040a2b03
b820d080447460
-
{e=>3,a=>3,m=>1,d=>1,j=>3,l=>4,c=>1,k=>6,h=>6,b=>1,g=>4,f=>1,i=>4}
0b090b341c2601
0b090b341c2601
0b090b341c2601
642464988cd020
0b090b341c260100
0b090b341c2601
642464988cd020
0b090b341c2601
642464988cd020
=
struct uch_wrap {
  unsigned char a:3;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
  short         n;
};
-
{e=>1,n=>106,a=>2,m=>4,d=>4,j=>1,l=>4,c=>1,k=>6,h=>1,b=>0,g=>4,f=>7,i=>1}
0221390c092604006a00
0221390c092604006a00
0221390c092604006a00
40303c8424d08000006a
0221390c092604006a000000
0221390c092604006a00
40303c8424d08000006a
0221390c092604006a00
40303c8424d08000006a
-
{e=>4,n=>74,a=>5,m=>5,d=>7,j=>0,l=>4,c=>0,k=>0,h=>4,b=>7,g=>2,f=>7,i=>5}
3d383c22052005004a00
3d383c22052005004a00
3d383c22052005004a00
bc1c9c50a010a000004a
3d383c22052005004a000000
3d383c22052005004a00
bc1c9c50a010a000004a
3d383c22052005004a00
bc1c9c50a010a000004a
-
{e=>7,n=>-6,a=>5,m=>1,d=>2,j=>6,l=>5,c=>2,k=>2,h=>7,b=>2,g=>0,f=>0,i=>7}
15120738372a0100faff
15120738372a0100faff
15120738372a0100faff
a848e01cf8542000fffa
15120738372a0100faff0000
15120738372a0100faff
a848e01cf8542000fffa
15120738372a0100faff
a848e01cf8542000fffa
-
{e=>7,n=>-54,a=>2,m=>1,d=>4,j=>7,l=>3,c=>1,k=>2,h=>1,b=>2,g=>0,f=>5,i=>3}
12212f083b1a0100caff
12212f083b1a0100caff
12212f083b1a0100caff
4830f4047c4c2000ffca
12212f083b1a0100caff0000
12212f083b1a0100caff
4830f4047c4c2000ffca
12212f083b1a0100caff
4830f4047c4c2000ffca
-
{e=>6,n=>118,a=>5,m=>6,d=>0,j=>7,l=>4,c=>2,k=>6,h=>3,b=>6,g=>4,f=>7,i=>0}
35023e1c382606007600
35023e1c382606007600
35023e1c382606007600
b840dc8c1cd0c0000076
35023e1c3826060076000000
35023e1c382606007600
b840dc8c1cd0c0000076
35023e1c382606007600
b840dc8c1cd0c0000076
=
struct uch_wrap {
  char a;
  unsigned char b:3;
};
-
{a=>-70,b=>6}
ba06
ba06
ba06
bac0
ba060000
ba06
bac0
ba06
bac0
-
{a=>-97,b=>5}
9f05
9f05
9f05
9fa0
9f050000
9f05
9fa0
9f05
9fa0
-
{a=>-15,b=>0}
f100
f100
f100
f100
f1000000
f100
f100
f100
f100
-
{a=>-44,b=>0}
d400
d400
d400
d400
d4000000
d400
d400
d400
d400
-
{a=>102,b=>7}
6607
6607
6607
66e0
66070000
6607
66e0
6607
66e0
=
struct uch_wrap {
  char a;
  unsigned char b:3;
  unsigned char c:3;
};
-
{c=>6,a=>32,b=>5}
2035
2035
2035
20b8
20350000
2035
20b8
2035
20b8
-
{c=>5,a=>-69,b=>3}
bb2b
bb2b
bb2b
bb74
bb2b0000
bb2b
bb74
bb2b
bb74
-
{c=>3,a=>90,b=>2}
5a1a
5a1a
5a1a
5a4c
5a1a0000
5a1a
5a4c
5a1a
5a4c
-
{c=>5,a=>80,b=>6}
502e
502e
502e
50d4
502e0000
502e
50d4
502e
50d4
-
{c=>6,a=>117,b=>3}
7533
7533
7533
7578
75330000
7533
7578
7533
7578
=
struct uch_wrap {
  char a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
};
-
{c=>1,a=>4,b=>6,d=>2}
040e02
040e02
040e02
04c440
040e0200
040e02
04c440
040e02
04c440
-
{c=>7,a=>-20,b=>1,d=>3}
ec3903
ec3903
ec3903
ec3c60
ec390300
ec3903
ec3c60
ec3903
ec3c60
-
{c=>2,a=>127,b=>1,d=>3}
7f1103
7f1103
7f1103
7f2860
7f110300
7f1103
7f2860
7f1103
7f2860
-
{c=>6,a=>-48,b=>4,d=>4}
d03404
d03404
d03404
d09880
d0340400
d03404
d09880
d03404
d09880
-
{c=>4,a=>-78,b=>2,d=>5}
b22205
b22205
b22205
b250a0
b2220500
b22205
b250a0
b22205
b250a0
=
struct uch_wrap {
  char a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
};
-
{e=>3,c=>0,a=>120,b=>7,d=>7}
78071f
78071f
78071f
78e0ec
78071f00
78071f
78e0ec
78071f
78e0ec
-
{e=>6,c=>6,a=>-75,b=>2,d=>3}
b53233
b53233
b53233
b55878
b5323300
b53233
b55878
b53233
b55878
-
{e=>3,c=>2,a=>-61,b=>6,d=>7}
c3161f
c3161f
c3161f
c3c8ec
c3161f00
c3161f
c3c8ec
c3161f
c3c8ec
-
{e=>1,c=>0,a=>59,b=>7,d=>2}
3b070a
3b070a
3b070a
3be044
3b070a00
3b070a
3be044
3b070a
3be044
-
{e=>2,c=>4,a=>61,b=>4,d=>6}
3d2416
3d2416
3d2416
3d90c8
3d241600
3d2416
3d90c8
3d2416
3d90c8
=
struct uch_wrap {
  char a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
};
-
{e=>1,c=>4,a=>48,b=>5,d=>6,f=>3}
30250e03
30250e03
30250e03
30b0c460
30250e03
30250e03
30b0c460
30250e03
30b0c460
-
{e=>6,c=>0,a=>-47,b=>4,d=>5,f=>3}
d1043503
d1043503
d1043503
d180b860
d1043503
d1043503
d180b860
d1043503
d180b860
-
{e=>5,c=>1,a=>-5,b=>4,d=>1,f=>0}
fb0c2900
fb0c2900
fb0c2900
fb843400
fb0c2900
fb0c2900
fb843400
fb0c2900
fb843400
-
{e=>6,c=>2,a=>106,b=>7,d=>3,f=>4}
6a173304
6a173304
6a173304
6ae87880
6a173304
6a173304
6ae87880
6a173304
6ae87880
-
{e=>5,c=>5,a=>-105,b=>3,d=>6,f=>3}
972b2e03
972b2e03
972b2e03
9774d460
972b2e03
972b2e03
9774d460
972b2e03
9774d460
=
struct uch_wrap {
  char a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
};
-
{e=>4,c=>1,a=>71,g=>5,b=>0,d=>7,f=>0}
47082728
47082728
47082728
4704f014
47082728
47082728
4704f014
47082728
4704f014
-
{e=>6,c=>7,a=>36,g=>5,b=>1,d=>5,f=>4}
2439352c
2439352c
2439352c
243cb894
2439352c
2439352c
243cb894
2439352c
243cb894
-
{e=>3,c=>5,a=>-22,g=>5,b=>5,d=>4,f=>1}
ea2d1c29
ea2d1c29
ea2d1c29
eab48c34
ea2d1c29
ea2d1c29
eab48c34
ea2d1c29
eab48c34
-
{e=>6,c=>2,a=>43,g=>6,b=>0,d=>2,f=>0}
2b103230
2b103230
2b103230
2b085818
2b103230
2b103230
2b085818
2b103230
2b085818
-
{e=>0,c=>1,a=>-119,g=>0,b=>4,d=>4,f=>1}
890c0401
890c0401
890c0401
89848020
890c0401
890c0401
89848020
890c0401
89848020
=
struct uch_wrap {
  char a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
};
-
{e=>6,a=>88,d=>3,c=>5,h=>1,b=>3,g=>7,f=>2}
582b333a01
582b333a01
582b333a01
5874785c20
582b333a01000000
582b333a01
5874785c20
582b333a01
5874785c20
-
{e=>3,a=>-69,d=>7,c=>6,h=>7,b=>3,g=>7,f=>4}
bb331f3c07
bb331f3c07
bb331f3c07
bb78ec9ce0
bb331f3c07000000
bb331f3c07
bb78ec9ce0
bb331f3c07
bb78ec9ce0
-
{e=>7,a=>-30,d=>6,c=>4,h=>5,b=>0,g=>7,f=>3}
e2203e3b05
e2203e3b05
e2203e3b05
e210dc7ca0
e2203e3b05000000
e2203e3b05
e210dc7ca0
e2203e3b05
e210dc7ca0
-
{e=>6,a=>-16,d=>6,c=>7,h=>5,b=>2,g=>1,f=>6}
f03a360e05
f03a360e05
f03a360e05
f05cd8c4a0
f03a360e05000000
f03a360e05
f05cd8c4a0
f03a360e05
f05cd8c4a0
-
{e=>1,a=>72,d=>2,c=>1,h=>1,b=>5,g=>1,f=>6}
480d0a0e01
480d0a0e01
480d0a0e01
48a444c420
480d0a0e01000000
480d0a0e01
48a444c420
480d0a0e01
48a444c420
=
struct uch_wrap {
  char a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
};
-
{e=>2,a=>-92,d=>4,c=>2,h=>6,b=>6,g=>0,f=>3,i=>7}
a41614033e
a41614033e
a41614033e
a4c88860dc
a41614033e000000
a41614033e
a4c88860dc
a41614033e
a4c88860dc
-
{e=>1,a=>50,d=>4,c=>7,h=>0,b=>5,g=>6,f=>2,i=>0}
323d0c3200
323d0c3200
323d0c3200
32bc845800
323d0c3200000000
323d0c3200
32bc845800
323d0c3200
32bc845800
-
{e=>7,a=>-126,d=>7,c=>3,h=>5,b=>2,g=>0,f=>0,i=>4}
821a3f0025
821a3f0025
821a3f0025
824cfc00b0
821a3f0025000000
821a3f0025
824cfc00b0
821a3f0025
824cfc00b0
-
{e=>6,a=>123,d=>7,c=>4,h=>6,b=>0,g=>3,f=>6,i=>4}
7b20371e26
7b20371e26
7b20371e26
7b10f8ccd0
7b20371e26000000
7b20371e26
7b10f8ccd0
7b20371e26
7b10f8ccd0
-
{e=>5,a=>21,d=>0,c=>7,h=>1,b=>3,g=>0,f=>7,i=>5}
153b280729
153b280729
153b280729
157c14e034
153b280729000000
153b280729
157c14e034
153b280729
157c14e034
=
struct uch_wrap {
  char a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
};
-
{e=>1,a=>79,d=>6,j=>1,c=>6,h=>0,b=>1,g=>1,f=>5,i=>4}
4f310e0d2001
4f310e0d2001
4f310e0d2001
4f38c4a41020
4f310e0d20010000
4f310e0d2001
4f38c4a41020
4f310e0d2001
4f38c4a41020
-
{e=>5,a=>70,d=>7,j=>4,c=>1,h=>1,b=>4,g=>2,f=>5,i=>2}
460c2f151104
460c2f151104
460c2f151104
4684f4a82880
460c2f1511040000
460c2f151104
4684f4a82880
460c2f151104
4684f4a82880
-
{e=>2,a=>90,d=>2,j=>3,c=>7,h=>2,b=>6,g=>4,f=>7,i=>4}
5a3e12272203
5a3e12272203
5a3e12272203
5adc48f05060
5a3e122722030000
5a3e12272203
5adc48f05060
5a3e12272203
5adc48f05060
-
{e=>6,a=>48,d=>0,j=>3,c=>5,h=>3,b=>5,g=>6,f=>5,i=>3}
302d30351b03
302d30351b03
302d30351b03
30b418b86c60
302d30351b030000
302d30351b03
30b418b86c60
302d30351b03
30b418b86c60
-
{e=>6,a=>-79,d=>1,j=>4,c=>1,h=>6,b=>7,g=>6,f=>4,i=>5}
b10f31342e04
b10f31342e04
b10f31342e04
b1e43898d480
b10f31342e040000
b10f31342e04
b1e43898d480
b10f31342e04
b1e43898d480
=
struct uch_wrap {
  char a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
};
-
{e=>3,a=>33,d=>5,j=>0,c=>5,k=>3,h=>3,b=>4,g=>0,f=>2,i=>4}
212c1d022318
212c1d022318
212c1d022318
2194ac40700c
212c1d0223180000
212c1d022318
2194ac40700c
212c1d022318
2194ac40700c
-
{e=>1,a=>64,d=>0,j=>2,c=>1,k=>7,h=>7,b=>1,g=>3,f=>0,i=>6}
40090818373a
40090818373a
40090818373a
4024040cf85c
40090818373a0000
40090818373a
4024040cf85c
40090818373a
4024040cf85c
-
{e=>0,a=>121,d=>0,j=>2,c=>3,k=>3,h=>1,b=>5,g=>0,f=>4,i=>5}
791d0004291a
791d0004291a
791d0004291a
79ac0080344c
791d0004291a0000
791d0004291a
79ac0080344c
791d0004291a
79ac0080344c
-
{e=>7,a=>-117,d=>1,j=>1,c=>6,k=>5,h=>1,b=>3,g=>1,f=>5,i=>4}
8b33390d2129
8b33390d2129
8b33390d2129
8b783ca43034
8b33390d21290000
8b33390d2129
8b783ca43034
8b33390d2129
8b783ca43034
-
{e=>5,a=>105,d=>3,j=>2,c=>3,k=>7,h=>6,b=>3,g=>5,f=>1,i=>1}
691b2b290e3a
691b2b290e3a
691b2b290e3a
696c7434c45c
691b2b290e3a0000
691b2b290e3a
696c7434c45c
691b2b290e3a
696c7434c45c
=
struct uch_wrap {
  char a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
};
-
{e=>1,a=>-36,d=>3,j=>4,l=>1,c=>5,k=>1,h=>3,b=>7,g=>3,f=>0,i=>2}
dc2f0b18130c01
dc2f0b18130c01
dc2f0b18130c01
dcf4640c688420
dc2f0b18130c0100
dc2f0b18130c01
dcf4640c688420
dc2f0b18130c01
dcf4640c688420
-
{e=>5,a=>-81,d=>1,j=>6,l=>1,c=>3,k=>7,h=>3,b=>5,g=>3,f=>5,i=>1}
af1d291d0b3e01
af1d291d0b3e01
af1d291d0b3e01
afac34ac64dc20
af1d291d0b3e0100
af1d291d0b3e01
afac34ac64dc20
af1d291d0b3e01
afac34ac64dc20
-
{e=>0,a=>-44,d=>7,j=>3,l=>5,c=>3,k=>2,h=>2,b=>2,g=>3,f=>0,i=>6}
d41a0718321305
d41a0718321305
d41a0718321305
d44ce00c5868a0
d41a071832130500
d41a0718321305
d44ce00c5868a0
d41a0718321305
d44ce00c5868a0
-
{e=>1,a=>-34,d=>1,j=>6,l=>7,c=>6,k=>0,h=>6,b=>6,g=>5,f=>2,i=>5}
de36092a2e0607
de36092a2e0607
de36092a2e0607
ded82454d4c0e0
de36092a2e060700
de36092a2e0607
ded82454d4c0e0
de36092a2e0607
ded82454d4c0e0
-
{e=>0,a=>57,d=>4,j=>0,l=>4,c=>6,k=>1,h=>2,b=>2,g=>7,f=>6,i=>2}
3932043e120804
3932043e120804
3932043e120804
395880dc480480
3932043e12080400
3932043e120804
395880dc480480
3932043e120804
395880dc480480
=
struct uch_wrap {
  char a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
};
-
{e=>7,a=>-101,m=>1,d=>6,j=>3,l=>6,c=>4,k=>6,h=>5,b=>1,g=>1,f=>6,i=>0}
9b213e0e05330e
9b213e0e05330e
9b213e0e05330e
9b30dcc4a078c4
9b213e0e05330e00
9b213e0e05330e
9b30dcc4a078c4
9b213e0e05330e
9b30dcc4a078c4
-
{e=>3,a=>-11,m=>4,d=>2,j=>6,l=>7,c=>6,k=>4,h=>7,b=>2,g=>1,f=>4,i=>3}
f5321a0c1f2627
f5321a0c1f2627
f5321a0c1f2627
f5584c84ecd0f0
f5321a0c1f262700
f5321a0c1f2627
f5584c84ecd0f0
f5321a0c1f2627
f5584c84ecd0f0
-
{e=>0,a=>47,m=>2,d=>7,j=>5,l=>2,c=>2,k=>3,h=>4,b=>5,g=>5,f=>1,i=>7}
2f1507293c1d12
2f1507293c1d12
2f1507293c1d12
2fa8e0349cac48
2f1507293c1d1200
2f1507293c1d12
2fa8e0349cac48
2f1507293c1d12
2fa8e0349cac48
-
{e=>1,a=>-113,m=>7,d=>2,j=>1,l=>6,c=>7,k=>4,h=>7,b=>5,g=>0,f=>6,i=>7}
8f3d0a063f213e
8f3d0a063f213e
8f3d0a063f213e
8fbc44c0fc30dc
8f3d0a063f213e00
8f3d0a063f213e
8fbc44c0fc30dc
8f3d0a063f213e
8fbc44c0fc30dc
-
{e=>2,a=>19,m=>6,d=>7,j=>5,l=>4,c=>3,k=>7,h=>4,b=>1,g=>4,f=>0,i=>3}
131917201c3d34
131917201c3d34
131917201c3d34
132ce8108cbc98
131917201c3d3400
131917201c3d34
132ce8108cbc98
131917201c3d34
132ce8108cbc98
=
struct uch_wrap {
  char a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
  unsigned char n:3;
};
-
{e=>6,n=>5,a=>-111,m=>0,d=>3,j=>5,l=>6,c=>7,k=>5,h=>6,b=>0,g=>4,f=>0,i=>6}
91383320362d0605
91383320362d0605
91383320362d0605
911c7810d8b4c0a0
91383320362d0605
91383320362d0605
911c7810d8b4c0a0
91383320362d0605
911c7810d8b4c0a0
-
{e=>7,n=>4,a=>-30,m=>6,d=>4,j=>3,l=>0,c=>4,k=>4,h=>1,b=>7,g=>7,f=>5,i=>0}
e2273c3d01233004
e2273c3d01233004
e2273c3d01233004
e2f09cbc20701880
e2273c3d01233004
e2273c3d01233004
e2f09cbc20701880
e2273c3d01233004
e2f09cbc20701880
-
{e=>0,n=>1,a=>22,m=>5,d=>7,j=>5,l=>0,c=>0,k=>1,h=>5,b=>3,g=>2,f=>7,i=>3}
160307171d0d2801
160307171d0d2801
160307171d0d2801
1660e0e8aca41420
160307171d0d2801
160307171d0d2801
1660e0e8aca41420
160307171d0d2801
1660e0e8aca41420
-
{e=>4,n=>5,a=>4,m=>0,d=>1,j=>2,l=>4,c=>1,k=>3,h=>0,b=>0,g=>0,f=>7,i=>6}
04082107301a0405
04082107301a0405
04082107301a0405
040430e0184c80a0
04082107301a0405
04082107301a0405
040430e0184c80a0
04082107301a0405
040430e0184c80a0
-
{e=>2,n=>3,a=>-83,m=>6,d=>6,j=>6,l=>6,c=>0,k=>1,h=>2,b=>6,g=>0,f=>6,i=>5}
ad0616062a0e3603
ad0616062a0e3603
ad0616062a0e3603
adc0c8c054c4d860
ad0616062a0e3603
ad0616062a0e3603
adc0c8c054c4d860
ad0616062a0e3603
adc0c8c054c4d860
=
struct uch_wrap {
  char a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
  unsigned char n:3;
  short         o;
};
-
{e=>0,n=>2,a=>-105,m=>1,d=>3,j=>0,l=>1,c=>6,k=>1,h=>1,b=>2,g=>7,f=>2,o=>-102,i=>2}
9732033a110809029aff
9732033a110809029aff
9732033a110809029aff
9758605c28042440ff9a
9732033a110809029aff0000
9732033a110809029aff
9758605c28042440ff9a
9732033a110809029aff
9758605c28042440ff9a
-
{e=>1,n=>2,a=>-82,m=>2,d=>4,j=>2,l=>6,c=>0,k=>3,h=>1,b=>6,g=>6,f=>3,o=>29,i=>2}
ae060c33111a16021d00
ae060c33111a16021d00
ae060c33111a16021d00
aec08478284cc840001d
ae060c33111a16021d000000
ae060c33111a16021d00
aec08478284cc840001d
ae060c33111a16021d00
aec08478284cc840001d
-
{e=>5,n=>7,a=>-14,m=>4,d=>0,j=>7,l=>1,c=>2,k=>7,h=>7,b=>4,g=>1,f=>5,o=>-24,i=>2}
f214280d173f2107e8ff
f214280d173f2107e8ff
f214280d173f2107e8ff
f28814a4e8fc30e0ffe8
f214280d173f2107e8ff0000
f214280d173f2107e8ff
f28814a4e8fc30e0ffe8
f214280d173f2107e8ff
f28814a4e8fc30e0ffe8
-
{e=>0,n=>6,a=>96,m=>7,d=>3,j=>0,l=>3,c=>3,k=>1,h=>3,b=>6,g=>6,f=>7,o=>81,i=>2}
601e033713083b065100
601e033713083b065100
601e033713083b065100
60cc60f868047cc00051
601e033713083b0651000000
601e033713083b065100
60cc60f868047cc00051
601e033713083b065100
60cc60f868047cc00051
-
{e=>6,n=>2,a=>-36,m=>0,d=>2,j=>6,l=>5,c=>4,k=>0,h=>3,b=>6,g=>6,f=>5,o=>-17,i=>5}
dc2632352b060502efff
dc2632352b060502efff
dc2632352b060502efff
dcd058b874c0a040ffef
dc2632352b060502efff0000
dc2632352b060502efff
dcd058b874c0a040ffef
dc2632352b060502efff
dcd058b874c0a040ffef
=
struct uch_wrap {
  short a;
  unsigned char b:3;
};
-
{a=>102,b=>2}
66000200
66000200
66000200
00664000
66000200
66000200
00664000
66000200
00664000
-
{a=>39,b=>4}
27000400
27000400
27000400
00278000
27000400
27000400
00278000
27000400
00278000
-
{a=>-119,b=>5}
89ff0500
89ff0500
89ff0500
ff89a000
89ff0500
89ff0500
ff89a000
89ff0500
ff89a000
-
{a=>69,b=>7}
45000700
45000700
45000700
0045e000
45000700
45000700
0045e000
45000700
0045e000
-
{a=>46,b=>7}
2e000700
2e000700
2e000700
002ee000
2e000700
2e000700
002ee000
2e000700
002ee000
=
struct uch_wrap {
  short a;
  unsigned char b:3;
  unsigned char c:3;
};
-
{c=>2,a=>-97,b=>2}
9fff1200
9fff1200
9fff1200
ff9f4800
9fff1200
9fff1200
ff9f4800
9fff1200
ff9f4800
-
{c=>5,a=>-16,b=>5}
f0ff2d00
f0ff2d00
f0ff2d00
fff0b400
f0ff2d00
f0ff2d00
fff0b400
f0ff2d00
fff0b400
-
{c=>5,a=>100,b=>5}
64002d00
64002d00
64002d00
0064b400
64002d00
64002d00
0064b400
64002d00
0064b400
-
{c=>1,a=>117,b=>2}
75000a00
75000a00
75000a00
00754400
75000a00
75000a00
00754400
75000a00
00754400
-
{c=>1,a=>-105,b=>4}
97ff0c00
97ff0c00
97ff0c00
ff978400
97ff0c00
97ff0c00
ff978400
97ff0c00
ff978400
=
struct uch_wrap {
  short a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
};
-
{c=>2,a=>7,b=>5,d=>3}
07001503
07001503
07001503
0007a860
07001503
07001503
0007a860
07001503
0007a860
-
{c=>7,a=>-90,b=>4,d=>1}
a6ff3c01
a6ff3c01
a6ff3c01
ffa69c20
a6ff3c01
a6ff3c01
ffa69c20
a6ff3c01
ffa69c20
-
{c=>1,a=>61,b=>0,d=>2}
3d000802
3d000802
3d000802
003d0440
3d000802
3d000802
003d0440
3d000802
003d0440
-
{c=>1,a=>36,b=>7,d=>2}
24000f02
24000f02
24000f02
0024e440
24000f02
24000f02
0024e440
24000f02
0024e440
-
{c=>4,a=>-76,b=>5,d=>0}
b4ff2500
b4ff2500
b4ff2500
ffb4b000
b4ff2500
b4ff2500
ffb4b000
b4ff2500
ffb4b000
=
struct uch_wrap {
  short a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
};
-
{e=>4,c=>2,a=>-103,b=>0,d=>3}
99ff1023
99ff1023
99ff1023
ff990870
99ff1023
99ff1023
ff990870
99ff1023
ff990870
-
{e=>2,c=>0,a=>17,b=>5,d=>5}
11000515
11000515
11000515
0011a0a8
11000515
11000515
0011a0a8
11000515
0011a0a8
-
{e=>5,c=>5,a=>27,b=>2,d=>1}
1b002a29
1b002a29
1b002a29
001b5434
1b002a29
1b002a29
001b5434
1b002a29
001b5434
-
{e=>1,c=>5,a=>-77,b=>3,d=>5}
b3ff2b0d
b3ff2b0d
b3ff2b0d
ffb374a4
b3ff2b0d
b3ff2b0d
ffb374a4
b3ff2b0d
ffb374a4
-
{e=>2,c=>0,a=>-112,b=>4,d=>1}
90ff0411
90ff0411
90ff0411
ff908028
90ff0411
90ff0411
ff908028
90ff0411
ff908028
=
struct uch_wrap {
  short a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
};
-
{e=>3,c=>1,a=>61,b=>4,d=>2,f=>2}
3d000c1a0200
3d000c1a0200
3d000c1a0200
003d844c4000
3d000c1a02000000
3d000c1a0200
003d844c4000
3d000c1a0200
003d844c4000
-
{e=>1,c=>7,a=>-8,b=>0,d=>6,f=>0}
f8ff380e0000
f8ff380e0000
f8ff380e0000
fff81cc40000
f8ff380e00000000
f8ff380e0000
fff81cc40000
f8ff380e0000
fff81cc40000
-
{e=>2,c=>6,a=>-96,b=>0,d=>5,f=>7}
a0ff30150700
a0ff30150700
a0ff30150700
ffa018a8e000
a0ff301507000000
a0ff30150700
ffa018a8e000
a0ff30150700
ffa018a8e000
-
{e=>3,c=>2,a=>122,b=>5,d=>0,f=>0}
7a0015180000
7a0015180000
7a0015180000
007aa80c0000
7a00151800000000
7a0015180000
007aa80c0000
7a0015180000
007aa80c0000
-
{e=>3,c=>6,a=>-122,b=>0,d=>1,f=>2}
86ff30190200
86ff30190200
86ff30190200
ff86182c4000
86ff301902000000
86ff30190200
ff86182c4000
86ff30190200
ff86182c4000
=
struct uch_wrap {
  short a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
};
-
{e=>1,c=>5,a=>-86,g=>7,b=>7,d=>7,f=>6}
aaff2f0f3e00
aaff2f0f3e00
aaff2f0f3e00
ffaaf4e4dc00
aaff2f0f3e000000
aaff2f0f3e00
ffaaf4e4dc00
aaff2f0f3e00
ffaaf4e4dc00
-
{e=>5,c=>7,a=>78,g=>2,b=>1,d=>6,f=>1}
4e00392e1100
4e00392e1100
4e00392e1100
004e3cd42800
4e00392e11000000
4e00392e1100
004e3cd42800
4e00392e1100
004e3cd42800
-
{e=>4,c=>0,a=>-57,g=>4,b=>2,d=>4,f=>1}
c7ff02242100
c7ff02242100
c7ff02242100
ffc740903000
c7ff022421000000
c7ff02242100
ffc740903000
c7ff02242100
ffc740903000
-
{e=>6,c=>6,a=>36,g=>3,b=>1,d=>5,f=>3}
240031351b00
240031351b00
240031351b00
002438b86c00
240031351b000000
240031351b00
002438b86c00
240031351b00
002438b86c00
-
{e=>5,c=>6,a=>-105,g=>2,b=>7,d=>7,f=>0}
97ff372f1000
97ff372f1000
97ff372f1000
ff97f8f40800
97ff372f10000000
97ff372f1000
ff97f8f40800
97ff372f1000
ff97f8f40800
=
struct uch_wrap {
  short a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
};
-
{e=>2,a=>103,d=>5,c=>5,h=>6,b=>3,g=>2,f=>1}
67002b151106
67002b151106
67002b151106
006774a828c0
67002b1511060000
67002b151106
006774a828c0
67002b151106
006774a828c0
-
{e=>1,a=>-88,d=>4,c=>6,h=>1,b=>5,g=>2,f=>3}
a8ff350c1301
a8ff350c1301
a8ff350c1301
ffa8b8846820
a8ff350c13010000
a8ff350c1301
ffa8b8846820
a8ff350c1301
ffa8b8846820
-
{e=>0,a=>-80,d=>3,c=>7,h=>5,b=>3,g=>5,f=>6}
b0ff3b032e05
b0ff3b032e05
b0ff3b032e05
ffb07c60d4a0
b0ff3b032e050000
b0ff3b032e05
ffb07c60d4a0
b0ff3b032e05
ffb07c60d4a0
-
{e=>5,a=>-89,d=>6,c=>6,h=>1,b=>0,g=>4,f=>1}
a7ff302e2101
a7ff302e2101
a7ff302e2101
ffa718d43020
a7ff302e21010000
a7ff302e2101
ffa718d43020
a7ff302e2101
ffa718d43020
-
{e=>4,a=>-32,d=>5,c=>2,h=>0,b=>4,g=>7,f=>7}
e0ff14253f00
e0ff14253f00
e0ff14253f00
ffe088b0fc00
e0ff14253f000000
e0ff14253f00
ffe088b0fc00
e0ff14253f00
ffe088b0fc00
=
struct uch_wrap {
  short a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
};
-
{e=>6,a=>-1,d=>6,c=>3,h=>1,b=>6,g=>2,f=>7,i=>5}
ffff1e361729
ffff1e361729
ffff1e361729
ffffccd8e834
ffff1e3617290000
ffff1e361729
ffffccd8e834
ffff1e361729
ffffccd8e834
-
{e=>1,a=>21,d=>3,c=>7,h=>0,b=>3,g=>5,f=>0,i=>1}
15003b0b2808
15003b0b2808
15003b0b2808
00157c641404
15003b0b28080000
15003b0b2808
00157c641404
15003b0b2808
00157c641404
-
{e=>4,a=>124,d=>0,c=>3,h=>5,b=>6,g=>1,f=>0,i=>7}
7c001e20083d
7c001e20083d
7c001e20083d
007ccc1004bc
7c001e20083d0000
7c001e20083d
007ccc1004bc
7c001e20083d
007ccc1004bc
-
{e=>6,a=>53,d=>6,c=>4,h=>3,b=>7,g=>3,f=>0,i=>0}
350027361803
350027361803
350027361803
0035f0d80c60
3500273618030000
350027361803
0035f0d80c60
350027361803
0035f0d80c60
-
{e=>5,a=>14,d=>0,c=>5,h=>0,b=>0,g=>0,f=>4,i=>1}
0e0028280408
0e0028280408
0e0028280408
000e14148004
0e00282804080000
0e0028280408
000e14148004
0e0028280408
000e14148004
=
struct uch_wrap {
  short a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
};
-
{e=>4,a=>-128,d=>5,j=>4,c=>0,h=>4,b=>2,g=>7,f=>5,i=>5}
80ff02253d2c0400
80ff02253d2c0400
80ff02253d2c0400
ff8040b0bc948000
80ff02253d2c0400
80ff02253d2c0400
ff8040b0bc948000
80ff02253d2c0400
ff8040b0bc948000
-
{e=>5,a=>-33,d=>3,j=>4,c=>5,h=>7,b=>7,g=>1,f=>6,i=>5}
dfff2f2b0e2f0400
dfff2f2b0e2f0400
dfff2f2b0e2f0400
ffdff474c4f48000
dfff2f2b0e2f0400
dfff2f2b0e2f0400
ffdff474c4f48000
dfff2f2b0e2f0400
ffdff474c4f48000
-
{e=>3,a=>-96,d=>1,j=>1,c=>4,h=>2,b=>3,g=>7,f=>6,i=>6}
a0ff23193e320100
a0ff23193e320100
a0ff23193e320100
ffa0702cdc582000
a0ff23193e320100
a0ff23193e320100
ffa0702cdc582000
a0ff23193e320100
ffa0702cdc582000
-
{e=>7,a=>-9,d=>6,j=>4,c=>3,h=>1,b=>3,g=>3,f=>1,i=>0}
f7ff1b3e19010400
f7ff1b3e19010400
f7ff1b3e19010400
fff76cdc2c208000
f7ff1b3e19010400
f7ff1b3e19010400
fff76cdc2c208000
f7ff1b3e19010400
fff76cdc2c208000
-
{e=>2,a=>63,d=>4,j=>2,c=>4,h=>0,b=>4,g=>3,f=>5,i=>0}
3f0024141d000200
3f0024141d000200
3f0024141d000200
003f9088ac004000
3f0024141d000200
3f0024141d000200
003f9088ac004000
3f0024141d000200
003f9088ac004000
=
struct uch_wrap {
  short a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
};
-
{e=>4,a=>57,d=>7,j=>7,c=>4,k=>0,h=>5,b=>3,g=>3,f=>4,i=>6}
390023271c350700
390023271c350700
390023271c350700
003970f08cb8e000
390023271c350700
390023271c350700
003970f08cb8e000
390023271c350700
003970f08cb8e000
-
{e=>7,a=>-11,d=>1,j=>4,c=>0,k=>5,h=>1,b=>5,g=>5,f=>7,i=>5}
f5ff05392f292c00
f5ff05392f292c00
f5ff05392f292c00
fff5a03cf4349400
f5ff05392f292c00
f5ff05392f292c00
fff5a03cf4349400
f5ff05392f292c00
fff5a03cf4349400
-
{e=>7,a=>-117,d=>2,j=>6,c=>7,k=>6,h=>1,b=>2,g=>0,f=>1,i=>1}
8bff3a3a01093600
8bff3a3a01093600
8bff3a3a01093600
ff8b5c5c2024d800
8bff3a3a01093600
8bff3a3a01093600
ff8b5c5c2024d800
8bff3a3a01093600
ff8b5c5c2024d800
-
{e=>7,a=>-118,d=>6,j=>3,c=>7,k=>4,h=>2,b=>4,g=>3,f=>6,i=>0}
8aff3c3e1e022300
8aff3c3e1e022300
8aff3c3e1e022300
ff8a9cdccc407000
8aff3c3e1e022300
8aff3c3e1e022300
ff8a9cdccc407000
8aff3c3e1e022300
ff8a9cdccc407000
-
{e=>4,a=>-15,d=>1,j=>1,c=>7,k=>6,h=>5,b=>4,g=>7,f=>3,i=>7}
f1ff3c213b3d3100
f1ff3c213b3d3100
f1ff3c213b3d3100
fff19c307cbc3800
f1ff3c213b3d3100
f1ff3c213b3d3100
fff19c307cbc3800
f1ff3c213b3d3100
fff19c307cbc3800
=
struct uch_wrap {
  short a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
};
-
{e=>5,a=>24,d=>4,j=>2,l=>6,c=>3,k=>2,h=>1,b=>5,g=>4,f=>5,i=>2}
18001d2c25111206
18001d2c25111206
18001d2c25111206
0018ac94b02848c0
18001d2c25111206
18001d2c25111206
0018ac94b02848c0
18001d2c25111206
0018ac94b02848c0
-
{e=>7,a=>-76,d=>2,j=>2,l=>5,c=>2,k=>2,h=>3,b=>5,g=>4,f=>7,i=>5}
b4ff153a272b1205
b4ff153a272b1205
b4ff153a272b1205
ffb4a85cf07448a0
b4ff153a272b1205
b4ff153a272b1205
ffb4a85cf07448a0
b4ff153a272b1205
ffb4a85cf07448a0
-
{e=>4,a=>69,d=>4,j=>6,l=>1,c=>1,k=>0,h=>0,b=>6,g=>7,f=>1,i=>3}
45000e2439180601
45000e2439180601
45000e2439180601
0045c4903c0cc020
45000e2439180601
45000e2439180601
0045c4903c0cc020
45000e2439180601
0045c4903c0cc020
-
{e=>6,a=>-5,d=>4,j=>4,l=>7,c=>6,k=>6,h=>2,b=>3,g=>6,f=>5,i=>6}
fbff333435323407
fbff333435323407
fbff333435323407
fffb7898b85898e0
fbff333435323407
fbff333435323407
fffb7898b85898e0
fbff333435323407
fffb7898b85898e0
-
{e=>1,a=>84,d=>1,j=>5,l=>6,c=>3,k=>4,h=>7,b=>2,g=>6,f=>4,i=>3}
54001a09341f2506
54001a09341f2506
54001a09341f2506
00544c2498ecb0c0
54001a09341f2506
54001a09341f2506
00544c2498ecb0c0
54001a09341f2506
00544c2498ecb0c0
=
struct uch_wrap {
  short a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
};
-
{e=>0,a=>-34,m=>7,d=>7,j=>0,l=>2,c=>3,k=>5,h=>5,b=>1,g=>0,f=>6,i=>6}
deff19070635283a
deff19070635283a
deff19070635283a
ffde2ce0c0b8145c
deff19070635283a
deff19070635283a
ffde2ce0c0b8145c
deff19070635283a
ffde2ce0c0b8145c
-
{e=>1,a=>-67,m=>0,d=>2,j=>7,l=>0,c=>2,k=>4,h=>2,b=>7,g=>3,f=>7,i=>4}
bdff170a1f222700
bdff170a1f222700
bdff170a1f222700
ffbde844ec50f000
bdff170a1f222700
bdff170a1f222700
ffbde844ec50f000
bdff170a1f222700
ffbde844ec50f000
-
{e=>5,a=>61,m=>7,d=>1,j=>3,l=>5,c=>6,k=>5,h=>3,b=>4,g=>7,f=>3,i=>7}
3d0034293b3b2b3d
3d0034293b3b2b3d
3d0034293b3b2b3d
003d98347c7c74bc
3d0034293b3b2b3d
3d0034293b3b2b3d
003d98347c7c74bc
3d0034293b3b2b3d
003d98347c7c74bc
-
{e=>5,a=>96,m=>6,d=>5,j=>4,l=>5,c=>1,k=>3,h=>1,b=>6,g=>2,f=>2,i=>3}
60000e2d12191c35
60000e2d12191c35
60000e2d12191c35
0060c4b4482c8cb8
60000e2d12191c35
60000e2d12191c35
0060c4b4482c8cb8
60000e2d12191c35
0060c4b4482c8cb8
-
{e=>3,a=>-6,m=>6,d=>3,j=>6,l=>6,c=>5,k=>2,h=>5,b=>6,g=>3,f=>5,i=>0}
faff2e1b1d051636
faff2e1b1d051636
faff2e1b1d051636
fffad46caca0c8d8
faff2e1b1d051636
faff2e1b1d051636
fffad46caca0c8d8
faff2e1b1d051636
fffad46caca0c8d8
=
struct uch_wrap {
  short a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
  unsigned char n:3;
};
-
{e=>7,n=>7,a=>-88,m=>4,d=>0,j=>4,l=>6,c=>3,k=>5,h=>2,b=>1,g=>6,f=>5,i=>7}
a8ff1938353a2c260700
a8ff1938353a2c260700
a8ff1938353a2c260700
ffa82c1cb85c94d0e000
a8ff1938353a2c2607000000
a8ff1938353a2c260700
ffa82c1cb85c94d0e000
a8ff1938353a2c260700
ffa82c1cb85c94d0e000
-
{e=>0,n=>1,a=>-51,m=>3,d=>3,j=>2,l=>4,c=>1,k=>1,h=>6,b=>6,g=>5,f=>7,i=>2}
cdff0e032f160a1c0100
cdff0e032f160a1c0100
cdff0e032f160a1c0100
ffcdc460f4c8448c2000
cdff0e032f160a1c01000000
cdff0e032f160a1c0100
ffcdc460f4c8448c2000
cdff0e032f160a1c0100
ffcdc460f4c8448c2000
-
{e=>2,n=>6,a=>20,m=>5,d=>3,j=>4,l=>6,c=>1,k=>3,h=>6,b=>5,g=>4,f=>2,i=>5}
14000d13222e1c2e0600
14000d13222e1c2e0600
14000d13222e1c2e0600
0014a46850d48cd4c000
14000d13222e1c2e06000000
14000d13222e1c2e0600
0014a46850d48cd4c000
14000d13222e1c2e0600
0014a46850d48cd4c000
-
{e=>4,n=>1,a=>-110,m=>2,d=>6,j=>4,l=>5,c=>4,k=>5,h=>0,b=>1,g=>7,f=>4,i=>6}
92ff21263c302c150100
92ff21263c302c150100
92ff21263c302c150100
ff9230d09c1894a82000
92ff21263c302c1501000000
92ff21263c302c150100
ff9230d09c1894a82000
92ff21263c302c150100
ff9230d09c1894a82000
-
{e=>0,n=>0,a=>-45,m=>2,d=>5,j=>7,l=>4,c=>5,k=>6,h=>1,b=>2,g=>6,f=>4,i=>0}
d3ff2a05340137140000
d3ff2a05340137140000
d3ff2a05340137140000
ffd354a09820f8880000
d3ff2a053401371400000000
d3ff2a05340137140000
ffd354a09820f8880000
d3ff2a05340137140000
ffd354a09820f8880000
=
struct uch_wrap {
  short a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
  unsigned char n:3;
  short         o;
};
-
{e=>0,n=>2,a=>-65,m=>5,d=>5,j=>4,l=>2,c=>5,k=>0,h=>7,b=>2,g=>6,f=>3,o=>-15,i=>2}
bfff2a053317042a0200f1ff
bfff2a053317042a0200f1ff
bfff2a053317042a0200f1ff
ffbf54a078e880544000fff1
bfff2a053317042a0200f1ff
bfff2a053317042a0200f1ff
ffbf54a078e880544000fff1
bfff2a053317042a0200f1ff
ffbf54a078e880544000fff1
-
{e=>3,n=>6,a=>15,m=>2,d=>7,j=>7,l=>4,c=>5,k=>4,h=>2,b=>0,g=>3,f=>3,o=>30,i=>1}
0f00281f1b0a271406001e00
0f00281f1b0a271406001e00
0f00281f1b0a271406001e00
000f14ec6c44f088c000001e
0f00281f1b0a271406001e00
0f00281f1b0a271406001e00
000f14ec6c44f088c000001e
0f00281f1b0a271406001e00
000f14ec6c44f088c000001e
-
{e=>5,n=>7,a=>74,m=>6,d=>0,j=>7,l=>5,c=>3,k=>4,h=>4,b=>3,g=>6,f=>2,o=>69,i=>5}
4a001b28322c273507004500
4a001b28322c273507004500
4a001b28322c273507004500
004a6c145894f0b8e0000045
4a001b28322c273507004500
4a001b28322c273507004500
004a6c145894f0b8e0000045
4a001b28322c273507004500
004a6c145894f0b8e0000045
-
{e=>1,n=>2,a=>84,m=>2,d=>3,j=>5,l=>4,c=>3,k=>6,h=>6,b=>1,g=>6,f=>7,o=>98,i=>6}
5400190b3736351402006200
5400190b3736351402006200
5400190b3736351402006200
00542c64f8d8b88840000062
5400190b3736351402006200
5400190b3736351402006200
00542c64f8d8b88840000062
5400190b3736351402006200
00542c64f8d8b88840000062
-
{e=>3,n=>6,a=>57,m=>7,d=>6,j=>0,l=>4,c=>4,k=>1,h=>1,b=>2,g=>2,f=>7,o=>-43,i=>0}
3900221e1701083c0600d5ff
3900221e1701083c0600d5ff
3900221e1701083c0600d5ff
003950cce820049cc000ffd5
3900221e1701083c0600d5ff
3900221e1701083c0600d5ff
003950cce820049cc000ffd5
3900221e1701083c0600d5ff
003950cce820049cc000ffd5
=
struct uch_wrap {
  int a;
  unsigned char b:3;
};
-
{a=>-6,b=>4}
faffffff04000000
faffffff04000000
faffffff04000000
fffffffa80000000
faffffff04000000
faffffff04000000
fffffffa80000000
faffffff04000000
fffffffa80000000
-
{a=>48,b=>4}
3000000004000000
3000000004000000
3000000004000000
0000003080000000
3000000004000000
3000000004000000
0000003080000000
3000000004000000
0000003080000000
-
{a=>24,b=>4}
1800000004000000
1800000004000000
1800000004000000
0000001880000000
1800000004000000
1800000004000000
0000001880000000
1800000004000000
0000001880000000
-
{a=>-13,b=>5}
f3ffffff05000000
f3ffffff05000000
f3ffffff05000000
fffffff3a0000000
f3ffffff05000000
f3ffffff05000000
fffffff3a0000000
f3ffffff05000000
fffffff3a0000000
-
{a=>-58,b=>1}
c6ffffff01000000
c6ffffff01000000
c6ffffff01000000
ffffffc620000000
c6ffffff01000000
c6ffffff01000000
ffffffc620000000
c6ffffff01000000
ffffffc620000000
=
struct uch_wrap {
  int a;
  unsigned char b:3;
  unsigned char c:3;
};
-
{c=>3,a=>52,b=>2}
340000001a000000
340000001a000000
340000001a000000
000000344c000000
340000001a000000
340000001a000000
000000344c000000
340000001a000000
000000344c000000
-
{c=>6,a=>-113,b=>2}
8fffffff32000000
8fffffff32000000
8fffffff32000000
ffffff8f58000000
8fffffff32000000
8fffffff32000000
ffffff8f58000000
8fffffff32000000
ffffff8f58000000
-
{c=>7,a=>-72,b=>6}
b8ffffff3e000000
b8ffffff3e000000
b8ffffff3e000000
ffffffb8dc000000
b8ffffff3e000000
b8ffffff3e000000
ffffffb8dc000000
b8ffffff3e000000
ffffffb8dc000000
-
{c=>4,a=>93,b=>7}
5d00000027000000
5d00000027000000
5d00000027000000
0000005df0000000
5d00000027000000
5d00000027000000
0000005df0000000
5d00000027000000
0000005df0000000
-
{c=>5,a=>34,b=>5}
220000002d000000
220000002d000000
220000002d000000
00000022b4000000
220000002d000000
220000002d000000
00000022b4000000
220000002d000000
00000022b4000000
=
struct uch_wrap {
  int a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
};
-
{c=>4,a=>1,b=>6,d=>5}
0100000026050000
0100000026050000
0100000026050000
00000001d0a00000
0100000026050000
0100000026050000
00000001d0a00000
0100000026050000
00000001d0a00000
-
{c=>1,a=>35,b=>0,d=>6}
2300000008060000
2300000008060000
2300000008060000
0000002304c00000
2300000008060000
2300000008060000
0000002304c00000
2300000008060000
0000002304c00000
-
{c=>3,a=>81,b=>1,d=>7}
5100000019070000
5100000019070000
5100000019070000
000000512ce00000
5100000019070000
5100000019070000
000000512ce00000
5100000019070000
000000512ce00000
-
{c=>5,a=>19,b=>3,d=>2}
130000002b020000
130000002b020000
130000002b020000
0000001374400000
130000002b020000
130000002b020000
0000001374400000
130000002b020000
0000001374400000
-
{c=>7,a=>-108,b=>5,d=>3}
94ffffff3d030000
94ffffff3d030000
94ffffff3d030000
ffffff94bc600000
94ffffff3d030000
94ffffff3d030000
ffffff94bc600000
94ffffff3d030000
ffffff94bc600000
=
struct uch_wrap {
  int a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
};
-
{e=>0,c=>0,a=>58,b=>1,d=>6}
3a00000001060000
3a00000001060000
3a00000001060000
0000003a20c00000
3a00000001060000
3a00000001060000
0000003a20c00000
3a00000001060000
0000003a20c00000
-
{e=>4,c=>2,a=>67,b=>4,d=>2}
4300000014220000
4300000014220000
4300000014220000
0000004388500000
4300000014220000
4300000014220000
0000004388500000
4300000014220000
0000004388500000
-
{e=>0,c=>2,a=>20,b=>7,d=>4}
1400000017040000
1400000017040000
1400000017040000
00000014e8800000
1400000017040000
1400000017040000
00000014e8800000
1400000017040000
00000014e8800000
-
{e=>7,c=>4,a=>-17,b=>5,d=>7}
efffffff253f0000
efffffff253f0000
efffffff253f0000
ffffffefb0fc0000
efffffff253f0000
efffffff253f0000
ffffffefb0fc0000
efffffff253f0000
ffffffefb0fc0000
-
{e=>7,c=>1,a=>-49,b=>4,d=>7}
cfffffff0c3f0000
cfffffff0c3f0000
cfffffff0c3f0000
ffffffcf84fc0000
cfffffff0c3f0000
cfffffff0c3f0000
ffffffcf84fc0000
cfffffff0c3f0000
ffffffcf84fc0000
=
struct uch_wrap {
  int a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
};
-
{e=>7,c=>0,a=>-9,b=>1,d=>3,f=>6}
f7ffffff013b0600
f7ffffff013b0600
f7ffffff013b0600
fffffff7207cc000
f7ffffff013b0600
f7ffffff013b0600
fffffff7207cc000
f7ffffff013b0600
fffffff7207cc000
-
{e=>2,c=>2,a=>72,b=>4,d=>6,f=>1}
4800000014160100
4800000014160100
4800000014160100
0000004888c82000
4800000014160100
4800000014160100
0000004888c82000
4800000014160100
0000004888c82000
-
{e=>7,c=>0,a=>-66,b=>1,d=>4,f=>5}
beffffff013c0500
beffffff013c0500
beffffff013c0500
ffffffbe209ca000
beffffff013c0500
beffffff013c0500
ffffffbe209ca000
beffffff013c0500
ffffffbe209ca000
-
{e=>6,c=>1,a=>121,b=>7,d=>2,f=>2}
790000000f320200
790000000f320200
790000000f320200
00000079e4584000
790000000f320200
790000000f320200
00000079e4584000
790000000f320200
00000079e4584000
-
{e=>1,c=>6,a=>-56,b=>7,d=>4,f=>3}
c8ffffff370c0300
c8ffffff370c0300
c8ffffff370c0300
ffffffc8f8846000
c8ffffff370c0300
c8ffffff370c0300
ffffffc8f8846000
c8ffffff370c0300
ffffffc8f8846000
=
struct uch_wrap {
  int a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
};
-
{e=>6,c=>3,a=>76,g=>4,b=>6,d=>4,f=>4}
4c0000001e342400
4c0000001e342400
4c0000001e342400
0000004ccc989000
4c0000001e342400
4c0000001e342400
0000004ccc989000
4c0000001e342400
0000004ccc989000
-
{e=>0,c=>4,a=>-114,g=>7,b=>4,d=>6,f=>5}
8effffff24063d00
8effffff24063d00
8effffff24063d00
ffffff8e90c0bc00
8effffff24063d00
8effffff24063d00
ffffff8e90c0bc00
8effffff24063d00
ffffff8e90c0bc00
-
{e=>4,c=>5,a=>8,g=>7,b=>4,d=>0,f=>4}
080000002c203c00
080000002c203c00
080000002c203c00
0000000894109c00
080000002c203c00
080000002c203c00
0000000894109c00
080000002c203c00
0000000894109c00
-
{e=>5,c=>3,a=>-73,g=>2,b=>6,d=>6,f=>4}
b7ffffff1e2e1400
b7ffffff1e2e1400
b7ffffff1e2e1400
ffffffb7ccd48800
b7ffffff1e2e1400
b7ffffff1e2e1400
ffffffb7ccd48800
b7ffffff1e2e1400
ffffffb7ccd48800
-
{e=>7,c=>6,a=>69,g=>5,b=>2,d=>5,f=>2}
45000000323d2a00
45000000323d2a00
45000000323d2a00
0000004558bc5400
45000000323d2a00
45000000323d2a00
0000004558bc5400
45000000323d2a00
0000004558bc5400
=
struct uch_wrap {
  int a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
};
-
{e=>0,a=>21,d=>5,c=>3,h=>0,b=>7,g=>4,f=>4}
150000001f052400
150000001f052400
150000001f052400
00000015eca09000
150000001f052400
150000001f052400
00000015eca09000
150000001f052400
00000015eca09000
-
{e=>5,a=>124,d=>3,c=>5,h=>6,b=>1,g=>3,f=>6}
7c000000292b1e06
7c000000292b1e06
7c000000292b1e06
0000007c3474ccc0
7c000000292b1e06
7c000000292b1e06
0000007c3474ccc0
7c000000292b1e06
0000007c3474ccc0
-
{e=>6,a=>1,d=>4,c=>7,h=>1,b=>2,g=>4,f=>7}
010000003a342701
010000003a342701
010000003a342701
000000015c98f020
010000003a342701
010000003a342701
000000015c98f020
010000003a342701
000000015c98f020
-
{e=>7,a=>36,d=>6,c=>0,h=>7,b=>1,g=>5,f=>2}
24000000013e2a07
24000000013e2a07
24000000013e2a07
0000002420dc54e0
24000000013e2a07
24000000013e2a07
0000002420dc54e0
24000000013e2a07
0000002420dc54e0
-
{e=>1,a=>121,d=>4,c=>4,h=>0,b=>0,g=>6,f=>5}
79000000200c3500
79000000200c3500
79000000200c3500
000000791084b800
79000000200c3500
79000000200c3500
000000791084b800
79000000200c3500
000000791084b800
=
struct uch_wrap {
  int a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
};
-
{e=>4,a=>-75,d=>3,c=>1,h=>2,b=>0,g=>4,f=>3,i=>4}
b5ffffff08232322
b5ffffff08232322
b5ffffff08232322
ffffffb504707050
b5ffffff08232322
b5ffffff08232322
ffffffb504707050
b5ffffff08232322
ffffffb504707050
-
{e=>4,a=>-82,d=>3,c=>2,h=>4,b=>5,g=>0,f=>2,i=>2}
aeffffff15230214
aeffffff15230214
aeffffff15230214
ffffffaea8704088
aeffffff15230214
aeffffff15230214
ffffffaea8704088
aeffffff15230214
ffffffaea8704088
-
{e=>0,a=>46,d=>7,c=>3,h=>6,b=>6,g=>7,f=>6,i=>5}
2e0000001e073e2e
2e0000001e073e2e
2e0000001e073e2e
0000002ecce0dcd4
2e0000001e073e2e
2e0000001e073e2e
0000002ecce0dcd4
2e0000001e073e2e
0000002ecce0dcd4
-
{e=>0,a=>4,d=>0,c=>6,h=>3,b=>5,g=>3,f=>0,i=>3}
040000003500181b
040000003500181b
040000003500181b
00000004b8000c6c
040000003500181b
040000003500181b
00000004b8000c6c
040000003500181b
00000004b8000c6c
-
{e=>0,a=>-54,d=>1,c=>7,h=>7,b=>1,g=>7,f=>6,i=>6}
caffffff39013e37
caffffff39013e37
caffffff39013e37
ffffffca3c20dcf8
caffffff39013e37
caffffff39013e37
ffffffca3c20dcf8
caffffff39013e37
ffffffca3c20dcf8
=
struct uch_wrap {
  int a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
};
-
{e=>4,a=>101,d=>4,j=>0,c=>1,h=>6,b=>4,g=>7,f=>6,i=>5}
650000000c243e2e00000000
650000000c243e2e00000000
650000000c243e2e00000000
000000658490dcd400000000
650000000c243e2e00000000
650000000c243e2e00000000
000000658490dcd400000000
650000000c243e2e00000000
000000658490dcd400000000
-
{e=>0,a=>33,d=>6,j=>1,c=>0,h=>2,b=>3,g=>0,f=>1,i=>4}
210000000306012201000000
210000000306012201000000
210000000306012201000000
0000002160c0205020000000
210000000306012201000000
210000000306012201000000
0000002160c0205020000000
210000000306012201000000
0000002160c0205020000000
-
{e=>0,a=>31,d=>4,j=>4,c=>3,h=>2,b=>7,g=>3,f=>7,i=>4}
1f0000001f041f2204000000
1f0000001f041f2204000000
1f0000001f041f2204000000
0000001fec80ec5080000000
1f0000001f041f2204000000
1f0000001f041f2204000000
0000001fec80ec5080000000
1f0000001f041f2204000000
0000001fec80ec5080000000
-
{e=>0,a=>-102,d=>5,j=>2,c=>1,h=>3,b=>1,g=>4,f=>5,i=>4}
9affffff0905252302000000
9affffff0905252302000000
9affffff0905252302000000
ffffff9a24a0b07040000000
9affffff0905252302000000
9affffff0905252302000000
ffffff9a24a0b07040000000
9affffff0905252302000000
ffffff9a24a0b07040000000
-
{e=>3,a=>117,d=>6,j=>5,c=>1,h=>3,b=>4,g=>4,f=>7,i=>4}
750000000c1e272305000000
750000000c1e272305000000
750000000c1e272305000000
0000007584ccf070a0000000
750000000c1e272305000000
750000000c1e272305000000
0000007584ccf070a0000000
750000000c1e272305000000
0000007584ccf070a0000000
=
struct uch_wrap {
  int a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
};
-
{e=>7,a=>7,d=>0,j=>2,c=>5,k=>6,h=>2,b=>2,g=>6,f=>1,i=>1}
070000002a38310a32000000
070000002a38310a32000000
070000002a38310a32000000
00000007541c384458000000
070000002a38310a32000000
070000002a38310a32000000
00000007541c384458000000
070000002a38310a32000000
00000007541c384458000000
-
{e=>0,a=>73,d=>0,j=>0,c=>6,k=>0,h=>7,b=>2,g=>4,f=>2,i=>6}
490000003200223700000000
490000003200223700000000
490000003200223700000000
00000049580050f800000000
490000003200223700000000
490000003200223700000000
00000049580050f800000000
490000003200223700000000
00000049580050f800000000
-
{e=>5,a=>-16,d=>1,j=>5,c=>2,k=>0,h=>5,b=>3,g=>5,f=>2,i=>0}
f0ffffff13292a0505000000
f0ffffff13292a0505000000
f0ffffff13292a0505000000
fffffff0683454a0a0000000
f0ffffff13292a0505000000
f0ffffff13292a0505000000
fffffff0683454a0a0000000
f0ffffff13292a0505000000
fffffff0683454a0a0000000
-
{e=>2,a=>85,d=>1,j=>7,c=>7,k=>5,h=>0,b=>2,g=>7,f=>4,i=>6}
550000003a113c302f000000
550000003a113c302f000000
550000003a113c302f000000
000000555c289c18f4000000
550000003a113c302f000000
550000003a113c302f000000
000000555c289c18f4000000
550000003a113c302f000000
000000555c289c18f4000000
-
{e=>1,a=>-111,d=>4,j=>1,c=>4,k=>4,h=>0,b=>1,g=>3,f=>1,i=>4}
91ffffff210c192021000000
91ffffff210c192021000000
91ffffff210c192021000000
ffffff9130842c1030000000
91ffffff210c192021000000
91ffffff210c192021000000
ffffff9130842c1030000000
91ffffff210c192021000000
ffffff9130842c1030000000
=
struct uch_wrap {
  int a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
};
-
{e=>4,a=>-94,d=>1,j=>5,l=>1,c=>6,k=>5,h=>7,b=>6,g=>1,f=>1,i=>7}
a2ffffff3621093f2d010000
a2ffffff3621093f2d010000
a2ffffff3621093f2d010000
ffffffa2d83024fcb4200000
a2ffffff3621093f2d010000
a2ffffff3621093f2d010000
ffffffa2d83024fcb4200000
a2ffffff3621093f2d010000
ffffffa2d83024fcb4200000
-
{e=>2,a=>-111,d=>5,j=>6,l=>5,c=>3,k=>0,h=>6,b=>2,g=>0,f=>1,i=>6}
91ffffff1a15013606050000
91ffffff1a15013606050000
91ffffff1a15013606050000
ffffff914ca820d8c0a00000
91ffffff1a15013606050000
91ffffff1a15013606050000
ffffff914ca820d8c0a00000
91ffffff1a15013606050000
ffffff914ca820d8c0a00000
-
{e=>6,a=>-48,d=>0,j=>4,l=>6,c=>7,k=>6,h=>2,b=>0,g=>6,f=>2,i=>3}
d0ffffff3830321a34060000
d0ffffff3830321a34060000
d0ffffff3830321a34060000
ffffffd01c18584c98c00000
d0ffffff3830321a34060000
d0ffffff3830321a34060000
ffffffd01c18584c98c00000
d0ffffff3830321a34060000
ffffffd01c18584c98c00000
-
{e=>4,a=>25,d=>5,j=>1,l=>4,c=>1,k=>1,h=>4,b=>3,g=>6,f=>7,i=>7}
190000000b25373c09040000
190000000b25373c09040000
190000000b25373c09040000
0000001964b0f89c24800000
190000000b25373c09040000
190000000b25373c09040000
0000001964b0f89c24800000
190000000b25373c09040000
0000001964b0f89c24800000
-
{e=>5,a=>-90,d=>1,j=>4,l=>1,c=>4,k=>6,h=>6,b=>6,g=>4,f=>7,i=>6}
a6ffffff2629273634010000
a6ffffff2629273634010000
a6ffffff2629273634010000
ffffffa6d034f0d898200000
a6ffffff2629273634010000
a6ffffff2629273634010000
ffffffa6d034f0d898200000
a6ffffff2629273634010000
ffffffa6d034f0d898200000
=
struct uch_wrap {
  int a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
};
-
{e=>0,a=>27,m=>0,d=>1,j=>1,l=>0,c=>1,k=>4,h=>7,b=>3,g=>3,f=>1,i=>7}
1b0000000b01193f21000000
1b0000000b01193f21000000
1b0000000b01193f21000000
0000001b64202cfc30000000
1b0000000b01193f21000000
1b0000000b01193f21000000
0000001b64202cfc30000000
1b0000000b01193f21000000
0000001b64202cfc30000000
-
{e=>4,a=>-76,m=>6,d=>7,j=>1,l=>5,c=>4,k=>7,h=>1,b=>3,g=>1,f=>4,i=>1}
b4ffffff23270c0939350000
b4ffffff23270c0939350000
b4ffffff23270c0939350000
ffffffb470f084243cb80000
b4ffffff23270c0939350000
b4ffffff23270c0939350000
ffffffb470f084243cb80000
b4ffffff23270c0939350000
ffffffb470f084243cb80000
-
{e=>2,a=>-46,m=>4,d=>7,j=>1,l=>1,c=>3,k=>7,h=>2,b=>4,g=>5,f=>0,i=>2}
d2ffffff1c17281239210000
d2ffffff1c17281239210000
d2ffffff1c17281239210000
ffffffd28ce814483c300000
d2ffffff1c17281239210000
d2ffffff1c17281239210000
ffffffd28ce814483c300000
d2ffffff1c17281239210000
ffffffd28ce814483c300000
-
{e=>2,a=>81,m=>0,d=>2,j=>0,l=>7,c=>1,k=>0,h=>1,b=>4,g=>7,f=>2,i=>6}
510000000c123a3100070000
510000000c123a3100070000
510000000c123a3100070000
0000005184485c3800e00000
510000000c123a3100070000
510000000c123a3100070000
0000005184485c3800e00000
510000000c123a3100070000
0000005184485c3800e00000
-
{e=>4,a=>-102,m=>6,d=>6,j=>4,l=>0,c=>7,k=>3,h=>1,b=>2,g=>3,f=>4,i=>6}
9affffff3a261c311c300000
9affffff3a261c311c300000
9affffff3a261c311c300000
ffffff9a5cd08c388c180000
9affffff3a261c311c300000
9affffff3a261c311c300000
ffffff9a5cd08c388c180000
9affffff3a261c311c300000
ffffff9a5cd08c388c180000
=
struct uch_wrap {
  int a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
  unsigned char n:3;
};
-
{e=>0,n=>2,a=>71,m=>2,d=>1,j=>7,l=>0,c=>5,k=>5,h=>3,b=>5,g=>5,f=>0,i=>7}
470000002d01283b2f100200
470000002d01283b2f100200
470000002d01283b2f100200
00000047b420147cf4084000
470000002d01283b2f100200
470000002d01283b2f100200
00000047b420147cf4084000
470000002d01283b2f100200
00000047b420147cf4084000
-
{e=>1,n=>0,a=>26,m=>3,d=>0,j=>5,l=>7,c=>2,k=>0,h=>0,b=>7,g=>1,f=>6,i=>4}
1a00000017080e20051f0000
1a00000017080e20051f0000
1a00000017080e20051f0000
0000001ae804c410a0ec0000
1a00000017080e20051f0000
1a00000017080e20051f0000
0000001ae804c410a0ec0000
1a00000017080e20051f0000
0000001ae804c410a0ec0000
-
{e=>2,n=>4,a=>60,m=>5,d=>5,j=>6,l=>6,c=>6,k=>2,h=>3,b=>0,g=>2,f=>4,i=>3}
3c0000003015141b162e0400
3c0000003015141b162e0400
3c0000003015141b162e0400
0000003c18a8886cc8d48000
3c0000003015141b162e0400
3c0000003015141b162e0400
0000003c18a8886cc8d48000
3c0000003015141b162e0400
0000003c18a8886cc8d48000
-
{e=>7,n=>3,a=>95,m=>4,d=>7,j=>4,l=>5,c=>2,k=>6,h=>4,b=>0,g=>3,f=>0,i=>3}
5f000000103f181c34250300
5f000000103f181c34250300
5f000000103f181c34250300
0000005f08fc0c8c98b06000
5f000000103f181c34250300
5f000000103f181c34250300
0000005f08fc0c8c98b06000
5f000000103f181c34250300
0000005f08fc0c8c98b06000
-
{e=>6,n=>2,a=>-72,m=>1,d=>7,j=>3,l=>3,c=>4,k=>4,h=>2,b=>2,g=>7,f=>7,i=>3}
b8ffffff22373f1a230b0200
b8ffffff22373f1a230b0200
b8ffffff22373f1a230b0200
ffffffb850f8fc4c70644000
b8ffffff22373f1a230b0200
b8ffffff22373f1a230b0200
ffffffb850f8fc4c70644000
b8ffffff22373f1a230b0200
ffffffb850f8fc4c70644000
=
struct uch_wrap {
  int a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
  unsigned char n:3;
  short         o;
};
-
{e=>3,n=>5,a=>-18,m=>0,d=>5,j=>5,l=>2,c=>0,k=>7,h=>6,b=>1,g=>3,f=>2,o=>-124,i=>5}
eeffffff011d1a2e3d02050084ff0000
eeffffff011d1a2e3d02050084ff0000
eeffffff011d1a2e3d02050084ff0000
ffffffee20ac4cd4bc40a000ff840000
eeffffff011d1a2e3d02050084ff0000
eeffffff011d1a2e3d02050084ff0000
ffffffee20ac4cd4bc40a000ff840000
eeffffff011d1a2e3d02050084ff0000
ffffffee20ac4cd4bc40a000ff840000
-
{e=>7,n=>6,a=>-18,m=>7,d=>6,j=>5,l=>7,c=>5,k=>6,h=>4,b=>5,g=>7,f=>5,o=>-74,i=>7}
eeffffff2d3e3d3c353f0600b6ff0000
eeffffff2d3e3d3c353f0600b6ff0000
eeffffff2d3e3d3c353f0600b6ff0000
ffffffeeb4dcbc9cb8fcc000ffb60000
eeffffff2d3e3d3c353f0600b6ff0000
eeffffff2d3e3d3c353f0600b6ff0000
ffffffeeb4dcbc9cb8fcc000ffb60000
eeffffff2d3e3d3c353f0600b6ff0000
ffffffeeb4dcbc9cb8fcc000ffb60000
-
{e=>1,n=>5,a=>121,m=>1,d=>3,j=>4,l=>5,c=>3,k=>7,h=>1,b=>0,g=>5,f=>1,o=>-94,i=>1}
79000000180b29093c0d0500a2ff0000
79000000180b29093c0d0500a2ff0000
79000000180b29093c0d0500a2ff0000
000000790c6434249ca4a000ffa20000
79000000180b29093c0d0500a2ff0000
79000000180b29093c0d0500a2ff0000
000000790c6434249ca4a000ffa20000
79000000180b29093c0d0500a2ff0000
000000790c6434249ca4a000ffa20000
-
{e=>2,n=>1,a=>-41,m=>4,d=>5,j=>7,l=>2,c=>6,k=>0,h=>4,b=>3,g=>7,f=>6,o=>-66,i=>7}
d7ffffff33153e3c07220100beff0000
d7ffffff33153e3c07220100beff0000
d7ffffff33153e3c07220100beff0000
ffffffd778a8dc9ce0502000ffbe0000
d7ffffff33153e3c07220100beff0000
d7ffffff33153e3c07220100beff0000
ffffffd778a8dc9ce0502000ffbe0000
d7ffffff33153e3c07220100beff0000
ffffffd778a8dc9ce0502000ffbe0000
-
{e=>7,n=>2,a=>39,m=>7,d=>4,j=>7,l=>6,c=>7,k=>2,h=>0,b=>7,g=>1,f=>2,o=>-125,i=>1}
270000003f3c0a08173e020083ff0000
270000003f3c0a08173e020083ff0000
270000003f3c0a08173e020083ff0000
00000027fc9c4404e8dc4000ff830000
270000003f3c0a08173e020083ff0000
270000003f3c0a08173e020083ff0000
00000027fc9c4404e8dc4000ff830000
270000003f3c0a08173e020083ff0000
00000027fc9c4404e8dc4000ff830000
=
struct uch_wrap {
  long a;
  unsigned char b:3;
};
-
{a=>-40,b=>5}
d8ffffff05000000
d8ffffffffffffff0500000000000000
d8ffffffffffffff0500000000000000
ffffffd8a0000000
d8ffffff05000000
d8ffffff05000000
ffffffffffffffd8a000000000000000
d8ffffff05000000
ffffffd8a0000000
-
{a=>-42,b=>6}
d6ffffff06000000
d6ffffffffffffff0600000000000000
d6ffffffffffffff0600000000000000
ffffffd6c0000000
d6ffffff06000000
d6ffffff06000000
ffffffffffffffd6c000000000000000
d6ffffff06000000
ffffffd6c0000000
-
{a=>-83,b=>0}
adffffff00000000
adffffffffffffff0000000000000000
adffffffffffffff0000000000000000
ffffffad00000000
adffffff00000000
adffffff00000000
ffffffffffffffad0000000000000000
adffffff00000000
ffffffad00000000
-
{a=>6,b=>4}
0600000004000000
06000000000000000400000000000000
06000000000000000400000000000000
0000000680000000
0600000004000000
0600000004000000
00000000000000068000000000000000
0600000004000000
0000000680000000
-
{a=>-27,b=>4}
e5ffffff04000000
e5ffffffffffffff0400000000000000
e5ffffffffffffff0400000000000000
ffffffe580000000
e5ffffff04000000
e5ffffff04000000
ffffffffffffffe58000000000000000
e5ffffff04000000
ffffffe580000000
=
struct uch_wrap {
  long a;
  unsigned char b:3;
  unsigned char c:3;
};
-
{c=>4,a=>56,b=>5}
3800000025000000
38000000000000002500000000000000
38000000000000002500000000000000
00000038b0000000
3800000025000000
3800000025000000
0000000000000038b000000000000000
3800000025000000
00000038b0000000
-
{c=>4,a=>-12,b=>5}
f4ffffff25000000
f4ffffffffffffff2500000000000000
f4ffffffffffffff2500000000000000
fffffff4b0000000
f4ffffff25000000
f4ffffff25000000
fffffffffffffff4b000000000000000
f4ffffff25000000
fffffff4b0000000
-
{c=>0,a=>-103,b=>3}
99ffffff03000000
99ffffffffffffff0300000000000000
99ffffffffffffff0300000000000000
ffffff9960000000
99ffffff03000000
99ffffff03000000
ffffffffffffff996000000000000000
99ffffff03000000
ffffff9960000000
-
{c=>3,a=>104,b=>6}
680000001e000000
68000000000000001e00000000000000
68000000000000001e00000000000000
00000068cc000000
680000001e000000
680000001e000000
0000000000000068cc00000000000000
680000001e000000
00000068cc000000
-
{c=>6,a=>-64,b=>6}
c0ffffff36000000
c0ffffffffffffff3600000000000000
c0ffffffffffffff3600000000000000
ffffffc0d8000000
c0ffffff36000000
c0ffffff36000000
ffffffffffffffc0d800000000000000
c0ffffff36000000
ffffffc0d8000000
=
struct uch_wrap {
  long a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
};
-
{c=>6,a=>-23,b=>3,d=>2}
e9ffffff33020000
e9ffffffffffffff3302000000000000
e9ffffffffffffff3302000000000000
ffffffe978400000
e9ffffff33020000
e9ffffff33020000
ffffffffffffffe97840000000000000
e9ffffff33020000
ffffffe978400000
-
{c=>7,a=>-55,b=>6,d=>0}
c9ffffff3e000000
c9ffffffffffffff3e00000000000000
c9ffffffffffffff3e00000000000000
ffffffc9dc000000
c9ffffff3e000000
c9ffffff3e000000
ffffffffffffffc9dc00000000000000
c9ffffff3e000000
ffffffc9dc000000
-
{c=>0,a=>84,b=>5,d=>3}
5400000005030000
54000000000000000503000000000000
54000000000000000503000000000000
00000054a0600000
5400000005030000
5400000005030000
0000000000000054a060000000000000
5400000005030000
00000054a0600000
-
{c=>7,a=>-40,b=>0,d=>5}
d8ffffff38050000
d8ffffffffffffff3805000000000000
d8ffffffffffffff3805000000000000
ffffffd81ca00000
d8ffffff38050000
d8ffffff38050000
ffffffffffffffd81ca0000000000000
d8ffffff38050000
ffffffd81ca00000
-
{c=>6,a=>-97,b=>1,d=>1}
9fffffff31010000
9fffffffffffffff3101000000000000
9fffffffffffffff3101000000000000
ffffff9f38200000
9fffffff31010000
9fffffff31010000
ffffffffffffff9f3820000000000000
9fffffff31010000
ffffff9f38200000
=
struct uch_wrap {
  long a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
};
-
{e=>5,c=>5,a=>-118,b=>4,d=>3}
8affffff2c2b0000
8affffffffffffff2c2b000000000000
8affffffffffffff2c2b000000000000
ffffff8a94740000
8affffff2c2b0000
8affffff2c2b0000
ffffffffffffff8a9474000000000000
8affffff2c2b0000
ffffff8a94740000
-
{e=>7,c=>6,a=>-96,b=>3,d=>4}
a0ffffff333c0000
a0ffffffffffffff333c000000000000
a0ffffffffffffff333c000000000000
ffffffa0789c0000
a0ffffff333c0000
a0ffffff333c0000
ffffffffffffffa0789c000000000000
a0ffffff333c0000
ffffffa0789c0000
-
{e=>0,c=>5,a=>93,b=>2,d=>3}
5d0000002a030000
5d000000000000002a03000000000000
5d000000000000002a03000000000000
0000005d54600000
5d0000002a030000
5d0000002a030000
000000000000005d5460000000000000
5d0000002a030000
0000005d54600000
-
{e=>4,c=>6,a=>60,b=>0,d=>0}
3c00000030200000
3c000000000000003020000000000000
3c000000000000003020000000000000
0000003c18100000
3c00000030200000
3c00000030200000
000000000000003c1810000000000000
3c00000030200000
0000003c18100000
-
{e=>7,c=>0,a=>-10,b=>2,d=>6}
f6ffffff023e0000
f6ffffffffffffff023e000000000000
f6ffffffffffffff023e000000000000
fffffff640dc0000
f6ffffff023e0000
f6ffffff023e0000
fffffffffffffff640dc000000000000
f6ffffff023e0000
fffffff640dc0000
=
struct uch_wrap {
  long a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
};
-
{e=>0,c=>2,a=>-92,b=>1,d=>1,f=>0}
a4ffffff11010000
a4ffffffffffffff1101000000000000
a4ffffffffffffff1101000000000000
ffffffa428200000
a4ffffff11010000
a4ffffff11010000
ffffffffffffffa42820000000000000
a4ffffff11010000
ffffffa428200000
-
{e=>3,c=>4,a=>-86,b=>4,d=>0,f=>7}
aaffffff24180700
aaffffffffffffff2418070000000000
aaffffffffffffff2418070000000000
ffffffaa900ce000
aaffffff24180700
aaffffff24180700
ffffffffffffffaa900ce00000000000
aaffffff24180700
ffffffaa900ce000
-
{e=>0,c=>5,a=>117,b=>0,d=>1,f=>3}
7500000028010300
75000000000000002801030000000000
75000000000000002801030000000000
0000007514206000
7500000028010300
7500000028010300
00000000000000751420600000000000
7500000028010300
0000007514206000
-
{e=>4,c=>6,a=>103,b=>2,d=>4,f=>0}
6700000032240000
67000000000000003224000000000000
67000000000000003224000000000000
0000006758900000
6700000032240000
6700000032240000
00000000000000675890000000000000
6700000032240000
0000006758900000
-
{e=>2,c=>4,a=>42,b=>3,d=>2,f=>5}
2a00000023120500
2a000000000000002312050000000000
2a000000000000002312050000000000
0000002a7048a000
2a00000023120500
2a00000023120500
000000000000002a7048a00000000000
2a00000023120500
0000002a7048a000
=
struct uch_wrap {
  long a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
};
-
{e=>2,c=>0,a=>-3,g=>2,b=>5,d=>4,f=>5}
fdffffff05141500
fdffffffffffffff0514150000000000
fdffffffffffffff0514150000000000
fffffffda088a800
fdffffff05141500
fdffffff05141500
fffffffffffffffda088a80000000000
fdffffff05141500
fffffffda088a800
-
{e=>5,c=>6,a=>-39,g=>0,b=>0,d=>0,f=>1}
d9ffffff30280100
d9ffffffffffffff3028010000000000
d9ffffffffffffff3028010000000000
ffffffd918142000
d9ffffff30280100
d9ffffff30280100
ffffffffffffffd91814200000000000
d9ffffff30280100
ffffffd918142000
-
{e=>4,c=>0,a=>79,g=>3,b=>3,d=>7,f=>1}
4f00000003271900
4f000000000000000327190000000000
4f000000000000000327190000000000
0000004f60f02c00
4f00000003271900
4f00000003271900
000000000000004f60f02c0000000000
4f00000003271900
0000004f60f02c00
-
{e=>1,c=>2,a=>-123,g=>2,b=>1,d=>0,f=>4}
85ffffff11081400
85ffffffffffffff1108140000000000
85ffffffffffffff1108140000000000
ffffff8528048800
85ffffff11081400
85ffffff11081400
ffffffffffffff852804880000000000
85ffffff11081400
ffffff8528048800
-
{e=>4,c=>7,a=>100,g=>2,b=>3,d=>3,f=>6}
640000003b231600
64000000000000003b23160000000000
64000000000000003b23160000000000
000000647c70c800
640000003b231600
640000003b231600
00000000000000647c70c80000000000
640000003b231600
000000647c70c800
=
struct uch_wrap {
  long a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
};
-
{e=>6,a=>-8,d=>6,c=>1,h=>6,b=>3,g=>1,f=>2}
f8ffffff0b360a06
f8ffffffffffffff0b360a0600000000
f8ffffffffffffff0b360a0600000000
fffffff864d844c0
f8ffffff0b360a06
f8ffffff0b360a06
fffffffffffffff864d844c000000000
f8ffffff0b360a06
fffffff864d844c0
-
{e=>4,a=>-75,d=>7,c=>3,h=>7,b=>3,g=>5,f=>3}
b5ffffff1b272b07
b5ffffffffffffff1b272b0700000000
b5ffffffffffffff1b272b0700000000
ffffffb56cf074e0
b5ffffff1b272b07
b5ffffff1b272b07
ffffffffffffffb56cf074e000000000
b5ffffff1b272b07
ffffffb56cf074e0
-
{e=>7,a=>-105,d=>6,c=>4,h=>5,b=>3,g=>2,f=>0}
97ffffff233e1005
97ffffffffffffff233e100500000000
97ffffffffffffff233e100500000000
ffffff9770dc08a0
97ffffff233e1005
97ffffff233e1005
ffffffffffffff9770dc08a000000000
97ffffff233e1005
ffffff9770dc08a0
-
{e=>4,a=>115,d=>1,c=>7,h=>4,b=>6,g=>0,f=>0}
730000003e210004
73000000000000003e21000400000000
73000000000000003e21000400000000
00000073dc300080
730000003e210004
730000003e210004
0000000000000073dc30008000000000
730000003e210004
00000073dc300080
-
{e=>4,a=>-9,d=>7,c=>1,h=>7,b=>7,g=>5,f=>3}
f7ffffff0f272b07
f7ffffffffffffff0f272b0700000000
f7ffffffffffffff0f272b0700000000
fffffff7e4f074e0
f7ffffff0f272b07
f7ffffff0f272b07
fffffffffffffff7e4f074e000000000
f7ffffff0f272b07
fffffff7e4f074e0
=
struct uch_wrap {
  long a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
};
-
{e=>4,a=>-19,d=>4,c=>4,h=>6,b=>5,g=>6,f=>5,i=>7}
edffffff2524353e
edffffffffffffff2524353e00000000
edffffffffffffff2524353e00000000
ffffffedb090b8dc
edffffff2524353e
edffffff2524353e
ffffffffffffffedb090b8dc00000000
edffffff2524353e
ffffffedb090b8dc
-
{e=>6,a=>-94,d=>4,c=>3,h=>2,b=>4,g=>7,f=>3,i=>1}
a2ffffff1c343b0a
a2ffffffffffffff1c343b0a00000000
a2ffffffffffffff1c343b0a00000000
ffffffa28c987c44
a2ffffff1c343b0a
a2ffffff1c343b0a
ffffffffffffffa28c987c4400000000
a2ffffff1c343b0a
ffffffa28c987c44
-
{e=>5,a=>117,d=>2,c=>3,h=>2,b=>6,g=>0,f=>7,i=>3}
750000001e2a071a
75000000000000001e2a071a00000000
75000000000000001e2a071a00000000
00000075cc54e04c
750000001e2a071a
750000001e2a071a
0000000000000075cc54e04c00000000
750000001e2a071a
00000075cc54e04c
-
{e=>7,a=>-27,d=>5,c=>4,h=>4,b=>1,g=>0,f=>5,i=>6}
e5ffffff213d0534
e5ffffffffffffff213d053400000000
e5ffffffffffffff213d053400000000
ffffffe530bca098
e5ffffff213d0534
e5ffffff213d0534
ffffffffffffffe530bca09800000000
e5ffffff213d0534
ffffffe530bca098
-
{e=>4,a=>-18,d=>4,c=>3,h=>2,b=>0,g=>4,f=>1,i=>0}
eeffffff18242102
eeffffffffffffff1824210200000000
eeffffffffffffff1824210200000000
ffffffee0c903040
eeffffff18242102
eeffffff18242102
ffffffffffffffee0c90304000000000
eeffffff18242102
ffffffee0c903040
=
struct uch_wrap {
  long a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
};
-
{e=>6,a=>-43,d=>7,j=>2,c=>3,h=>5,b=>4,g=>2,f=>2,i=>3}
d5ffffff1c37121d02000000
d5ffffffffffffff1c37121d02000000
d5ffffffffffffff1c37121d02000000
ffffffd58cf848ac40000000
d5ffffff1c37121d02000000
d5ffffff1c37121d02000000
ffffffffffffffd58cf848ac40000000
d5ffffff1c37121d02000000
ffffffd58cf848ac40000000
-
{e=>1,a=>41,d=>0,j=>6,c=>4,h=>7,b=>5,g=>5,f=>6,i=>0}
2900000025082e0706000000
290000000000000025082e0706000000
290000000000000025082e0706000000
00000029b004d4e0c0000000
2900000025082e0706000000
2900000025082e0706000000
0000000000000029b004d4e0c0000000
2900000025082e0706000000
00000029b004d4e0c0000000
-
{e=>0,a=>-53,d=>2,j=>3,c=>6,h=>4,b=>2,g=>2,f=>1,i=>3}
cbffffff3202111c03000000
cbffffffffffffff3202111c03000000
cbffffffffffffff3202111c03000000
ffffffcb5840288c60000000
cbffffff3202111c03000000
cbffffff3202111c03000000
ffffffffffffffcb5840288c60000000
cbffffff3202111c03000000
ffffffcb5840288c60000000
-
{e=>7,a=>6,d=>6,j=>3,c=>7,h=>3,b=>3,g=>4,f=>6,i=>0}
060000003b3e260303000000
06000000000000003b3e260303000000
06000000000000003b3e260303000000
000000067cdcd06060000000
060000003b3e260303000000
060000003b3e260303000000
00000000000000067cdcd06060000000
060000003b3e260303000000
000000067cdcd06060000000
-
{e=>7,a=>8,d=>4,j=>4,c=>4,h=>1,b=>2,g=>7,f=>1,i=>5}
08000000223c392904000000
0800000000000000223c392904000000
0800000000000000223c392904000000
00000008509c3c3480000000
08000000223c392904000000
08000000223c392904000000
0000000000000008509c3c3480000000
08000000223c392904000000
00000008509c3c3480000000
=
struct uch_wrap {
  long a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
};
-
{e=>2,a=>-120,d=>3,j=>3,c=>1,k=>7,h=>5,b=>6,g=>1,f=>2,i=>6}
88ffffff0e130a353b000000
88ffffffffffffff0e130a353b000000
88ffffffffffffff0e130a353b000000
ffffff88c46844b87c000000
88ffffff0e130a353b000000
88ffffff0e130a353b000000
ffffffffffffff88c46844b87c000000
88ffffff0e130a353b000000
ffffff88c46844b87c000000
-
{e=>0,a=>116,d=>7,j=>1,c=>4,k=>0,h=>3,b=>1,g=>4,f=>3,i=>1}
740000002107230b01000000
74000000000000002107230b01000000
74000000000000002107230b01000000
0000007430e0706420000000
740000002107230b01000000
740000002107230b01000000
000000000000007430e0706420000000
740000002107230b01000000
0000007430e0706420000000
-
{e=>4,a=>108,d=>2,j=>7,c=>4,k=>6,h=>2,b=>1,g=>0,f=>5,i=>0}
6c0000002122050237000000
6c000000000000002122050237000000
6c000000000000002122050237000000
0000006c3050a040f8000000
6c0000002122050237000000
6c0000002122050237000000
000000000000006c3050a040f8000000
6c0000002122050237000000
0000006c3050a040f8000000
-
{e=>3,a=>-126,d=>7,j=>0,c=>5,k=>6,h=>1,b=>0,g=>1,f=>7,i=>3}
82ffffff281f0f1930000000
82ffffffffffffff281f0f1930000000
82ffffffffffffff281f0f1930000000
ffffff8214ece42c18000000
82ffffff281f0f1930000000
82ffffff281f0f1930000000
ffffffffffffff8214ece42c18000000
82ffffff281f0f1930000000
ffffff8214ece42c18000000
-
{e=>2,a=>-78,d=>3,j=>3,c=>7,k=>4,h=>1,b=>7,g=>2,f=>1,i=>2}
b2ffffff3f13111123000000
b2ffffffffffffff3f13111123000000
b2ffffffffffffff3f13111123000000
ffffffb2fc68282870000000
b2ffffff3f13111123000000
b2ffffff3f13111123000000
ffffffffffffffb2fc68282870000000
b2ffffff3f13111123000000
ffffffb2fc68282870000000
=
struct uch_wrap {
  long a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
};
-
{e=>7,a=>14,d=>4,j=>1,l=>0,c=>6,k=>4,h=>3,b=>1,g=>2,f=>7,i=>1}
0e000000313c170b21000000
0e00000000000000313c170b21000000
0e00000000000000313c170b21000000
0000000e389ce86430000000
0e000000313c170b21000000
0e000000313c170b21000000
000000000000000e389ce86430000000
0e000000313c170b21000000
0000000e389ce86430000000
-
{e=>0,a=>121,d=>5,j=>2,l=>2,c=>3,k=>1,h=>2,b=>0,g=>4,f=>2,i=>0}
79000000180522020a020000
7900000000000000180522020a020000
7900000000000000180522020a020000
000000790ca0504044400000
79000000180522020a020000
79000000180522020a020000
00000000000000790ca0504044400000
79000000180522020a020000
000000790ca0504044400000
-
{e=>5,a=>-2,d=>5,j=>7,l=>4,c=>3,k=>0,h=>2,b=>2,g=>6,f=>3,i=>0}
feffffff1a2d330207040000
feffffffffffffff1a2d330207040000
feffffffffffffff1a2d330207040000
fffffffe4cb47840e0800000
feffffff1a2d330207040000
feffffff1a2d330207040000
fffffffffffffffe4cb47840e0800000
feffffff1a2d330207040000
fffffffe4cb47840e0800000
-
{e=>4,a=>8,d=>2,j=>4,l=>3,c=>7,k=>2,h=>6,b=>4,g=>0,f=>5,i=>2}
080000003c22051614030000
08000000000000003c22051614030000
08000000000000003c22051614030000
000000089c50a0c888600000
080000003c22051614030000
080000003c22051614030000
00000000000000089c50a0c888600000
080000003c22051614030000
000000089c50a0c888600000
-
{e=>1,a=>-123,d=>4,j=>6,l=>2,c=>4,k=>3,h=>5,b=>7,g=>1,f=>5,i=>6}
85ffffff270c0d351e020000
85ffffffffffffff270c0d351e020000
85ffffffffffffff270c0d351e020000
ffffff85f084a4b8cc400000
85ffffff270c0d351e020000
85ffffff270c0d351e020000
ffffffffffffff85f084a4b8cc400000
85ffffff270c0d351e020000
ffffff85f084a4b8cc400000
=
struct uch_wrap {
  long a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
};
-
{e=>5,a=>-111,m=>3,d=>7,j=>6,l=>5,c=>6,k=>6,h=>6,b=>0,g=>4,f=>1,i=>2}
91ffffff302f2116361d0000
91ffffffffffffff302f2116361d0000
91ffffffffffffff302f2116361d0000
ffffff9118f430c8d8ac0000
91ffffff302f2116361d0000
91ffffff302f2116361d0000
ffffffffffffff9118f430c8d8ac0000
91ffffff302f2116361d0000
ffffff9118f430c8d8ac0000
-
{e=>4,a=>-44,m=>0,d=>4,j=>5,l=>1,c=>5,k=>0,h=>2,b=>2,g=>4,f=>7,i=>6}
d4ffffff2a24273205010000
d4ffffffffffffff2a24273205010000
d4ffffffffffffff2a24273205010000
ffffffd45490f058a0200000
d4ffffff2a24273205010000
d4ffffff2a24273205010000
ffffffffffffffd45490f058a0200000
d4ffffff2a24273205010000
ffffffd45490f058a0200000
-
{e=>7,a=>-24,m=>0,d=>0,j=>3,l=>1,c=>5,k=>5,h=>1,b=>2,g=>3,f=>5,i=>4}
e8ffffff2a381d212b010000
e8ffffffffffffff2a381d212b010000
e8ffffffffffffff2a381d212b010000
ffffffe8541cac3074200000
e8ffffff2a381d212b010000
e8ffffff2a381d212b010000
ffffffffffffffe8541cac3074200000
e8ffffff2a381d212b010000
ffffffe8541cac3074200000
-
{e=>4,a=>96,m=>2,d=>0,j=>1,l=>2,c=>2,k=>4,h=>4,b=>4,g=>3,f=>7,i=>2}
6000000014201f1421120000
600000000000000014201f1421120000
600000000000000014201f1421120000
000000608810ec8830480000
6000000014201f1421120000
6000000014201f1421120000
00000000000000608810ec8830480000
6000000014201f1421120000
000000608810ec8830480000
-
{e=>2,a=>-3,m=>4,d=>0,j=>4,l=>5,c=>7,k=>3,h=>7,b=>5,g=>0,f=>1,i=>6}
fdffffff3d1001371c250000
fdffffffffffffff3d1001371c250000
fdffffffffffffff3d1001371c250000
fffffffdbc0820f88cb00000
fdffffff3d1001371c250000
fdffffff3d1001371c250000
fffffffffffffffdbc0820f88cb00000
fdffffff3d1001371c250000
fffffffdbc0820f88cb00000
=
struct uch_wrap {
  long a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
  unsigned char n:3;
};
-
{e=>5,n=>3,a=>-107,m=>1,d=>3,j=>7,l=>5,c=>0,k=>2,h=>0,b=>6,g=>2,f=>2,i=>7}
95ffffff062b1238170d0300
95ffffffffffffff062b1238170d0300
95ffffffffffffff062b1238170d0300
ffffff95c074481ce8a46000
95ffffff062b1238170d0300
95ffffff062b1238170d0300
ffffffffffffff95c074481ce8a46000
95ffffff062b1238170d0300
ffffff95c074481ce8a46000
-
{e=>7,n=>1,a=>9,m=>6,d=>1,j=>2,l=>4,c=>7,k=>6,h=>7,b=>5,g=>4,f=>4,i=>6}
090000003d39243732340100
09000000000000003d39243732340100
09000000000000003d39243732340100
00000009bc3c90f858982000
090000003d39243732340100
090000003d39243732340100
0000000000000009bc3c90f858982000
090000003d39243732340100
00000009bc3c90f858982000
-
{e=>2,n=>1,a=>-50,m=>7,d=>3,j=>1,l=>6,c=>0,k=>2,h=>7,b=>2,g=>1,f=>5,i=>6}
ceffffff02130d37113e0100
ceffffffffffffff02130d37113e0100
ceffffffffffffff02130d37113e0100
ffffffce4068a4f828dc2000
ceffffff02130d37113e0100
ceffffff02130d37113e0100
ffffffffffffffce4068a4f828dc2000
ceffffff02130d37113e0100
ffffffce4068a4f828dc2000
-
{e=>7,n=>4,a=>123,m=>1,d=>1,j=>2,l=>4,c=>4,k=>7,h=>0,b=>4,g=>6,f=>0,i=>6}
7b000000243930303a0c0400
7b00000000000000243930303a0c0400
7b00000000000000243930303a0c0400
0000007b903c18185c848000
7b000000243930303a0c0400
7b000000243930303a0c0400
000000000000007b903c18185c848000
7b000000243930303a0c0400
0000007b903c18185c848000
-
{e=>2,n=>4,a=>-2,m=>5,d=>3,j=>4,l=>4,c=>3,k=>2,h=>7,b=>4,g=>7,f=>3,i=>4}
feffffff1c133b27142c0400
feffffffffffffff1c133b27142c0400
feffffffffffffff1c133b27142c0400
fffffffe8c687cf088948000
feffffff1c133b27142c0400
feffffff1c133b27142c0400
fffffffffffffffe8c687cf088948000
feffffff1c133b27142c0400
fffffffe8c687cf088948000
=
struct uch_wrap {
  long a;
  unsigned char b:3;
  unsigned char c:3;
  unsigned char d:3;
  unsigned char e:3;
  unsigned char f:3;
  unsigned char g:3;
  unsigned char h:3;
  unsigned char i:3;
  unsigned char j:3;
  unsigned char k:3;
  unsigned char l:3;
  unsigned char m:3;
  unsigned char n:3;
  short         o;
};
-
{e=>2,n=>2,a=>66,m=>1,d=>2,j=>2,l=>3,c=>0,k=>3,h=>7,b=>2,g=>5,f=>1,o=>-57,i=>2}
42000000021229171a0b0200c7ff0000
4200000000000000021229171a0b0200c7ff000000000000
4200000000000000021229171a0b0200c7ff000000000000
00000042404834e84c644000ffc70000
42000000021229171a0b0200c7ff0000
42000000021229171a0b0200c7ff0000
0000000000000042404834e84c644000ffc7000000000000
42000000021229171a0b0200c7ff0000
00000042404834e84c644000ffc70000
-
{e=>5,n=>3,a=>-74,m=>0,d=>7,j=>6,l=>1,c=>4,k=>7,h=>6,b=>7,g=>3,f=>5,o=>39,i=>2}
b6ffffff272f1d163e01030027000000
b6ffffffffffffff272f1d163e0103002700000000000000
b6ffffffffffffff272f1d163e0103002700000000000000
ffffffb6f0f4acc8dc20600000270000
b6ffffff272f1d163e01030027000000
b6ffffff272f1d163e01030027000000
ffffffffffffffb6f0f4acc8dc2060000027000000000000
b6ffffff272f1d163e01030027000000
ffffffb6f0f4acc8dc20600000270000
-
{e=>0,n=>4,a=>-119,m=>6,d=>5,j=>3,l=>4,c=>5,k=>2,h=>2,b=>3,g=>4,f=>1,o=>-9,i=>4}
89ffffff2b05212213340400f7ff0000
89ffffffffffffff2b05212213340400f7ff000000000000
89ffffffffffffff2b05212213340400f7ff000000000000
ffffff8974a0305068988000fff70000
89ffffff2b05212213340400f7ff0000
89ffffff2b05212213340400f7ff0000
ffffffffffffff8974a0305068988000fff7000000000000
89ffffff2b05212213340400f7ff0000
ffffff8974a0305068988000fff70000
-
{e=>3,n=>6,a=>-85,m=>7,d=>1,j=>6,l=>3,c=>7,k=>4,h=>4,b=>2,g=>5,f=>0,o=>120,i=>0}
abffffff3a192804263b060078000000
abffffffffffffff3a192804263b06007800000000000000
abffffffffffffff3a192804263b06007800000000000000
ffffffab5c2c1480d07cc00000780000
abffffff3a192804263b060078000000
abffffff3a192804263b060078000000
ffffffffffffffab5c2c1480d07cc0000078000000000000
abffffff3a192804263b060078000000
ffffffab5c2c1480d07cc00000780000
-
{e=>1,n=>6,a=>5,m=>5,d=>5,j=>2,l=>1,c=>4,k=>2,h=>0,b=>7,g=>0,f=>2,o=>-21,i=>6}
05000000270d023012290600ebff0000
0500000000000000270d023012290600ebff000000000000
0500000000000000270d023012290600ebff000000000000
00000005f0a440184834c000ffeb0000
05000000270d023012290600ebff0000
05000000270d023012290600ebff0000
0000000000000005f0a440184834c000ffeb000000000000
05000000270d023012290600ebff0000
00000005f0a440184834c000ffeb0000
=
struct int_wrap {
  int a:3;
};
-
{a=>3}
03000000
03000000
03000000
60000000
03000000
03000000
60000000
03000000
60000000
-
{a=>-2}
06000000
06000000
06000000
c0000000
06000000
06000000
c0000000
06000000
c0000000
-
{a=>-2}
06000000
06000000
06000000
c0000000
06000000
06000000
c0000000
06000000
c0000000
-
{a=>2}
02000000
02000000
02000000
40000000
02000000
02000000
40000000
02000000
40000000
-
{a=>1}
01000000
01000000
01000000
20000000
01000000
01000000
20000000
01000000
20000000
=
struct int_wrap {
  int a:3;
  int b:3;
};
-
{a=>-4,b=>-1}
3c000000
3c000000
3c000000
9c000000
3c000000
3c000000
9c000000
3c000000
9c000000
-
{a=>-1,b=>-1}
3f000000
3f000000
3f000000
fc000000
3f000000
3f000000
fc000000
3f000000
fc000000
-
{a=>2,b=>3}
1a000000
1a000000
1a000000
4c000000
1a000000
1a000000
4c000000
1a000000
4c000000
-
{a=>-2,b=>-4}
26000000
26000000
26000000
d0000000
26000000
26000000
d0000000
26000000
d0000000
-
{a=>-2,b=>1}
0e000000
0e000000
0e000000
c4000000
0e000000
0e000000
c4000000
0e000000
c4000000
=
struct int_wrap {
  int a:3;
  int b:3;
  int c:3;
};
-
{c=>-2,a=>-3,b=>2}
95010000
95010000
95010000
ab000000
95010000
95010000
ab000000
95010000
ab000000
-
{c=>-3,a=>-4,b=>3}
5c010000
5c010000
5c010000
8e800000
5c010000
5c010000
8e800000
5c010000
8e800000
-
{c=>2,a=>1,b=>3}
99000000
99000000
99000000
2d000000
99000000
99000000
2d000000
99000000
2d000000
-
{c=>-4,a=>-4,b=>-1}
3c010000
3c010000
3c010000
9e000000
3c010000
3c010000
9e000000
3c010000
9e000000
-
{c=>-1,a=>-3,b=>-4}
e5010000
e5010000
e5010000
b3800000
e5010000
e5010000
b3800000
e5010000
b3800000
=
struct int_wrap {
  int a:3;
  int b:3;
  int c:3;
  int d:3;
};
-
{c=>-1,a=>0,b=>-1,d=>0}
f8010000
f8010000
f8010000
1f800000
f8010000
f8010000
1f800000
f8010000
1f800000
-
{c=>-2,a=>-2,b=>1,d=>2}
8e050000
8e050000
8e050000
c7200000
8e050000
8e050000
c7200000
8e050000
c7200000
-
{c=>-2,a=>0,b=>-4,d=>2}
a0050000
a0050000
a0050000
13200000
a0050000
a0050000
13200000
a0050000
13200000
-
{c=>-3,a=>1,b=>-4,d=>3}
61070000
61070000
61070000
32b00000
61070000
61070000
32b00000
61070000
32b00000
-
{c=>1,a=>-2,b=>2,d=>0}
56000000
56000000
56000000
c8800000
56000000
56000000
c8800000
56000000
c8800000
=
struct int_wrap {
  int a:3;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
};
-
{e=>-3,c=>-3,a=>1,b=>-4,d=>-4}
61590000
61590000
61590000
32ca0000
61590000
61590000
32ca0000
61590000
32ca0000
-
{e=>-3,c=>2,a=>0,b=>1,d=>0}
88500000
88500000
88500000
050a0000
88500000
88500000
050a0000
88500000
050a0000
-
{e=>-3,c=>3,a=>2,b=>-1,d=>0}
fa500000
fa500000
fa500000
5d8a0000
fa500000
fa500000
5d8a0000
fa500000
5d8a0000
-
{e=>1,c=>-2,a=>-2,b=>-2,d=>3}
b6170000
b6170000
b6170000
db320000
b6170000
b6170000
db320000
b6170000
db320000
-
{e=>3,c=>1,a=>-1,b=>2,d=>-2}
573c0000
573c0000
573c0000
e8e60000
573c0000
573c0000
e8e60000
573c0000
e8e60000
=
struct int_wrap {
  int a:3;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
};
-
{e=>-1,c=>-2,a=>-2,b=>2,d=>1,f=>3}
96f30100
96f30100
96f30100
cb1ec000
96f30100
96f30100
cb1ec000
96f30100
cb1ec000
-
{e=>-3,c=>-4,a=>3,b=>2,d=>1,f=>-3}
13d30200
13d30200
13d30200
6a1b4000
13d30200
13d30200
6a1b4000
13d30200
6a1b4000
-
{e=>-4,c=>0,a=>-1,b=>-4,d=>-1,f=>-2}
274e0300
274e0300
274e0300
f0798000
274e0300
274e0300
f0798000
274e0300
f0798000
-
{e=>-1,c=>-4,a=>-1,b=>1,d=>0,f=>-3}
0ff10200
0ff10200
0ff10200
e60f4000
0ff10200
0ff10200
e60f4000
0ff10200
e60f4000
-
{e=>-4,c=>-2,a=>1,b=>3,d=>2,f=>-3}
99c50200
99c50200
99c50200
2f294000
99c50200
99c50200
2f294000
99c50200
2f294000
=
struct int_wrap {
  int a:3;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
};
-
{e=>-4,c=>1,a=>-4,g=>0,b=>-2,d=>0,f=>-3}
74c00200
74c00200
74c00200
98894000
74c00200
74c00200
98894000
74c00200
98894000
-
{e=>-2,c=>0,a=>-4,g=>3,b=>-4,d=>0,f=>-3}
24e00e00
24e00e00
24e00e00
900d5800
24e00e00
24e00e00
900d5800
24e00e00
900d5800
-
{e=>0,c=>1,a=>3,g=>2,b=>-3,d=>0,f=>0}
6b000800
6b000800
6b000800
74801000
6b000800
6b000800
74801000
6b000800
74801000
-
{e=>-4,c=>-2,a=>-1,g=>3,b=>1,d=>1,f=>0}
8f430c00
8f430c00
8f430c00
e7181800
8f430c00
8f430c00
e7181800
8f430c00
e7181800
-
{e=>2,c=>-2,a=>-3,g=>0,b=>-3,d=>1,f=>-2}
ad230300
ad230300
ad230300
b7158000
ad230300
ad230300
b7158000
ad230300
b7158000
=
struct int_wrap {
  int a:3;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
};
-
{e=>-2,a=>3,d=>-1,c=>-4,h=>-2,b=>-1,g=>0,f=>-4}
3b6fc200
3b6fc200
3b6fc200
7e7d0600
3b6fc200
3b6fc200
7e7d0600
3b6fc200
7e7d0600
-
{e=>3,a=>-4,d=>1,c=>1,h=>0,b=>2,g=>-3,f=>2}
54321500
54321500
54321500
8896a800
54321500
54321500
8896a800
54321500
8896a800
-
{e=>2,a=>-2,d=>2,c=>3,h=>-3,b=>3,g=>3,f=>-4}
de24ae00
de24ae00
de24ae00
cda51d00
de24ae00
de24ae00
cda51d00
de24ae00
cda51d00
-
{e=>2,a=>-1,d=>-1,c=>1,h=>-3,b=>-4,g=>2,f=>-4}
672eaa00
672eaa00
672eaa00
f0f51500
672eaa00
672eaa00
f0f51500
672eaa00
f0f51500
-
{e=>0,a=>0,d=>0,c=>-4,h=>2,b=>3,g=>3,f=>0}
18014c00
18014c00
18014c00
0e001a00
18014c00
18014c00
0e001a00
18014c00
0e001a00
=
struct int_wrap {
  int a:3;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
};
-
{e=>-4,a=>2,d=>-2,c=>-2,h=>3,b=>-3,g=>-2,f=>-3,i=>0}
aacd7a00
aacd7a00
aacd7a00
57697300
aacd7a00
aacd7a00
57697300
aacd7a00
57697300
-
{e=>-4,a=>-1,d=>2,c=>3,h=>1,b=>-1,g=>0,f=>-1,i=>0}
ffc42300
ffc42300
ffc42300
fda9c100
ffc42300
ffc42300
fda9c100
ffc42300
fda9c100
-
{e=>2,a=>0,d=>-1,c=>2,h=>2,b=>1,g=>3,f=>-1,i=>0}
88ae4f00
88ae4f00
88ae4f00
0575da00
88ae4f00
88ae4f00
0575da00
88ae4f00
0575da00
-
{e=>-3,a=>-4,d=>2,c=>-1,h=>-3,b=>2,g=>1,f=>-3,i=>-3}
d4d5a605
d4d5a605
d4d5a605
8bab4da0
d4d5a605
d4d5a605
8bab4da0
d4d5a605
8bab4da0
-
{e=>1,a=>-1,d=>-1,c=>-1,h=>0,b=>-1,g=>-3,f=>-3,i=>2}
ff9f1602
ff9f1602
ff9f1602
fff36840
ff9f1602
ff9f1602
fff36840
ff9f1602
fff36840
=
struct int_wrap {
  int a:3;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
};
-
{e=>-3,a=>0,d=>-3,j=>-4,c=>3,h=>-1,b=>-3,g=>1,f=>1,i=>-4}
e8dae424
e8dae424
e8dae424
15da4f90
e8dae424
e8dae424
15da4f90
e8dae424
15da4f90
-
{e=>1,a=>3,d=>-3,j=>2,c=>-3,h=>3,b=>-1,g=>1,f=>-1,i=>-4}
7b9b6714
7b9b6714
7b9b6714
7ed3cb88
7b9b6714
7b9b6714
7ed3cb88
7b9b6714
7ed3cb88
-
{e=>-3,a=>-3,d=>1,j=>-4,c=>-4,h=>3,b=>-1,g=>-1,f=>-2,i=>0}
3d537f20
3d537f20
3d537f20
be1bbb10
3d537f20
3d537f20
be1bbb10
3d537f20
be1bbb10
-
{e=>2,a=>0,d=>-4,j=>1,c=>3,h=>1,b=>-2,g=>1,f=>-2,i=>2}
f028270a
f028270a
f028270a
19c58944
f028270a
f028270a
19c58944
f028270a
19c58944
-
{e=>-2,a=>1,d=>-1,j=>3,c=>-4,h=>2,b=>1,g=>0,f=>2,i=>3}
096f411b
096f411b
096f411b
267c826c
096f411b
096f411b
267c826c
096f411b
267c826c
=
struct int_wrap {
  int a:3;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
};
-
{e=>-4,a=>2,d=>-4,j=>2,c=>-3,k=>-1,h=>-1,b=>2,g=>-3,f=>-3,i=>-4}
52c9f61407000000
52c9f61407000000
52c9f61407000000
4ac96f88e0000000
52c9f61407000000
52c9f61407000000
4ac96f88e0000000
52c9f61407000000
4ac96f88e0000000
-
{e=>3,a=>2,d=>-3,j=>-3,c=>-1,k=>-3,h=>-3,b=>0,g=>-4,f=>-3,i=>0}
c2bbb22805000000
c2bbb22805000000
c2bbb22805000000
43d76514a0000000
c2bbb22805000000
c2bbb22805000000
43d76514a0000000
c2bbb22805000000
43d76514a0000000
-
{e=>-2,a=>1,d=>3,j=>-4,c=>-1,k=>3,h=>3,b=>1,g=>1,f=>2,i=>-3}
c967652503000000
c967652503000000
c967652503000000
27bc8bb060000000
c967652503000000
c967652503000000
27bc8bb060000000
c967652503000000
27bc8bb060000000
-
{e=>2,a=>3,d=>-4,j=>-4,c=>0,k=>-4,h=>-4,b=>3,g=>3,f=>-3,i=>-2}
1ba88e2604000000
1ba88e2604000000
1ba88e2604000000
6c455cd080000000
1ba88e2604000000
1ba88e2604000000
6c455cd080000000
1ba88e2604000000
6c455cd080000000
-
{e=>-1,a=>0,d=>-1,j=>-3,c=>-1,k=>2,h=>2,b=>-4,g=>-4,f=>-4,i=>-1}
e07f522f02000000
e07f522f02000000
e07f522f02000000
13ff22f440000000
e07f522f02000000
e07f522f02000000
13ff22f440000000
e07f522f02000000
13ff22f440000000
=
struct int_wrap {
  int a:3;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
};
-
{e=>-3,a=>3,d=>-2,j=>-3,l=>0,c=>-3,k=>3,h=>-3,b=>-1,g=>1,f=>-3,i=>1}
7bdda62903000000
7bdda62903000000
7bdda62903000000
7eeb4d3460000000
7bdda62903000000
7bdda62903000000
7eeb4d3460000000
7bdda62903000000
7eeb4d3460000000
-
{e=>-2,a=>-1,d=>1,j=>3,l=>-3,c=>-2,k=>-1,h=>1,b=>3,g=>2,f=>-4,i=>2}
9f632a1a2f000000
9f632a1a2f000000
9f632a1a2f000000
ef1d114cf4000000
9f632a1a2f000000
9f632a1a2f000000
ef1d114cf4000000
9f632a1a2f000000
ef1d114cf4000000
-
{e=>-3,a=>3,d=>3,j=>3,l=>3,c=>2,k=>2,h=>-2,b=>0,g=>1,f=>-3,i=>-1}
83d6c61f1a000000
83d6c61f1a000000
83d6c61f1a000000
613b4eec4c000000
83d6c61f1a000000
83d6c61f1a000000
613b4eec4c000000
83d6c61f1a000000
613b4eec4c000000
-
{e=>1,a=>2,d=>-3,j=>-4,l=>-4,c=>-4,k=>-3,h=>0,b=>-4,g=>1,f=>2,i=>3}
221b052325000000
221b052325000000
221b052325000000
52528870b0000000
221b052325000000
221b052325000000
52528870b0000000
221b052325000000
52528870b0000000
-
{e=>0,a=>-4,d=>3,j=>-1,l=>0,c=>-1,k=>-3,h=>-2,b=>-3,g=>0,f=>-3,i=>-1}
ec87c23f05000000
ec87c23f05000000
ec87c23f05000000
97b146fca0000000
ec87c23f05000000
ec87c23f05000000
97b146fca0000000
ec87c23f05000000
97b146fca0000000
=
struct int_wrap {
  int a:3;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
};
-
{e=>2,a=>3,m=>-2,d=>0,j=>-1,l=>0,c=>-3,k=>-4,h=>0,b=>1,g=>1,f=>0,i=>-1}
4b21043f84010000
4b21043f84010000
4b21043f84010000
668408fc83000000
4b21043f84010000
4b21043f84010000
668408fc83000000
4b21043f84010000
668408fc83000000
-
{e=>1,a=>-1,m=>0,d=>3,j=>2,l=>-2,c=>1,k=>1,h=>-3,b=>0,g=>3,f=>0,i=>-1}
4716ac1731000000
4716ac1731000000
4716ac1731000000
e0b21de838000000
4716ac1731000000
4716ac1731000000
e0b21de838000000
4716ac1731000000
e0b21de838000000
-
{e=>3,a=>0,m=>-3,d=>2,j=>-4,l=>-3,c=>-4,k=>-1,h=>2,b=>2,g=>2,f=>-3,i=>-2}
10b54a266f010000
10b54a266f010000
10b54a266f010000
0a2752d0f6800000
10b54a266f010000
10b54a266f010000
0a2752d0f6800000
10b54a266f010000
0a2752d0f6800000
-
{e=>3,a=>1,m=>0,d=>3,j=>0,l=>3,c=>-4,k=>-1,h=>-3,b=>-3,g=>-3,f=>1,i=>1}
29b7b4011f000000
29b7b4011f000000
29b7b4011f000000
36366d20ec000000
29b7b4011f000000
29b7b4011f000000
36366d20ec000000
29b7b4011f000000
36366d20ec000000
-
{e=>-4,a=>-3,m=>1,d=>1,j=>-4,l=>0,c=>0,k=>0,h=>-1,b=>3,g=>1,f=>2,i=>3}
1d42e52340000000
1d42e52340000000
1d42e52340000000
ac188f7000800000
1d42e52340000000
1d42e52340000000
ac188f7000800000
1d42e52340000000
ac188f7000800000
=
struct int_wrap {
  int a:3;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
  int n;
};
-
{e=>-4,n=>-50,a=>0,m=>-1,d=>-4,j=>-4,l=>3,c=>-4,k=>2,h=>2,b=>0,g=>1,f=>-1,i=>-3}
00c94725da010000ceffffff
00c94725da010000ceffffff
00c94725da010000ceffffff
0249cab04f800000ffffffce
00c94725da010000ceffffff
00c94725da010000ceffffff
0249cab04f800000ffffffce
00c94725da010000ceffffff
0249cab04f800000ffffffce
-
{e=>2,n=>59,a=>1,m=>2,d=>-1,j=>2,l=>0,c=>-3,k=>0,h=>-2,b=>-3,g=>-3,f=>0,i=>0}
692fd410800000003b000000
692fd410800000003b000000
692fd410800000003b000000
36f42e08010000000000003b
692fd410800000003b000000
692fd410800000003b000000
36f42e08010000000000003b
692fd410800000003b000000
36f42e08010000000000003b
-
{e=>3,n=>94,a=>2,m=>2,d=>-4,j=>-2,l=>-2,c=>-3,k=>-1,h=>-3,b=>-1,g=>-2,f=>2,i=>2}
7a39b932b70000005e000000
7a39b932b70000005e000000
7a39b932b70000005e000000
5ec6b558f90000000000005e
7a39b932b70000005e000000
7a39b932b70000005e000000
5ec6b558f90000000000005e
7a39b932b70000005e000000
5ec6b558f90000000000005e
-
{e=>0,n=>126,a=>3,m=>1,d=>0,j=>0,l=>2,c=>-2,k=>-1,h=>-4,b=>2,g=>-3,f=>0,i=>0}
93019400570000007e000000
93019400570000007e000000
93019400570000007e000000
6b002c00e88000000000007e
93019400570000007e000000
93019400570000007e000000
6b002c00e88000000000007e
93019400570000007e000000
6b002c00e88000000000007e
-
{e=>3,n=>50,a=>-3,m=>2,d=>2,j=>-2,l=>-3,c=>-2,k=>3,h=>-1,b=>-2,g=>2,f=>-3,i=>-1}
b5b5ea37ab00000032000000
b5b5ea37ab00000032000000
b5b5ea37ab00000032000000
bb2757f87500000000000032
b5b5ea37ab00000032000000
b5b5ea37ab00000032000000
bb2757f87500000000000032
b5b5ea37ab00000032000000
bb2757f87500000000000032
=
struct int_wrap {
  char a;
  int b:3;
};
-
{a=>-96,b=>2}
a0020000
a0020000
a0020000
a0400000
a0020000
a0020000
a0400000
a0020000
a0400000
-
{a=>-46,b=>2}
d2020000
d2020000
d2020000
d2400000
d2020000
d2020000
d2400000
d2020000
d2400000
-
{a=>-68,b=>3}
bc030000
bc030000
bc030000
bc600000
bc030000
bc030000
bc600000
bc030000
bc600000
-
{a=>0,b=>3}
00030000
00030000
00030000
00600000
00030000
00030000
00600000
00030000
00600000
-
{a=>-26,b=>-2}
e6060000
e6060000
e6060000
e6c00000
e6060000
e6060000
e6c00000
e6060000
e6c00000
=
struct int_wrap {
  char a;
  int b:3;
  int c:3;
};
-
{c=>1,a=>123,b=>0}
7b080000
7b080000
7b080000
7b040000
7b080000
7b080000
7b040000
7b080000
7b040000
-
{c=>-1,a=>-98,b=>2}
9e3a0000
9e3a0000
9e3a0000
9e5c0000
9e3a0000
9e3a0000
9e5c0000
9e3a0000
9e5c0000
-
{c=>-3,a=>75,b=>-4}
4b2c0000
4b2c0000
4b2c0000
4b940000
4b2c0000
4b2c0000
4b940000
4b2c0000
4b940000
-
{c=>-4,a=>-4,b=>-4}
fc240000
fc240000
fc240000
fc900000
fc240000
fc240000
fc900000
fc240000
fc900000
-
{c=>-1,a=>17,b=>1}
11390000
11390000
11390000
113c0000
11390000
11390000
113c0000
11390000
113c0000
=
struct int_wrap {
  char a;
  int b:3;
  int c:3;
  int d:3;
};
-
{c=>-4,a=>17,b=>-2,d=>1}
11660000
11660000
11660000
11d08000
11660000
11660000
11d08000
11660000
11d08000
-
{c=>0,a=>75,b=>0,d=>3}
4bc00000
4bc00000
4bc00000
4b018000
4bc00000
4bc00000
4b018000
4bc00000
4b018000
-
{c=>3,a=>-89,b=>1,d=>1}
a7590000
a7590000
a7590000
a72c8000
a7590000
a7590000
a72c8000
a7590000
a72c8000
-
{c=>2,a=>86,b=>2,d=>3}
56d20000
56d20000
56d20000
56498000
56d20000
56d20000
56498000
56d20000
56498000
-
{c=>-4,a=>53,b=>-1,d=>0}
35270000
35270000
35270000
35f00000
35270000
35270000
35f00000
35270000
35f00000
=
struct int_wrap {
  char a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
};
-
{e=>-4,c=>-3,a=>-104,b=>-2,d=>0}
982e0800
982e0800
982e0800
98d44000
982e0800
982e0800
98d44000
982e0800
98d44000
-
{e=>0,c=>2,a=>8,b=>2,d=>-3}
08520100
08520100
08520100
084a8000
08520100
08520100
084a8000
08520100
084a8000
-
{e=>0,c=>-2,a=>-41,b=>-2,d=>0}
d7360000
d7360000
d7360000
d7d80000
d7360000
d7360000
d7d80000
d7360000
d7d80000
-
{e=>-4,c=>-4,a=>56,b=>2,d=>-4}
38220900
38220900
38220900
38524000
38220900
38220900
38524000
38220900
38524000
-
{e=>-3,c=>3,a=>-43,b=>-2,d=>-3}
d55e0b00
d55e0b00
d55e0b00
d5ced000
d55e0b00
d55e0b00
d5ced000
d55e0b00
d5ced000
=
struct int_wrap {
  char a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
};
-
{e=>-4,c=>1,a=>119,b=>1,d=>1,f=>1}
77491800
77491800
77491800
7724c200
77491800
77491800
7724c200
77491800
7724c200
-
{e=>-1,c=>-3,a=>-91,b=>-2,d=>2,f=>-4}
a5ae4e00
a5ae4e00
a5ae4e00
a5d57800
a5ae4e00
a5ae4e00
a5d57800
a5ae4e00
a5d57800
-
{e=>0,c=>-4,a=>-43,b=>2,d=>0,f=>-1}
d5227000
d5227000
d5227000
d5500e00
d5227000
d5227000
d5500e00
d5227000
d5500e00
-
{e=>1,c=>-3,a=>121,b=>2,d=>1,f=>-3}
796a5200
796a5200
796a5200
79549a00
796a5200
796a5200
79549a00
796a5200
79549a00
-
{e=>1,c=>3,a=>12,b=>0,d=>1,f=>-2}
0c586200
0c586200
0c586200
0c0c9c00
0c586200
0c586200
0c0c9c00
0c586200
0c0c9c00
=
struct int_wrap {
  char a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
};
-
{e=>1,c=>3,a=>92,g=>2,b=>0,d=>-4,f=>-1}
5c187301
5c187301
5c187301
5c0e1e80
5c187301
5c187301
5c0e1e80
5c187301
5c0e1e80
-
{e=>-3,c=>3,a=>70,g=>-1,b=>1,d=>2,f=>1}
46999a03
46999a03
46999a03
462d53c0
46999a03
46999a03
462d53c0
46999a03
462d53c0
-
{e=>0,c=>2,a=>61,g=>-4,b=>-3,d=>-3,f=>0}
3d550102
3d550102
3d550102
3daa8100
3d550102
3d550102
3daa8100
3d550102
3daa8100
-
{e=>1,c=>1,a=>-72,g=>-3,b=>2,d=>0,f=>0}
b80a8202
b80a8202
b80a8202
b8441140
b80a8202
b80a8202
b8441140
b80a8202
b8441140
-
{e=>3,c=>2,a=>36,g=>-3,b=>-1,d=>1,f=>-1}
2457f602
2457f602
2457f602
24e8bf40
2457f602
2457f602
24e8bf40
2457f602
24e8bf40
=
struct int_wrap {
  char a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
};
-
{e=>1,a=>2,d=>2,c=>-4,h=>1,b=>1,g=>3,f=>3}
02a1b205
02a1b205
02a1b205
023116c8
02a1b205
02a1b205
023116c8
02a1b205
023116c8
-
{e=>-4,a=>-16,d=>-2,c=>2,h=>-3,b=>0,g=>-4,f=>-3}
f0905916
f0905916
f0905916
f00b4b28
f0905916
f0905916
f00b4b28
f0905916
f00b4b28
-
{e=>-3,a=>86,d=>2,c=>3,h=>-3,b=>0,g=>1,f=>-3}
5698da14
5698da14
5698da14
560d5a68
5698da14
5698da14
560d5a68
5698da14
560d5a68
-
{e=>-2,a=>-5,d=>-2,c=>1,h=>2,b=>-1,g=>-4,f=>2}
fb8f2d0a
fb8f2d0a
fb8f2d0a
fbe76510
fb8f2d0a
fb8f2d0a
fbe76510
fb8f2d0a
fbe76510
-
{e=>3,a=>-13,d=>-3,c=>-2,h=>1,b=>-3,g=>2,f=>-2}
f3756705
f3756705
f3756705
f3babc88
f3756705
f3756705
f3babc88
f3756705
f3babc88
=
struct int_wrap {
  char a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
};
-
{e=>0,a=>87,d=>-1,c=>-2,h=>-2,b=>-2,g=>1,f=>-3,i=>-3}
57f6d1b8
57f6d1b8
57f6d1b8
57db8a75
57f6d1b8
57f6d1b8
57db8a75
57f6d1b8
57db8a75
-
{e=>0,a=>28,d=>-3,c=>-3,h=>1,b=>0,g=>-1,f=>2,i=>1}
1c68a127
1c68a127
1c68a127
1c1685c9
1c68a127
1c68a127
1c1685c9
1c68a127
1c1685c9
-
{e=>3,a=>63,d=>3,c=>2,h=>-3,b=>-4,g=>-2,f=>-2,i=>2}
3fd46657
3fd46657
3fd46657
3f89bdaa
3fd46657
3fd46657
3f89bdaa
3fd46657
3f89bdaa
-
{e=>-4,a=>70,d=>3,c=>-4,h=>2,b=>-1,g=>-2,f=>3,i=>-3}
46e738ab
46e738ab
46e738ab
46f1c795
46e738ab
46e738ab
46f1c795
46e738ab
46f1c795
-
{e=>-1,a=>16,d=>-4,c=>0,h=>-1,b=>-2,g=>-2,f=>2,i=>0}
10062f1f
10062f1f
10062f1f
10c275b8
10062f1f
10062f1f
10c275b8
10062f1f
10c275b8
=
struct int_wrap {
  char a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
};
-
{e=>3,a=>-82,d=>-3,j=>-4,c=>-2,h=>0,b=>-3,g=>2,f=>3,i=>0}
ae75370104000000
ae75370104000000
ae75370104000000
aebab68080000000
ae75370104000000
ae75370104000000
aebab68080000000
ae75370104000000
aebab68080000000
-
{e=>-2,a=>-73,d=>0,j=>-3,c=>-2,h=>2,b=>-4,g=>0,f=>0,i=>0}
b7340c0805000000
b7340c0805000000
b7340c0805000000
b7986010a0000000
b7340c0805000000
b7340c0805000000
b7986010a0000000
b7340c0805000000
b7986010a0000000
-
{e=>2,a=>-108,d=>3,j=>2,c=>2,h=>3,b=>1,g=>-1,f=>-2,i=>3}
94d1e46f02000000
94d1e46f02000000
94d1e46f02000000
9429addb40000000
94d1e46f02000000
94d1e46f02000000
9429addb40000000
94d1e46f02000000
9429addb40000000
-
{e=>-1,a=>-101,d=>1,j=>2,c=>-4,h=>0,b=>2,g=>-1,f=>-3,i=>2}
9b62de4302000000
9b62de4302000000
9b62de4302000000
9b50fbc240000000
9b62de4302000000
9b62de4302000000
9b50fbc240000000
9b62de4302000000
9b50fbc240000000
-
{e=>2,a=>67,d=>-1,j=>-1,c=>-4,h=>-4,b=>1,g=>-4,f=>-1,i=>-3}
43e175b207000000
43e175b207000000
43e175b207000000
4333af25e0000000
43e175b207000000
43e175b207000000
4333af25e0000000
43e175b207000000
4333af25e0000000
=
struct int_wrap {
  char a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
};
-
{e=>-3,a=>-38,d=>-4,j=>0,c=>1,k=>3,h=>-1,b=>3,g=>-2,f=>2,i=>0}
da0b2b1f18000000
da0b2b1f18000000
da0b2b1f18000000
da6655b80c000000
da0b2b1f18000000
da0b2b1f18000000
da6655b80c000000
da0b2b1f18000000
da6655b80c000000
-
{e=>2,a=>-104,d=>-4,j=>-2,c=>2,k=>1,h=>0,b=>3,g=>1,f=>1,i=>-2}
981395c00e000000
981395c00e000000
981395c00e000000
986a2246c4000000
981395c00e000000
981395c00e000000
986a2246c4000000
981395c00e000000
986a2246c4000000
-
{e=>-1,a=>-37,d=>-1,j=>-3,c=>-4,k=>-4,h=>-1,b=>1,g=>-3,f=>-4,i=>0}
dbe1cf1e25000000
dbe1cf1e25000000
dbe1cf1e25000000
db33f978b0000000
dbe1cf1e25000000
dbe1cf1e25000000
db33f978b0000000
dbe1cf1e25000000
db33f978b0000000
-
{e=>1,a=>93,d=>3,j=>0,c=>0,k=>0,h=>-2,b=>1,g=>3,f=>2,i=>1}
5dc1a23900000000
5dc1a23900000000
5dc1a23900000000
5d2194f100000000
5dc1a23900000000
5dc1a23900000000
5d2194f100000000
5dc1a23900000000
5d2194f100000000
-
{e=>3,a=>41,d=>2,j=>-2,c=>3,k=>-1,h=>-3,b=>0,g=>-1,f=>0,i=>3}
299886773e000000
299886773e000000
299886773e000000
290d31ebdc000000
299886773e000000
299886773e000000
290d31ebdc000000
299886773e000000
290d31ebdc000000
=
struct int_wrap {
  char a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
};
-
{e=>-1,a=>104,d=>3,j=>-3,l=>1,c=>-3,k=>3,h=>-2,b=>3,g=>-4,f=>-2,i=>-1}
68eb6efa5d000000
68eb6efa5d000000
68eb6efa5d000000
6875fd37ac800000
68eb6efa5d000000
68eb6efa5d000000
6875fd37ac800000
68eb6efa5d000000
6875fd37ac800000
-
{e=>-1,a=>-32,d=>2,j=>-3,l=>3,c=>0,k=>0,h=>-2,b=>-2,g=>1,f=>0,i=>0}
e0868e18c5000000
e0868e18c5000000
e0868e18c5000000
e0c17070a1800000
e0868e18c5000000
e0868e18c5000000
e0c17070a1800000
e0868e18c5000000
e0c17070a1800000
-
{e=>0,a=>-7,d=>2,j=>3,l=>3,c=>2,k=>1,h=>-4,b=>1,g=>-3,f=>-3,i=>-2}
f991d0d2cb000000
f991d0d2cb000000
f991d0d2cb000000
f9290b6665800000
f991d0d2cb000000
f991d0d2cb000000
f9290b6665800000
f991d0d2cb000000
f9290b6665800000
-
{e=>-1,a=>78,d=>0,j=>1,l=>-2,c=>-2,k=>3,h=>1,b=>-2,g=>1,f=>1,i=>0}
4e369e0499010000
4e369e0499010000
4e369e0499010000
4ed872482f000000
4e369e0499010000
4e369e0499010000
4ed872482f000000
4e369e0499010000
4ed872482f000000
-
{e=>2,a=>-39,d=>-4,j=>-4,l=>2,c=>3,k=>-1,h=>1,b=>2,g=>-3,f=>-2,i=>0}
d91ae506bc000000
d91ae506bc000000
d91ae506bc000000
d94e2d489d000000
d91ae506bc000000
d91ae506bc000000
d94e2d489d000000
d91ae506bc000000
d94e2d489d000000
=
struct int_wrap {
  char a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
};
-
{e=>-4,a=>4,m=>-2,d=>-4,j=>2,l=>-2,c=>0,k=>1,h=>1,b=>2,g=>-3,f=>2,i=>1}
0402a9268a0d0000
0402a9268a0d0000
0402a9268a0d0000
0442454947600000
0402a9268a0d0000
0402a9268a0d0000
0442454947600000
0402a9268a0d0000
0442454947600000
-
{e=>-1,a=>-76,m=>-1,d=>1,j=>0,l=>-1,c=>-4,k=>3,h=>-1,b=>-1,g=>2,f=>0,i=>-3}
b4670ebdd80f0000
b4670ebdd80f0000
b4670ebdd80f0000
b4f0f0bd0ff00000
b4670ebdd80f0000
b4670ebdd80f0000
b4f0f0bd0ff00000
b4670ebdd80f0000
b4f0f0bd0ff00000
-
{e=>3,a=>64,m=>-2,d=>-2,j=>-1,l=>1,c=>2,k=>2,h=>2,b=>1,g=>-2,f=>3,i=>-2}
409137cb570c0000
409137cb570c0000
409137cb570c0000
402b3796e8e00000
409137cb570c0000
409137cb570c0000
402b3796e8e00000
409137cb570c0000
402b3796e8e00000
-
{e=>0,a=>13,m=>1,d=>-3,j=>0,l=>-3,c=>-4,k=>0,h=>-3,b=>0,g=>2,f=>3,i=>-1}
0d6031f540030000
0d6031f540030000
0d6031f540030000
0d1286af02900000
0d6031f540030000
0d6031f540030000
0d1286af02900000
0d6031f540030000
0d1286af02900000
-
{e=>-3,a=>-31,m=>3,d=>3,j=>-3,l=>-3,c=>-3,k=>1,h=>-3,b=>-1,g=>3,f=>0,i=>-2}
e1ef8ad54d070000
e1ef8ad54d070000
e1ef8ad54d070000
e1f5d0eea6b00000
e1ef8ad54d070000
e1ef8ad54d070000
e1f5d0eea6b00000
e1ef8ad54d070000
e1f5d0eea6b00000
=
struct int_wrap {
  char a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
  int n:3;
};
-
{e=>3,n=>0,a=>68,m=>2,d=>2,j=>-1,l=>0,c=>-1,k=>0,h=>-4,b=>-3,g=>2,f=>-2,i=>2}
44bd665107040000
44bd665107040000
44bd665107040000
44bd3ca2e0200000
44bd665107040000
44bd665107040000
44bd3ca2e0200000
44bd665107040000
44bd3ca2e0200000
-
{e=>-3,n=>-2,a=>83,m=>3,d=>-3,j=>0,l=>-4,c=>-3,k=>-3,h=>0,b=>2,g=>-4,f=>-1,i=>2}
536a7b4228670000
536a7b4228670000
536a7b4228670000
5356df02163c0000
536a7b4228670000
536a7b4228670000
5356df02163c0000
536a7b4228670000
5356df02163c0000
-
{e=>-4,n=>-1,a=>-51,m=>3,d=>-2,j=>-3,l=>-4,c=>3,k=>0,h=>2,b=>0,g=>0,f=>-3,i=>-3}
cd9859a805770000
cd9859a805770000
cd9859a805770000
cd0f4a15a23e0000
cd9859a805770000
cd9859a805770000
cd0f4a15a23e0000
cd9859a805770000
cd0f4a15a23e0000
-
{e=>-4,n=>-2,a=>53,m=>2,d=>0,j=>-4,l=>-1,c=>2,k=>-4,h=>-2,b=>0,g=>-1,f=>2,i=>1}
3510a83be4650000
3510a83be4650000
3510a83be4650000
350845f193ac0000
3510a83be4650000
3510a83be4650000
350845f193ac0000
3510a83be4650000
350845f193ac0000
-
{e=>-4,n=>-4,a=>-114,m=>-1,d=>-1,j=>0,l=>3,c=>-1,k=>3,h=>1,b=>0,g=>1,f=>-4,i=>0}
8ef8c904d84e0000
8ef8c904d84e0000
8ef8c904d84e0000
8e1fc8480df80000
8ef8c904d84e0000
8ef8c904d84e0000
8e1fc8480df80000
8ef8c904d84e0000
8e1fc8480df80000
=
struct int_wrap {
  char a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
  int n:3;
  int o;
};
-
{e=>2,n=>2,a=>81,m=>3,d=>2,j=>0,l=>1,c=>-2,k=>-1,h=>3,b=>-2,g=>-1,f=>3,o=>64,i=>2}
51b6b44f7826000040000000
51b6b44f7826000040000000
51b6b44f7826000040000000
51d927da1cb4000000000040
51b6b44f7826000040000000
51b6b44f7826000040000000
51d927da1cb4000000000040
51b6b44f7826000040000000
51d927da1cb4000000000040
-
{e=>-3,n=>0,a=>114,m=>0,d=>1,j=>-1,l=>-4,c=>1,k=>0,h=>-3,b=>3,g=>-4,f=>-3,o=>31,i=>2}
724b5a56070100001f000000
724b5a56070100001f000000
724b5a56070100001f000000
7264db2ae20000000000001f
724b5a56070100001f000000
724b5a56070100001f000000
7264db2ae20000000000001f
724b5a56070100001f000000
7264db2ae20000000000001f
-
{e=>-2,n=>2,a=>-90,m=>-1,d=>-2,j=>1,l=>2,c=>-1,k=>-2,h=>-2,b=>-3,g=>2,f=>3,o=>11,i=>-2}
a6bd3dd9b12e00000b000000
a6bd3dd9b12e00000b000000
a6bd3dd9b12e00000b000000
a6bf66b6397400000000000b
a6bd3dd9b12e00000b000000
a6bd3dd9b12e00000b000000
a6bf66b6397400000000000b
a6bd3dd9b12e00000b000000
a6bf66b6397400000000000b
-
{e=>-4,n=>1,a=>-83,m=>2,d=>0,j=>-3,l=>3,c=>-3,k=>0,h=>0,b=>0,g=>-3,f=>-3,o=>-60,i=>-1}
ad28d8e2c5140000c4ffffff
ad28d8e2c5140000c4ffffff
ad28d8e2c5140000c4ffffff
ad144b47a1a20000ffffffc4
ad28d8e2c5140000c4ffffff
ad28d8e2c5140000c4ffffff
ad144b47a1a20000ffffffc4
ad28d8e2c5140000c4ffffff
ad144b47a1a20000ffffffc4
-
{e=>3,n=>0,a=>-38,m=>-4,d=>2,j=>-3,l=>-4,c=>-2,k=>-4,h=>-3,b=>0,g=>-4,f=>-4,o=>-32,i=>-4}
dab0469625090000e0ffffff
dab0469625090000e0ffffff
dab0469625090000e0ffffff
da19392cb2400000ffffffe0
dab0469625090000e0ffffff
dab0469625090000e0ffffff
da19392cb2400000ffffffe0
dab0469625090000e0ffffff
da19392cb2400000ffffffe0
=
struct int_wrap {
  short a;
  int b:3;
};
-
{a=>69,b=>-1}
45000700
45000700
45000700
0045e000
45000700
45000700
0045e000
45000700
0045e000
-
{a=>50,b=>1}
32000100
32000100
32000100
00322000
32000100
32000100
00322000
32000100
00322000
-
{a=>40,b=>0}
28000000
28000000
28000000
00280000
28000000
28000000
00280000
28000000
00280000
-
{a=>-10,b=>-4}
f6ff0400
f6ff0400
f6ff0400
fff68000
f6ff0400
f6ff0400
fff68000
f6ff0400
fff68000
-
{a=>-64,b=>-1}
c0ff0700
c0ff0700
c0ff0700
ffc0e000
c0ff0700
c0ff0700
ffc0e000
c0ff0700
ffc0e000
=
struct int_wrap {
  short a;
  int b:3;
  int c:3;
};
-
{c=>0,a=>106,b=>-1}
6a000700
6a000700
6a000700
006ae000
6a000700
6a000700
006ae000
6a000700
006ae000
-
{c=>-3,a=>112,b=>0}
70002800
70002800
70002800
00701400
70002800
70002800
00701400
70002800
00701400
-
{c=>-1,a=>75,b=>-4}
4b003c00
4b003c00
4b003c00
004b9c00
4b003c00
4b003c00
004b9c00
4b003c00
004b9c00
-
{c=>1,a=>-46,b=>1}
d2ff0900
d2ff0900
d2ff0900
ffd22400
d2ff0900
d2ff0900
ffd22400
d2ff0900
ffd22400
-
{c=>-4,a=>22,b=>-4}
16002400
16002400
16002400
00169000
16002400
16002400
00169000
16002400
00169000
=
struct int_wrap {
  short a;
  int b:3;
  int c:3;
  int d:3;
};
-
{c=>0,a=>-84,b=>-2,d=>-1}
acffc601
acffc601
acffc601
ffacc380
acffc601
acffc601
ffacc380
acffc601
ffacc380
-
{c=>0,a=>-79,b=>2,d=>-1}
b1ffc201
b1ffc201
b1ffc201
ffb14380
b1ffc201
b1ffc201
ffb14380
b1ffc201
ffb14380
-
{c=>-2,a=>102,b=>2,d=>0}
66003200
66003200
66003200
00665800
66003200
66003200
00665800
66003200
00665800
-
{c=>-4,a=>117,b=>-3,d=>-2}
7500a501
7500a501
7500a501
0075b300
7500a501
7500a501
0075b300
7500a501
0075b300
-
{c=>-1,a=>-97,b=>-1,d=>-2}
9fffbf01
9fffbf01
9fffbf01
ff9fff00
9fffbf01
9fffbf01
ff9fff00
9fffbf01
ff9fff00
=
struct int_wrap {
  short a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
};
-
{e=>-1,c=>-2,a=>63,b=>0,d=>-4}
3f00300f
3f00300f
3f00300f
003f1a70
3f00300f
3f00300f
003f1a70
3f00300f
003f1a70
-
{e=>2,c=>-1,a=>-22,b=>-2,d=>2}
eaffbe04
eaffbe04
eaffbe04
ffeadd20
eaffbe04
eaffbe04
ffeadd20
eaffbe04
ffeadd20
-
{e=>0,c=>1,a=>-97,b=>0,d=>3}
9fffc800
9fffc800
9fffc800
ff9f0580
9fffc800
9fffc800
ff9f0580
9fffc800
ff9f0580
-
{e=>0,c=>-3,a=>-3,b=>-3,d=>3}
fdffed00
fdffed00
fdffed00
fffdb580
fdffed00
fdffed00
fffdb580
fdffed00
fffdb580
-
{e=>-2,c=>0,a=>-35,b=>-1,d=>-1}
ddffc70d
ddffc70d
ddffc70d
ffdde3e0
ddffc70d
ddffc70d
ffdde3e0
ddffc70d
ffdde3e0
=
struct int_wrap {
  short a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
};
-
{e=>-3,c=>0,a=>-77,b=>-2,d=>3,f=>3}
b3ffc63a
b3ffc63a
b3ffc63a
ffb3c1d6
b3ffc63a
b3ffc63a
ffb3c1d6
b3ffc63a
ffb3c1d6
-
{e=>-2,c=>1,a=>108,b=>2,d=>1,f=>2}
6c004a2c
6c004a2c
6c004a2c
006c44e4
6c004a2c
6c004a2c
006c44e4
6c004a2c
006c44e4
-
{e=>-3,c=>3,a=>-37,b=>-2,d=>-3,f=>2}
dbff5e2b
dbff5e2b
dbff5e2b
ffdbced4
dbff5e2b
dbff5e2b
ffdbced4
dbff5e2b
ffdbced4
-
{e=>-2,c=>3,a=>-8,b=>-3,d=>-1,f=>-1}
f8ffdd7d
f8ffdd7d
f8ffdd7d
fff8afee
f8ffdd7d
f8ffdd7d
fff8afee
f8ffdd7d
fff8afee
-
{e=>3,c=>-1,a=>-111,b=>-4,d=>-2,f=>-2}
91ffbc67
91ffbc67
91ffbc67
ff919f3c
91ffbc67
91ffbc67
ff919f3c
91ffbc67
ff919f3c
=
struct int_wrap {
  short a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
};
-
{e=>-2,c=>1,a=>81,g=>-3,b=>2,d=>-3,f=>3}
51004a3d05000000
51004a3d05000000
51004a3d05000000
005146e6a0000000
51004a3d05000000
51004a3d05000000
005146e6a0000000
51004a3d05000000
005146e6a0000000
-
{e=>1,c=>-2,a=>75,g=>-3,b=>-4,d=>-3,f=>-1}
4b00747305000000
4b00747305000000
4b00747305000000
004b9a9ea0000000
4b00747305000000
4b00747305000000
004b9a9ea0000000
4b00747305000000
004b9a9ea0000000
-
{e=>1,c=>-4,a=>54,g=>-4,b=>-1,d=>-4,f=>-4}
3600274304000000
3600274304000000
3600274304000000
0036f21880000000
3600274304000000
3600274304000000
0036f21880000000
3600274304000000
0036f21880000000
-
{e=>-1,c=>-2,a=>82,g=>3,b=>1,d=>-4,f=>-3}
5200315f03000000
5200315f03000000
5200315f03000000
00523a7a60000000
5200315f03000000
5200315f03000000
00523a7a60000000
5200315f03000000
00523a7a60000000
-
{e=>0,c=>-2,a=>-94,g=>3,b=>-1,d=>-4,f=>3}
a2ff373103000000
a2ff373103000000
a2ff373103000000
ffa2fa0660000000
a2ff373103000000
a2ff373103000000
ffa2fa0660000000
a2ff373103000000
ffa2fa0660000000
=
struct int_wrap {
  short a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
};
-
{e=>-2,a=>-123,d=>2,c=>3,h=>0,b=>2,g=>2,f=>-2}
85ff9a6c02000000
85ff9a6c02000000
85ff9a6c02000000
ff854d6c40000000
85ff9a6c02000000
85ff9a6c02000000
ff854d6c40000000
85ff9a6c02000000
ff854d6c40000000
-
{e=>-4,a=>-75,d=>-2,c=>2,h=>-3,b=>0,g=>-4,f=>0}
b5ff90092c000000
b5ff90092c000000
b5ff90092c000000
ffb50b4094000000
b5ff90092c000000
b5ff90092c000000
ffb50b4094000000
b5ff90092c000000
ffb50b4094000000
-
{e=>-1,a=>-85,d=>0,c=>-4,h=>-4,b=>1,g=>-2,f=>-4}
abff214e26000000
abff214e26000000
abff214e26000000
ffab3078d0000000
abff214e26000000
abff214e26000000
ffab3078d0000000
abff214e26000000
ffab3078d0000000
-
{e=>-4,a=>94,d=>-1,c=>-4,h=>2,b=>-2,g=>-2,f=>3}
5e00e63916000000
5e00e63916000000
5e00e63916000000
005ed3c6c8000000
5e00e63916000000
5e00e63916000000
005ed3c6c8000000
5e00e63916000000
005ed3c6c8000000
-
{e=>1,a=>26,d=>-3,c=>-3,h=>-3,b=>2,g=>-4,f=>2}
1a006a232c000000
1a006a232c000000
1a006a232c000000
001a569494000000
1a006a232c000000
1a006a232c000000
001a569494000000
1a006a232c000000
001a569494000000
=
struct int_wrap {
  short a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
};
-
{e=>-4,a=>-127,d=>1,c=>0,h=>3,b=>1,g=>-1,f=>3,i=>3}
81ff4138df000000
81ff4138df000000
81ff4138df000000
ff8120c6ed800000
81ff4138df000000
81ff4138df000000
ff8120c6ed800000
81ff4138df000000
ff8120c6ed800000
-
{e=>-2,a=>-73,d=>-3,c=>1,h=>-3,b=>-1,g=>3,f=>-3,i=>-4}
b7ff4f5d2b010000
b7ff4f5d2b010000
b7ff4f5d2b010000
ffb7e6ea76000000
b7ff4f5d2b010000
b7ff4f5d2b010000
ffb7e6ea76000000
b7ff4f5d2b010000
ffb7e6ea76000000
-
{e=>-4,a=>-22,d=>2,c=>-4,h=>3,b=>2,g=>0,f=>3,i=>-2}
eaffa23898010000
eaffa23898010000
eaffa23898010000
ffea51460f000000
eaffa23898010000
eaffa23898010000
ffea51460f000000
eaffa23898010000
ffea51460f000000
-
{e=>3,a=>-124,d=>3,c=>2,h=>3,b=>0,g=>0,f=>2,i=>2}
84ffd02698000000
84ffd02698000000
84ffd02698000000
ff8409b40d000000
84ffd02698000000
84ffd02698000000
ff8409b40d000000
84ffd02698000000
ff8409b40d000000
-
{e=>2,a=>115,d=>3,c=>1,h=>-3,b=>2,g=>3,f=>-1,i=>0}
7300ca742b000000
7300ca742b000000
7300ca742b000000
007345ae74000000
7300ca742b000000
7300ca742b000000
007345ae74000000
7300ca742b000000
007345ae74000000
=
struct int_wrap {
  short a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
};
-
{e=>-4,a=>-21,d=>-2,j=>-2,c=>-1,h=>-1,b=>-2,g=>-2,f=>-3,i=>1}
ebffbe597e0c0000
ebffbe597e0c0000
ebffbe597e0c0000
ffebdf4adce00000
ebffbe597e0c0000
ebffbe597e0c0000
ffebdf4adce00000
ebffbe597e0c0000
ffebdf4adce00000
-
{e=>-3,a=>71,d=>1,j=>-1,c=>2,h=>0,b=>-4,g=>1,f=>-4,i=>-4}
4700544a010f0000
4700544a010f0000
4700544a010f0000
004788d822700000
4700544a010f0000
4700544a010f0000
004788d822700000
4700544a010f0000
004788d822700000
-
{e=>-2,a=>-5,d=>-3,j=>3,c=>-3,h=>1,b=>-3,g=>3,f=>2,i=>-1}
fbff6d2dcb070000
fbff6d2dcb070000
fbff6d2dcb070000
fffbb6e467b00000
fbff6d2dcb070000
fbff6d2dcb070000
fffbb6e467b00000
fbff6d2dcb070000
fffbb6e467b00000
-
{e=>1,a=>-46,d=>3,j=>-2,c=>3,h=>-4,b=>-4,g=>-3,f=>-2,i=>0}
d2ffdc62250c0000
d2ffdc62250c0000
d2ffdc62250c0000
ffd28d9cb0600000
d2ffdc62250c0000
d2ffdc62250c0000
ffd28d9cb0600000
d2ffdc62250c0000
ffd28d9cb0600000
-
{e=>2,a=>-69,d=>-4,j=>0,c=>3,h=>3,b=>1,g=>2,f=>-2,i=>2}
bbff19659a000000
bbff19659a000000
bbff19659a000000
ffbb2e2c4d000000
bbff19659a000000
bbff19659a000000
ffbb2e2c4d000000
bbff19659a000000
ffbb2e2c4d000000
=
struct int_wrap {
  short a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
};
-
{e=>3,a=>-20,d=>2,j=>-2,c=>-4,k=>3,h=>-1,b=>-1,g=>-2,f=>-4,i=>-3}
ecffa7467e3d0000
ecffa7467e3d0000
ecffa7467e3d0000
ffecf138dee60000
ecffa7467e3d0000
ecffa7467e3d0000
ffecf138dee60000
ecffa7467e3d0000
ffecf138dee60000
-
{e=>-1,a=>-104,d=>2,j=>-4,c=>1,k=>-2,h=>-1,b=>1,g=>-3,f=>-4,i=>1}
98ff894e7d680000
98ff894e7d680000
98ff894e7d680000
ff982578bccc0000
98ff894e7d680000
98ff894e7d680000
ff982578bccc0000
98ff894e7d680000
ff982578bccc0000
-
{e=>3,a=>11,d=>3,j=>0,c=>2,k=>-3,h=>-3,b=>-2,g=>0,f=>-1,i=>-4}
0b00d67628510000
0b00d67628510000
0b00d67628510000
000bc9be160a0000
0b00d67628510000
0b00d67628510000
000bc9be160a0000
0b00d67628510000
000bc9be160a0000
-
{e=>-1,a=>102,d=>2,j=>-2,c=>-4,k=>-4,h=>-1,b=>0,g=>-4,f=>-2,i=>2}
6600a06ebc4c0000
6600a06ebc4c0000
6600a06ebc4c0000
0066117c9d680000
6600a06ebc4c0000
6600a06ebc4c0000
0066117c9d680000
6600a06ebc4c0000
0066117c9d680000
-
{e=>0,a=>-79,d=>-3,j=>-1,c=>0,k=>-2,h=>0,b=>3,g=>1,f=>-3,i=>-3}
b1ff4351416f0000
b1ff4351416f0000
b1ff4351416f0000
ffb1628a22fc0000
b1ff4351416f0000
b1ff4351416f0000
ffb1628a22fc0000
b1ff4351416f0000
ffb1628a22fc0000
=
struct int_wrap {
  short a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
};
-
{e=>-3,a=>-109,d=>-4,j=>-3,l=>-4,c=>-4,k=>-4,h=>-1,b=>1,g=>-1,f=>-4,i=>1}
93ff214b7f4a0200
93ff214b7f4a0200
93ff214b7f4a0200
ff933258fcd90000
93ff214b7f4a0200
93ff214b7f4a0200
ff933258fcd90000
93ff214b7f4a0200
ff933258fcd90000
-
{e=>1,a=>-37,d=>-3,j=>-2,l=>-3,c=>2,k=>-3,h=>-4,b=>3,g=>-1,f=>-4,i=>-2}
dbff5343a7dd0200
dbff5343a7dd0200
dbff5343a7dd0200
ffdb6a98f36b4000
dbff5343a7dd0200
dbff5343a7dd0200
ffdb6a98f36b4000
dbff5343a7dd0200
ffdb6a98f36b4000
-
{e=>-3,a=>-27,d=>-3,j=>-2,l=>-3,c=>1,k=>1,h=>-2,b=>-4,g=>1,f=>3,i=>-4}
e5ff4c3b319d0200
e5ff4c3b319d0200
e5ff4c3b319d0200
ffe586d63a634000
e5ff4c3b319d0200
e5ff4c3b319d0200
ffe586d63a634000
e5ff4c3b319d0200
ffe586d63a634000
-
{e=>3,a=>-69,d=>-3,j=>-3,l=>-1,c=>-3,k=>1,h=>2,b=>3,g=>2,f=>0,i=>3}
bbff6b07d29a0300
bbff6b07d29a0300
bbff6b07d29a0300
ffbb76b049d3c000
bbff6b07d29a0300
bbff6b07d29a0300
ffbb76b049d3c000
bbff6b07d29a0300
ffbb76b049d3c000
-
{e=>0,a=>-52,d=>1,j=>2,l=>1,c=>-3,k=>-4,h=>0,b=>-3,g=>3,f=>-3,i=>0}
ccff6d5003c40000
ccff6d5003c40000
ccff6d5003c40000
ffccb48a60284000
ccff6d5003c40000
ccff6d5003c40000
ffccb48a60284000
ccff6d5003c40000
ffccb48a60284000
=
struct int_wrap {
  short a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
};
-
{e=>1,a=>-21,m=>-3,d=>-4,j=>-2,l=>2,c=>-4,k=>-2,h=>-4,b=>-4,g=>2,f=>-1,i=>2}
ebff2473a26c1500
ebff2473a26c1500
ebff2473a26c1500
ffeb921e516ca800
ebff2473a26c1500
ebff2473a26c1500
ffeb921e516ca800
ebff2473a26c1500
ffeb921e516ca800
-
{e=>-1,a=>-68,m=>-2,d=>-2,j=>0,l=>1,c=>3,k=>2,h=>-3,b=>0,g=>3,f=>-3,i=>0}
bcff985f2ba01800
bcff985f2ba01800
bcff985f2ba01800
ffbc0f7a74047000
bcff985f2ba01800
bcff985f2ba01800
ffbc0f7a74047000
bcff985f2ba01800
ffbc0f7a74047000
-
{e=>-1,a=>-32,m=>-3,d=>0,j=>1,l=>2,c=>2,k=>-2,h=>0,b=>0,g=>-2,f=>-2,i=>-3}
e0ff106e46631500
e0ff106e46631500
e0ff106e46631500
ffe0087cc29ca800
e0ff106e46631500
e0ff106e46631500
ffe0087cc29ca800
e0ff106e46631500
ffe0087cc29ca800
-
{e=>1,a=>-68,m=>0,d=>1,j=>-3,l=>3,c=>-4,k=>2,h=>-4,b=>0,g=>3,f=>-1,i=>2}
bcff6072a3aa0100
bcff6072a3aa0100
bcff6072a3aa0100
ffbc109e7154c000
bcff6072a3aa0100
bcff6072a3aa0100
ffbc109e7154c000
bcff6072a3aa0100
ffbc109e7154c000
-
{e=>-4,a=>-109,m=>-4,d=>2,j=>2,l=>-1,c=>-2,k=>2,h=>-1,b=>-4,g=>-1,f=>0,i=>-2}
93ffb408bfa51300
93ffb408bfa51300
93ffb408bfa51300
ff939940ff25e000
93ffb408bfa51300
93ffb408bfa51300
ff939940ff25e000
93ffb408bfa51300
ff939940ff25e000
=
struct int_wrap {
  short a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
  int n:3;
};
-
{e=>-2,n=>-4,a=>79,m=>-3,d=>3,j=>-2,l=>2,c=>-4,k=>-1,h=>0,b=>-1,g=>-4,f=>-4,i=>-4}
4f00e74c047d9500
4f00e74c047d9500
4f00e74c047d9500
004ff1e8826eac00
4f00e74c047d9500
4f00e74c047d9500
004ff1e8826eac00
4f00e74c047d9500
004ff1e8826eac00
-
{e=>3,n=>0,a=>-114,m=>-3,d=>-1,j=>2,l=>-1,c=>0,k=>1,h=>0,b=>-1,g=>-1,f=>3,i=>0}
8effc73707941700
8effc73707941700
8effc73707941700
ff8ee3b6e023e800
8effc73707941700
8effc73707941700
ff8ee3b6e023e800
8effc73707941700
ff8ee3b6e023e800
-
{e=>1,n=>0,a=>-17,m=>-1,d=>1,j=>2,l=>-2,c=>-4,k=>3,h=>-4,b=>-3,g=>-3,f=>0,i=>0}
efff650225341f00
efff650225341f00
efff650225341f00
ffefb090b027b800
efff650225341f00
efff650225341f00
ffefb090b027b800
efff650225341f00
ffefb090b027b800
-
{e=>2,n=>2,a=>-31,m=>0,d=>-4,j=>2,l=>-1,c=>0,k=>-2,h=>-1,b=>-3,g=>-4,f=>-2,i=>-1}
e1ff0565fce54300
e1ff0565fce54300
e1ff0565fce54300
ffe1a22c9fadc200
e1ff0565fce54300
e1ff0565fce54300
ffe1a22c9fadc200
e1ff0565fce54300
ffe1a22c9fadc200
-
{e=>-4,n=>3,a=>-41,m=>1,d=>-1,j=>0,l=>-2,c=>1,k=>-1,h=>-2,b=>1,g=>0,f=>0,i=>0}
d7ffc90930706700
d7ffc90930706700
d7ffc90930706700
ffd727c0180f8b00
d7ffc90930706700
d7ffc90930706700
ffd727c0180f8b00
d7ffc90930706700
ffd727c0180f8b00
=
struct int_wrap {
  short a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
  int n:3;
  int o;
};
-
{e=>1,n=>0,a=>69,m=>-1,d=>-4,j=>1,l=>1,c=>-1,k=>-2,h=>-1,b=>-1,g=>-2,f=>-3,o=>1,i=>-1}
45003f53fee31c0001000000
45003f53fee31c0001000000
45003f53fee31c0001000000
0045fe1adf9c780000000001
45003f53fee31c0001000000
45003f53fee31c0001000000
0045fe1adf9c780000000001
45003f53fee31c0001000000
0045fe1adf9c780000000001
-
{e=>2,n=>0,a=>-113,m=>3,d=>1,j=>1,l=>-1,c=>0,k=>3,h=>2,b=>-1,g=>-1,f=>-4,o=>-65,i=>-3}
8fff474457b30f00bfffffff
8fff474457b30f00bfffffff
8fff474457b30f00bfffffff
ff8fe0a8ea97d800ffffffbf
8fff474457b30f00bfffffff
8fff474457b30f00bfffffff
ff8fe0a8ea97d800ffffffbf
8fff474457b30f00bfffffff
ff8fe0a8ea97d800ffffffbf
-
{e=>1,n=>-3,a=>-34,m=>0,d=>-1,j=>3,l=>0,c=>1,k=>3,h=>-1,b=>-1,g=>-1,f=>2,o=>-8,i=>0}
deffcf233f36a000f8ffffff
deffcf233f36a000f8ffffff
deffcf233f36a000f8ffffff
ffdee794fc360500fffffff8
deffcf233f36a000f8ffffff
deffcf233f36a000f8ffffff
ffdee794fc360500fffffff8
deffcf233f36a000f8ffffff
ffdee794fc360500fffffff8
-
{e=>3,n=>1,a=>84,m=>-2,d=>1,j=>1,l=>1,c=>2,k=>3,h=>3,b=>3,g=>-4,f=>3,o=>115,i=>-3}
540053365cb3380073000000
540053365cb3380073000000
540053365cb3380073000000
005468b68e96710000000073
540053365cb3380073000000
540053365cb3380073000000
005468b68e96710000000073
540053365cb3380073000000
005468b68e96710000000073
-
{e=>3,n=>0,a=>-51,m=>-3,d=>-3,j=>2,l=>0,c=>3,k=>2,h=>0,b=>1,g=>1,f=>3,o=>-72,i=>-3}
cdff593741251400b8ffffff
cdff593741251400b8ffffff
cdff593741251400b8ffffff
ffcd2eb622a42800ffffffb8
cdff593741251400b8ffffff
cdff593741251400b8ffffff
ffcd2eb622a42800ffffffb8
cdff593741251400b8ffffff
ffcd2eb622a42800ffffffb8
=
struct int_wrap {
  int a;
  int b:3;
};
-
{a=>-84,b=>-2}
acffffff06000000
acffffff06000000
acffffff06000000
ffffffacc0000000
acffffff06000000
acffffff06000000
ffffffacc0000000
acffffff06000000
ffffffacc0000000
-
{a=>71,b=>2}
4700000002000000
4700000002000000
4700000002000000
0000004740000000
4700000002000000
4700000002000000
0000004740000000
4700000002000000
0000004740000000
-
{a=>-81,b=>0}
afffffff00000000
afffffff00000000
afffffff00000000
ffffffaf00000000
afffffff00000000
afffffff00000000
ffffffaf00000000
afffffff00000000
ffffffaf00000000
-
{a=>-113,b=>-3}
8fffffff05000000
8fffffff05000000
8fffffff05000000
ffffff8fa0000000
8fffffff05000000
8fffffff05000000
ffffff8fa0000000
8fffffff05000000
ffffff8fa0000000
-
{a=>16,b=>-1}
1000000007000000
1000000007000000
1000000007000000
00000010e0000000
1000000007000000
1000000007000000
00000010e0000000
1000000007000000
00000010e0000000
=
struct int_wrap {
  int a;
  int b:3;
  int c:3;
};
-
{c=>-3,a=>53,b=>-4}
350000002c000000
350000002c000000
350000002c000000
0000003594000000
350000002c000000
350000002c000000
0000003594000000
350000002c000000
0000003594000000
-
{c=>-3,a=>67,b=>-4}
430000002c000000
430000002c000000
430000002c000000
0000004394000000
430000002c000000
430000002c000000
0000004394000000
430000002c000000
0000004394000000
-
{c=>1,a=>102,b=>2}
660000000a000000
660000000a000000
660000000a000000
0000006644000000
660000000a000000
660000000a000000
0000006644000000
660000000a000000
0000006644000000
-
{c=>0,a=>-10,b=>1}
f6ffffff01000000
f6ffffff01000000
f6ffffff01000000
fffffff620000000
f6ffffff01000000
f6ffffff01000000
fffffff620000000
f6ffffff01000000
fffffff620000000
-
{c=>0,a=>-76,b=>0}
b4ffffff00000000
b4ffffff00000000
b4ffffff00000000
ffffffb400000000
b4ffffff00000000
b4ffffff00000000
ffffffb400000000
b4ffffff00000000
ffffffb400000000
=
struct int_wrap {
  int a;
  int b:3;
  int c:3;
  int d:3;
};
-
{c=>-1,a=>-33,b=>-1,d=>-1}
dfffffffff010000
dfffffffff010000
dfffffffff010000
ffffffdfff800000
dfffffffff010000
dfffffffff010000
ffffffdfff800000
dfffffffff010000
ffffffdfff800000
-
{c=>-4,a=>-87,b=>2,d=>-1}
a9ffffffe2010000
a9ffffffe2010000
a9ffffffe2010000
ffffffa953800000
a9ffffffe2010000
a9ffffffe2010000
ffffffa953800000
a9ffffffe2010000
ffffffa953800000
-
{c=>3,a=>19,b=>0,d=>3}
13000000d8000000
13000000d8000000
13000000d8000000
000000130d800000
13000000d8000000
13000000d8000000
000000130d800000
13000000d8000000
000000130d800000
-
{c=>-4,a=>39,b=>0,d=>-1}
27000000e0010000
27000000e0010000
27000000e0010000
0000002713800000
27000000e0010000
27000000e0010000
0000002713800000
27000000e0010000
0000002713800000
-
{c=>0,a=>-2,b=>3,d=>-4}
feffffff03010000
feffffff03010000
feffffff03010000
fffffffe62000000
feffffff03010000
feffffff03010000
fffffffe62000000
feffffff03010000
fffffffe62000000
=
struct int_wrap {
  int a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
};
-
{e=>1,c=>2,a=>-32,b=>1,d=>-2}
e0ffffff91030000
e0ffffff91030000
e0ffffff91030000
ffffffe02b100000
e0ffffff91030000
e0ffffff91030000
ffffffe02b100000
e0ffffff91030000
ffffffe02b100000
-
{e=>-4,c=>0,a=>12,b=>0,d=>2}
0c00000080080000
0c00000080080000
0c00000080080000
0000000c01400000
0c00000080080000
0c00000080080000
0000000c01400000
0c00000080080000
0000000c01400000
-
{e=>-2,c=>1,a=>74,b=>0,d=>0}
4a000000080c0000
4a000000080c0000
4a000000080c0000
0000004a04600000
4a000000080c0000
4a000000080c0000
0000004a04600000
4a000000080c0000
0000004a04600000
-
{e=>-3,c=>3,a=>-43,b=>-1,d=>-1}
d5ffffffdf0b0000
d5ffffffdf0b0000
d5ffffffdf0b0000
ffffffd5efd00000
d5ffffffdf0b0000
d5ffffffdf0b0000
ffffffd5efd00000
d5ffffffdf0b0000
ffffffd5efd00000
-
{e=>3,c=>3,a=>67,b=>1,d=>-1}
43000000d9070000
43000000d9070000
43000000d9070000
000000432fb00000
43000000d9070000
43000000d9070000
000000432fb00000
43000000d9070000
000000432fb00000
=
struct int_wrap {
  int a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
};
-
{e=>0,c=>3,a=>-63,b=>2,d=>0,f=>1}
c1ffffff1a100000
c1ffffff1a100000
c1ffffff1a100000
ffffffc14c020000
c1ffffff1a100000
c1ffffff1a100000
ffffffc14c020000
c1ffffff1a100000
ffffffc14c020000
-
{e=>3,c=>3,a=>-76,b=>-1,d=>-4,f=>3}
b4ffffff1f370000
b4ffffff1f370000
b4ffffff1f370000
ffffffb4ee360000
b4ffffff1f370000
b4ffffff1f370000
ffffffb4ee360000
b4ffffff1f370000
ffffffb4ee360000
-
{e=>-1,c=>0,a=>45,b=>3,d=>3,f=>0}
2d000000c30e0000
2d000000c30e0000
2d000000c30e0000
0000002d61f00000
2d000000c30e0000
2d000000c30e0000
0000002d61f00000
2d000000c30e0000
0000002d61f00000
-
{e=>1,c=>2,a=>117,b=>-1,d=>-3,f=>-2}
7500000057630000
7500000057630000
7500000057630000
00000075ea9c0000
7500000057630000
7500000057630000
00000075ea9c0000
7500000057630000
00000075ea9c0000
-
{e=>-3,c=>-1,a=>75,b=>-4,d=>3,f=>3}
4b000000fc3a0000
4b000000fc3a0000
4b000000fc3a0000
0000004b9dd60000
4b000000fc3a0000
4b000000fc3a0000
0000004b9dd60000
4b000000fc3a0000
0000004b9dd60000
=
struct int_wrap {
  int a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
};
-
{e=>2,c=>0,a=>94,g=>-4,b=>2,d=>2,f=>2}
5e00000082240200
5e00000082240200
5e00000082240200
0000005e41250000
5e00000082240200
5e00000082240200
0000005e41250000
5e00000082240200
0000005e41250000
-
{e=>-4,c=>-3,a=>-22,g=>-3,b=>3,d=>3,f=>3}
eaffffffebb80200
eaffffffebb80200
eaffffffebb80200
ffffffea75c74000
eaffffffebb80200
eaffffffebb80200
ffffffea75c74000
eaffffffebb80200
ffffffea75c74000
-
{e=>3,c=>1,a=>14,g=>0,b=>1,d=>1,f=>1}
0e00000049160000
0e00000049160000
0e00000049160000
0000000e24b20000
0e00000049160000
0e00000049160000
0000000e24b20000
0e00000049160000
0000000e24b20000
-
{e=>-3,c=>3,a=>-61,g=>-1,b=>-3,d=>-2,f=>-4}
c3ffffff9dcb0300
c3ffffff9dcb0300
c3ffffff9dcb0300
ffffffc3af59c000
c3ffffff9dcb0300
c3ffffff9dcb0300
ffffffc3af59c000
c3ffffff9dcb0300
ffffffc3af59c000
-
{e=>-1,c=>-2,a=>28,g=>2,b=>1,d=>0,f=>-3}
1c000000315e0100
1c000000315e0100
1c000000315e0100
0000001c387a8000
1c000000315e0100
1c000000315e0100
0000001c387a8000
1c000000315e0100
0000001c387a8000
=
struct int_wrap {
  int a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
};
-
{e=>1,a=>115,d=>2,c=>1,h=>0,b=>1,g=>1,f=>3}
7300000089b20000
7300000089b20000
7300000089b20000
0000007325164000
7300000089b20000
7300000089b20000
0000007325164000
7300000089b20000
0000007325164000
-
{e=>1,a=>19,d=>-2,c=>-3,h=>2,b=>-1,g=>-1,f=>-1}
13000000aff30b00
13000000aff30b00
13000000aff30b00
00000013f71fd000
13000000aff30b00
13000000aff30b00
00000013f71fd000
13000000aff30b00
00000013f71fd000
-
{e=>2,a=>-115,d=>2,c=>-4,h=>0,b=>-2,g=>-3,f=>-3}
8dffffffa6d40200
8dffffffa6d40200
8dffffffa6d40200
ffffff8dd12b4000
8dffffffa6d40200
8dffffffa6d40200
ffffff8dd12b4000
8dffffffa6d40200
ffffff8dd12b4000
-
{e=>-1,a=>126,d=>2,c=>-3,h=>2,b=>-4,g=>2,f=>2}
7e000000ac2e0900
7e000000ac2e0900
7e000000ac2e0900
0000007e95749000
7e000000ac2e0900
7e000000ac2e0900
0000007e95749000
7e000000ac2e0900
0000007e95749000
-
{e=>3,a=>123,d=>3,c=>0,h=>-4,b=>-2,g=>1,f=>-4}
7b000000c6c61000
7b000000c6c61000
7b000000c6c61000
0000007bc1b86000
7b000000c6c61000
7b000000c6c61000
0000007bc1b86000
7b000000c6c61000
0000007bc1b86000
=
struct int_wrap {
  int a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
};
-
{e=>0,a=>-116,d=>-4,c=>0,h=>-3,b=>0,g=>-4,f=>3,i=>-1}
8cffffff0031f600
8cffffff0031f600
8cffffff0031f600
ffffff8c02072f00
8cffffff0031f600
8cffffff0031f600
ffffff8c02072f00
8cffffff0031f600
ffffff8c02072f00
-
{e=>-1,a=>-120,d=>0,c=>0,h=>-2,b=>2,g=>-1,f=>1,i=>-4}
88ffffff029e9b00
88ffffff029e9b00
88ffffff029e9b00
ffffff884073f400
88ffffff029e9b00
88ffffff029e9b00
ffffff884073f400
88ffffff029e9b00
ffffff884073f400
-
{e=>0,a=>89,d=>0,c=>-3,h=>3,b=>-2,g=>0,f=>-1,i=>-4}
590000002e708c00
590000002e708c00
590000002e708c00
00000059d40e1c00
590000002e708c00
590000002e708c00
00000059d40e1c00
590000002e708c00
00000059d40e1c00
-
{e=>2,a=>107,d=>-1,c=>0,h=>-4,b=>0,g=>-2,f=>1,i=>2}
6b000000c0155300
6b000000c0155300
6b000000c0155300
0000006b03a3a200
6b000000c0155300
6b000000c0155300
0000006b03a3a200
6b000000c0155300
0000006b03a3a200
-
{e=>1,a=>126,d=>-2,c=>-1,h=>-3,b=>1,g=>3,f=>-4,i=>-2}
7e000000b9c3d500
7e000000b9c3d500
7e000000b9c3d500
0000007e3f18ee00
7e000000b9c3d500
7e000000b9c3d500
0000007e3f18ee00
7e000000b9c3d500
0000007e3f18ee00
=
struct int_wrap {
  int a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
};
-
{e=>-1,a=>-65,d=>2,j=>-4,c=>-2,h=>-4,b=>0,g=>-1,f=>-3,i=>1}
bfffffffb0de3304
bfffffffb0de3304
bfffffffb0de3304
ffffffbf197be180
bfffffffb0de3304
bfffffffb0de3304
ffffffbf197be180
bfffffffb0de3304
ffffffbf197be180
-
{e=>-4,a=>-87,d=>-1,j=>1,c=>-2,h=>1,b=>3,g=>-2,f=>0,i=>2}
a9fffffff3094701
a9fffffff3094701
a9fffffff3094701
ffffffa97bc18a20
a9fffffff3094701
a9fffffff3094701
ffffffa97bc18a20
a9fffffff3094701
ffffffa97bc18a20
-
{e=>0,a=>19,d=>0,j=>0,c=>1,h=>1,b=>2,g=>-3,f=>3,i=>3}
130000000ab06600
130000000ab06600
130000000ab06600
0000001344074b00
130000000ab06600
130000000ab06600
0000001344074b00
130000000ab06600
0000001344074b00
-
{e=>1,a=>-111,d=>-2,j=>1,c=>3,h=>0,b=>-4,g=>-4,f=>1,i=>0}
91ffffff9c130201
91ffffff9c130201
91ffffff9c130201
ffffff918f130020
91ffffff9c130201
91ffffff9c130201
ffffff918f130020
91ffffff9c130201
ffffff918f130020
-
{e=>-1,a=>-103,d=>1,j=>0,c=>-1,h=>-4,b=>2,g=>1,f=>-3,i=>3}
99ffffff7ade7000
99ffffff7ade7000
99ffffff7ade7000
ffffff995cfa6300
99ffffff7ade7000
99ffffff7ade7000
ffffff995cfa6300
99ffffff7ade7000
ffffff995cfa6300
=
struct int_wrap {
  int a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
};
-
{e=>-3,a=>38,d=>-2,j=>2,c=>-2,k=>1,h=>1,b=>0,g=>0,f=>2,i=>0}
26000000b02b040a
26000000b02b040a
26000000b02b040a
000000261b540844
26000000b02b040a
26000000b02b040a
000000261b540844
26000000b02b040a
000000261b540844
-
{e=>2,a=>41,d=>0,j=>-3,c=>1,k=>-2,h=>-3,b=>0,g=>0,f=>0,i=>0}
2900000008041435
2900000008041435
2900000008041435
00000029042028b8
2900000008041435
2900000008041435
00000029042028b8
2900000008041435
00000029042028b8
-
{e=>3,a=>107,d=>-3,j=>-1,c=>2,k=>-2,h=>1,b=>0,g=>-1,f=>3,i=>1}
6b00000050b72737
6b00000050b72737
6b00000050b72737
0000006b0ab7c9f8
6b00000050b72737
6b00000050b72737
0000006b0ab7c9f8
6b00000050b72737
0000006b0ab7c9f8
-
{e=>3,a=>18,d=>-4,j=>2,c=>-4,k=>-1,h=>-3,b=>-1,g=>-3,f=>-3,i=>-3}
1200000027d7b63a
1200000027d7b63a
1200000027d7b63a
00000012f23b6d5c
1200000027d7b63a
1200000027d7b63a
00000012f23b6d5c
1200000027d7b63a
00000012f23b6d5c
-
{e=>3,a=>-10,d=>-4,j=>2,c=>1,k=>0,h=>-1,b=>-4,g=>0,f=>1,i=>2}
f6ffffff0c175c02
f6ffffff0c175c02
f6ffffff0c175c02
fffffff686323a40
f6ffffff0c175c02
f6ffffff0c175c02
fffffff686323a40
f6ffffff0c175c02
fffffff686323a40
=
struct int_wrap {
  int a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
};
-
{e=>1,a=>-91,d=>3,j=>-3,l=>2,c=>2,k=>-1,h=>1,b=>-1,g=>-4,f=>-2,i=>-3}
a5ffffffd762a63d02000000
a5ffffffd762a63d02000000
a5ffffffd762a63d02000000
ffffffa5e99d0dbc40000000
a5ffffffd762a63d02000000
a5ffffffd762a63d02000000
ffffffa5e99d0dbc40000000
a5ffffffd762a63d02000000
ffffffa5e99d0dbc40000000
-
{e=>-1,a=>-28,d=>0,j=>-4,l=>-3,c=>-2,k=>2,h=>-4,b=>-2,g=>-2,f=>-1,i=>0}
e4ffffff367e131405000000
e4ffffff367e131405000000
e4ffffff367e131405000000
ffffffe4d87fa088a0000000
e4ffffff367e131405000000
e4ffffff367e131405000000
ffffffe4d87fa088a0000000
e4ffffff367e131405000000
ffffffe4d87fa088a0000000
-
{e=>1,a=>78,d=>-3,j=>-3,l=>-2,c=>1,k=>2,h=>0,b=>-2,g=>0,f=>-2,i=>-3}
4e0000004e63a01506000000
4e0000004e63a01506000000
4e0000004e63a01506000000
0000004ec69c05a8c0000000
4e0000004e63a01506000000
4e0000004e63a01506000000
0000004ec69c05a8c0000000
4e0000004e63a01506000000
0000004ec69c05a8c0000000
-
{e=>-2,a=>71,d=>2,j=>-4,l=>-1,c=>-4,k=>2,h=>3,b=>1,g=>0,f=>-1,i=>1}
47000000a17c2c1407000000
47000000a17c2c1407000000
47000000a17c2c1407000000
00000047316e1988e0000000
47000000a17c2c1407000000
47000000a17c2c1407000000
00000047316e1988e0000000
47000000a17c2c1407000000
00000047316e1988e0000000
-
{e=>-2,a=>-99,d=>-4,j=>-2,l=>-4,c=>-2,k=>3,h=>-1,b=>1,g=>-4,f=>-1,i=>-1}
9dffffff317dfe1e04000000
9dffffff317dfe1e04000000
9dffffff317dfe1e04000000
ffffff9d3a6f3fcc80000000
9dffffff317dfe1e04000000
9dffffff317dfe1e04000000
ffffff9d3a6f3fcc80000000
9dffffff317dfe1e04000000
ffffff9d3a6f3fcc80000000
=
struct int_wrap {
  int a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
};
-
{e=>1,a=>11,m=>3,d=>0,j=>-1,l=>2,c=>2,k=>-2,h=>0,b=>2,g=>-1,f=>-4,i=>-3}
0b00000012c2a3371a000000
0b00000012c2a3371a000000
0b00000012c2a3371a000000
0000000b4819c5f84c000000
0b00000012c2a3371a000000
0b00000012c2a3371a000000
0000000b4819c5f84c000000
0b00000012c2a3371a000000
0000000b4819c5f84c000000
-
{e=>3,a=>-31,m=>-1,d=>1,j=>3,l=>1,c=>-3,k=>-4,h=>-3,b=>-3,g=>3,f=>-2,i=>0}
e1ffffff6de6152339000000
e1ffffff6de6152339000000
e1ffffff6de6152339000000
ffffffe1b4bce8703c000000
e1ffffff6de6152339000000
e1ffffff6de6152339000000
ffffffe1b4bce8703c000000
e1ffffff6de6152339000000
ffffffe1b4bce8703c000000
-
{e=>-1,a=>-107,m=>-1,d=>-4,j=>3,l=>-4,c=>3,k=>-3,h=>3,b=>0,g=>3,f=>-1,i=>2}
95ffffff18ff4d2b3c000000
95ffffff18ff4d2b3c000000
95ffffff18ff4d2b3c000000
ffffff950e7eda749c000000
95ffffff18ff4d2b3c000000
95ffffff18ff4d2b3c000000
ffffff950e7eda749c000000
95ffffff18ff4d2b3c000000
ffffff950e7eda749c000000
-
{e=>-3,a=>-123,m=>-3,d=>3,j=>-1,l=>3,c=>2,k=>-2,h=>1,b=>2,g=>-4,f=>-2,i=>-2}
85ffffffd26ac6372b000000
85ffffffd26ac6372b000000
85ffffffd26ac6372b000000
ffffff8549dd0ef874000000
85ffffffd26ac6372b000000
85ffffffd26ac6372b000000
ffffff8549dd0ef874000000
85ffffffd26ac6372b000000
ffffff8549dd0ef874000000
-
{e=>-3,a=>-105,m=>-4,d=>-1,j=>-2,l=>-2,c=>-1,k=>3,h=>-4,b=>3,g=>-1,f=>3,i=>1}
97fffffffbbb331e26000000
97fffffffbbb331e26000000
97fffffffbbb331e26000000
ffffff977fd7e1ccd0000000
97fffffffbbb331e26000000
97fffffffbbb331e26000000
ffffff977fd7e1ccd0000000
97fffffffbbb331e26000000
ffffff977fd7e1ccd0000000
=
struct int_wrap {
  int a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
  int n:3;
};
-
{e=>1,n=>2,a=>-70,m=>2,d=>-1,j=>-2,l=>-2,c=>-4,k=>0,h=>-3,b=>-3,g=>-4,f=>0,i=>-2}
baffffffe503d60696000000
baffffffe503d60696000000
baffffffe503d60696000000
ffffffbab3912ec0c9000000
baffffffe503d60696000000
baffffffe503d60696000000
ffffffbab3912ec0c9000000
baffffffe503d60696000000
ffffffbab3912ec0c9000000
-
{e=>-2,n=>-3,a=>99,m=>1,d=>-4,j=>0,l=>2,c=>-3,k=>2,h=>-4,b=>3,g=>1,f=>3,i=>1}
630000002bbd30104a010000
630000002bbd30104a010000
630000002bbd30104a010000
000000637666610846800000
630000002bbd30104a010000
630000002bbd30104a010000
000000637666610846800000
630000002bbd30104a010000
000000637666610846800000
-
{e=>0,n=>-4,a=>-106,m=>2,d=>-4,j=>-1,l=>-3,c=>-1,k=>3,h=>2,b=>-4,g=>2,f=>-1,i=>2}
96ffffff3c71491f15010000
96ffffff3c71491f15010000
96ffffff3c71491f15010000
ffffff969e0e92ecaa000000
96ffffff3c71491f15010000
96ffffff3c71491f15010000
ffffff969e0e92ecaa000000
96ffffff3c71491f15010000
ffffff969e0e92ecaa000000
-
{e=>0,n=>1,a=>-37,m=>1,d=>1,j=>-3,l=>-4,c=>0,k=>-2,h=>0,b=>3,g=>-4,f=>-2,i=>-1}
dbffffff4360e2354c000000
dbffffff4360e2354c000000
dbffffff4360e2354c000000
ffffffdb608d07b884800000
dbffffff4360e2354c000000
dbffffff4360e2354c000000
ffffffdb608d07b884800000
dbffffff4360e2354c000000
ffffffdb608d07b884800000
-
{e=>-2,n=>-1,a=>21,m=>1,d=>-4,j=>-2,l=>0,c=>1,k=>-4,h=>-3,b=>1,g=>3,f=>-2,i=>-3}
1500000009edb526c8010000
1500000009edb526c8010000
1500000009edb526c8010000
00000015266cedd007800000
1500000009edb526c8010000
1500000009edb526c8010000
00000015266cedd007800000
1500000009edb526c8010000
00000015266cedd007800000
=
struct int_wrap {
  int a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
  int n:3;
  int o;
};
-
{e=>-2,n=>-3,a=>77,m=>1,d=>0,j=>3,l=>-4,c=>1,k=>3,h=>-2,b=>-3,g=>0,f=>3,o=>-17,i=>2}
4d0000000d3c581b4c010000efffffff
4d0000000d3c581b4c010000efffffff
4d0000000d3c581b4c010000efffffff
0000004da466326c86800000ffffffef
4d0000000d3c581b4c010000efffffff
4d0000000d3c581b4c010000efffffff
0000004da466326c86800000ffffffef
4d0000000d3c581b4c010000efffffff
0000004da466326c86800000ffffffef
-
{e=>-1,n=>3,a=>113,m=>3,d=>3,j=>-1,l=>3,c=>3,k=>-3,h=>-4,b=>-4,g=>2,f=>-3,o=>72,i=>2}
71000000dc5e512fdb00000048000000
71000000dc5e512fdb00000048000000
71000000dc5e512fdb00000048000000
000000718dfaa2f46d80000000000048
71000000dc5e512fdb00000048000000
71000000dc5e512fdb00000048000000
000000718dfaa2f46d80000000000048
71000000dc5e512fdb00000048000000
000000718dfaa2f46d80000000000048
-
{e=>-4,n=>2,a=>0,m=>2,d=>1,j=>2,l=>-2,c=>2,k=>-1,h=>-1,b=>-2,g=>-3,f=>-4,o=>60,i=>2}
0000000056c85e3a960000003c000000
0000000056c85e3a960000003c000000
0000000056c85e3a960000003c000000
00000000c8c97a5cc90000000000003c
0000000056c85e3a960000003c000000
0000000056c85e3a960000003c000000
00000000c8c97a5cc90000000000003c
0000000056c85e3a960000003c000000
00000000c8c97a5cc90000000000003c
-
{e=>-1,n=>-3,a=>65,m=>2,d=>-2,j=>3,l=>2,c=>3,k=>0,h=>3,b=>-4,g=>0,f=>1,o=>-92,i=>0}
410000009c1f0c0352010000a4ffffff
410000009c1f0c0352010000a4ffffff
410000009c1f0c0352010000a4ffffff
000000418f7218604a800000ffffffa4
410000009c1f0c0352010000a4ffffff
410000009c1f0c0352010000a4ffffff
000000418f7218604a800000ffffffa4
410000009c1f0c0352010000a4ffffff
000000418f7218604a800000ffffffa4
-
{e=>1,n=>2,a=>64,m=>0,d=>-2,j=>2,l=>1,c=>-3,k=>0,h=>-1,b=>3,g=>2,f=>1,o=>-43,i=>-2}
40000000ab13dd0281000000d5ffffff
40000000ab13dd0281000000d5ffffff
40000000ab13dd0281000000d5ffffff
000000407712be4021000000ffffffd5
40000000ab13dd0281000000d5ffffff
40000000ab13dd0281000000d5ffffff
000000407712be4021000000ffffffd5
40000000ab13dd0281000000d5ffffff
000000407712be4021000000ffffffd5
=
struct int_wrap {
  long a;
  int b:3;
};
-
{a=>33,b=>-4}
2100000004000000
21000000000000000400000000000000
21000000000000000400000000000000
0000002180000000
2100000004000000
2100000004000000
00000000000000218000000000000000
2100000004000000
0000002180000000
-
{a=>122,b=>-4}
7a00000004000000
7a000000000000000400000000000000
7a000000000000000400000000000000
0000007a80000000
7a00000004000000
7a00000004000000
000000000000007a8000000000000000
7a00000004000000
0000007a80000000
-
{a=>107,b=>-3}
6b00000005000000
6b000000000000000500000000000000
6b000000000000000500000000000000
0000006ba0000000
6b00000005000000
6b00000005000000
000000000000006ba000000000000000
6b00000005000000
0000006ba0000000
-
{a=>17,b=>1}
1100000001000000
11000000000000000100000000000000
11000000000000000100000000000000
0000001120000000
1100000001000000
1100000001000000
00000000000000112000000000000000
1100000001000000
0000001120000000
-
{a=>-47,b=>2}
d1ffffff02000000
d1ffffffffffffff0200000000000000
d1ffffffffffffff0200000000000000
ffffffd140000000
d1ffffff02000000
d1ffffff02000000
ffffffffffffffd14000000000000000
d1ffffff02000000
ffffffd140000000
=
struct int_wrap {
  long a;
  int b:3;
  int c:3;
};
-
{c=>-2,a=>-37,b=>1}
dbffffff31000000
dbffffffffffffff3100000000000000
dbffffffffffffff3100000000000000
ffffffdb38000000
dbffffff31000000
dbffffff31000000
ffffffffffffffdb3800000000000000
dbffffff31000000
ffffffdb38000000
-
{c=>-2,a=>-7,b=>1}
f9ffffff31000000
f9ffffffffffffff3100000000000000
f9ffffffffffffff3100000000000000
fffffff938000000
f9ffffff31000000
f9ffffff31000000
fffffffffffffff93800000000000000
f9ffffff31000000
fffffff938000000
-
{c=>3,a=>124,b=>0}
7c00000018000000
7c000000000000001800000000000000
7c000000000000001800000000000000
0000007c0c000000
7c00000018000000
7c00000018000000
000000000000007c0c00000000000000
7c00000018000000
0000007c0c000000
-
{c=>0,a=>-128,b=>-4}
80ffffff04000000
80ffffffffffffff0400000000000000
80ffffffffffffff0400000000000000
ffffff8080000000
80ffffff04000000
80ffffff04000000
ffffffffffffff808000000000000000
80ffffff04000000
ffffff8080000000
-
{c=>3,a=>5,b=>2}
050000001a000000
05000000000000001a00000000000000
05000000000000001a00000000000000
000000054c000000
050000001a000000
050000001a000000
00000000000000054c00000000000000
050000001a000000
000000054c000000
=
struct int_wrap {
  long a;
  int b:3;
  int c:3;
  int d:3;
};
-
{c=>3,a=>-33,b=>0,d=>-2}
dfffffff98010000
dfffffffffffffff9801000000000000
dfffffffffffffff9801000000000000
ffffffdf0f000000
dfffffff98010000
dfffffff98010000
ffffffffffffffdf0f00000000000000
dfffffff98010000
ffffffdf0f000000
-
{c=>1,a=>87,b=>1,d=>-3}
5700000049010000
57000000000000004901000000000000
57000000000000004901000000000000
0000005726800000
5700000049010000
5700000049010000
00000000000000572680000000000000
5700000049010000
0000005726800000
-
{c=>2,a=>-12,b=>0,d=>0}
f4ffffff10000000
f4ffffffffffffff1000000000000000
f4ffffffffffffff1000000000000000
fffffff408000000
f4ffffff10000000
f4ffffff10000000
fffffffffffffff40800000000000000
f4ffffff10000000
fffffff408000000
-
{c=>3,a=>-30,b=>-2,d=>3}
e2ffffffde000000
e2ffffffffffffffde00000000000000
e2ffffffffffffffde00000000000000
ffffffe2cd800000
e2ffffffde000000
e2ffffffde000000
ffffffffffffffe2cd80000000000000
e2ffffffde000000
ffffffe2cd800000
-
{c=>1,a=>81,b=>3,d=>2}
510000008b000000
51000000000000008b00000000000000
51000000000000008b00000000000000
0000005165000000
510000008b000000
510000008b000000
00000000000000516500000000000000
510000008b000000
0000005165000000
=
struct int_wrap {
  long a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
};
-
{e=>2,c=>-1,a=>-61,b=>3,d=>2}
c3ffffffbb040000
c3ffffffffffffffbb04000000000000
c3ffffffffffffffbb04000000000000
ffffffc37d200000
c3ffffffbb040000
c3ffffffbb040000
ffffffffffffffc37d20000000000000
c3ffffffbb040000
ffffffc37d200000
-
{e=>-2,c=>-3,a=>86,b=>2,d=>-1}
56000000ea0d0000
5600000000000000ea0d000000000000
5600000000000000ea0d000000000000
0000005657e00000
56000000ea0d0000
56000000ea0d0000
000000000000005657e0000000000000
56000000ea0d0000
0000005657e00000
-
{e=>-2,c=>0,a=>126,b=>3,d=>-2}
7e000000830d0000
7e00000000000000830d000000000000
7e00000000000000830d000000000000
0000007e63600000
7e000000830d0000
7e000000830d0000
000000000000007e6360000000000000
7e000000830d0000
0000007e63600000
-
{e=>-4,c=>2,a=>-98,b=>-3,d=>-2}
9effffff95090000
9effffffffffffff9509000000000000
9effffffffffffff9509000000000000
ffffff9eab400000
9effffff95090000
9effffff95090000
ffffffffffffff9eab40000000000000
9effffff95090000
ffffff9eab400000
-
{e=>3,c=>3,a=>-97,b=>0,d=>3}
9fffffffd8060000
9fffffffffffffffd806000000000000
9fffffffffffffffd806000000000000
ffffff9f0db00000
9fffffffd8060000
9fffffffd8060000
ffffffffffffff9f0db0000000000000
9fffffffd8060000
ffffff9f0db00000
=
struct int_wrap {
  long a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
};
-
{e=>-4,c=>-1,a=>-9,b=>-1,d=>1,f=>-2}
f7ffffff7f680000
f7ffffffffffffff7f68000000000000
f7ffffffffffffff7f68000000000000
fffffff7fccc0000
f7ffffff7f680000
f7ffffff7f680000
fffffffffffffff7fccc000000000000
f7ffffff7f680000
fffffff7fccc0000
-
{e=>1,c=>-4,a=>112,b=>-4,d=>1,f=>-3}
7000000064520000
70000000000000006452000000000000
70000000000000006452000000000000
00000070909a0000
7000000064520000
7000000064520000
0000000000000070909a000000000000
7000000064520000
00000070909a0000
-
{e=>3,c=>-1,a=>-116,b=>2,d=>2,f=>-4}
8cffffffba460000
8cffffffffffffffba46000000000000
8cffffffffffffffba46000000000000
ffffff8c5d380000
8cffffffba460000
8cffffffba460000
ffffffffffffff8c5d38000000000000
8cffffffba460000
ffffff8c5d380000
-
{e=>-4,c=>-3,a=>-4,b=>-4,d=>2,f=>1}
fcffffffac180000
fcffffffffffffffac18000000000000
fcffffffffffffffac18000000000000
fffffffc95420000
fcffffffac180000
fcffffffac180000
fffffffffffffffc9542000000000000
fcffffffac180000
fffffffc95420000
-
{e=>-2,c=>-3,a=>-52,b=>3,d=>3,f=>0}
ccffffffeb0c0000
ccffffffffffffffeb0c000000000000
ccffffffffffffffeb0c000000000000
ffffffcc75e00000
ccffffffeb0c0000
ccffffffeb0c0000
ffffffffffffffcc75e0000000000000
ccffffffeb0c0000
ffffffcc75e00000
=
struct int_wrap {
  long a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
};
-
{e=>-2,c=>0,a=>92,g=>-1,b=>-2,d=>-2,f=>-2}
5c00000086ed0300
5c0000000000000086ed030000000000
5c0000000000000086ed030000000000
0000005cc36dc000
5c00000086ed0300
5c00000086ed0300
000000000000005cc36dc00000000000
5c00000086ed0300
0000005cc36dc000
-
{e=>1,c=>-1,a=>-32,g=>-4,b=>3,d=>0,f=>-1}
e0ffffff3b720200
e0ffffffffffffff3b72020000000000
e0ffffffffffffff3b72020000000000
ffffffe07c1f0000
e0ffffff3b720200
e0ffffff3b720200
ffffffffffffffe07c1f000000000000
e0ffffff3b720200
ffffffe07c1f0000
-
{e=>-4,c=>3,a=>17,g=>-4,b=>1,d=>-4,f=>2}
1100000019290200
11000000000000001929020000000000
11000000000000001929020000000000
000000112e450000
1100000019290200
1100000019290200
00000000000000112e45000000000000
1100000019290200
000000112e450000
-
{e=>1,c=>-4,a=>-113,g=>-1,b=>1,d=>-4,f=>-4}
8fffffff21c30300
8fffffffffffffff21c3030000000000
8fffffffffffffff21c3030000000000
ffffff8f3219c000
8fffffff21c30300
8fffffff21c30300
ffffffffffffff8f3219c00000000000
8fffffff21c30300
ffffff8f3219c000
-
{e=>0,c=>1,a=>23,g=>2,b=>3,d=>-3,f=>-3}
170000004b510100
17000000000000004b51010000000000
17000000000000004b51010000000000
00000017668a8000
170000004b510100
170000004b510100
0000000000000017668a800000000000
170000004b510100
00000017668a8000
=
struct int_wrap {
  long a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
};
-
{e=>0,a=>76,d=>2,c=>-1,h=>-3,b=>3,g=>-3,f=>0}
4c000000bb801600
4c00000000000000bb80160000000000
4c00000000000000bb80160000000000
0000004c7d016800
4c000000bb801600
4c000000bb801600
000000000000004c7d01680000000000
4c000000bb801600
0000004c7d016800
-
{e=>3,a=>39,d=>-4,c=>-3,h=>1,b=>-2,g=>-2,f=>1}
270000002e170700
27000000000000002e17070000000000
27000000000000002e17070000000000
00000027d6338800
270000002e170700
270000002e170700
0000000000000027d633880000000000
270000002e170700
00000027d6338800
-
{e=>2,a=>108,d=>2,c=>1,h=>3,b=>1,g=>2,f=>-2}
6c00000089640d00
6c0000000000000089640d0000000000
6c0000000000000089640d0000000000
0000006c252c9800
6c00000089640d00
6c00000089640d00
000000000000006c252c980000000000
6c00000089640d00
0000006c252c9800
-
{e=>-2,a=>52,d=>-2,c=>-3,h=>-2,b=>1,g=>-4,f=>-2}
34000000a96d1a00
3400000000000000a96d1a0000000000
3400000000000000a96d1a0000000000
00000034376d3000
34000000a96d1a00
34000000a96d1a00
0000000000000034376d300000000000
34000000a96d1a00
00000034376d3000
-
{e=>-3,a=>-110,d=>-4,c=>-4,h=>2,b=>-1,g=>1,f=>2}
92ffffff27ab0800
92ffffffffffffff27ab080000000000
92ffffffffffffff27ab080000000000
ffffff92f2545000
92ffffff27ab0800
92ffffff27ab0800
ffffffffffffff92f254500000000000
92ffffff27ab0800
ffffff92f2545000
=
struct int_wrap {
  long a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
};
-
{e=>2,a=>-27,d=>0,c=>0,h=>-3,b=>2,g=>-3,f=>-4,i=>-4}
e5ffffff02c49600
e5ffffffffffffff02c4960000000000
e5ffffffffffffff02c4960000000000
ffffffe540296c00
e5ffffff02c49600
e5ffffff02c49600
ffffffffffffffe540296c0000000000
e5ffffff02c49600
ffffffe540296c00
-
{e=>-1,a=>109,d=>2,c=>1,h=>-2,b=>1,g=>0,f=>-3,i=>-3}
6d000000895eb800
6d00000000000000895eb80000000000
6d00000000000000895eb80000000000
0000006d257a3500
6d000000895eb800
6d000000895eb800
000000000000006d257a350000000000
6d000000895eb800
0000006d257a3500
-
{e=>-3,a=>-65,d=>3,c=>2,h=>3,b=>0,g=>2,f=>-4,i=>-2}
bfffffffd04acd00
bfffffffffffffffd04acd0000000000
bfffffffffffffffd04acd0000000000
ffffffbf09d89e00
bfffffffd04acd00
bfffffffd04acd00
ffffffffffffffbf09d89e0000000000
bfffffffd04acd00
ffffffbf09d89e00
-
{e=>3,a=>-118,d=>-1,c=>1,h=>-1,b=>0,g=>3,f=>2,i=>-4}
8affffffc8a79d00
8affffffffffffffc8a79d0000000000
8affffffffffffffc8a79d0000000000
ffffff8a07b4fc00
8affffffc8a79d00
8affffffc8a79d00
ffffffffffffff8a07b4fc0000000000
8affffffc8a79d00
ffffff8a07b4fc00
-
{e=>-4,a=>77,d=>-3,c=>3,h=>-1,b=>-2,g=>-1,f=>-3,i=>-3}
4d0000005ed9bf00
4d000000000000005ed9bf0000000000
4d000000000000005ed9bf0000000000
0000004dcecbfd00
4d0000005ed9bf00
4d0000005ed9bf00
000000000000004dcecbfd0000000000
4d0000005ed9bf00
0000004dcecbfd00
=
struct int_wrap {
  long a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
};
-
{e=>-3,a=>60,d=>2,j=>2,c=>2,h=>-3,b=>3,g=>-1,f=>-2,i=>-1}
3c00000093eaf702
3c0000000000000093eaf70200000000
3c0000000000000093eaf70200000000
0000003c695def40
3c00000093eaf702
3c00000093eaf702
000000000000003c695def4000000000
3c00000093eaf702
0000003c695def40
-
{e=>-3,a=>-119,d=>0,j=>-2,c=>3,h=>-3,b=>3,g=>-3,f=>-3,i=>-3}
89ffffff1bdab606
89ffffffffffffff1bdab60600000000
89ffffffffffffff1bdab60600000000
ffffff896c5b6dc0
89ffffff1bdab606
89ffffff1bdab606
ffffffffffffff896c5b6dc000000000
89ffffff1bdab606
ffffff896c5b6dc0
-
{e=>-4,a=>94,d=>2,j=>2,c=>1,h=>3,b=>1,g=>1,f=>3,i=>3}
5e00000089b86c02
5e0000000000000089b86c0200000000
5e0000000000000089b86c0200000000
0000005e25465b40
5e00000089b86c02
5e00000089b86c02
000000000000005e25465b4000000000
5e00000089b86c02
0000005e25465b40
-
{e=>3,a=>116,d=>1,j=>2,c=>-4,h=>-3,b=>0,g=>3,f=>2,i=>-4}
7400000060a69502
740000000000000060a6950200000000
740000000000000060a6950200000000
0000007410b4ec40
7400000060a69502
7400000060a69502
000000000000007410b4ec4000000000
7400000060a69502
0000007410b4ec40
-
{e=>1,a=>42,d=>-4,j=>-4,c=>-2,h=>-2,b=>2,g=>-3,f=>-2,i=>-3}
2a00000032e3ba04
2a0000000000000032e3ba0400000000
2a0000000000000032e3ba0400000000
0000002a5a1d7580
2a00000032e3ba04
2a00000032e3ba04
000000000000002a5a1d758000000000
2a00000032e3ba04
0000002a5a1d7580
=
struct int_wrap {
  long a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
};
-
{e=>0,a=>15,d=>3,j=>2,c=>0,k=>3,h=>-4,b=>3,g=>-1,f=>-4,i=>-4}
0f000000c3c0931a
0f00000000000000c3c0931a00000000
0f00000000000000c3c0931a00000000
0000000f6189e44c
0f000000c3c0931a
0f000000c3c0931a
000000000000000f6189e44c00000000
0f000000c3c0931a
0000000f6189e44c
-
{e=>-2,a=>-58,d=>-3,j=>-1,c=>-1,k=>-2,h=>1,b=>-2,g=>3,f=>-4,i=>-3}
c6ffffff7ecda537
c6ffffffffffffff7ecda53700000000
c6ffffffffffffff7ecda53700000000
ffffffc6dee8cdf8
c6ffffff7ecda537
c6ffffff7ecda537
ffffffffffffffc6dee8cdf800000000
c6ffffff7ecda537
ffffffc6dee8cdf8
-
{e=>0,a=>3,d=>-4,j=>-4,c=>2,k=>1,h=>3,b=>0,g=>-4,f=>3,i=>-4}
0300000010318e0c
030000000000000010318e0c00000000
030000000000000010318e0c00000000
000000030a071c84
0300000010318e0c
0300000010318e0c
00000000000000030a071c8400000000
0300000010318e0c
000000030a071c84
-
{e=>-2,a=>9,d=>3,j=>3,c=>-3,k=>-2,h=>-1,b=>-1,g=>1,f=>-4,i=>3}
09000000efcc7c33
0900000000000000efcc7c3300000000
0900000000000000efcc7c3300000000
00000009f5e87b78
09000000efcc7c33
09000000efcc7c33
0000000000000009f5e87b7800000000
09000000efcc7c33
00000009f5e87b78
-
{e=>-2,a=>41,d=>2,j=>-1,c=>-3,k=>-2,h=>-4,b=>-2,g=>-1,f=>2,i=>3}
29000000aeac7337
2900000000000000aeac733700000000
2900000000000000aeac733700000000
00000029d565e3f8
29000000aeac7337
29000000aeac7337
0000000000000029d565e3f800000000
29000000aeac7337
00000029d565e3f8
=
struct int_wrap {
  long a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
};
-
{e=>-3,a=>-21,d=>3,j=>0,l=>-3,c=>-3,k=>3,h=>0,b=>2,g=>-4,f=>-3,i=>-3}
ebffffffea5aa21805000000
ebffffffffffffffea5aa21805000000
ebffffffffffffffea5aa21805000000
ffffffeb55db050ca0000000
ebffffffea5aa21805000000
ebffffffea5aa21805000000
ffffffffffffffeb55db050ca0000000
ebffffffea5aa21805000000
ffffffeb55db050ca0000000
-
{e=>0,a=>26,d=>3,j=>3,l=>-4,c=>0,k=>2,h=>-1,b=>-1,g=>-2,f=>0,i=>-4}
1a000000c7009f1304000000
1a00000000000000c7009f1304000000
1a00000000000000c7009f1304000000
0000001ae181bc6880000000
1a000000c7009f1304000000
1a000000c7009f1304000000
000000000000001ae181bc6880000000
1a000000c7009f1304000000
0000001ae181bc6880000000
-
{e=>-3,a=>-32,d=>-2,j=>0,l=>-4,c=>-3,k=>-2,h=>2,b=>-1,g=>1,f=>2,i=>-3}
e0ffffffafaba83004000000
e0ffffffffffffffafaba83004000000
e0ffffffffffffffafaba83004000000
ffffffe0f754551880000000
e0ffffffafaba83004000000
e0ffffffafaba83004000000
ffffffffffffffe0f754551880000000
e0ffffffafaba83004000000
ffffffe0f754551880000000
-
{e=>2,a=>-37,d=>-2,j=>-3,l=>-4,c=>1,k=>1,h=>-2,b=>2,g=>3,f=>0,i=>3}
dbffffff8a85790d04000000
dbffffffffffffff8a85790d04000000
dbffffffffffffff8a85790d04000000
ffffffdb4720f3a480000000
dbffffff8a85790d04000000
dbffffff8a85790d04000000
ffffffffffffffdb4720f3a480000000
dbffffff8a85790d04000000
ffffffdb4720f3a480000000
-
{e=>1,a=>-116,d=>-2,j=>0,l=>2,c=>1,k=>-4,h=>0,b=>2,g=>-3,f=>-1,i=>-4}
8cffffff8af3822002000000
8cffffffffffffff8af3822002000000
8cffffffffffffff8af3822002000000
ffffff8c471f441040000000
8cffffff8af3822002000000
8cffffff8af3822002000000
ffffffffffffff8c471f441040000000
8cffffff8af3822002000000
ffffff8c471f441040000000
=
struct int_wrap {
  long a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
};
-
{e=>-1,a=>-6,m=>-3,d=>0,j=>3,l=>1,c=>-4,k=>1,h=>-4,b=>1,g=>2,f=>1,i=>2}
faffffff211e510b29000000
faffffffffffffff211e510b29000000
faffffffffffffff211e510b29000000
fffffffa3072a26434000000
faffffff211e510b29000000
faffffff211e510b29000000
fffffffffffffffa3072a26434000000
faffffff211e510b29000000
fffffffa3072a26434000000
-
{e=>2,a=>-118,m=>-4,d=>-1,j=>-2,l=>2,c=>3,k=>-3,h=>3,b=>0,g=>-3,f=>-4,i=>3}
8affffffd8c56e2e22000000
8affffffffffffffd8c56e2e22000000
8affffffffffffffd8c56e2e22000000
ffffff8a0fa95bd450000000
8affffffd8c56e2e22000000
8affffffd8c56e2e22000000
ffffffffffffff8a0fa95bd450000000
8affffffd8c56e2e22000000
ffffff8a0fa95bd450000000
-
{e=>3,a=>-56,m=>1,d=>3,j=>0,l=>3,c=>2,k=>-2,h=>1,b=>2,g=>0,f=>-3,i=>-2}
c8ffffffd256c4300b000000
c8ffffffffffffffd256c4300b000000
c8ffffffffffffffd256c4300b000000
ffffffc849ba0e1864000000
c8ffffffd256c4300b000000
c8ffffffd256c4300b000000
ffffffffffffffc849ba0e1864000000
c8ffffffd256c4300b000000
ffffffc849ba0e1864000000
-
{e=>1,a=>-55,m=>-4,d=>0,j=>-1,l=>3,c=>-3,k=>-4,h=>3,b=>-4,g=>2,f=>-2,i=>-4}
c9ffffff2c628d2723000000
c9ffffffffffffff2c628d2723000000
c9ffffffffffffff2c628d2723000000
ffffffc9941c9cf070000000
c9ffffff2c628d2723000000
c9ffffff2c628d2723000000
ffffffffffffffc9941c9cf070000000
c9ffffff2c628d2723000000
ffffffc9941c9cf070000000
-
{e=>-3,a=>-107,m=>0,d=>-1,j=>2,l=>-3,c=>-2,k=>-2,h=>-2,b=>-4,g=>2,f=>1,i=>-3}
95fffffff41bb93205000000
95fffffffffffffff41bb93205000000
95fffffffffffffff41bb93205000000
ffffff959bd2b558a0000000
95fffffff41bb93205000000
95fffffff41bb93205000000
ffffffffffffff959bd2b558a0000000
95fffffff41bb93205000000
ffffff959bd2b558a0000000
=
struct int_wrap {
  long a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
  int n:3;
};
-
{e=>-1,n=>-1,a=>-103,m=>-3,d=>-3,j=>2,l=>-4,c=>-3,k=>3,h=>2,b=>3,g=>-4,f=>1,i=>1}
99ffffff6b1f2a1aec010000
99ffffffffffffff6b1f2a1aec010000
99ffffffffffffff6b1f2a1aec010000
ffffff9976f3114c97800000
99ffffff6b1f2a1aec010000
99ffffff6b1f2a1aec010000
ffffffffffffff9976f3114c97800000
99ffffff6b1f2a1aec010000
ffffff9976f3114c97800000
-
{e=>1,n=>-1,a=>-117,m=>3,d=>-3,j=>3,l=>2,c=>-4,k=>2,h=>-1,b=>-3,g=>-1,f=>0,i=>-1}
8bffffff6583ff13da010000
8bffffffffffffff6583ff13da010000
8bffffffffffffff6583ff13da010000
ffffff8bb291ff684f800000
8bffffff6583ff13da010000
8bffffff6583ff13da010000
ffffffffffffff8bb291ff684f800000
8bffffff6583ff13da010000
ffffff8bb291ff684f800000
-
{e=>1,n=>-3,a=>28,m=>-1,d=>-4,j=>2,l=>-4,c=>3,k=>-4,h=>-2,b=>0,g=>2,f=>-4,i=>1}
1c000000184339227c010000
1c00000000000000184339227c010000
1c00000000000000184339227c010000
0000001c0e18b1509e800000
1c000000184339227c010000
1c000000184339227c010000
000000000000001c0e18b1509e800000
1c000000184339227c010000
0000001c0e18b1509e800000
-
{e=>-4,n=>3,a=>29,m=>-4,d=>2,j=>-2,l=>-4,c=>-2,k=>-2,h=>2,b=>-2,g=>-2,f=>-2,i=>-2}
1d000000b668cb36e4000000
1d00000000000000b668cb36e4000000
1d00000000000000b668cb36e4000000
0000001dd94d96d891800000
1d000000b668cb36e4000000
1d000000b668cb36e4000000
000000000000001dd94d96d891800000
1d000000b668cb36e4000000
0000001dd94d96d891800000
-
{e=>3,n=>-1,a=>-93,m=>-1,d=>3,j=>3,l=>-2,c=>2,k=>2,h=>-2,b=>1,g=>0,f=>3,i=>2}
a3ffffffd1365813fe010000
a3ffffffffffffffd1365813fe010000
a3ffffffffffffffd1365813fe010000
ffffffa329b63268df800000
a3ffffffd1365813fe010000
a3ffffffd1365813fe010000
ffffffffffffffa329b63268df800000
a3ffffffd1365813fe010000
ffffffa329b63268df800000
=
struct int_wrap {
  long a;
  int b:3;
  int c:3;
  int d:3;
  int e:3;
  int f:3;
  int g:3;
  int h:3;
  int i:3;
  int j:3;
  int k:3;
  int l:3;
  int m:3;
  int n:3;
  int o;
};
-
{e=>-3,n=>1,a=>-24,m=>2,d=>-2,j=>-2,l=>-4,c=>-1,k=>0,h=>-4,b=>-1,g=>-4,f=>0,o=>10,i=>1}
e8ffffffbf0b3206540000000a000000
e8ffffffffffffffbf0b3206540000000a00000000000000
e8ffffffffffffffbf0b3206540000000a00000000000000
ffffffe8ff5121c0888000000000000a
e8ffffffbf0b3206540000000a000000
e8ffffffbf0b3206540000000a000000
ffffffffffffffe8ff5121c0888000000000000a00000000
e8ffffffbf0b3206540000000a000000
ffffffe8ff5121c0888000000000000a
-
{e=>0,n=>3,a=>91,m=>3,d=>1,j=>-2,l=>-1,c=>-3,k=>0,h=>1,b=>3,g=>3,f=>0,o=>0,i=>0}
5b0000006b800506df00000000000000
5b000000000000006b800506df0000000000000000000000
5b000000000000006b800506df0000000000000000000000
0000005b7480c8c0ed80000000000000
5b0000006b800506df00000000000000
5b0000006b800506df00000000000000
000000000000005b7480c8c0ed8000000000000000000000
5b0000006b800506df00000000000000
0000005b7480c8c0ed80000000000000
-
{e=>-4,n=>-4,a=>-91,m=>0,d=>1,j=>0,l=>3,c=>1,k=>-4,h=>0,b=>3,g=>1,f=>-2,o=>81,i=>-3}
a5ffffff4be8a0200301000051000000
a5ffffffffffffff4be8a020030100005100000000000000
a5ffffffffffffff4be8a020030100005100000000000000
ffffffa564cc45106200000000000051
a5ffffff4be8a0200301000051000000
a5ffffff4be8a0200301000051000000
ffffffffffffffa564cc4510620000000000005100000000
a5ffffff4be8a0200301000051000000
ffffffa564cc45106200000000000051
-
{e=>0,n=>-3,a=>-22,m=>-1,d=>-4,j=>-1,l=>0,c=>3,k=>-2,h=>3,b=>-3,g=>-1,f=>-3,o=>40,i=>2}
eaffffff1dd14f377801000028000000
eaffffffffffffff1dd14f37780100002800000000000000
eaffffffffffffff1dd14f37780100002800000000000000
ffffffeaae0bdaf81e80000000000028
eaffffff1dd14f377801000028000000
eaffffff1dd14f377801000028000000
ffffffffffffffeaae0bdaf81e8000000000002800000000
eaffffff1dd14f377801000028000000
ffffffeaae0bdaf81e80000000000028
-
{e=>-2,n=>1,a=>-71,m=>2,d=>2,j=>-3,l=>-4,c=>0,k=>-3,h=>2,b=>-2,g=>2,f=>0,o=>-119,i=>-2}
b9ffffff860cc92d5400000089ffffff
b9ffffffffffffff860cc92d5400000089ffffff00000000
b9ffffffffffffff860cc92d5400000089ffffff00000000
ffffffb9c16096b488800000ffffff89
b9ffffff860cc92d5400000089ffffff
b9ffffff860cc92d5400000089ffffff
ffffffffffffffb9c16096b488800000ffffff8900000000
b9ffffff860cc92d5400000089ffffff
ffffffb9c16096b488800000ffffff89
=
struct umixed3 {
  unsigned char  a:3;
};
-
{a=>7}
07
07
07
e0
07000000
07
e0
07
e0
-
{a=>4}
04
04
04
80
04000000
04
80
04
80
-
{a=>1}
01
01
01
20
01000000
01
20
01
20
-
{a=>2}
02
02
02
40
02000000
02
40
02
40
-
{a=>5}
05
05
05
a0
05000000
05
a0
05
a0
=
struct umixed3 {
  unsigned char  a:3;
  unsigned char  b:3;
};
-
{a=>6,b=>0}
06
06
06
c0
06000000
06
c0
06
c0
-
{a=>0,b=>4}
20
20
20
10
20000000
20
10
20
10
-
{a=>2,b=>1}
0a
0a
0a
44
0a000000
0a
44
0a
44
-
{a=>7,b=>3}
1f
1f
1f
ec
1f000000
1f
ec
1f
ec
-
{a=>2,b=>3}
1a
1a
1a
4c
1a000000
1a
4c
1a
4c
=
struct umixed3 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned int   c:3;
};
-
{c=>0,a=>7,b=>5}
2f000000
2f000000
2f000000
f4000000
2f000000
2f000000
f4000000
2f000000
f4000000
-
{c=>2,a=>6,b=>7}
be000000
be000000
be000000
dd000000
be000000
be000000
dd000000
be000000
dd000000
-
{c=>2,a=>7,b=>2}
97000000
97000000
97000000
e9000000
97000000
97000000
e9000000
97000000
e9000000
-
{c=>7,a=>1,b=>3}
d9010000
d9010000
d9010000
2f800000
d9010000
d9010000
2f800000
d9010000
2f800000
-
{c=>5,a=>3,b=>4}
63010000
63010000
63010000
72800000
63010000
63010000
72800000
63010000
72800000
=
struct umixed3 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned int   c:3;
  unsigned char  d:3;
};
-
{c=>6,a=>2,b=>1,d=>2}
8a050000
8a050000
8a050000
47200000
8a050000
8a050000
47200000
8a050000
47200000
-
{c=>5,a=>6,b=>1,d=>3}
4e070000
4e070000
4e070000
c6b00000
4e070000
4e070000
c6b00000
4e070000
c6b00000
-
{c=>4,a=>6,b=>1,d=>0}
0e010000
0e010000
0e010000
c6000000
0e010000
0e010000
c6000000
0e010000
c6000000
-
{c=>0,a=>1,b=>5,d=>6}
290c0000
290c0000
290c0000
34600000
290c0000
290c0000
34600000
290c0000
34600000
-
{c=>7,a=>6,b=>2,d=>2}
d6050000
d6050000
d6050000
cba00000
d6050000
d6050000
cba00000
d6050000
cba00000
=
struct umixed3 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned int   c:3;
  unsigned char  d:3;
  unsigned short e:3;
};
-
{e=>3,c=>6,a=>3,b=>0,d=>1}
83330000
83330000
83330000
63160000
83330000
83330000
63160000
83330000
63160000
-
{e=>6,c=>0,a=>3,b=>1,d=>5}
0b6a0000
0b6a0000
0b6a0000
645c0000
0b6a0000
0b6a0000
645c0000
0b6a0000
645c0000
-
{e=>7,c=>2,a=>2,b=>6,d=>5}
b27a0000
b27a0000
b27a0000
595e0000
b27a0000
b27a0000
595e0000
b27a0000
595e0000
-
{e=>6,c=>0,a=>3,b=>3,d=>3}
1b660000
1b660000
1b660000
6c3c0000
1b660000
1b660000
6c3c0000
1b660000
6c3c0000
-
{e=>6,c=>7,a=>0,b=>3,d=>3}
d8670000
d8670000
d8670000
0fbc0000
d8670000
d8670000
0fbc0000
d8670000
0fbc0000
=
struct umixed3 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned int   c:3;
  unsigned char  d:3;
  unsigned short e:3;
  unsigned char  f:3;
};
-
{e=>3,c=>4,a=>4,b=>7,d=>6,f=>2}
3c3d0200
3c3d0200
3c3d0200
9e664000
3c3d0200
3c3d0200
9e664000
3c3d0200
9e664000
-
{e=>5,c=>4,a=>2,b=>7,d=>0,f=>6}
3a510600
3a510600
3a510600
5e0ac000
3a510600
3a510600
5e0ac000
3a510600
5e0ac000
-
{e=>7,c=>6,a=>0,b=>4,d=>1,f=>6}
a0730600
a0730600
a0730600
131ec000
a0730600
a0730600
131ec000
a0730600
131ec000
-
{e=>4,c=>6,a=>1,b=>0,d=>1,f=>3}
81430300
81430300
81430300
23186000
81430300
81430300
23186000
81430300
23186000
-
{e=>6,c=>4,a=>6,b=>6,d=>6,f=>0}
366d0000
366d0000
366d0000
da6c0000
366d0000
366d0000
da6c0000
366d0000
da6c0000
=
struct umixed3 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned int   c:3;
  unsigned char  d:3;
  unsigned short e:3;
  unsigned char  f:3;
  unsigned long  g;
};
-
{e=>4,c=>5,a=>4,g=>216,b=>7,d=>5,f=>4}
7c4b0400d8000000
7c4b040000000000d800000000000000
7c4b040000000000d800000000000000
9ed88000000000d8
7c4b0400d8000000
7c4b0400d8000000
9ed880000000000000000000000000d8
7c4b0400d8000000
9ed88000000000d8
-
{e=>0,c=>0,a=>7,g=>119,b=>7,d=>3,f=>5}
3f06050077000000
3f060500000000007700000000000000
3f060500000000007700000000000000
fc30a00000000077
3f06050077000000
3f06050077000000
fc30a000000000000000000000000077
3f06050077000000
fc30a00000000077
-
{e=>4,c=>0,a=>7,g=>69,b=>6,d=>3,f=>3}
3746030045000000
37460300000000004500000000000000
37460300000000004500000000000000
f838600000000045
3746030045000000
3746030045000000
f8386000000000000000000000000045
3746030045000000
f838600000000045
-
{e=>1,c=>0,a=>5,g=>247,b=>4,d=>1,f=>7}
25120700f7000000
2512070000000000f700000000000000
2512070000000000f700000000000000
b012e000000000f7
25120700f7000000
25120700f7000000
b012e0000000000000000000000000f7
25120700f7000000
b012e000000000f7
-
{e=>4,c=>5,a=>4,g=>112,b=>1,d=>3,f=>4}
4c47040070000000
4c470400000000007000000000000000
4c470400000000007000000000000000
86b8800000000070
4c47040070000000
4c47040070000000
86b88000000000000000000000000070
4c47040070000000
86b8800000000070
=
struct umixed3 {
  char a;
  unsigned char  b:3;
};
-
{a=>-63,b=>6}
c106
c106
c106
c1c0
c1060000
c106
c1c0
c106
c1c0
-
{a=>-85,b=>7}
ab07
ab07
ab07
abe0
ab070000
ab07
abe0
ab07
abe0
-
{a=>52,b=>0}
3400
3400
3400
3400
34000000
3400
3400
3400
3400
-
{a=>-89,b=>2}
a702
a702
a702
a740
a7020000
a702
a740
a702
a740
-
{a=>-62,b=>7}
c207
c207
c207
c2e0
c2070000
c207
c2e0
c207
c2e0
=
struct umixed3 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>1,a=>77,b=>0}
4d08
4d08
4d08
4d04
4d080000
4d08
4d04
4d08
4d04
-
{c=>7,a=>73,b=>2}
493a
493a
493a
495c
493a0000
493a
495c
493a
495c
-
{c=>5,a=>116,b=>5}
742d
742d
742d
74b4
742d0000
742d
74b4
742d
74b4
-
{c=>7,a=>-44,b=>1}
d439
d439
d439
d43c
d4390000
d439
d43c
d439
d43c
-
{c=>7,a=>-66,b=>7}
be3f
be3f
be3f
befc
be3f0000
be3f
befc
be3f
befc
=
struct umixed3 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
};
-
{c=>0,a=>-16,b=>5,d=>5}
f0450100
f0450100
f0450100
f0a28000
f0450100
f0450100
f0a28000
f0450100
f0a28000
-
{c=>0,a=>-4,b=>7,d=>6}
fc870100
fc870100
fc870100
fce30000
fc870100
fc870100
fce30000
fc870100
fce30000
-
{c=>5,a=>-11,b=>0,d=>2}
f5a80000
f5a80000
f5a80000
f5150000
f5a80000
f5a80000
f5150000
f5a80000
f5150000
-
{c=>6,a=>-39,b=>1,d=>0}
d9310000
d9310000
d9310000
d9380000
d9310000
d9310000
d9380000
d9310000
d9380000
-
{c=>7,a=>78,b=>1,d=>0}
4e390000
4e390000
4e390000
4e3c0000
4e390000
4e390000
4e3c0000
4e390000
4e3c0000
=
struct umixed3 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
};
-
{e=>2,c=>6,a=>28,b=>6,d=>7}
1cf60500
1cf60500
1cf60500
1cdba000
1cf60500
1cf60500
1cdba000
1cf60500
1cdba000
-
{e=>0,c=>6,a=>-11,b=>2,d=>3}
f5f20000
f5f20000
f5f20000
f5598000
f5f20000
f5f20000
f5598000
f5f20000
f5598000
-
{e=>5,c=>7,a=>27,b=>0,d=>1}
1b780a00
1b780a00
1b780a00
1b1cd000
1b780a00
1b780a00
1b1cd000
1b780a00
1b1cd000
-
{e=>2,c=>5,a=>1,b=>0,d=>7}
01e80500
01e80500
01e80500
0117a000
01e80500
01e80500
0117a000
01e80500
0117a000
-
{e=>7,c=>1,a=>79,b=>3,d=>7}
4fcb0f00
4fcb0f00
4fcb0f00
4f67f000
4fcb0f00
4fcb0f00
4f67f000
4fcb0f00
4f67f000
=
struct umixed3 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
  unsigned short f:3;
};
-
{e=>1,c=>7,a=>43,b=>0,d=>7,f=>3}
2bf83300
2bf83300
2bf83300
2b1f9600
2bf83300
2bf83300
2b1f9600
2bf83300
2b1f9600
-
{e=>3,c=>7,a=>-115,b=>7,d=>5,f=>4}
8d7f4700
8d7f4700
8d7f4700
8dfeb800
8d7f4700
8d7f4700
8dfeb800
8d7f4700
8dfeb800
-
{e=>4,c=>7,a=>86,b=>7,d=>6,f=>6}
56bf6900
56bf6900
56bf6900
56ff4c00
56bf6900
56bf6900
56ff4c00
56bf6900
56ff4c00
-
{e=>1,c=>0,a=>-25,b=>3,d=>2,f=>1}
e7831200
e7831200
e7831200
e7611200
e7831200
e7831200
e7611200
e7831200
e7611200
-
{e=>7,c=>7,a=>19,b=>4,d=>7,f=>0}
13fc0f00
13fc0f00
13fc0f00
139ff000
13fc0f00
13fc0f00
139ff000
13fc0f00
139ff000
=
struct umixed3 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
  unsigned short f:3;
  unsigned char  g:3;
};
-
{e=>7,c=>3,a=>-86,g=>1,b=>7,d=>6,f=>1}
aa9f1f01
aa9f1f01
aa9f1f01
aaef7220
aa9f1f01
aa9f1f01
aaef7220
aa9f1f01
aaef7220
-
{e=>1,c=>6,a=>18,g=>4,b=>6,d=>5,f=>5}
12765304
12765304
12765304
12da9a80
12765304
12765304
12da9a80
12765304
12da9a80
-
{e=>0,c=>5,a=>6,g=>2,b=>6,d=>1,f=>0}
066e0002
066e0002
066e0002
06d48040
066e0002
066e0002
06d48040
066e0002
06d48040
-
{e=>0,c=>2,a=>2,g=>1,b=>5,d=>3,f=>4}
02d54001
02d54001
02d54001
02a98820
02d54001
02d54001
02a98820
02d54001
02a98820
-
{e=>4,c=>6,a=>110,g=>5,b=>6,d=>3,f=>1}
6ef61805
6ef61805
6ef61805
6ed9c2a0
6ef61805
6ef61805
6ed9c2a0
6ef61805
6ed9c2a0
=
struct umixed3 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
  unsigned short f:3;
  unsigned char  g:3;
  unsigned long  h;
};
-
{e=>7,a=>-103,d=>2,c=>7,h=>28,b=>4,g=>0,f=>0}
99bc0e001c000000
99bc0e00000000001c00000000000000
99bc0e00000000001c00000000000000
999d70000000001c
99bc0e001c000000
99bc0e001c000000
999d700000000000000000000000001c
99bc0e001c000000
999d70000000001c
-
{e=>1,a=>-118,d=>7,c=>2,h=>87,b=>6,g=>2,f=>7}
8ad6730257000000
8ad67302000000005700000000000000
8ad67302000000005700000000000000
8acb9e4000000057
8ad6730257000000
8ad6730257000000
8acb9e40000000000000000000000057
8ad6730257000000
8acb9e4000000057
-
{e=>0,a=>93,d=>0,c=>4,h=>190,b=>4,g=>2,f=>4}
5d244002be000000
5d24400200000000be00000000000000
5d24400200000000be00000000000000
5d900840000000be
5d244002be000000
5d244002be000000
5d9008400000000000000000000000be
5d244002be000000
5d900840000000be
-
{e=>4,a=>119,d=>3,c=>2,h=>230,b=>0,g=>6,f=>3}
77d03806e6000000
77d0380600000000e600000000000000
77d0380600000000e600000000000000
7709c6c0000000e6
77d03806e6000000
77d03806e6000000
7709c6c00000000000000000000000e6
77d03806e6000000
7709c6c0000000e6
-
{e=>5,a=>-101,d=>5,c=>7,h=>52,b=>3,g=>7,f=>4}
9b7b4b0734000000
9b7b4b07000000003400000000000000
9b7b4b07000000003400000000000000
9b7ed8e000000034
9b7b4b0734000000
9b7b4b0734000000
9b7ed8e0000000000000000000000034
9b7b4b0734000000
9b7ed8e000000034
=
struct umixed3 {
  short a;
  unsigned char  b:3;
};
-
{a=>117,b=>6}
75000600
75000600
75000600
0075c000
75000600
75000600
0075c000
75000600
0075c000
-
{a=>27,b=>7}
1b000700
1b000700
1b000700
001be000
1b000700
1b000700
001be000
1b000700
001be000
-
{a=>-51,b=>0}
cdff0000
cdff0000
cdff0000
ffcd0000
cdff0000
cdff0000
ffcd0000
cdff0000
ffcd0000
-
{a=>-8,b=>4}
f8ff0400
f8ff0400
f8ff0400
fff88000
f8ff0400
f8ff0400
fff88000
f8ff0400
fff88000
-
{a=>72,b=>7}
48000700
48000700
48000700
0048e000
48000700
48000700
0048e000
48000700
0048e000
=
struct umixed3 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>0,a=>-49,b=>3}
cfff0300
cfff0300
cfff0300
ffcf6000
cfff0300
cfff0300
ffcf6000
cfff0300
ffcf6000
-
{c=>4,a=>28,b=>7}
1c002700
1c002700
1c002700
001cf000
1c002700
1c002700
001cf000
1c002700
001cf000
-
{c=>2,a=>97,b=>5}
61001500
61001500
61001500
0061a800
61001500
61001500
0061a800
61001500
0061a800
-
{c=>3,a=>-123,b=>0}
85ff1800
85ff1800
85ff1800
ff850c00
85ff1800
85ff1800
ff850c00
85ff1800
ff850c00
-
{c=>3,a=>71,b=>7}
47001f00
47001f00
47001f00
0047ec00
47001f00
47001f00
0047ec00
47001f00
0047ec00
=
struct umixed3 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
};
-
{c=>6,a=>-55,b=>7,d=>2}
c9ffb700
c9ffb700
c9ffb700
ffc9f900
c9ffb700
c9ffb700
ffc9f900
c9ffb700
ffc9f900
-
{c=>4,a=>118,b=>0,d=>7}
7600e001
7600e001
7600e001
00761380
7600e001
7600e001
00761380
7600e001
00761380
-
{c=>4,a=>-56,b=>7,d=>0}
c8ff2700
c8ff2700
c8ff2700
ffc8f000
c8ff2700
c8ff2700
ffc8f000
c8ff2700
ffc8f000
-
{c=>1,a=>111,b=>5,d=>1}
6f004d00
6f004d00
6f004d00
006fa480
6f004d00
6f004d00
006fa480
6f004d00
006fa480
-
{c=>4,a=>-108,b=>3,d=>3}
94ffe300
94ffe300
94ffe300
ff947180
94ffe300
94ffe300
ff947180
94ffe300
ff947180
=
struct umixed3 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
};
-
{e=>2,c=>5,a=>2,b=>4,d=>4}
02002c05
02002c05
02002c05
00029620
02002c05
02002c05
00029620
02002c05
00029620
-
{e=>7,c=>2,a=>57,b=>2,d=>1}
3900520e
3900520e
3900520e
003948f0
3900520e
3900520e
003948f0
3900520e
003948f0
-
{e=>1,c=>6,a=>92,b=>1,d=>3}
5c00f102
5c00f102
5c00f102
005c3990
5c00f102
5c00f102
005c3990
5c00f102
005c3990
-
{e=>0,c=>1,a=>-36,b=>0,d=>2}
dcff8800
dcff8800
dcff8800
ffdc0500
dcff8800
dcff8800
ffdc0500
dcff8800
ffdc0500
-
{e=>1,c=>4,a=>-88,b=>1,d=>0}
a8ff2102
a8ff2102
a8ff2102
ffa83010
a8ff2102
a8ff2102
ffa83010
a8ff2102
ffa83010
=
struct umixed3 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
  unsigned short f:3;
};
-
{e=>0,c=>1,a=>-52,b=>6,d=>1,f=>6}
ccff4e60
ccff4e60
ccff4e60
ffccc48c
ccff4e60
ccff4e60
ffccc48c
ccff4e60
ffccc48c
-
{e=>3,c=>5,a=>-41,b=>2,d=>6,f=>0}
d7ffaa07
d7ffaa07
d7ffaa07
ffd75730
d7ffaa07
d7ffaa07
ffd75730
d7ffaa07
ffd75730
-
{e=>2,c=>3,a=>-90,b=>5,d=>7,f=>3}
a6ffdd35
a6ffdd35
a6ffdd35
ffa6afa6
a6ffdd35
a6ffdd35
ffa6afa6
a6ffdd35
ffa6afa6
-
{e=>1,c=>4,a=>6,b=>2,d=>4,f=>7}
06002273
06002273
06002273
0006521e
06002273
06002273
0006521e
06002273
0006521e
-
{e=>2,c=>4,a=>24,b=>4,d=>4,f=>7}
18002475
18002475
18002475
0018922e
18002475
18002475
0018922e
18002475
0018922e
=
struct umixed3 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
  unsigned short f:3;
  unsigned char  g:3;
};
-
{e=>4,c=>2,a=>-91,g=>7,b=>6,d=>2,f=>3}
a5ff963807000000
a5ff963807000000
a5ff963807000000
ffa5c946e0000000
a5ff963807000000
a5ff963807000000
ffa5c946e0000000
a5ff963807000000
ffa5c946e0000000
-
{e=>3,c=>0,a=>116,g=>7,b=>3,d=>7,f=>4}
7400c34707000000
7400c34707000000
7400c34707000000
007463b8e0000000
7400c34707000000
7400c34707000000
007463b8e0000000
7400c34707000000
007463b8e0000000
-
{e=>2,c=>7,a=>93,g=>4,b=>6,d=>6,f=>7}
5d00be7504000000
5d00be7504000000
5d00be7504000000
005ddf2e80000000
5d00be7504000000
5d00be7504000000
005ddf2e80000000
5d00be7504000000
005ddf2e80000000
-
{e=>2,c=>5,a=>108,g=>5,b=>4,d=>4,f=>2}
6c002c2505000000
6c002c2505000000
6c002c2505000000
006c9624a0000000
6c002c2505000000
6c002c2505000000
006c9624a0000000
6c002c2505000000
006c9624a0000000
-
{e=>4,c=>2,a=>-28,g=>3,b=>4,d=>2,f=>6}
e4ff946803000000
e4ff946803000000
e4ff946803000000
ffe4894c60000000
e4ff946803000000
e4ff946803000000
ffe4894c60000000
e4ff946803000000
ffe4894c60000000
=
struct umixed3 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
  unsigned short f:3;
  unsigned char  g:3;
  unsigned long  h;
};
-
{e=>4,a=>-83,d=>2,c=>5,h=>218,b=>0,g=>2,f=>5}
adffa85802000000da000000
adffa85802000000da00000000000000
adffa85802000000da00000000000000
ffad154a40000000000000da
adffa85802000000da000000
adffa85802000000da000000
ffad154a4000000000000000000000da
adffa85802000000da000000
ffad154a40000000000000da
-
{e=>2,a=>12,d=>1,c=>2,h=>88,b=>2,g=>6,f=>2}
0c0052240600000058000000
0c005224060000005800000000000000
0c005224060000005800000000000000
000c48a4c000000000000058
0c0052240600000058000000
0c0052240600000058000000
000c48a4c00000000000000000000058
0c0052240600000058000000
000c48a4c000000000000058
-
{e=>1,a=>-57,d=>1,c=>1,h=>75,b=>1,g=>4,f=>3}
c7ff4932040000004b000000
c7ff4932040000004b00000000000000
c7ff4932040000004b00000000000000
ffc72496800000000000004b
c7ff4932040000004b000000
c7ff4932040000004b000000
ffc7249680000000000000000000004b
c7ff4932040000004b000000
ffc72496800000000000004b
-
{e=>7,a=>17,d=>6,c=>0,h=>143,b=>5,g=>4,f=>1}
1100851f040000008f000000
1100851f040000008f00000000000000
1100851f040000008f00000000000000
0011a372800000000000008f
1100851f040000008f000000
1100851f040000008f000000
0011a37280000000000000000000008f
1100851f040000008f000000
0011a372800000000000008f
-
{e=>1,a=>10,d=>6,c=>1,h=>73,b=>1,g=>0,f=>6}
0a0089630000000049000000
0a008963000000004900000000000000
0a008963000000004900000000000000
000a271c0000000000000049
0a0089630000000049000000
0a0089630000000049000000
000a271c000000000000000000000049
0a0089630000000049000000
000a271c0000000000000049
=
struct umixed3 {
  int a;
  unsigned char  b:3;
};
-
{a=>-62,b=>6}
c2ffffff06000000
c2ffffff06000000
c2ffffff06000000
ffffffc2c0000000
c2ffffff06000000
c2ffffff06000000
ffffffc2c0000000
c2ffffff06000000
ffffffc2c0000000
-
{a=>-53,b=>2}
cbffffff02000000
cbffffff02000000
cbffffff02000000
ffffffcb40000000
cbffffff02000000
cbffffff02000000
ffffffcb40000000
cbffffff02000000
ffffffcb40000000
-
{a=>118,b=>0}
7600000000000000
7600000000000000
7600000000000000
0000007600000000
7600000000000000
7600000000000000
0000007600000000
7600000000000000
0000007600000000
-
{a=>59,b=>0}
3b00000000000000
3b00000000000000
3b00000000000000
0000003b00000000
3b00000000000000
3b00000000000000
0000003b00000000
3b00000000000000
0000003b00000000
-
{a=>-20,b=>1}
ecffffff01000000
ecffffff01000000
ecffffff01000000
ffffffec20000000
ecffffff01000000
ecffffff01000000
ffffffec20000000
ecffffff01000000
ffffffec20000000
=
struct umixed3 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>5,a=>-62,b=>7}
c2ffffff2f000000
c2ffffff2f000000
c2ffffff2f000000
ffffffc2f4000000
c2ffffff2f000000
c2ffffff2f000000
ffffffc2f4000000
c2ffffff2f000000
ffffffc2f4000000
-
{c=>6,a=>-14,b=>1}
f2ffffff31000000
f2ffffff31000000
f2ffffff31000000
fffffff238000000
f2ffffff31000000
f2ffffff31000000
fffffff238000000
f2ffffff31000000
fffffff238000000
-
{c=>6,a=>63,b=>7}
3f00000037000000
3f00000037000000
3f00000037000000
0000003ff8000000
3f00000037000000
3f00000037000000
0000003ff8000000
3f00000037000000
0000003ff8000000
-
{c=>3,a=>41,b=>2}
290000001a000000
290000001a000000
290000001a000000
000000294c000000
290000001a000000
290000001a000000
000000294c000000
290000001a000000
000000294c000000
-
{c=>7,a=>18,b=>2}
120000003a000000
120000003a000000
120000003a000000
000000125c000000
120000003a000000
120000003a000000
000000125c000000
120000003a000000
000000125c000000
=
struct umixed3 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
};
-
{c=>5,a=>75,b=>4,d=>6}
4b000000ac010000
4b000000ac010000
4b000000ac010000
0000004b97000000
4b000000ac010000
4b000000ac010000
0000004b97000000
4b000000ac010000
0000004b97000000
-
{c=>0,a=>117,b=>6,d=>0}
7500000006000000
7500000006000000
7500000006000000
00000075c0000000
7500000006000000
7500000006000000
00000075c0000000
7500000006000000
00000075c0000000
-
{c=>2,a=>-47,b=>1,d=>6}
d1ffffff91010000
d1ffffff91010000
d1ffffff91010000
ffffffd12b000000
d1ffffff91010000
d1ffffff91010000
ffffffd12b000000
d1ffffff91010000
ffffffd12b000000
-
{c=>4,a=>-11,b=>0,d=>3}
f5ffffffe0000000
f5ffffffe0000000
f5ffffffe0000000
fffffff511800000
f5ffffffe0000000
f5ffffffe0000000
fffffff511800000
f5ffffffe0000000
fffffff511800000
-
{c=>1,a=>64,b=>7,d=>5}
400000004f010000
400000004f010000
400000004f010000
00000040e6800000
400000004f010000
400000004f010000
00000040e6800000
400000004f010000
00000040e6800000
=
struct umixed3 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
};
-
{e=>1,c=>3,a=>-106,b=>7,d=>0}
96ffffff1f020000
96ffffff1f020000
96ffffff1f020000
ffffff96ec100000
96ffffff1f020000
96ffffff1f020000
ffffff96ec100000
96ffffff1f020000
ffffff96ec100000
-
{e=>5,c=>5,a=>-62,b=>1,d=>2}
c2ffffffa90a0000
c2ffffffa90a0000
c2ffffffa90a0000
ffffffc235500000
c2ffffffa90a0000
c2ffffffa90a0000
ffffffc235500000
c2ffffffa90a0000
ffffffc235500000
-
{e=>6,c=>2,a=>-4,b=>4,d=>4}
fcffffff140d0000
fcffffff140d0000
fcffffff140d0000
fffffffc8a600000
fcffffff140d0000
fcffffff140d0000
fffffffc8a600000
fcffffff140d0000
fffffffc8a600000
-
{e=>5,c=>7,a=>-93,b=>4,d=>2}
a3ffffffbc0a0000
a3ffffffbc0a0000
a3ffffffbc0a0000
ffffffa39d500000
a3ffffffbc0a0000
a3ffffffbc0a0000
ffffffa39d500000
a3ffffffbc0a0000
ffffffa39d500000
-
{e=>7,c=>3,a=>67,b=>3,d=>2}
430000009b0e0000
430000009b0e0000
430000009b0e0000
000000436d700000
430000009b0e0000
430000009b0e0000
000000436d700000
430000009b0e0000
000000436d700000
=
struct umixed3 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
  unsigned short f:3;
};
-
{e=>2,c=>6,a=>83,b=>3,d=>5,f=>4}
5300000073450000
5300000073450000
5300000073450000
000000537aa80000
5300000073450000
5300000073450000
000000537aa80000
5300000073450000
000000537aa80000
-
{e=>0,c=>5,a=>121,b=>1,d=>7,f=>3}
79000000e9310000
79000000e9310000
79000000e9310000
0000007937860000
79000000e9310000
79000000e9310000
0000007937860000
79000000e9310000
0000007937860000
-
{e=>7,c=>2,a=>-79,b=>3,d=>7,f=>1}
b1ffffffd31f0000
b1ffffffd31f0000
b1ffffffd31f0000
ffffffb16bf20000
b1ffffffd31f0000
b1ffffffd31f0000
ffffffb16bf20000
b1ffffffd31f0000
ffffffb16bf20000
-
{e=>4,c=>0,a=>-82,b=>1,d=>3,f=>3}
aeffffffc1380000
aeffffffc1380000
aeffffffc1380000
ffffffae21c60000
aeffffffc1380000
aeffffffc1380000
ffffffae21c60000
aeffffffc1380000
ffffffae21c60000
-
{e=>3,c=>4,a=>32,b=>4,d=>6,f=>0}
20000000a4070000
20000000a4070000
20000000a4070000
0000002093300000
20000000a4070000
20000000a4070000
0000002093300000
20000000a4070000
0000002093300000
=
struct umixed3 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
  unsigned short f:3;
  unsigned char  g:3;
};
-
{e=>7,c=>4,a=>-119,g=>7,b=>6,d=>2,f=>5}
89ffffffa65e0700
89ffffffa65e0700
89ffffffa65e0700
ffffff89d17ae000
89ffffffa65e0700
89ffffffa65e0700
ffffff89d17ae000
89ffffffa65e0700
ffffff89d17ae000
-
{e=>4,c=>7,a=>75,g=>5,b=>7,d=>2,f=>3}
4b000000bf380500
4b000000bf380500
4b000000bf380500
0000004bfd46a000
4b000000bf380500
4b000000bf380500
0000004bfd46a000
4b000000bf380500
0000004bfd46a000
-
{e=>1,c=>0,a=>-122,g=>5,b=>5,d=>2,f=>1}
86ffffff85120500
86ffffff85120500
86ffffff85120500
ffffff86a112a000
86ffffff85120500
86ffffff85120500
ffffff86a112a000
86ffffff85120500
ffffff86a112a000
-
{e=>7,c=>6,a=>-118,g=>7,b=>5,d=>1,f=>3}
8affffff753e0700
8affffff753e0700
8affffff753e0700
ffffff8ab8f6e000
8affffff753e0700
8affffff753e0700
ffffff8ab8f6e000
8affffff753e0700
ffffff8ab8f6e000
-
{e=>6,c=>5,a=>-69,g=>0,b=>7,d=>1,f=>1}
bbffffff6f1c0000
bbffffff6f1c0000
bbffffff6f1c0000
ffffffbbf4e20000
bbffffff6f1c0000
bbffffff6f1c0000
ffffffbbf4e20000
bbffffff6f1c0000
ffffffbbf4e20000
=
struct umixed3 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
  unsigned short f:3;
  unsigned char  g:3;
  unsigned long  h;
};
-
{e=>7,a=>22,d=>3,c=>6,h=>27,b=>7,g=>2,f=>4}
16000000f74e02001b000000
16000000f74e02001b00000000000000
16000000f74e02001b00000000000000
00000016f9f840000000001b
16000000f74e02001b000000
16000000f74e02001b000000
00000016f9f84000000000000000001b
16000000f74e02001b000000
00000016f9f840000000001b
-
{e=>0,a=>-54,d=>1,c=>7,h=>112,b=>1,g=>4,f=>2}
caffffff7920040070000000
caffffff792004007000000000000000
caffffff792004007000000000000000
ffffffca3c84800000000070
caffffff7920040070000000
caffffff7920040070000000
ffffffca3c8480000000000000000070
caffffff7920040070000000
ffffffca3c84800000000070
-
{e=>7,a=>1,d=>5,c=>7,h=>4,b=>5,g=>5,f=>4}
010000007d4f050004000000
010000007d4f05000400000000000000
010000007d4f05000400000000000000
00000001bef8a00000000004
010000007d4f050004000000
010000007d4f050004000000
00000001bef8a0000000000000000004
010000007d4f050004000000
00000001bef8a00000000004
-
{e=>2,a=>10,d=>0,c=>1,h=>37,b=>2,g=>4,f=>7}
0a0000000a74040025000000
0a0000000a7404002500000000000000
0a0000000a7404002500000000000000
0000000a442e800000000025
0a0000000a74040025000000
0a0000000a74040025000000
0000000a442e80000000000000000025
0a0000000a74040025000000
0000000a442e800000000025
-
{e=>4,a=>-17,d=>3,c=>0,h=>76,b=>4,g=>0,f=>6}
efffffffc46800004c000000
efffffffc46800004c00000000000000
efffffffc46800004c00000000000000
ffffffef81cc00000000004c
efffffffc46800004c000000
efffffffc46800004c000000
ffffffef81cc0000000000000000004c
efffffffc46800004c000000
ffffffef81cc00000000004c
=
struct umixed3 {
  long a;
  unsigned char  b:3;
};
-
{a=>83,b=>2}
5300000002000000
53000000000000000200000000000000
53000000000000000200000000000000
0000005340000000
5300000002000000
5300000002000000
00000000000000534000000000000000
5300000002000000
0000005340000000
-
{a=>21,b=>7}
1500000007000000
15000000000000000700000000000000
15000000000000000700000000000000
00000015e0000000
1500000007000000
1500000007000000
0000000000000015e000000000000000
1500000007000000
00000015e0000000
-
{a=>-112,b=>2}
90ffffff02000000
90ffffffffffffff0200000000000000
90ffffffffffffff0200000000000000
ffffff9040000000
90ffffff02000000
90ffffff02000000
ffffffffffffff904000000000000000
90ffffff02000000
ffffff9040000000
-
{a=>56,b=>1}
3800000001000000
38000000000000000100000000000000
38000000000000000100000000000000
0000003820000000
3800000001000000
3800000001000000
00000000000000382000000000000000
3800000001000000
0000003820000000
-
{a=>-36,b=>0}
dcffffff00000000
dcffffffffffffff0000000000000000
dcffffffffffffff0000000000000000
ffffffdc00000000
dcffffff00000000
dcffffff00000000
ffffffffffffffdc0000000000000000
dcffffff00000000
ffffffdc00000000
=
struct umixed3 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>5,a=>-25,b=>4}
e7ffffff2c000000
e7ffffffffffffff2c00000000000000
e7ffffffffffffff2c00000000000000
ffffffe794000000
e7ffffff2c000000
e7ffffff2c000000
ffffffffffffffe79400000000000000
e7ffffff2c000000
ffffffe794000000
-
{c=>4,a=>-122,b=>2}
86ffffff22000000
86ffffffffffffff2200000000000000
86ffffffffffffff2200000000000000
ffffff8650000000
86ffffff22000000
86ffffff22000000
ffffffffffffff865000000000000000
86ffffff22000000
ffffff8650000000
-
{c=>1,a=>-102,b=>1}
9affffff09000000
9affffffffffffff0900000000000000
9affffffffffffff0900000000000000
ffffff9a24000000
9affffff09000000
9affffff09000000
ffffffffffffff9a2400000000000000
9affffff09000000
ffffff9a24000000
-
{c=>4,a=>2,b=>3}
0200000023000000
02000000000000002300000000000000
02000000000000002300000000000000
0000000270000000
0200000023000000
0200000023000000
00000000000000027000000000000000
0200000023000000
0000000270000000
-
{c=>4,a=>120,b=>2}
7800000022000000
78000000000000002200000000000000
78000000000000002200000000000000
0000007850000000
7800000022000000
7800000022000000
00000000000000785000000000000000
7800000022000000
0000007850000000
=
struct umixed3 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
};
-
{c=>5,a=>-39,b=>2,d=>0}
d9ffffff2a000000
d9ffffffffffffff2a00000000000000
d9ffffffffffffff2a00000000000000
ffffffd954000000
d9ffffff2a000000
d9ffffff2a000000
ffffffffffffffd95400000000000000
d9ffffff2a000000
ffffffd954000000
-
{c=>3,a=>-53,b=>0,d=>4}
cbffffff18010000
cbffffffffffffff1801000000000000
cbffffffffffffff1801000000000000
ffffffcb0e000000
cbffffff18010000
cbffffff18010000
ffffffffffffffcb0e00000000000000
cbffffff18010000
ffffffcb0e000000
-
{c=>5,a=>-104,b=>4,d=>7}
98ffffffec010000
98ffffffffffffffec01000000000000
98ffffffffffffffec01000000000000
ffffff9897800000
98ffffffec010000
98ffffffec010000
ffffffffffffff989780000000000000
98ffffffec010000
ffffff9897800000
-
{c=>6,a=>-123,b=>4,d=>2}
85ffffffb4000000
85ffffffffffffffb400000000000000
85ffffffffffffffb400000000000000
ffffff8599000000
85ffffffb4000000
85ffffffb4000000
ffffffffffffff859900000000000000
85ffffffb4000000
ffffff8599000000
-
{c=>3,a=>-127,b=>3,d=>6}
81ffffff9b010000
81ffffffffffffff9b01000000000000
81ffffffffffffff9b01000000000000
ffffff816f000000
81ffffff9b010000
81ffffff9b010000
ffffffffffffff816f00000000000000
81ffffff9b010000
ffffff816f000000
=
struct umixed3 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
};
-
{e=>6,c=>5,a=>61,b=>1,d=>1}
3d000000690c0000
3d00000000000000690c000000000000
3d00000000000000690c000000000000
0000003d34e00000
3d000000690c0000
3d000000690c0000
000000000000003d34e0000000000000
3d000000690c0000
0000003d34e00000
-
{e=>7,c=>2,a=>72,b=>7,d=>7}
48000000d70f0000
4800000000000000d70f000000000000
4800000000000000d70f000000000000
00000048ebf00000
48000000d70f0000
48000000d70f0000
0000000000000048ebf0000000000000
48000000d70f0000
00000048ebf00000
-
{e=>6,c=>1,a=>33,b=>1,d=>5}
21000000490d0000
2100000000000000490d000000000000
2100000000000000490d000000000000
0000002126e00000
21000000490d0000
21000000490d0000
000000000000002126e0000000000000
21000000490d0000
0000002126e00000
-
{e=>1,c=>5,a=>59,b=>3,d=>6}
3b000000ab030000
3b00000000000000ab03000000000000
3b00000000000000ab03000000000000
0000003b77100000
3b000000ab030000
3b000000ab030000
000000000000003b7710000000000000
3b000000ab030000
0000003b77100000
-
{e=>5,c=>7,a=>-74,b=>4,d=>1}
b6ffffff7c0a0000
b6ffffffffffffff7c0a000000000000
b6ffffffffffffff7c0a000000000000
ffffffb69cd00000
b6ffffff7c0a0000
b6ffffff7c0a0000
ffffffffffffffb69cd0000000000000
b6ffffff7c0a0000
ffffffb69cd00000
=
struct umixed3 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
  unsigned short f:3;
};
-
{e=>2,c=>0,a=>72,b=>0,d=>6,f=>6}
4800000080650000
48000000000000008065000000000000
48000000000000008065000000000000
00000048032c0000
4800000080650000
4800000080650000
0000000000000048032c000000000000
4800000080650000
00000048032c0000
-
{e=>1,c=>6,a=>-5,b=>3,d=>2,f=>4}
fbffffffb3420000
fbffffffffffffffb342000000000000
fbffffffffffffffb342000000000000
fffffffb79180000
fbffffffb3420000
fbffffffb3420000
fffffffffffffffb7918000000000000
fbffffffb3420000
fffffffb79180000
-
{e=>3,c=>4,a=>-25,b=>7,d=>2,f=>1}
e7ffffffa7160000
e7ffffffffffffffa716000000000000
e7ffffffffffffffa716000000000000
ffffffe7f1320000
e7ffffffa7160000
e7ffffffa7160000
ffffffffffffffe7f132000000000000
e7ffffffa7160000
ffffffe7f1320000
-
{e=>6,c=>2,a=>127,b=>5,d=>2,f=>0}
7f000000950c0000
7f00000000000000950c000000000000
7f00000000000000950c000000000000
0000007fa9600000
7f000000950c0000
7f000000950c0000
000000000000007fa960000000000000
7f000000950c0000
0000007fa9600000
-
{e=>1,c=>2,a=>-28,b=>2,d=>6,f=>6}
e4ffffff92630000
e4ffffffffffffff9263000000000000
e4ffffffffffffff9263000000000000
ffffffe44b1c0000
e4ffffff92630000
e4ffffff92630000
ffffffffffffffe44b1c000000000000
e4ffffff92630000
ffffffe44b1c0000
=
struct umixed3 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
  unsigned short f:3;
  unsigned char  g:3;
};
-
{e=>5,c=>0,a=>-20,g=>4,b=>1,d=>6,f=>7}
ecffffff817b0400
ecffffffffffffff817b040000000000
ecffffffffffffff817b040000000000
ffffffec235e8000
ecffffff817b0400
ecffffff817b0400
ffffffffffffffec235e800000000000
ecffffff817b0400
ffffffec235e8000
-
{e=>6,c=>7,a=>89,g=>0,b=>6,d=>5,f=>4}
590000007e4d0000
59000000000000007e4d000000000000
59000000000000007e4d000000000000
00000059dee80000
590000007e4d0000
590000007e4d0000
0000000000000059dee8000000000000
590000007e4d0000
00000059dee80000
-
{e=>2,c=>7,a=>75,g=>1,b=>0,d=>5,f=>5}
4b00000078550100
4b000000000000007855010000000000
4b000000000000007855010000000000
0000004b1eaa2000
4b00000078550100
4b00000078550100
000000000000004b1eaa200000000000
4b00000078550100
0000004b1eaa2000
-
{e=>5,c=>6,a=>-7,g=>2,b=>2,d=>4,f=>2}
f9ffffff322b0200
f9ffffffffffffff322b020000000000
f9ffffffffffffff322b020000000000
fffffff95a544000
f9ffffff322b0200
f9ffffff322b0200
fffffffffffffff95a54400000000000
f9ffffff322b0200
fffffff95a544000
-
{e=>0,c=>5,a=>-93,g=>6,b=>5,d=>1,f=>2}
a3ffffff6d200600
a3ffffffffffffff6d20060000000000
a3ffffffffffffff6d20060000000000
ffffffa3b484c000
a3ffffff6d200600
a3ffffff6d200600
ffffffffffffffa3b484c00000000000
a3ffffff6d200600
ffffffa3b484c000
=
struct umixed3 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned int   d:3;
  unsigned char  e:3;
  unsigned short f:3;
  unsigned char  g:3;
  unsigned long  h;
};
-
{e=>7,a=>-73,d=>5,c=>2,h=>27,b=>3,g=>0,f=>5}
b7ffffff535f00001b000000
b7ffffffffffffff535f0000000000001b00000000000000
b7ffffffffffffff535f0000000000001b00000000000000
ffffffb76afa00000000001b
b7ffffff535f00001b000000
b7ffffff535f00001b000000
ffffffffffffffb76afa000000000000000000000000001b
b7ffffff535f00001b000000
ffffffb76afa00000000001b
-
{e=>5,a=>-115,d=>0,c=>4,h=>51,b=>2,g=>3,f=>6}
8dffffff226a030033000000
8dffffffffffffff226a0300000000003300000000000000
8dffffffffffffff226a0300000000003300000000000000
ffffff8d505c600000000033
8dffffff226a030033000000
8dffffff226a030033000000
ffffffffffffff8d505c6000000000000000000000000033
8dffffff226a030033000000
ffffff8d505c600000000033
-
{e=>4,a=>20,d=>0,c=>2,h=>56,b=>5,g=>7,f=>4}
140000001548070038000000
140000000000000015480700000000003800000000000000
140000000000000015480700000000003800000000000000
00000014a848e00000000038
140000001548070038000000
140000001548070038000000
0000000000000014a848e000000000000000000000000038
140000001548070038000000
00000014a848e00000000038
-
{e=>6,a=>115,d=>7,c=>2,h=>157,b=>2,g=>0,f=>3}
73000000d23d00009d000000
7300000000000000d23d0000000000009d00000000000000
7300000000000000d23d0000000000009d00000000000000
000000734be600000000009d
73000000d23d00009d000000
73000000d23d00009d000000
00000000000000734be6000000000000000000000000009d
73000000d23d00009d000000
000000734be600000000009d
-
{e=>1,a=>101,d=>4,c=>2,h=>189,b=>7,g=>1,f=>6}
6500000017630100bd000000
65000000000000001763010000000000bd00000000000000
65000000000000001763010000000000bd00000000000000
00000065ea1c2000000000bd
6500000017630100bd000000
6500000017630100bd000000
0000000000000065ea1c20000000000000000000000000bd
6500000017630100bd000000
00000065ea1c2000000000bd
=
struct umixed_no_pack {
  unsigned char  a:3;
};
-
{a=>2}
02
02
02
40
02000000
02
40
02
40
-
{a=>3}
03
03
03
60
03000000
03
60
03
60
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>6}
06
06
06
c0
06000000
06
c0
06
c0
-
{a=>5}
05
05
05
a0
05000000
05
a0
05
a0
=
struct umixed_no_pack {
  unsigned char  a:3;
  unsigned char  b:3;
};
-
{a=>3,b=>4}
23
23
23
70
23000000
23
70
23
70
-
{a=>4,b=>4}
24
24
24
90
24000000
24
90
24
90
-
{a=>0,b=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>6,b=>0}
06
06
06
c0
06000000
06
c0
06
c0
-
{a=>7,b=>2}
17
17
17
e8
17000000
17
e8
17
e8
=
struct umixed_no_pack {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
};
-
{c=>2,a=>4,b=>5}
ac00
ac00
ac00
9500
ac000000
ac00
9500
ac00
9500
-
{c=>6,a=>2,b=>7}
ba01
ba01
ba01
5f00
ba010000
ba01
5f00
ba01
5f00
-
{c=>5,a=>1,b=>5}
6901
6901
6901
3680
69010000
6901
3680
6901
3680
-
{c=>5,a=>1,b=>5}
6901
6901
6901
3680
69010000
6901
3680
6901
3680
-
{c=>6,a=>2,b=>0}
8201
8201
8201
4300
82010000
8201
4300
8201
4300
=
struct umixed_no_pack {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
};
-
{c=>2,a=>3,b=>4,d=>16659437}
a3000000ed33fe00
a3000000ed33fe00
a3000000ed33fe00
710000000fe33ed0
a3000000ed33fe00
a3000000ed33fe00
710000000fe33ed0
a3000000ed33fe00
710000000fe33ed0
-
{c=>7,a=>2,b=>3,d=>201260983}
da010000b7fffe0b
da010000b7fffe0b
da010000b7fffe0b
4f800000bfeffb70
da010000b7fffe0b
da010000b7fffe0b
4f800000bfeffb70
da010000b7fffe0b
4f800000bfeffb70
-
{c=>1,a=>6,b=>3,d=>256219575}
5e000000b799450f
5e000000b799450f
5e000000b799450f
cc800000f4599b70
5e000000b799450f
5e000000b799450f
cc800000f4599b70
5e000000b799450f
cc800000f4599b70
-
{c=>7,a=>6,b=>0,d=>55997687}
c6010000f7745603
c6010000f7745603
c6010000f7745603
c380000035674f70
c6010000f7745603
c6010000f7745603
c380000035674f70
c6010000f7745603
c380000035674f70
-
{c=>2,a=>4,b=>4,d=>103672891}
a40000003bec2d06
a40000003bec2d06
a40000003bec2d06
9100000062dec3b0
a40000003bec2d06
a40000003bec2d06
9100000062dec3b0
a40000003bec2d06
9100000062dec3b0
=
struct umixed_no_pack {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
};
-
{e=>4,c=>3,a=>3,b=>1,d=>63303944}
cb00000008f1c543
cb00000008f1c543
cb00000008f1c543
658000003c5f1088
cb00000008f1c543
cb00000008f1c543
658000003c5f1088
cb00000008f1c543
658000003c5f1088
-
{e=>6,c=>1,a=>7,b=>5,d=>115286698}
6f000000aa22df66
6f000000aa22df66
6f000000aa22df66
f48000006df22aac
6f000000aa22df66
6f000000aa22df66
f48000006df22aac
6f000000aa22df66
f48000006df22aac
-
{e=>5,c=>7,a=>5,b=>1,d=>33758906}
cd010000ba1e0352
cd010000ba1e0352
cd010000ba1e0352
a78000002031ebaa
cd010000ba1e0352
cd010000ba1e0352
a78000002031ebaa
cd010000ba1e0352
a78000002031ebaa
-
{e=>1,c=>7,a=>2,b=>1,d=>75998826}
ca0100006aa68714
ca0100006aa68714
ca0100006aa68714
47800000487a66a2
ca0100006aa68714
ca0100006aa68714
47800000487a66a2
ca0100006aa68714
47800000487a66a2
-
{e=>0,c=>4,a=>2,b=>7,d=>23580046}
3a0100008ecd6701
3a0100008ecd6701
3a0100008ecd6701
5e000000167cd8e0
3a0100008ecd6701
3a0100008ecd6701
5e000000167cd8e0
3a0100008ecd6701
5e000000167cd8e0
=
struct umixed_no_pack {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
  unsigned char  f:2;
};
-
{e=>1,c=>0,a=>2,b=>7,d=>158148049,f=>0}
3a000000d1256d1900000000
3a000000d1256d1900000000
3a000000d1256d1900000000
5c00000096d25d1200000000
3a000000d1256d1900000000
3a000000d1256d1900000000
5c00000096d25d1200000000
3a000000d1256d1900000000
5c00000096d25d1200000000
-
{e=>3,c=>1,a=>1,b=>7,d=>228592629,f=>0}
79000000f50ba03d00000000
79000000f50ba03d00000000
79000000f50ba03d00000000
3c800000da00bf5600000000
79000000f50ba03d00000000
79000000f50ba03d00000000
3c800000da00bf5600000000
79000000f50ba03d00000000
3c800000da00bf5600000000
-
{e=>6,c=>5,a=>5,b=>6,d=>13400160,f=>0}
750100006078cc6000000000
750100006078cc6000000000
750100006078cc6000000000
ba8000000cc7860c00000000
750100006078cc6000000000
750100006078cc6000000000
ba8000000cc7860c00000000
750100006078cc6000000000
ba8000000cc7860c00000000
-
{e=>1,c=>2,a=>1,b=>1,d=>252868262,f=>3}
89000000a676121f03000000
89000000a676121f03000000
89000000a676121f03000000
25000000f1276a62c0000000
89000000a676121f03000000
89000000a676121f03000000
25000000f1276a62c0000000
89000000a676121f03000000
25000000f1276a62c0000000
-
{e=>6,c=>3,a=>3,b=>0,d=>45793175,f=>0}
c300000097bfba6200000000
c300000097bfba6200000000
c300000097bfba6200000000
618000002babf97c00000000
c300000097bfba6200000000
c300000097bfba6200000000
618000002babf97c00000000
c300000097bfba6200000000
618000002babf97c00000000
=
struct umixed_no_pack {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
  unsigned char  f:2;
  unsigned short g:13;
};
-
{e=>1,c=>2,a=>6,g=>1699,b=>6,d=>41631336,f=>2}
b6000000683e7b128e1a0000
b6000000683e7b128e1a0000
b6000000683e7b128e1a0000
d900000027b3e6828d460000
b6000000683e7b128e1a0000
b6000000683e7b128e1a0000
d900000027b3e6828d460000
b6000000683e7b128e1a0000
d900000027b3e6828d460000
-
{e=>2,c=>0,a=>2,g=>602,b=>2,d=>186423654,f=>2}
1200000066991c2b6a090000
1200000066991c2b6a090000
1200000066991c2b6a090000
48000000b1c9966484b40000
1200000066991c2b6a090000
1200000066991c2b6a090000
48000000b1c9966484b40000
1200000066991c2b6a090000
48000000b1c9966484b40000
-
{e=>2,c=>7,a=>4,g=>6342,b=>7,d=>247473427,f=>2}
fc0100001325c02e1a630000
fc0100001325c02e1a630000
fc0100001325c02e1a630000
9f800000ec025134b18c0000
fc0100001325c02e1a630000
fc0100001325c02e1a630000
9f800000ec025134b18c0000
fc0100001325c02e1a630000
9f800000ec025134b18c0000
-
{e=>5,c=>7,a=>4,g=>2765,b=>7,d=>238172392,f=>1}
fc010000e838325e352b0000
fc010000e838325e352b0000
fc010000e838325e352b0000
9f800000e3238e8a559a0000
fc010000e838325e352b0000
fc010000e838325e352b0000
9f800000e3238e8a559a0000
fc010000e838325e352b0000
9f800000e3238e8a559a0000
-
{e=>1,c=>7,a=>1,g=>5584,b=>7,d=>2742541,f=>3}
f90100000dd9291043570000
f90100000dd9291043570000
f90100000dd9291043570000
3f800000029d90d2eba00000
f90100000dd9291043570000
f90100000dd9291043570000
3f800000029d90d2eba00000
f90100000dd9291043570000
3f800000029d90d2eba00000
=
struct umixed_no_pack {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
  unsigned char  f:2;
  unsigned short g:13;
  signed   int   h;
};
-
{e=>5,a=>0,d=>63927408,c=>7,h=>-86,b=>6,g=>5835,f=>1}
f00100007074cf532d5b0000aaffffff
f00100007074cf532d5b0000aaffffff
f00100007074cf532d5b0000aaffffff
1b8000003cf7470a6d960000ffffffaa
f00100007074cf532d5b0000aaffffff
f00100007074cf532d5b0000aaffffff
1b8000003cf7470a6d960000ffffffaa
f00100007074cf532d5b0000aaffffff
1b8000003cf7470a6d960000ffffffaa
-
{e=>7,a=>3,d=>165783275,c=>6,h=>-85,b=>5,g=>3147,f=>0}
ab010000eba6e1792c310000abffffff
ab010000eba6e1792c310000abffffff
ab010000eba6e1792c310000abffffff
770000009e1a6ebe18960000ffffffab
ab010000eba6e1792c310000abffffff
ab010000eba6e1792c310000abffffff
770000009e1a6ebe18960000ffffffab
ab010000eba6e1792c310000abffffff
770000009e1a6ebe18960000ffffffab
-
{e=>7,a=>0,d=>262181766,c=>7,h=>-76,b=>2,g=>3227,f=>0}
d00100008693a07f6c320000b4ffffff
d00100008693a07f6c320000b4ffffff
d00100008693a07f6c320000b4ffffff
0b800000fa09386e19360000ffffffb4
d00100008693a07f6c320000b4ffffff
d00100008693a07f6c320000b4ffffff
0b800000fa09386e19360000ffffffb4
d00100008693a07f6c320000b4ffffff
0b800000fa09386e19360000ffffffb4
-
{e=>2,a=>1,d=>258295770,c=>1,h=>-44,b=>2,g=>2696,f=>2}
51000000da47652f222a0000d4ffffff
51000000da47652f222a0000d4ffffff
51000000da47652f222a0000d4ffffff
28800000f6547da495100000ffffffd4
51000000da47652f222a0000d4ffffff
51000000da47652f222a0000d4ffffff
28800000f6547da495100000ffffffd4
51000000da47652f222a0000d4ffffff
28800000f6547da495100000ffffffd4
-
{e=>6,a=>7,d=>149674579,c=>6,h=>44,b=>7,g=>3480,f=>1}
bf01000053daeb68613600002c000000
bf01000053daeb68613600002c000000
bf01000053daeb68613600002c000000
ff0000008ebda53c5b3000000000002c
bf01000053daeb68613600002c000000
bf01000053daeb68613600002c000000
ff0000008ebda53c5b3000000000002c
bf01000053daeb68613600002c000000
ff0000008ebda53c5b3000000000002c
=
struct umixed_no_pack {
  char a;
  unsigned char  b:3;
};
-
{a=>18,b=>7}
1207
1207
1207
12e0
12070000
1207
12e0
1207
12e0
-
{a=>-34,b=>4}
de04
de04
de04
de80
de040000
de04
de80
de04
de80
-
{a=>-63,b=>4}
c104
c104
c104
c180
c1040000
c104
c180
c104
c180
-
{a=>-10,b=>4}
f604
f604
f604
f680
f6040000
f604
f680
f604
f680
-
{a=>117,b=>1}
7501
7501
7501
7520
75010000
7501
7520
7501
7520
=
struct umixed_no_pack {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>4,a=>-68,b=>6}
bc26
bc26
bc26
bcd0
bc260000
bc26
bcd0
bc26
bcd0
-
{c=>7,a=>48,b=>6}
303e
303e
303e
30dc
303e0000
303e
30dc
303e
30dc
-
{c=>7,a=>124,b=>0}
7c38
7c38
7c38
7c1c
7c380000
7c38
7c1c
7c38
7c1c
-
{c=>7,a=>111,b=>4}
6f3c
6f3c
6f3c
6f9c
6f3c0000
6f3c
6f9c
6f3c
6f9c
-
{c=>5,a=>-83,b=>1}
ad29
ad29
ad29
ad34
ad290000
ad29
ad34
ad29
ad34
=
struct umixed_no_pack {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>2,a=>116,b=>6,d=>5}
74160500
74160500
74160500
74c8a000
74160500
74160500
74c8a000
74160500
74c8a000
-
{c=>0,a=>-85,b=>7,d=>7}
ab070700
ab070700
ab070700
abe0e000
ab070700
ab070700
abe0e000
ab070700
abe0e000
-
{c=>7,a=>13,b=>7,d=>6}
0d3f0600
0d3f0600
0d3f0600
0dfcc000
0d3f0600
0d3f0600
0dfcc000
0d3f0600
0dfcc000
-
{c=>6,a=>118,b=>4,d=>6}
76340600
76340600
76340600
7698c000
76340600
76340600
7698c000
76340600
7698c000
-
{c=>3,a=>59,b=>4,d=>5}
3b1c0500
3b1c0500
3b1c0500
3b8ca000
3b1c0500
3b1c0500
3b8ca000
3b1c0500
3b8ca000
=
struct umixed_no_pack {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>27672616,c=>4,a=>110,b=>5,d=>2}
6e2502002840a601
6e2502002840a601
6e2502002840a601
6eb040001a640280
6e2502002840a601
6e2502002840a601
6eb040001a640280
6e2502002840a601
6eb040001a640280
-
{e=>87433172,c=>4,a=>106,b=>7,d=>5}
6a270500d41f3605
6a270500d41f3605
6a270500d41f3605
6af0a0005361fd40
6a270500d41f3605
6a270500d41f3605
6af0a0005361fd40
6a270500d41f3605
6af0a0005361fd40
-
{e=>33757072,c=>4,a=>-72,b=>4,d=>2}
b824020090170302
b824020090170302
b824020090170302
b890400020317900
b824020090170302
b824020090170302
b890400020317900
b824020090170302
b890400020317900
-
{e=>12459290,c=>0,a=>49,b=>7,d=>0}
310700001a1dbe00
310700001a1dbe00
310700001a1dbe00
31e000000be1d1a0
310700001a1dbe00
310700001a1dbe00
31e000000be1d1a0
310700001a1dbe00
31e000000be1d1a0
-
{e=>265383931,c=>3,a=>-91,b=>4,d=>1}
a51c0100fb6fd10f
a51c0100fb6fd10f
a51c0100fb6fd10f
a58c2000fd16ffb0
a51c0100fb6fd10f
a51c0100fb6fd10f
a58c2000fd16ffb0
a51c0100fb6fd10f
a58c2000fd16ffb0
=
struct umixed_no_pack {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>121017809,c=>3,a=>-127,b=>5,d=>0,f=>6}
811d0000d1953667
811d0000d1953667
811d0000d1953667
81ac000073695d1c
811d0000d1953667
811d0000d1953667
81ac000073695d1c
811d0000d1953667
81ac000073695d1c
-
{e=>38181014,c=>5,a=>-86,b=>4,d=>3,f=>1}
aa2c030096984612
aa2c030096984612
aa2c030096984612
aa94600024698962
aa2c030096984612
aa2c030096984612
aa94600024698962
aa2c030096984612
aa94600024698962
-
{e=>206063701,c=>2,a=>-126,b=>5,d=>3,f=>4}
821503005548484c
821503005548484c
821503005548484c
82a86000c4848558
821503005548484c
821503005548484c
82a86000c4848558
821503005548484c
82a86000c4848558
-
{e=>102799155,c=>1,a=>-102,b=>5,d=>0,f=>1}
9a0d000033972016
9a0d000033972016
9a0d000033972016
9aa4000062097332
9a0d000033972016
9a0d000033972016
9aa4000062097332
9a0d000033972016
9aa4000062097332
-
{e=>35733158,c=>5,a=>48,b=>7,d=>5,f=>4}
302f0500a63e2142
302f0500a63e2142
302f0500a63e2142
30f4a0002213ea68
302f0500a63e2142
302f0500a63e2142
30f4a0002213ea68
302f0500a63e2142
30f4a0002213ea68
=
struct umixed_no_pack {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>259030873,c=>6,a=>-99,g=>3,b=>6,d=>6,f=>7}
9d360600597f707f03000000
9d360600597f707f03000000
9d360600597f707f03000000
9dd8c000f707f59ec0000000
9d360600597f707f03000000
9d360600597f707f03000000
9dd8c000f707f59ec0000000
9d360600597f707f03000000
9dd8c000f707f59ec0000000
-
{e=>113534093,c=>3,a=>-82,g=>1,b=>7,d=>1,f=>1}
ae1f01008d64c41601000000
ae1f01008d64c41601000000
ae1f01008d64c41601000000
aeec20006c4648d240000000
ae1f01008d64c41601000000
ae1f01008d64c41601000000
aeec20006c4648d240000000
ae1f01008d64c41601000000
aeec20006c4648d240000000
-
{e=>196254634,c=>6,a=>-82,g=>0,b=>2,d=>5,f=>3}
ae320500aa9bb23b00000000
ae320500aa9bb23b00000000
ae320500aa9bb23b00000000
ae58a000bb29baa600000000
ae320500aa9bb23b00000000
ae320500aa9bb23b00000000
ae58a000bb29baa600000000
ae320500aa9bb23b00000000
ae58a000bb29baa600000000
-
{e=>211207759,c=>7,a=>26,g=>3,b=>3,d=>6,f=>4}
1a3b06004fc6964c03000000
1a3b06004fc6964c03000000
1a3b06004fc6964c03000000
1a7cc000c96c64f8c0000000
1a3b06004fc6964c03000000
1a3b06004fc6964c03000000
1a7cc000c96c64f8c0000000
1a3b06004fc6964c03000000
1a7cc000c96c64f8c0000000
-
{e=>35365642,c=>5,a=>-40,g=>0,b=>6,d=>0,f=>6}
d82e00000aa31b6200000000
d82e00000aa31b6200000000
d82e00000aa31b6200000000
d8d4000021ba30ac00000000
d82e00000aa31b6200000000
d82e00000aa31b6200000000
d8d4000021ba30ac00000000
d82e00000aa31b6200000000
d8d4000021ba30ac00000000
=
struct umixed_no_pack {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>95421875,a=>113,d=>4,c=>0,h=>6613,b=>1,g=>2,f=>5}
71010400b305b05556670000
71010400b305b05556670000
71010400b305b05556670000
712080005b005b3ab3aa0000
71010400b305b05556670000
71010400b305b05556670000
712080005b005b3ab3aa0000
71010400b305b05556670000
712080005b005b3ab3aa0000
-
{e=>219735823,a=>24,d=>6,c=>5,h=>3918,b=>5,g=>1,f=>0}
182d06000fe7180d393d0000
182d06000fe7180d393d0000
182d06000fe7180d393d0000
18b4c000d18e70f05e9c0000
182d06000fe7180d393d0000
182d06000fe7180d393d0000
18b4c000d18e70f05e9c0000
182d06000fe7180d393d0000
18b4c000d18e70f05e9c0000
-
{e=>114141874,a=>-127,d=>4,c=>4,h=>3018,b=>0,g=>0,f=>2}
81200400b2aacd26282f0000
81200400b2aacd26282f0000
81200400b2aacd26282f0000
811080006cdaab2417940000
81200400b2aacd26282f0000
81200400b2aacd26282f0000
811080006cdaab2417940000
81200400b2aacd26282f0000
811080006cdaab2417940000
-
{e=>116157792,a=>52,d=>7,c=>1,h=>7261,b=>4,g=>0,f=>5}
340c0700606dec5674710000
340c0700606dec5674710000
340c0700606dec5674710000
3484e0006ec6d60a38ba0000
340c0700606dec5674710000
340c0700606dec5674710000
3484e0006ec6d60a38ba0000
340c0700606dec5674710000
3484e0006ec6d60a38ba0000
-
{e=>164478627,a=>-23,d=>7,c=>1,h=>2155,b=>4,g=>3,f=>7}
e90c0700a3becd79af210000
e90c0700a3becd79af210000
e90c0700a3becd79af210000
e984e0009cdbea3ed0d60000
e90c0700a3becd79af210000
e90c0700a3becd79af210000
e984e0009cdbea3ed0d60000
e90c0700a3becd79af210000
e984e0009cdbea3ed0d60000
=
struct umixed_no_pack {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  signed   int   i;
};
-
{e=>31308849,a=>-51,d=>6,c=>1,h=>3257,b=>7,g=>2,f=>6,i=>35}
cd0f060031bcdd61e632000023000000
cd0f060031bcdd61e632000023000000
cd0f060031bcdd61e632000023000000
cde4c0001ddbc31c9972000000000023
cd0f060031bcdd61e632000023000000
cd0f060031bcdd61e632000023000000
cde4c0001ddbc31c9972000000000023
cd0f060031bcdd61e632000023000000
cde4c0001ddbc31c9972000000000023
-
{e=>200850095,a=>59,d=>3,c=>5,h=>4223,b=>2,g=>3,f=>7,i=>-30}
3b2a0300afbaf87bff410000e2ffffff
3b2a0300afbaf87bff410000e2ffffff
3b2a0300afbaf87bff410000e2ffffff
3b546000bf8baafee0fe0000ffffffe2
3b2a0300afbaf87bff410000e2ffffff
3b2a0300afbaf87bff410000e2ffffff
3b546000bf8baafee0fe0000ffffffe2
3b2a0300afbaf87bff410000e2ffffff
3b546000bf8baafee0fe0000ffffffe2
-
{e=>2384984,a=>-78,d=>5,c=>3,h=>4113,b=>0,g=>3,f=>7,i=>33}
b2180500586424704740000021000000
b2180500586424704740000021000000
b2180500586424704740000021000000
b20ca0000246458ee022000000000021
b2180500586424704740000021000000
b2180500586424704740000021000000
b20ca0000246458ee022000000000021
b2180500586424704740000021000000
b20ca0000246458ee022000000000021
-
{e=>170834401,a=>-122,d=>7,c=>0,h=>305,b=>5,g=>1,f=>3,i=>93}
86050700e1b92e3ac50400005d000000
86050700e1b92e3ac50400005d000000
86050700e1b92e3ac50400005d000000
86a0e000a2eb9e16426200000000005d
86050700e1b92e3ac50400005d000000
86050700e1b92e3ac50400005d000000
86a0e000a2eb9e16426200000000005d
86050700e1b92e3ac50400005d000000
86a0e000a2eb9e16426200000000005d
-
{e=>202616049,a=>-1,d=>7,c=>3,h=>4385,b=>5,g=>3,f=>0,i=>101}
ff1d0700f1ac130c8744000065000000
ff1d0700f1ac130c8744000065000000
ff1d0700f1ac130c8744000065000000
fface000c13acf10e242000000000065
ff1d0700f1ac130c8744000065000000
ff1d0700f1ac130c8744000065000000
fface000c13acf10e242000000000065
ff1d0700f1ac130c8744000065000000
fface000c13acf10e242000000000065
=
struct umixed_no_pack {
  short a;
  unsigned char  b:3;
};
-
{a=>-23,b=>3}
e9ff0300
e9ff0300
e9ff0300
ffe96000
e9ff0300
e9ff0300
ffe96000
e9ff0300
ffe96000
-
{a=>-90,b=>7}
a6ff0700
a6ff0700
a6ff0700
ffa6e000
a6ff0700
a6ff0700
ffa6e000
a6ff0700
ffa6e000
-
{a=>33,b=>2}
21000200
21000200
21000200
00214000
21000200
21000200
00214000
21000200
00214000
-
{a=>-4,b=>6}
fcff0600
fcff0600
fcff0600
fffcc000
fcff0600
fcff0600
fffcc000
fcff0600
fffcc000
-
{a=>-31,b=>5}
e1ff0500
e1ff0500
e1ff0500
ffe1a000
e1ff0500
e1ff0500
ffe1a000
e1ff0500
ffe1a000
=
struct umixed_no_pack {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>4,a=>-107,b=>7}
95ff2700
95ff2700
95ff2700
ff95f000
95ff2700
95ff2700
ff95f000
95ff2700
ff95f000
-
{c=>7,a=>6,b=>0}
06003800
06003800
06003800
00061c00
06003800
06003800
00061c00
06003800
00061c00
-
{c=>7,a=>47,b=>6}
2f003e00
2f003e00
2f003e00
002fdc00
2f003e00
2f003e00
002fdc00
2f003e00
002fdc00
-
{c=>2,a=>-33,b=>2}
dfff1200
dfff1200
dfff1200
ffdf4800
dfff1200
dfff1200
ffdf4800
dfff1200
ffdf4800
-
{c=>2,a=>-93,b=>3}
a3ff1300
a3ff1300
a3ff1300
ffa36800
a3ff1300
a3ff1300
ffa36800
a3ff1300
ffa36800
=
struct umixed_no_pack {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>4,a=>35,b=>3,d=>7}
2300e301
2300e301
2300e301
00237380
2300e301
2300e301
00237380
2300e301
00237380
-
{c=>1,a=>-77,b=>0,d=>4}
b3ff0801
b3ff0801
b3ff0801
ffb30600
b3ff0801
b3ff0801
ffb30600
b3ff0801
ffb30600
-
{c=>4,a=>-88,b=>6,d=>0}
a8ff2600
a8ff2600
a8ff2600
ffa8d000
a8ff2600
a8ff2600
ffa8d000
a8ff2600
ffa8d000
-
{c=>2,a=>-10,b=>6,d=>4}
f6ff1601
f6ff1601
f6ff1601
fff6ca00
f6ff1601
f6ff1601
fff6ca00
f6ff1601
fff6ca00
-
{c=>2,a=>17,b=>4,d=>3}
1100d400
1100d400
1100d400
00118980
1100d400
1100d400
00118980
1100d400
00118980
=
struct umixed_no_pack {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>230924365,c=>5,a=>-34,b=>0,d=>1}
deff68004da0c30d
deff68004da0c30d
deff68004da0c30d
ffde1480dc3a04d0
deff68004da0c30d
deff68004da0c30d
ffde1480dc3a04d0
deff68004da0c30d
ffde1480dc3a04d0
-
{e=>235124443,c=>6,a=>-25,b=>1,d=>0}
e7ff3100dbb6030e
e7ff3100dbb6030e
e7ff3100dbb6030e
ffe73800e03b6db0
e7ff3100dbb6030e
e7ff3100dbb6030e
ffe73800e03b6db0
e7ff3100dbb6030e
ffe73800e03b6db0
-
{e=>218139234,c=>4,a=>-11,b=>4,d=>6}
f5ffa401628a000d
f5ffa401628a000d
f5ffa401628a000d
fff59300d008a620
f5ffa401628a000d
f5ffa401628a000d
fff59300d008a620
f5ffa401628a000d
fff59300d008a620
-
{e=>96460758,c=>3,a=>-25,b=>1,d=>3}
e7ffd900d6dfbf05
e7ffd900d6dfbf05
e7ffd900d6dfbf05
ffe72d805bfdfd60
e7ffd900d6dfbf05
e7ffd900d6dfbf05
ffe72d805bfdfd60
e7ffd900d6dfbf05
ffe72d805bfdfd60
-
{e=>143236939,c=>5,a=>117,b=>3,d=>0}
75002b004b9f8908
75002b004b9f8908
75002b004b9f8908
007574008899f4b0
75002b004b9f8908
75002b004b9f8908
007574008899f4b0
75002b004b9f8908
007574008899f4b0
=
struct umixed_no_pack {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>81182875,c=>2,a=>49,b=>2,d=>5,f=>3}
310052019bc0d634
310052019bc0d634
310052019bc0d634
00314a804d6c09b6
310052019bc0d634
310052019bc0d634
00314a804d6c09b6
310052019bc0d634
00314a804d6c09b6
-
{e=>165824077,c=>1,a=>51,b=>0,d=>0,f=>4}
330008004d46e249
330008004d46e249
330008004d46e249
003304009e2464d8
330008004d46e249
330008004d46e249
003304009e2464d8
330008004d46e249
003304009e2464d8
-
{e=>20080403,c=>1,a=>41,b=>4,d=>7,f=>6}
2900cc0113673261
2900cc0113673261
2900cc0113673261
002987801326713c
2900cc0113673261
2900cc0113673261
002987801326713c
2900cc0113673261
002987801326713c
-
{e=>100629693,c=>0,a=>61,b=>6,d=>6,f=>1}
3d008601bd7cff15
3d008601bd7cff15
3d008601bd7cff15
003dc3005ff7cbd2
3d008601bd7cff15
3d008601bd7cff15
003dc3005ff7cbd2
3d008601bd7cff15
003dc3005ff7cbd2
-
{e=>190350127,c=>5,a=>-101,b=>6,d=>0,f=>3}
9bff2e002f83583b
9bff2e002f83583b
9bff2e002f83583b
ff9bd400b58832f6
9bff2e002f83583b
9bff2e002f83583b
ff9bd400b58832f6
9bff2e002f83583b
ff9bd400b58832f6
=
struct umixed_no_pack {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>227828092,c=>0,a=>-16,g=>2,b=>1,d=>0,f=>0}
f0ff01007c61940d02000000
f0ff01007c61940d02000000
f0ff01007c61940d02000000
fff02000d94617c080000000
f0ff01007c61940d02000000
f0ff01007c61940d02000000
fff02000d94617c080000000
f0ff01007c61940d02000000
fff02000d94617c080000000
-
{e=>182355747,c=>1,a=>112,g=>0,b=>0,d=>3,f=>7}
7000c8002387de7a00000000
7000c8002387de7a00000000
7000c8002387de7a00000000
00700580ade8723e00000000
7000c8002387de7a00000000
7000c8002387de7a00000000
00700580ade8723e00000000
7000c8002387de7a00000000
00700580ade8723e00000000
-
{e=>183757219,c=>3,a=>117,g=>3,b=>6,d=>6,f=>2}
75009e01a3e9f32a03000000
75009e01a3e9f32a03000000
75009e01a3e9f32a03000000
0075cf00af3e9a34c0000000
75009e01a3e9f32a03000000
75009e01a3e9f32a03000000
0075cf00af3e9a34c0000000
75009e01a3e9f32a03000000
0075cf00af3e9a34c0000000
-
{e=>250036859,c=>6,a=>66,g=>1,b=>2,d=>0,f=>6}
420032007b42e76e01000000
420032007b42e76e01000000
420032007b42e76e01000000
00425800ee7427bc40000000
420032007b42e76e01000000
420032007b42e76e01000000
00425800ee7427bc40000000
420032007b42e76e01000000
00425800ee7427bc40000000
-
{e=>238803723,c=>4,a=>110,g=>0,b=>1,d=>6,f=>1}
6e00a1010bdb3b1e00000000
6e00a1010bdb3b1e00000000
6e00a1010bdb3b1e00000000
006e3300e3bdb0b200000000
6e00a1010bdb3b1e00000000
6e00a1010bdb3b1e00000000
006e3300e3bdb0b200000000
6e00a1010bdb3b1e00000000
006e3300e3bdb0b200000000
=
struct umixed_no_pack {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>123354721,a=>77,d=>1,c=>5,h=>6510,b=>2,g=>2,f=>7}
4d006a00613e5a77ba650000
4d006a00613e5a77ba650000
4d006a00613e5a77ba650000
004d548075a3e61eb2dc0000
4d006a00613e5a77ba650000
4d006a00613e5a77ba650000
004d548075a3e61eb2dc0000
4d006a00613e5a77ba650000
004d548075a3e61eb2dc0000
-
{e=>6270702,a=>72,d=>1,c=>2,h=>3832,b=>3,g=>1,f=>4}
48005300eeae5f40e13b0000
48005300eeae5f40e13b0000
48005300eeae5f40e13b0000
0048688005faeee85df00000
48005300eeae5f40e13b0000
48005300eeae5f40e13b0000
0048688005faeee85df00000
48005300eeae5f40e13b0000
0048688005faeee85df00000
-
{e=>151397274,a=>-111,d=>6,c=>7,h=>1061,b=>6,g=>3,f=>3}
91ffbe019a23063997100000
91ffbe019a23063997100000
91ffbe019a23063997100000
ff91df00906239a6c84a0000
91ffbe019a23063997100000
91ffbe019a23063997100000
ff91df00906239a6c84a0000
91ffbe019a23063997100000
ff91df00906239a6c84a0000
-
{e=>139689776,a=>26,d=>3,c=>0,h=>1364,b=>6,g=>1,f=>4}
1a00c600307f534851150000
1a00c600307f534851150000
1a00c600307f534851150000
001ac1808537f3084aa80000
1a00c600307f534851150000
1a00c600307f534851150000
001ac1808537f3084aa80000
1a00c600307f534851150000
001ac1808537f3084aa80000
-
{e=>36719821,a=>73,d=>2,c=>4,h=>2049,b=>7,g=>2,f=>3}
4900a700cd4c303206200000
4900a700cd4c303206200000
4900a700cd4c303206200000
0049f1002304ccd690020000
4900a700cd4c303206200000
4900a700cd4c303206200000
0049f1002304ccd690020000
4900a700cd4c303206200000
0049f1002304ccd690020000
=
struct umixed_no_pack {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  signed   int   i;
};
-
{e=>80052423,a=>38,d=>7,c=>5,h=>719,b=>0,g=>1,f=>2,i=>58}
2600e801c780c5243d0b00003a000000
2600e801c780c5243d0b00003a000000
2600e801c780c5243d0b00003a000000
002617804c580c74459e00000000003a
2600e801c780c5243d0b00003a000000
2600e801c780c5243d0b00003a000000
002617804c580c74459e00000000003a
2600e801c780c5243d0b00003a000000
002617804c580c74459e00000000003a
-
{e=>84879964,a=>-58,d=>2,c=>2,h=>7754,b=>5,g=>2,f=>6,i=>3}
c6ff95005c2a0f652a79000003000000
c6ff95005c2a0f652a79000003000000
c6ff95005c2a0f652a79000003000000
ffc6a90050f2a5ccbc94000000000003
c6ff95005c2a0f652a79000003000000
c6ff95005c2a0f652a79000003000000
ffc6a90050f2a5ccbc94000000000003
c6ff95005c2a0f652a79000003000000
ffc6a90050f2a5ccbc94000000000003
-
{e=>208832370,a=>-38,d=>5,c=>6,h=>7000,b=>7,g=>3,f=>1,i=>27}
daff77017287721c636d00001b000000
daff77017287721c636d00001b000000
daff77017287721c636d00001b000000
ffdafa80c7287722f6b000000000001b
daff77017287721c636d00001b000000
daff77017287721c636d00001b000000
ffdafa80c7287722f6b000000000001b
daff77017287721c636d00001b000000
ffdafa80c7287722f6b000000000001b
-
{e=>224138316,a=>99,d=>4,c=>7,h=>2886,b=>1,g=>1,f=>2,i=>-60}
630039014c145c2d192d0000c4ffffff
630039014c145c2d192d0000c4ffffff
630039014c145c2d192d0000c4ffffff
00633e00d5c144c4568c0000ffffffc4
630039014c145c2d192d0000c4ffffff
630039014c145c2d192d0000c4ffffff
00633e00d5c144c4568c0000ffffffc4
630039014c145c2d192d0000c4ffffff
00633e00d5c144c4568c0000ffffffc4
-
{e=>208271774,a=>61,d=>7,c=>5,h=>4345,b=>5,g=>1,f=>2,i=>-10}
3d00ed019ef9692ce5430000f6ffffff
3d00ed019ef9692ce5430000f6ffffff
3d00ed019ef9692ce5430000f6ffffff
003db780c69f99e461f20000fffffff6
3d00ed019ef9692ce5430000f6ffffff
3d00ed019ef9692ce5430000f6ffffff
003db780c69f99e461f20000fffffff6
3d00ed019ef9692ce5430000f6ffffff
003db780c69f99e461f20000fffffff6
=
struct umixed_no_pack {
  int a;
  unsigned char  b:3;
};
-
{a=>77,b=>5}
4d00000005000000
4d00000005000000
4d00000005000000
0000004da0000000
4d00000005000000
4d00000005000000
0000004da0000000
4d00000005000000
0000004da0000000
-
{a=>-91,b=>1}
a5ffffff01000000
a5ffffff01000000
a5ffffff01000000
ffffffa520000000
a5ffffff01000000
a5ffffff01000000
ffffffa520000000
a5ffffff01000000
ffffffa520000000
-
{a=>42,b=>3}
2a00000003000000
2a00000003000000
2a00000003000000
0000002a60000000
2a00000003000000
2a00000003000000
0000002a60000000
2a00000003000000
0000002a60000000
-
{a=>-15,b=>3}
f1ffffff03000000
f1ffffff03000000
f1ffffff03000000
fffffff160000000
f1ffffff03000000
f1ffffff03000000
fffffff160000000
f1ffffff03000000
fffffff160000000
-
{a=>-34,b=>2}
deffffff02000000
deffffff02000000
deffffff02000000
ffffffde40000000
deffffff02000000
deffffff02000000
ffffffde40000000
deffffff02000000
ffffffde40000000
=
struct umixed_no_pack {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>0,a=>123,b=>7}
7b00000007000000
7b00000007000000
7b00000007000000
0000007be0000000
7b00000007000000
7b00000007000000
0000007be0000000
7b00000007000000
0000007be0000000
-
{c=>5,a=>35,b=>6}
230000002e000000
230000002e000000
230000002e000000
00000023d4000000
230000002e000000
230000002e000000
00000023d4000000
230000002e000000
00000023d4000000
-
{c=>3,a=>-76,b=>4}
b4ffffff1c000000
b4ffffff1c000000
b4ffffff1c000000
ffffffb48c000000
b4ffffff1c000000
b4ffffff1c000000
ffffffb48c000000
b4ffffff1c000000
ffffffb48c000000
-
{c=>6,a=>84,b=>4}
5400000034000000
5400000034000000
5400000034000000
0000005498000000
5400000034000000
5400000034000000
0000005498000000
5400000034000000
0000005498000000
-
{c=>5,a=>-26,b=>5}
e6ffffff2d000000
e6ffffff2d000000
e6ffffff2d000000
ffffffe6b4000000
e6ffffff2d000000
e6ffffff2d000000
ffffffe6b4000000
e6ffffff2d000000
ffffffe6b4000000
=
struct umixed_no_pack {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>6,a=>89,b=>0,d=>2}
59000000b0000000
59000000b0000000
59000000b0000000
0000005919000000
59000000b0000000
59000000b0000000
0000005919000000
59000000b0000000
0000005919000000
-
{c=>2,a=>71,b=>6,d=>6}
4700000096010000
4700000096010000
4700000096010000
00000047cb000000
4700000096010000
4700000096010000
00000047cb000000
4700000096010000
00000047cb000000
-
{c=>6,a=>43,b=>6,d=>4}
2b00000036010000
2b00000036010000
2b00000036010000
0000002bda000000
2b00000036010000
2b00000036010000
0000002bda000000
2b00000036010000
0000002bda000000
-
{c=>7,a=>74,b=>6,d=>1}
4a0000007e000000
4a0000007e000000
4a0000007e000000
0000004adc800000
4a0000007e000000
4a0000007e000000
0000004adc800000
4a0000007e000000
0000004adc800000
-
{c=>1,a=>24,b=>1,d=>7}
18000000c9010000
18000000c9010000
18000000c9010000
0000001827800000
18000000c9010000
18000000c9010000
0000001827800000
18000000c9010000
0000001827800000
=
struct umixed_no_pack {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>258411058,c=>2,a=>-56,b=>3,d=>1}
c8ffffff53000000320a670f
c8ffffff53000000320a670f
c8ffffff53000000320a670f
ffffffc868800000f670a320
c8ffffff53000000320a670f
c8ffffff53000000320a670f
ffffffc868800000f670a320
c8ffffff53000000320a670f
ffffffc868800000f670a320
-
{e=>192775493,c=>2,a=>6,b=>7,d=>4}
060000001701000045857d0b
060000001701000045857d0b
060000001701000045857d0b
00000006ea000000b7d85450
060000001701000045857d0b
060000001701000045857d0b
00000006ea000000b7d85450
060000001701000045857d0b
00000006ea000000b7d85450
-
{e=>70245712,c=>3,a=>-1,b=>7,d=>1}
ffffffff5f00000050dd2f04
ffffffff5f00000050dd2f04
ffffffff5f00000050dd2f04
ffffffffec80000042fdd500
ffffffff5f00000050dd2f04
ffffffff5f00000050dd2f04
ffffffffec80000042fdd500
ffffffff5f00000050dd2f04
ffffffffec80000042fdd500
-
{e=>100376726,c=>7,a=>115,b=>0,d=>7}
73000000f801000096a0fb05
73000000f801000096a0fb05
73000000f801000096a0fb05
000000731f8000005fba0960
73000000f801000096a0fb05
73000000f801000096a0fb05
000000731f8000005fba0960
73000000f801000096a0fb05
000000731f8000005fba0960
-
{e=>261070995,c=>7,a=>-47,b=>1,d=>0}
d1ffffff3900000093a08f0f
d1ffffff3900000093a08f0f
d1ffffff3900000093a08f0f
ffffffd13c000000f8fa0930
d1ffffff3900000093a08f0f
d1ffffff3900000093a08f0f
ffffffd13c000000f8fa0930
d1ffffff3900000093a08f0f
ffffffd13c000000f8fa0930
=
struct umixed_no_pack {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>202903687,c=>1,a=>-41,b=>7,d=>0,f=>7}
d7ffffff0f0000008710187c
d7ffffff0f0000008710187c
d7ffffff0f0000008710187c
ffffffd7e4000000c181087e
d7ffffff0f0000008710187c
d7ffffff0f0000008710187c
ffffffd7e4000000c181087e
d7ffffff0f0000008710187c
ffffffd7e4000000c181087e
-
{e=>156182618,c=>1,a=>83,b=>7,d=>1,f=>1}
530000004f0000005a284f19
530000004f0000005a284f19
530000004f0000005a284f19
00000053e480000094f285a2
530000004f0000005a284f19
530000004f0000005a284f19
00000053e480000094f285a2
530000004f0000005a284f19
00000053e480000094f285a2
-
{e=>30752427,c=>5,a=>-26,b=>6,d=>3,f=>6}
e6ffffffee000000ab3ed561
e6ffffffee000000ab3ed561
e6ffffffee000000ab3ed561
ffffffe6d58000001d53eabc
e6ffffffee000000ab3ed561
e6ffffffee000000ab3ed561
ffffffe6d58000001d53eabc
e6ffffffee000000ab3ed561
ffffffe6d58000001d53eabc
-
{e=>13986533,c=>2,a=>73,b=>0,d=>3,f=>0}
49000000d0000000e56ad500
49000000d0000000e56ad500
49000000d0000000e56ad500
00000049098000000d56ae50
49000000d0000000e56ad500
49000000d0000000e56ad500
00000049098000000d56ae50
49000000d0000000e56ad500
00000049098000000d56ae50
-
{e=>97832562,c=>7,a=>67,b=>3,d=>1,f=>6}
430000007b00000072ced465
430000007b00000072ced465
430000007b00000072ced465
000000437c8000005d4ce72c
430000007b00000072ced465
430000007b00000072ced465
000000437c8000005d4ce72c
430000007b00000072ced465
000000437c8000005d4ce72c
=
struct umixed_no_pack {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>224204808,c=>0,a=>-125,g=>3,b=>2,d=>6,f=>5}
83ffffff8201000008185d5d03000000
83ffffff8201000008185d5d03000000
83ffffff8201000008185d5d03000000
ffffff8343000000d5d1808ac0000000
83ffffff8201000008185d5d03000000
83ffffff8201000008185d5d03000000
ffffff8343000000d5d1808ac0000000
83ffffff8201000008185d5d03000000
ffffff8343000000d5d1808ac0000000
-
{e=>248110203,c=>2,a=>32,g=>2,b=>2,d=>2,f=>2}
20000000920000007bdcc92e02000000
20000000920000007bdcc92e02000000
20000000920000007bdcc92e02000000
0000002049000000ec9dc7b480000000
20000000920000007bdcc92e02000000
20000000920000007bdcc92e02000000
0000002049000000ec9dc7b480000000
20000000920000007bdcc92e02000000
0000002049000000ec9dc7b480000000
-
{e=>176808355,c=>3,a=>74,g=>3,b=>7,d=>1,f=>0}
4a0000005f000000a3e1890a03000000
4a0000005f000000a3e1890a03000000
4a0000005f000000a3e1890a03000000
0000004aec800000a89e1a30c0000000
4a0000005f000000a3e1890a03000000
4a0000005f000000a3e1890a03000000
0000004aec800000a89e1a30c0000000
4a0000005f000000a3e1890a03000000
0000004aec800000a89e1a30c0000000
-
{e=>200366377,c=>3,a=>-125,g=>2,b=>4,d=>6,f=>4}
83ffffff9c0100002959f14b02000000
83ffffff9c0100002959f14b02000000
83ffffff9c0100002959f14b02000000
ffffff838f000000bf15929880000000
83ffffff9c0100002959f14b02000000
83ffffff9c0100002959f14b02000000
ffffff838f000000bf15929880000000
83ffffff9c0100002959f14b02000000
ffffff838f000000bf15929880000000
-
{e=>40965455,c=>3,a=>107,g=>2,b=>0,d=>3,f=>4}
6b000000d80000004f15714202000000
6b000000d80000004f15714202000000
6b000000d80000004f15714202000000
0000006b0d800000271154f880000000
6b000000d80000004f15714202000000
6b000000d80000004f15714202000000
0000006b0d800000271154f880000000
6b000000d80000004f15714202000000
0000006b0d800000271154f880000000
=
struct umixed_no_pack {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>261834522,a=>113,d=>2,c=>3,h=>1720,b=>5,g=>2,f=>7}
710000009d0000001a479b7fe21a0000
710000009d0000001a479b7fe21a0000
710000009d0000001a479b7fe21a0000
00000071ad000000f9b471ae8d700000
710000009d0000001a479b7fe21a0000
710000009d0000001a479b7fe21a0000
00000071ad000000f9b471ae8d700000
710000009d0000001a479b7fe21a0000
00000071ad000000f9b471ae8d700000
-
{e=>81177197,a=>52,d=>7,c=>0,h=>7442,b=>0,g=>0,f=>3}
34000000c00100006daad63448740000
34000000c00100006daad63448740000
34000000c00100006daad63448740000
00000034038000004d6aa6d63a240000
34000000c00100006daad63448740000
34000000c00100006daad63448740000
00000034038000004d6aa6d63a240000
34000000c00100006daad63448740000
00000034038000004d6aa6d63a240000
-
{e=>252859983,a=>117,d=>4,c=>2,h=>3820,b=>7,g=>1,f=>3}
75000000170100004f56123fb13b0000
75000000170100004f56123fb13b0000
75000000170100004f56123fb13b0000
00000075ea000000f12564f65dd80000
75000000170100004f56123fb13b0000
75000000170100004f56123fb13b0000
00000075ea000000f12564f65dd80000
75000000170100004f56123fb13b0000
00000075ea000000f12564f65dd80000
-
{e=>260755755,a=>39,d=>6,c=>3,h=>5333,b=>4,g=>1,f=>6}
270000009c0100002bd18a6f55530000
270000009c0100002bd18a6f55530000
270000009c0100002bd18a6f55530000
000000278f000000f8ad12bc69aa0000
270000009c0100002bd18a6f55530000
270000009c0100002bd18a6f55530000
000000278f000000f8ad12bc69aa0000
270000009c0100002bd18a6f55530000
000000278f000000f8ad12bc69aa0000
-
{e=>197646476,a=>44,d=>1,c=>0,h=>1255,b=>0,g=>1,f=>7}
2c000000400000008cd8c77b9d130000
2c000000400000008cd8c77b9d130000
2c000000400000008cd8c77b9d130000
0000002c00800000bc7d88ce49ce0000
2c000000400000008cd8c77b9d130000
2c000000400000008cd8c77b9d130000
0000002c00800000bc7d88ce49ce0000
2c000000400000008cd8c77b9d130000
0000002c00800000bc7d88ce49ce0000
=
struct umixed_no_pack {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  signed   int   i;
};
-
{e=>3714946,a=>-88,d=>6,c=>2,h=>3065,b=>4,g=>0,f=>1,i=>-7}
a8ffffff9401000082af3810e42f0000f9ffffff
a8ffffff9401000082af3810e42f0000f9ffffff
a8ffffff9401000082af3810e42f0000f9ffffff
ffffffa88b000000038af82217f20000fffffff9
a8ffffff9401000082af3810e42f0000f9ffffff
a8ffffff9401000082af3810e42f0000f9ffffff
ffffffa88b000000038af82217f20000fffffff9
a8ffffff9401000082af3810e42f0000f9ffffff
ffffffa88b000000038af82217f20000fffffff9
-
{e=>217660046,a=>63,d=>4,c=>2,h=>4968,b=>5,g=>3,f=>5,i=>-17}
3f000000150100008e3af95ca34d0000efffffff
3f000000150100008e3af95ca34d0000efffffff
3f000000150100008e3af95ca34d0000efffffff
0000003faa000000cf93a8eae6d00000ffffffef
3f000000150100008e3af95ca34d0000efffffff
3f000000150100008e3af95ca34d0000efffffff
0000003faa000000cf93a8eae6d00000ffffffef
3f000000150100008e3af95ca34d0000efffffff
0000003faa000000cf93a8eae6d00000ffffffef
-
{e=>50265395,a=>101,d=>1,c=>3,h=>1816,b=>7,g=>1,f=>7,i=>113}
650000005f00000033fdfe72611c000071000000
650000005f00000033fdfe72611c000071000000
650000005f00000033fdfe72611c000071000000
00000065ec8000002fefd33e4e30000000000071
650000005f00000033fdfe72611c000071000000
650000005f00000033fdfe72611c000071000000
00000065ec8000002fefd33e4e30000000000071
650000005f00000033fdfe72611c000071000000
00000065ec8000002fefd33e4e30000000000071
-
{e=>165795744,a=>11,d=>5,c=>4,h=>2771,b=>2,g=>3,f=>6,i=>-6}
0b00000062010000a0d7e1694f2b0000faffffff
0b00000062010000a0d7e1694f2b0000faffffff
0b00000062010000a0d7e1694f2b0000faffffff
0000000b528000009e1d7a0cd5a60000fffffffa
0b00000062010000a0d7e1694f2b0000faffffff
0b00000062010000a0d7e1694f2b0000faffffff
0000000b528000009e1d7a0cd5a60000fffffffa
0b00000062010000a0d7e1694f2b0000faffffff
0000000b528000009e1d7a0cd5a60000fffffffa
-
{e=>246643849,a=>56,d=>5,c=>2,h=>3254,b=>0,g=>3,f=>7,i=>-43}
3800000050010000897cb37edb320000d5ffffff
3800000050010000897cb37edb320000d5ffffff
3800000050010000897cb37edb320000d5ffffff
000000380a800000eb37c89ed96c0000ffffffd5
3800000050010000897cb37edb320000d5ffffff
3800000050010000897cb37edb320000d5ffffff
000000380a800000eb37c89ed96c0000ffffffd5
3800000050010000897cb37edb320000d5ffffff
000000380a800000eb37c89ed96c0000ffffffd5
=
struct umixed_no_pack {
  long a;
  unsigned char  b:3;
};
-
{a=>-22,b=>3}
eaffffff03000000
eaffffffffffffff0300000000000000
eaffffffffffffff0300000000000000
ffffffea60000000
eaffffff03000000
eaffffff03000000
ffffffffffffffea6000000000000000
eaffffff03000000
ffffffea60000000
-
{a=>15,b=>0}
0f00000000000000
0f000000000000000000000000000000
0f000000000000000000000000000000
0000000f00000000
0f00000000000000
0f00000000000000
000000000000000f0000000000000000
0f00000000000000
0000000f00000000
-
{a=>-58,b=>4}
c6ffffff04000000
c6ffffffffffffff0400000000000000
c6ffffffffffffff0400000000000000
ffffffc680000000
c6ffffff04000000
c6ffffff04000000
ffffffffffffffc68000000000000000
c6ffffff04000000
ffffffc680000000
-
{a=>39,b=>0}
2700000000000000
27000000000000000000000000000000
27000000000000000000000000000000
0000002700000000
2700000000000000
2700000000000000
00000000000000270000000000000000
2700000000000000
0000002700000000
-
{a=>55,b=>0}
3700000000000000
37000000000000000000000000000000
37000000000000000000000000000000
0000003700000000
3700000000000000
3700000000000000
00000000000000370000000000000000
3700000000000000
0000003700000000
=
struct umixed_no_pack {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>6,a=>53,b=>3}
3500000033000000
35000000000000003300000000000000
35000000000000003300000000000000
0000003578000000
3500000033000000
3500000033000000
00000000000000357800000000000000
3500000033000000
0000003578000000
-
{c=>6,a=>-101,b=>4}
9bffffff34000000
9bffffffffffffff3400000000000000
9bffffffffffffff3400000000000000
ffffff9b98000000
9bffffff34000000
9bffffff34000000
ffffffffffffff9b9800000000000000
9bffffff34000000
ffffff9b98000000
-
{c=>6,a=>62,b=>1}
3e00000031000000
3e000000000000003100000000000000
3e000000000000003100000000000000
0000003e38000000
3e00000031000000
3e00000031000000
000000000000003e3800000000000000
3e00000031000000
0000003e38000000
-
{c=>5,a=>-63,b=>5}
c1ffffff2d000000
c1ffffffffffffff2d00000000000000
c1ffffffffffffff2d00000000000000
ffffffc1b4000000
c1ffffff2d000000
c1ffffff2d000000
ffffffffffffffc1b400000000000000
c1ffffff2d000000
ffffffc1b4000000
-
{c=>2,a=>26,b=>4}
1a00000014000000
1a000000000000001400000000000000
1a000000000000001400000000000000
0000001a88000000
1a00000014000000
1a00000014000000
000000000000001a8800000000000000
1a00000014000000
0000001a88000000
=
struct umixed_no_pack {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>7,a=>84,b=>5,d=>0}
540000003d000000
54000000000000003d00000000000000
54000000000000003d00000000000000
00000054bc000000
540000003d000000
540000003d000000
0000000000000054bc00000000000000
540000003d000000
00000054bc000000
-
{c=>2,a=>-4,b=>6,d=>7}
fcffffffd6010000
fcffffffffffffffd601000000000000
fcffffffffffffffd601000000000000
fffffffccb800000
fcffffffd6010000
fcffffffd6010000
fffffffffffffffccb80000000000000
fcffffffd6010000
fffffffccb800000
-
{c=>0,a=>-1,b=>2,d=>4}
ffffffff02010000
ffffffffffffffff0201000000000000
ffffffffffffffff0201000000000000
ffffffff42000000
ffffffff02010000
ffffffff02010000
ffffffffffffffff4200000000000000
ffffffff02010000
ffffffff42000000
-
{c=>5,a=>75,b=>2,d=>1}
4b0000006a000000
4b000000000000006a00000000000000
4b000000000000006a00000000000000
0000004b54800000
4b0000006a000000
4b0000006a000000
000000000000004b5480000000000000
4b0000006a000000
0000004b54800000
-
{c=>1,a=>-35,b=>2,d=>2}
ddffffff8a000000
ddffffffffffffff8a00000000000000
ddffffffffffffff8a00000000000000
ffffffdd45000000
ddffffff8a000000
ddffffff8a000000
ffffffffffffffdd4500000000000000
ddffffff8a000000
ffffffdd45000000
=
struct umixed_no_pack {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>12846720,c=>5,a=>-2,b=>6,d=>4}
feffffff2e0100008006c400
feffffffffffffff2e0100008006c400
feffffffffffffff2e0100008006c400
fffffffed60000000c406800
feffffff2e0100008006c400
feffffff2e0100008006c400
fffffffffffffffed60000000c406800
feffffff2e0100008006c400
fffffffed60000000c406800
-
{e=>122850482,c=>0,a=>44,b=>4,d=>5}
2c00000044010000b28c5207
2c0000000000000044010000b28c5207
2c0000000000000044010000b28c5207
0000002c828000007528cb20
2c00000044010000b28c5207
2c00000044010000b28c5207
000000000000002c828000007528cb20
2c00000044010000b28c5207
0000002c828000007528cb20
-
{e=>110531108,c=>0,a=>6,b=>7,d=>5}
060000004701000024929606
06000000000000004701000024929606
06000000000000004701000024929606
00000006e280000069692240
060000004701000024929606
060000004701000024929606
0000000000000006e280000069692240
060000004701000024929606
00000006e280000069692240
-
{e=>172922041,c=>3,a=>-21,b=>6,d=>1}
ebffffff5e000000b9944e0a
ebffffffffffffff5e000000b9944e0a
ebffffffffffffff5e000000b9944e0a
ffffffebcc800000a4e94b90
ebffffff5e000000b9944e0a
ebffffff5e000000b9944e0a
ffffffffffffffebcc800000a4e94b90
ebffffff5e000000b9944e0a
ffffffebcc800000a4e94b90
-
{e=>55535187,c=>1,a=>-73,b=>2,d=>3}
b7ffffffca00000053664f03
b7ffffffffffffffca00000053664f03
b7ffffffffffffffca00000053664f03
ffffffb74580000034f66530
b7ffffffca00000053664f03
b7ffffffca00000053664f03
ffffffffffffffb74580000034f66530
b7ffffffca00000053664f03
ffffffb74580000034f66530
=
struct umixed_no_pack {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>66805985,c=>5,a=>115,b=>6,d=>2,f=>6}
73000000ae000000e160fb63
7300000000000000ae000000e160fb63
7300000000000000ae000000e160fb63
00000073d50000003fb60e1c
73000000ae000000e160fb63
73000000ae000000e160fb63
0000000000000073d50000003fb60e1c
73000000ae000000e160fb63
00000073d50000003fb60e1c
-
{e=>217412345,c=>5,a=>83,b=>2,d=>7,f=>1}
53000000ea010000f972f51c
5300000000000000ea010000f972f51c
5300000000000000ea010000f972f51c
0000005357800000cf572f92
53000000ea010000f972f51c
53000000ea010000f972f51c
000000000000005357800000cf572f92
53000000ea010000f972f51c
0000005357800000cf572f92
-
{e=>143288860,c=>4,a=>80,b=>4,d=>7,f=>2}
50000000e40100001c6a8a28
5000000000000000e40100001c6a8a28
5000000000000000e40100001c6a8a28
000000509380000088a6a1c4
50000000e40100001c6a8a28
50000000e40100001c6a8a28
00000000000000509380000088a6a1c4
50000000e40100001c6a8a28
000000509380000088a6a1c4
-
{e=>80533529,c=>3,a=>-56,b=>0,d=>4,f=>3}
c8ffffff1801000019d8cc34
c8ffffffffffffff1801000019d8cc34
c8ffffffffffffff1801000019d8cc34
ffffffc80e0000004ccd8196
c8ffffff1801000019d8cc34
c8ffffff1801000019d8cc34
ffffffffffffffc80e0000004ccd8196
c8ffffff1801000019d8cc34
ffffffc80e0000004ccd8196
-
{e=>76049210,c=>4,a=>41,b=>4,d=>0,f=>2}
29000000240000003a6b8824
2900000000000000240000003a6b8824
2900000000000000240000003a6b8824
00000029900000004886b3a4
29000000240000003a6b8824
29000000240000003a6b8824
0000000000000029900000004886b3a4
29000000240000003a6b8824
00000029900000004886b3a4
=
struct umixed_no_pack {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>33149186,c=>0,a=>-66,g=>2,b=>6,d=>0,f=>2}
beffffff0600000002d1f92102000000
beffffffffffffff0600000002d1f9210200000000000000
beffffffffffffff0600000002d1f9210200000000000000
ffffffbec00000001f9d102480000000
beffffff0600000002d1f92102000000
beffffff0600000002d1f92102000000
ffffffffffffffbec00000001f9d10248000000000000000
beffffff0600000002d1f92102000000
ffffffbec00000001f9d102480000000
-
{e=>24018713,c=>6,a=>42,g=>0,b=>3,d=>1,f=>7}
2a00000073000000197f6e7100000000
2a0000000000000073000000197f6e710000000000000000
2a0000000000000073000000197f6e710000000000000000
0000002a7880000016e7f19e00000000
2a00000073000000197f6e7100000000
2a00000073000000197f6e7100000000
000000000000002a7880000016e7f19e0000000000000000
2a00000073000000197f6e7100000000
0000002a7880000016e7f19e00000000
-
{e=>238049791,c=>1,a=>-89,g=>0,b=>5,d=>4,f=>3}
a7ffffff0d010000ff59303e00000000
a7ffffffffffffff0d010000ff59303e0000000000000000
a7ffffffffffffff0d010000ff59303e0000000000000000
ffffffa7a6000000e3059ff600000000
a7ffffff0d010000ff59303e00000000
a7ffffff0d010000ff59303e00000000
ffffffffffffffa7a6000000e3059ff60000000000000000
a7ffffff0d010000ff59303e00000000
ffffffa7a6000000e3059ff600000000
-
{e=>45452680,c=>4,a=>85,g=>3,b=>5,d=>4,f=>2}
5500000025010000888db52203000000
550000000000000025010000888db5220300000000000000
550000000000000025010000888db5220300000000000000
00000055b20000002b58d884c0000000
5500000025010000888db52203000000
5500000025010000888db52203000000
0000000000000055b20000002b58d884c000000000000000
5500000025010000888db52203000000
00000055b20000002b58d884c0000000
-
{e=>127560049,c=>0,a=>38,g=>3,b=>5,d=>1,f=>4}
260000004500000071699a4703000000
26000000000000004500000071699a470300000000000000
26000000000000004500000071699a470300000000000000
00000026a080000079a69718c0000000
260000004500000071699a4703000000
260000004500000071699a4703000000
0000000000000026a080000079a69718c000000000000000
260000004500000071699a4703000000
00000026a080000079a69718c0000000
=
struct umixed_no_pack {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>143259895,a=>-70,d=>4,c=>3,h=>4312,b=>6,g=>0,f=>5}
baffffff1e010000f7f8895860430000
baffffffffffffff1e010000f7f889586043000000000000
baffffffffffffff1e010000f7f889586043000000000000
ffffffbace000000889f8f7a21b00000
baffffff1e010000f7f8895860430000
baffffff1e010000f7f8895860430000
ffffffffffffffbace000000889f8f7a21b0000000000000
baffffff1e010000f7f8895860430000
ffffffbace000000889f8f7a21b00000
-
{e=>130209381,a=>75,d=>3,c=>6,h=>1172,b=>2,g=>1,f=>0}
4b000000f200000065d6c20751120000
4b00000000000000f200000065d6c2075112000000000000
4b00000000000000f200000065d6c2075112000000000000
0000004b598000007c2d665049280000
4b000000f200000065d6c20751120000
4b000000f200000065d6c20751120000
000000000000004b598000007c2d66504928000000000000
4b000000f200000065d6c20751120000
0000004b598000007c2d665049280000
-
{e=>169515883,a=>36,d=>3,c=>7,h=>7983,b=>7,g=>2,f=>0}
24000000ff0000006b9b1a0abe7c0000
2400000000000000ff0000006b9b1a0abe7c000000000000
2400000000000000ff0000006b9b1a0abe7c000000000000
00000024fd800000a1a9b6b0be5e0000
24000000ff0000006b9b1a0abe7c0000
24000000ff0000006b9b1a0abe7c0000
0000000000000024fd800000a1a9b6b0be5e000000000000
24000000ff0000006b9b1a0abe7c0000
00000024fd800000a1a9b6b0be5e0000
-
{e=>204680465,a=>-15,d=>2,c=>5,h=>8017,b=>2,g=>0,f=>6}
f1ffffffaa000000112d336c447d0000
f1ffffffffffffffaa000000112d336c447d000000000000
f1ffffffffffffffaa000000112d336c447d000000000000
fffffff155000000c332d11c3ea20000
f1ffffffaa000000112d336c447d0000
f1ffffffaa000000112d336c447d0000
fffffffffffffff155000000c332d11c3ea2000000000000
f1ffffffaa000000112d336c447d0000
fffffff155000000c332d11c3ea20000
-
{e=>243063688,a=>85,d=>2,c=>6,h=>342,b=>2,g=>0,f=>3}
55000000b200000088db7c3e58050000
5500000000000000b200000088db7c3e5805000000000000
5500000000000000b200000088db7c3e5805000000000000
0000005559000000e7cdb88602ac0000
55000000b200000088db7c3e58050000
55000000b200000088db7c3e58050000
000000000000005559000000e7cdb88602ac000000000000
55000000b200000088db7c3e58050000
0000005559000000e7cdb88602ac0000
=
struct umixed_no_pack {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  signed   int   i;
};
-
{e=>256419346,a=>25,d=>4,c=>1,h=>4924,b=>3,g=>1,f=>2,i=>-112}
190000000b01000012a6482ff14c000090ffffff
19000000000000000b01000012a6482ff14c000090ffffff
19000000000000000b01000012a6482ff14c000090ffffff
0000001966000000f48a612466780000ffffff90
190000000b01000012a6482ff14c000090ffffff
190000000b01000012a6482ff14c000090ffffff
000000000000001966000000f48a612466780000ffffff90
190000000b01000012a6482ff14c000090ffffff
0000001966000000f48a612466780000ffffff90
-
{e=>155022430,a=>75,d=>3,c=>2,h=>362,b=>7,g=>2,f=>1,i=>-49}
4b000000d70000005e743d19aa050000cfffffff
4b00000000000000d70000005e743d19aa050000cfffffff
4b00000000000000d70000005e743d19aa050000cfffffff
0000004be980000093d745e282d40000ffffffcf
4b000000d70000005e743d19aa050000cfffffff
4b000000d70000005e743d19aa050000cfffffff
000000000000004be980000093d745e282d40000ffffffcf
4b000000d70000005e743d19aa050000cfffffff
0000004be980000093d745e282d40000ffffffcf
-
{e=>190447867,a=>-73,d=>1,c=>2,h=>2876,b=>7,g=>0,f=>7,i=>1}
b7ffffff57000000fb005a7bf02c000001000000
b7ffffffffffffff57000000fb005a7bf02c000001000000
b7ffffffffffffff57000000fb005a7bf02c000001000000
ffffffb7e8800000b5a00fbe1678000000000001
b7ffffff57000000fb005a7bf02c000001000000
b7ffffff57000000fb005a7bf02c000001000000
ffffffffffffffb7e8800000b5a00fbe1678000000000001
b7ffffff57000000fb005a7bf02c000001000000
ffffffb7e8800000b5a00fbe1678000000000001
-
{e=>179690236,a=>9,d=>7,c=>0,h=>7267,b=>7,g=>1,f=>0,i=>-85}
09000000c7010000fcdab50a8d710000abffffff
0900000000000000c7010000fcdab50a8d710000abffffff
0900000000000000c7010000fcdab50a8d710000abffffff
00000009e3800000ab5dafc078c60000ffffffab
09000000c7010000fcdab50a8d710000abffffff
09000000c7010000fcdab50a8d710000abffffff
0000000000000009e3800000ab5dafc078c60000ffffffab
09000000c7010000fcdab50a8d710000abffffff
00000009e3800000ab5dafc078c60000ffffffab
-
{e=>104415787,a=>74,d=>7,c=>3,h=>3028,b=>4,g=>3,f=>7,i=>92}
4a000000dc0100002b423976532f00005c000000
4a00000000000000dc0100002b423976532f00005c000000
4a00000000000000dc0100002b423976532f00005c000000
0000004a8f800000639422bed7a800000000005c
4a000000dc0100002b423976532f00005c000000
4a000000dc0100002b423976532f00005c000000
000000000000004a8f800000639422bed7a800000000005c
4a000000dc0100002b423976532f00005c000000
0000004a8f800000639422bed7a800000000005c
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  unsigned char  a:3;
};
-
{a=>1}
01
01
01
20
01000000
01
20
01
20
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>1}
01
01
01
20
01000000
01
20
01
20
-
{a=>3}
03
03
03
60
03000000
03
60
03
60
-
{a=>5}
05
05
05
a0
05000000
05
a0
05
a0
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  unsigned char  a:3;
  unsigned char  b:3;
};
-
{a=>4,b=>3}
1c
1c
1c
8c
1c000000
1c
8c
1c
8c
-
{a=>5,b=>6}
35
35
35
b8
35000000
35
b8
35
b8
-
{a=>1,b=>3}
19
19
19
2c
19000000
19
2c
19
2c
-
{a=>7,b=>6}
37
37
37
f8
37000000
37
f8
37
f8
-
{a=>1,b=>0}
01
01
01
20
01000000
01
20
01
20
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
};
-
{c=>7,a=>2,b=>6}
f201
f201
f201
5b80
f2010000
f201
5b80
f201
5b80
-
{c=>3,a=>1,b=>4}
e100
e100
e100
3180
e1000000
e100
3180
e100
3180
-
{c=>0,a=>2,b=>1}
0a00
0a00
0a00
4400
0a000000
0a00
4400
0a00
4400
-
{c=>7,a=>6,b=>6}
f601
f601
f601
db80
f6010000
f601
db80
f601
db80
-
{c=>6,a=>5,b=>3}
9d01
9d01
9d01
af00
9d010000
9d01
af00
9d01
af00
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
};
-
{c=>3,a=>4,b=>6,d=>50977657}
f400000079db0903
f400000079db0903
f400000079db0903
99800000309db790
f400000079db0903
f400000079db0903
99800000309db790
f400000079db0903
99800000309db790
-
{c=>4,a=>1,b=>0,d=>156580251}
010100009b395509
010100009b395509
010100009b395509
22000000955399b0
010100009b395509
010100009b395509
22000000955399b0
010100009b395509
22000000955399b0
-
{c=>0,a=>6,b=>1,d=>120765803}
0e0000006bbd3207
0e0000006bbd3207
0e0000006bbd3207
c4000000732bd6b0
0e0000006bbd3207
0e0000006bbd3207
c4000000732bd6b0
0e0000006bbd3207
c4000000732bd6b0
-
{c=>5,a=>6,b=>4,d=>190259749}
660100002522570b
660100002522570b
660100002522570b
d2800000b5722250
660100002522570b
660100002522570b
d2800000b5722250
660100002522570b
d2800000b5722250
-
{c=>3,a=>6,b=>1,d=>14877875}
ce000000b304e300
ce000000b304e300
ce000000b304e300
c58000000e304b30
ce000000b304e300
ce000000b304e300
c58000000e304b30
ce000000b304e300
c58000000e304b30
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
};
-
{e=>7,c=>0,a=>5,b=>4,d=>131151049}
25000000c934d177
25000000c934d177
25000000c934d177
b00000007d134c9e
25000000c934d177
25000000c934d177
b00000007d134c9e
25000000c934d177
b00000007d134c9e
-
{e=>4,c=>6,a=>0,b=>3,d=>27196562}
9801000092fc9e41
9801000092fc9e41
9801000092fc9e41
0f00000019efc928
9801000092fc9e41
9801000092fc9e41
0f00000019efc928
9801000092fc9e41
0f00000019efc928
-
{e=>5,c=>2,a=>5,b=>2,d=>79198194}
95000000f277b854
95000000f277b854
95000000f277b854
a90000004b877f2a
95000000f277b854
95000000f277b854
a90000004b877f2a
95000000f277b854
a90000004b877f2a
-
{e=>1,c=>6,a=>1,b=>1,d=>53011008}
8901000040e22813
8901000040e22813
8901000040e22813
27000000328e2402
8901000040e22813
8901000040e22813
27000000328e2402
8901000040e22813
27000000328e2402
-
{e=>3,c=>0,a=>3,b=>5,d=>229669114}
2b000000fa78b03d
2b000000fa78b03d
2b000000fa78b03d
74000000db078fa6
2b000000fa78b03d
2b000000fa78b03d
74000000db078fa6
2b000000fa78b03d
74000000db078fa6
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
  unsigned char  f:2;
};
-
{e=>7,c=>4,a=>3,b=>2,d=>224213968,f=>0}
13010000d03b5d7d00000000
13010000d03b5d7d00000000
13010000d03b5d7d00000000
6a000000d5d3bd0e00000000
13010000d03b5d7d00000000
13010000d03b5d7d00000000
6a000000d5d3bd0e00000000
13010000d03b5d7d00000000
6a000000d5d3bd0e00000000
-
{e=>5,c=>0,a=>6,b=>7,d=>149199438,f=>2}
3e0000004e9ae45802000000
3e0000004e9ae45802000000
3e0000004e9ae45802000000
dc0000008e49a4ea80000000
3e0000004e9ae45802000000
3e0000004e9ae45802000000
dc0000008e49a4ea80000000
3e0000004e9ae45802000000
dc0000008e49a4ea80000000
-
{e=>4,c=>7,a=>4,b=>6,d=>212284222,f=>0}
f40100003e33a74c00000000
f40100003e33a74c00000000
f40100003e33a74c00000000
9b800000ca7333e800000000
f40100003e33a74c00000000
f40100003e33a74c00000000
9b800000ca7333e800000000
f40100003e33a74c00000000
9b800000ca7333e800000000
-
{e=>0,c=>4,a=>1,b=>3,d=>183266435,f=>3}
19010000836cec0a03000000
19010000836cec0a03000000
19010000836cec0a03000000
2e000000aec6c830c0000000
19010000836cec0a03000000
19010000836cec0a03000000
2e000000aec6c830c0000000
19010000836cec0a03000000
2e000000aec6c830c0000000
-
{e=>3,c=>3,a=>2,b=>0,d=>193465720,f=>3}
c2000000780d883b03000000
c2000000780d883b03000000
c2000000780d883b03000000
41800000b880d786c0000000
c2000000780d883b03000000
c2000000780d883b03000000
41800000b880d786c0000000
c2000000780d883b03000000
41800000b880d786c0000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
  unsigned char  f:2;
  unsigned short g:13;
};
-
{e=>2,c=>0,a=>4,g=>7279,b=>3,d=>226086089,f=>0}
1c000000c9cc792dbc710000
1c000000c9cc792dbc710000
1c000000c9cc792dbc710000
8c000000d79ccc9438de0000
1c000000c9cc792dbc710000
1c000000c9cc792dbc710000
8c000000d79ccc9438de0000
1c000000c9cc792dbc710000
8c000000d79ccc9438de0000
-
{e=>4,c=>1,a=>5,g=>1474,b=>6,d=>135043372,f=>2}
750000002c990c480a170000
750000002c990c480a170000
750000002c990c480a170000
b880000080c992c88b840000
750000002c990c480a170000
750000002c990c480a170000
b880000080c992c88b840000
750000002c990c480a170000
b880000080c992c88b840000
-
{e=>0,c=>2,a=>4,g=>4289,b=>6,d=>167538358,f=>2}
b4000000b66efc0906430000
b4000000b66efc0906430000
b4000000b66efc0906430000
990000009fc6eb60a1820000
b4000000b66efc0906430000
b4000000b66efc0906430000
990000009fc6eb60a1820000
b4000000b66efc0906430000
990000009fc6eb60a1820000
-
{e=>3,c=>4,a=>0,g=>1460,b=>0,d=>191785714,f=>1}
00010000f26a6e3bd1160000
00010000f26a6e3bd1160000
00010000f26a6e3bd1160000
02000000b6e6af264b680000
00010000f26a6e3bd1160000
00010000f26a6e3bd1160000
02000000b6e6af264b680000
00010000f26a6e3bd1160000
02000000b6e6af264b680000
-
{e=>1,c=>0,a=>4,g=>4192,b=>7,d=>193646184,f=>0}
3c00000068ce8a1b80410000
3c00000068ce8a1b80410000
3c00000068ce8a1b80410000
9c000000b8ace68220c00000
3c00000068ce8a1b80410000
3c00000068ce8a1b80410000
9c000000b8ace68220c00000
3c00000068ce8a1b80410000
9c000000b8ace68220c00000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
  unsigned char  f:2;
  unsigned short g:13;
  unsigned char  h;
};
-
{e=>2,a=>6,d=>72412399,c=>7,h=>156,b=>2,g=>1487,f=>3}
d6010000efec50243f179c00
d6010000efec50243f179c00
d6010000efec50243f179c00
cb800000450ecef4cb9e9c00
d6010000efec50243f179c00
d6010000efec50243f179c00
cb800000450ecef4cb9e9c00
d6010000efec50243f179c00
cb800000450ecef4cb9e9c00
-
{e=>6,a=>3,d=>227300670,c=>1,h=>201,b=>3,g=>4275,f=>1}
5b0000003e558c6dcd42c900
5b0000003e558c6dcd42c900
5b0000003e558c6dcd42c900
6c800000d8c553ec6166c900
5b0000003e558c6dcd42c900
5b0000003e558c6dcd42c900
6c800000d8c553ec6166c900
5b0000003e558c6dcd42c900
6c800000d8c553ec6166c900
-
{e=>3,a=>7,d=>180879568,c=>1,h=>224,b=>5,g=>7892,f=>3}
6f000000d000c83a537be000
6f000000d000c83a537be000
6f000000d000c83a537be000
f4800000ac800d06fda8e000
6f000000d000c83a537be000
6f000000d000c83a537be000
f4800000ac800d06fda8e000
6f000000d000c83a537be000
f4800000ac800d06fda8e000
-
{e=>3,a=>0,d=>137129408,c=>6,h=>116,b=>2,g=>269,f=>0}
90010000c06d2c3834047400
90010000c06d2c3834047400
90010000c06d2c3834047400
0b00000082c6dc06021a7400
90010000c06d2c3834047400
90010000c06d2c3834047400
0b00000082c6dc06021a7400
90010000c06d2c3834047400
0b00000082c6dc06021a7400
-
{e=>1,a=>3,d=>206927027,c=>2,h=>226,b=>7,g=>3383,f=>2}
bb000000b374551cde34e200
bb000000b374551cde34e200
bb000000b374551cde34e200
7d000000c5574b329a6ee200
bb000000b374551cde34e200
bb000000b374551cde34e200
7d000000c5574b329a6ee200
bb000000b374551cde34e200
7d000000c5574b329a6ee200
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  char a;
  unsigned char  b:3;
};
-
{a=>5,b=>0}
0500
0500
0500
0500
05000000
0500
0500
0500
0500
-
{a=>53,b=>0}
3500
3500
3500
3500
35000000
3500
3500
3500
3500
-
{a=>83,b=>5}
5305
5305
5305
53a0
53050000
5305
53a0
5305
53a0
-
{a=>4,b=>3}
0403
0403
0403
0460
04030000
0403
0460
0403
0460
-
{a=>-108,b=>1}
9401
9401
9401
9420
94010000
9401
9420
9401
9420
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>4,a=>-89,b=>5}
a725
a725
a725
a7b0
a7250000
a725
a7b0
a725
a7b0
-
{c=>3,a=>-94,b=>1}
a219
a219
a219
a22c
a2190000
a219
a22c
a219
a22c
-
{c=>2,a=>41,b=>1}
2911
2911
2911
2928
29110000
2911
2928
2911
2928
-
{c=>0,a=>-104,b=>5}
9805
9805
9805
98a0
98050000
9805
98a0
9805
98a0
-
{c=>4,a=>123,b=>7}
7b27
7b27
7b27
7bf0
7b270000
7b27
7bf0
7b27
7bf0
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>1,a=>26,b=>2,d=>6}
1a0a0600
1a0a0600
1a0a0600
1a44c000
1a0a0600
1a0a0600
1a44c000
1a0a0600
1a44c000
-
{c=>0,a=>41,b=>3,d=>7}
29030700
29030700
29030700
2960e000
29030700
29030700
2960e000
29030700
2960e000
-
{c=>0,a=>-60,b=>7,d=>5}
c4070500
c4070500
c4070500
c4e0a000
c4070500
c4070500
c4e0a000
c4070500
c4e0a000
-
{c=>4,a=>21,b=>5,d=>1}
15250100
15250100
15250100
15b02000
15250100
15250100
15b02000
15250100
15b02000
-
{c=>1,a=>-57,b=>3,d=>7}
c70b0700
c70b0700
c70b0700
c764e000
c70b0700
c70b0700
c764e000
c70b0700
c764e000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>251650091,c=>3,a=>18,b=>2,d=>6}
121a06002be0ff0e
121a06002be0ff0e
121a06002be0ff0e
124cc000effe02b0
121a06002be0ff0e
121a06002be0ff0e
124cc000effe02b0
121a06002be0ff0e
124cc000effe02b0
-
{e=>184337798,c=>4,a=>67,b=>1,d=>5}
4321050086c5fc0a
4321050086c5fc0a
4321050086c5fc0a
4330a000afcc5860
4321050086c5fc0a
4321050086c5fc0a
4330a000afcc5860
4321050086c5fc0a
4330a000afcc5860
-
{e=>18454609,c=>4,a=>-22,b=>2,d=>3}
ea22030051981901
ea22030051981901
ea22030051981901
ea50600011998510
ea22030051981901
ea22030051981901
ea50600011998510
ea22030051981901
ea50600011998510
-
{e=>172433341,c=>6,a=>76,b=>6,d=>7}
4c360700bd1f470a
4c360700bd1f470a
4c360700bd1f470a
4cd8e000a471fbd0
4c360700bd1f470a
4c360700bd1f470a
4cd8e000a471fbd0
4c360700bd1f470a
4cd8e000a471fbd0
-
{e=>134101335,c=>2,a=>103,b=>0,d=>4}
671004005739fe07
671004005739fe07
671004005739fe07
670880007fe39570
671004005739fe07
671004005739fe07
670880007fe39570
671004005739fe07
670880007fe39570
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>200236336,c=>5,a=>-24,b=>2,d=>3,f=>1}
e82a0300305def1b
e82a0300305def1b
e82a0300305def1b
e8546000bef5d302
e82a0300305def1b
e82a0300305def1b
e8546000bef5d302
e82a0300305def1b
e8546000bef5d302
-
{e=>16740769,c=>4,a=>-26,b=>0,d=>1,f=>3}
e6200100a171ff30
e6200100a171ff30
e6200100a171ff30
e61020000ff71a16
e6200100a171ff30
e6200100a171ff30
e61020000ff71a16
e6200100a171ff30
e61020000ff71a16
-
{e=>6071845,c=>4,a=>121,b=>4,d=>1,f=>2}
7924010025a65c20
7924010025a65c20
7924010025a65c20
7990200005ca6254
7924010025a65c20
7924010025a65c20
7990200005ca6254
7924010025a65c20
7990200005ca6254
-
{e=>24355757,c=>3,a=>-75,b=>5,d=>2,f=>2}
b51d0200ada37321
b51d0200ada37321
b51d0200ada37321
b5ac4000173a3ad4
b51d0200ada37321
b51d0200ada37321
b5ac4000173a3ad4
b51d0200ada37321
b5ac4000173a3ad4
-
{e=>167185341,c=>2,a=>21,b=>6,d=>4,f=>4}
15160400bd0bf749
15160400bd0bf749
15160400bd0bf749
15c880009f70bbd8
15160400bd0bf749
15160400bd0bf749
15c880009f70bbd8
15160400bd0bf749
15c880009f70bbd8
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>98259173,c=>2,a=>-44,g=>2,b=>6,d=>2,f=>2}
d4160200e550db2502000000
d4160200e550db2502000000
d4160200e550db2502000000
d4c840005db50e5480000000
d4160200e550db2502000000
d4160200e550db2502000000
d4c840005db50e5480000000
d4160200e550db2502000000
d4c840005db50e5480000000
-
{e=>101458287,c=>3,a=>107,g=>0,b=>2,d=>7,f=>2}
6b1a07006f210c2600000000
6b1a07006f210c2600000000
6b1a07006f210c2600000000
6b4ce00060c216f400000000
6b1a07006f210c2600000000
6b1a07006f210c2600000000
6b4ce00060c216f400000000
6b1a07006f210c2600000000
6b4ce00060c216f400000000
-
{e=>73372275,c=>5,a=>-94,g=>0,b=>1,d=>7,f=>1}
a229070073925f1400000000
a229070073925f1400000000
a229070073925f1400000000
a234e00045f9273200000000
a229070073925f1400000000
a229070073925f1400000000
a234e00045f9273200000000
a229070073925f1400000000
a234e00045f9273200000000
-
{e=>168006158,c=>5,a=>-34,g=>0,b=>0,d=>0,f=>5}
de2800000e92035a00000000
de2800000e92035a00000000
de2800000e92035a00000000
de140000a03920ea00000000
de2800000e92035a00000000
de2800000e92035a00000000
de140000a03920ea00000000
de2800000e92035a00000000
de140000a03920ea00000000
-
{e=>251692646,c=>0,a=>58,g=>1,b=>7,d=>2,f=>6}
3a0702006686006f01000000
3a0702006686006f01000000
3a0702006686006f01000000
3ae04000f008666c40000000
3a0702006686006f01000000
3a0702006686006f01000000
3ae04000f008666c40000000
3a0702006686006f01000000
3ae04000f008666c40000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>72582175,a=>66,d=>0,c=>0,h=>6020,b=>1,g=>0,f=>1}
420100001f845314105e0000
420100001f845314105e0000
420100001f845314105e0000
42200000453841f22f080000
420100001f845314105e0000
420100001f845314105e0000
42200000453841f22f080000
420100001f845314105e0000
42200000453841f22f080000
-
{e=>184039552,a=>30,d=>0,c=>3,h=>2419,b=>7,g=>2,f=>0}
1e1f00008038f80ace250000
1e1f00008038f80ace250000
1e1f00008038f80ace250000
1eec0000af83880092e60000
1e1f00008038f80ace250000
1e1f00008038f80ace250000
1eec0000af83880092e60000
1e1f00008038f80ace250000
1eec0000af83880092e60000
-
{e=>80164592,a=>-49,d=>3,c=>6,h=>7825,b=>5,g=>0,f=>7}
cf350300f036c774447a0000
cf350300f036c774447a0000
cf350300f036c774447a0000
cfb860004c736f0e3d220000
cf350300f036c774447a0000
cf350300f036c774447a0000
cfb860004c736f0e3d220000
cf350300f036c774447a0000
cfb860004c736f0e3d220000
-
{e=>159880110,a=>-107,d=>6,c=>0,h=>4520,b=>3,g=>1,f=>4}
95030600ae938749a1460000
95030600ae938749a1460000
95030600ae938749a1460000
9560c00098793ae863500000
95030600ae938749a1460000
95030600ae938749a1460000
9560c00098793ae863500000
95030600ae938749a1460000
9560c00098793ae863500000
-
{e=>237506163,a=>-31,d=>6,c=>0,h=>1061,b=>7,g=>3,f=>6}
e1070600730e286e97100000
e1070600730e286e97100000
e1070600730e286e97100000
e1e0c000e280e73cc84a0000
e1070600730e286e97100000
e1070600730e286e97100000
e1e0c000e280e73cc84a0000
e1070600730e286e97100000
e1e0c000e280e73cc84a0000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  unsigned char  i;
};
-
{e=>75173975,a=>0,d=>7,c=>5,h=>219,b=>2,g=>0,f=>2,i=>75}
002a070057107b246c034b00
002a070057107b246c034b00
002a070057107b246c034b00
0054e00047b1057401b64b00
002a070057107b246c034b00
002a070057107b246c034b00
0054e00047b1057401b64b00
002a070057107b246c034b00
0054e00047b1057401b64b00
-
{e=>14359521,a=>-73,d=>7,c=>3,h=>7081,b=>3,g=>1,f=>4,i=>127}
b71b0700e11bdb40a56e7f00
b71b0700e11bdb40a56e7f00
b71b0700e11bdb40a56e7f00
b76ce0000db1be1877527f00
b71b0700e11bdb40a56e7f00
b71b0700e11bdb40a56e7f00
b76ce0000db1be1877527f00
b71b0700e11bdb40a56e7f00
b76ce0000db1be1877527f00
-
{e=>93479715,a=>-14,d=>2,c=>4,h=>5837,b=>2,g=>0,f=>5,i=>120}
f222020023639255345b7800
f222020023639255345b7800
f222020023639255345b7800
f25040005926323a2d9a7800
f222020023639255345b7800
f222020023639255345b7800
f25040005926323a2d9a7800
f222020023639255345b7800
f25040005926323a2d9a7800
-
{e=>240985188,a=>123,d=>3,c=>4,h=>1817,b=>6,g=>0,f=>0,i=>75}
7b26030064245d0e641c4b00
7b26030064245d0e641c4b00
7b26030064245d0e641c4b00
7bd06000e5d246400e324b00
7b26030064245d0e641c4b00
7b26030064245d0e641c4b00
7bd06000e5d246400e324b00
7b26030064245d0e641c4b00
7bd06000e5d246400e324b00
-
{e=>31234999,a=>99,d=>6,c=>3,h=>4938,b=>0,g=>3,f=>3,i=>200}
63180600b79bdc312b4dc800
63180600b79bdc312b4dc800
63180600b79bdc312b4dc800
630cc0001dc9bb76e694c800
63180600b79bdc312b4dc800
63180600b79bdc312b4dc800
630cc0001dc9bb76e694c800
63180600b79bdc312b4dc800
630cc0001dc9bb76e694c800
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  short a;
  unsigned char  b:3;
};
-
{a=>-20,b=>2}
ecff0200
ecff0200
ecff0200
ffec4000
ecff0200
ecff0200
ffec4000
ecff0200
ffec4000
-
{a=>51,b=>0}
33000000
33000000
33000000
00330000
33000000
33000000
00330000
33000000
00330000
-
{a=>-61,b=>7}
c3ff0700
c3ff0700
c3ff0700
ffc3e000
c3ff0700
c3ff0700
ffc3e000
c3ff0700
ffc3e000
-
{a=>109,b=>2}
6d000200
6d000200
6d000200
006d4000
6d000200
6d000200
006d4000
6d000200
006d4000
-
{a=>3,b=>5}
03000500
03000500
03000500
0003a000
03000500
03000500
0003a000
03000500
0003a000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>1,a=>91,b=>0}
5b000800
5b000800
5b000800
005b0400
5b000800
5b000800
005b0400
5b000800
005b0400
-
{c=>6,a=>40,b=>1}
28003100
28003100
28003100
00283800
28003100
28003100
00283800
28003100
00283800
-
{c=>3,a=>73,b=>7}
49001f00
49001f00
49001f00
0049ec00
49001f00
49001f00
0049ec00
49001f00
0049ec00
-
{c=>2,a=>-70,b=>0}
baff1000
baff1000
baff1000
ffba0800
baff1000
baff1000
ffba0800
baff1000
ffba0800
-
{c=>3,a=>-86,b=>2}
aaff1a00
aaff1a00
aaff1a00
ffaa4c00
aaff1a00
aaff1a00
ffaa4c00
aaff1a00
ffaa4c00
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>7,a=>-16,b=>2,d=>0}
f0ff3a00
f0ff3a00
f0ff3a00
fff05c00
f0ff3a00
f0ff3a00
fff05c00
f0ff3a00
fff05c00
-
{c=>2,a=>120,b=>3,d=>3}
7800d300
7800d300
7800d300
00786980
7800d300
7800d300
00786980
7800d300
00786980
-
{c=>1,a=>109,b=>6,d=>6}
6d008e01
6d008e01
6d008e01
006dc700
6d008e01
6d008e01
006dc700
6d008e01
006dc700
-
{c=>2,a=>109,b=>7,d=>5}
6d005701
6d005701
6d005701
006dea80
6d005701
6d005701
006dea80
6d005701
006dea80
-
{c=>7,a=>35,b=>6,d=>4}
23003e01
23003e01
23003e01
0023de00
23003e01
23003e01
0023de00
23003e01
0023de00
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>242573218,c=>0,a=>-82,b=>5,d=>3}
aeffc500a25f750e
aeffc500a25f750e
aeffc500a25f750e
ffaea180e755fa20
aeffc500a25f750e
aeffc500a25f750e
ffaea180e755fa20
aeffc500a25f750e
ffaea180e755fa20
-
{e=>30225390,c=>1,a=>-90,b=>1,d=>0}
a6ff0900ee33cd01
a6ff0900ee33cd01
a6ff0900ee33cd01
ffa624001cd33ee0
a6ff0900ee33cd01
a6ff0900ee33cd01
ffa624001cd33ee0
a6ff0900ee33cd01
ffa624001cd33ee0
-
{e=>42673361,c=>7,a=>2,b=>7,d=>4}
02003f01d1248b02
02003f01d1248b02
02003f01d1248b02
0002fe0028b24d10
02003f01d1248b02
02003f01d1248b02
0002fe0028b24d10
02003f01d1248b02
0002fe0028b24d10
-
{e=>177618799,c=>1,a=>-74,b=>4,d=>0}
b6ff0c006f3f960a
b6ff0c006f3f960a
b6ff0c006f3f960a
ffb68400a963f6f0
b6ff0c006f3f960a
b6ff0c006f3f960a
ffb68400a963f6f0
b6ff0c006f3f960a
ffb68400a963f6f0
-
{e=>162146214,c=>1,a=>9,b=>5,d=>2}
09008d00a627aa09
09008d00a627aa09
09008d00a627aa09
0009a5009aa27a60
09008d00a627aa09
09008d00a627aa09
0009a5009aa27a60
09008d00a627aa09
0009a5009aa27a60
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>51386433,c=>7,a=>-38,b=>4,d=>2,f=>2}
daffbc0041181023
daffbc0041181023
daffbc0041181023
ffda9d0031018414
daffbc0041181023
daffbc0041181023
ffda9d0031018414
daffbc0041181023
ffda9d0031018414
-
{e=>119132246,c=>3,a=>-125,b=>6,d=>1,f=>0}
83ff5e0056d01907
83ff5e0056d01907
83ff5e0056d01907
ff83cc80719d0560
83ff5e0056d01907
83ff5e0056d01907
ff83cc80719d0560
83ff5e0056d01907
ff83cc80719d0560
-
{e=>28309628,c=>6,a=>-101,b=>5,d=>5,f=>0}
9bff75017cf8af01
9bff75017cf8af01
9bff75017cf8af01
ff9bba801aff87c0
9bff75017cf8af01
9bff75017cf8af01
ff9bba801aff87c0
9bff75017cf8af01
ff9bba801aff87c0
-
{e=>151543114,c=>3,a=>3,b=>2,d=>7,f=>5}
0300da014a5d0859
0300da014a5d0859
0300da014a5d0859
00034f809085d4aa
0300da014a5d0859
0300da014a5d0859
00034f809085d4aa
0300da014a5d0859
00034f809085d4aa
-
{e=>213132804,c=>5,a=>-95,b=>4,d=>0,f=>0}
a1ff2c000426b40c
a1ff2c000426b40c
a1ff2c000426b40c
ffa19400cb426040
a1ff2c000426b40c
a1ff2c000426b40c
ffa19400cb426040
a1ff2c000426b40c
ffa19400cb426040
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>142590409,c=>6,a=>-41,g=>0,b=>6,d=>3,f=>7}
d7fff600c9c17f7800000000
d7fff600c9c17f7800000000
d7fff600c9c17f7800000000
ffd7d98087fc1c9e00000000
d7fff600c9c17f7800000000
d7fff600c9c17f7800000000
ffd7d98087fc1c9e00000000
d7fff600c9c17f7800000000
ffd7d98087fc1c9e00000000
-
{e=>97470275,c=>4,a=>81,g=>1,b=>6,d=>6,f=>3}
5100a6014347cf3501000000
5100a6014347cf3501000000
5100a6014347cf3501000000
0051d3005cf4743640000000
5100a6014347cf3501000000
5100a6014347cf3501000000
0051d3005cf4743640000000
5100a6014347cf3501000000
0051d3005cf4743640000000
-
{e=>267791921,c=>1,a=>34,g=>1,b=>7,d=>2,f=>1}
22008f00312ef61f01000000
22008f00312ef61f01000000
22008f00312ef61f01000000
0022e500ff62e31240000000
22008f00312ef61f01000000
22008f00312ef61f01000000
0022e500ff62e31240000000
22008f00312ef61f01000000
0022e500ff62e31240000000
-
{e=>41800024,c=>3,a=>-80,g=>2,b=>0,d=>0,f=>1}
b0ff180058d17d1202000000
b0ff180058d17d1202000000
b0ff180058d17d1202000000
ffb00c0027dd158280000000
b0ff180058d17d1202000000
b0ff180058d17d1202000000
ffb00c0027dd158280000000
b0ff180058d17d1202000000
ffb00c0027dd158280000000
-
{e=>258096646,c=>0,a=>-31,g=>2,b=>3,d=>0,f=>3}
e1ff0300063e623f02000000
e1ff0300063e623f02000000
e1ff0300063e623f02000000
ffe16000f623e06680000000
e1ff0300063e623f02000000
e1ff0300063e623f02000000
ffe16000f623e06680000000
e1ff0300063e623f02000000
ffe16000f623e06680000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>122313407,a=>19,d=>3,c=>0,h=>650,b=>1,g=>1,f=>3}
1300c100bf5a4a37290a0000
1300c100bf5a4a37290a0000
1300c100bf5a4a37290a0000
0013218074a5abf645140000
1300c100bf5a4a37290a0000
1300c100bf5a4a37290a0000
0013218074a5abf645140000
1300c100bf5a4a37290a0000
0013218074a5abf645140000
-
{e=>94490750,a=>35,d=>1,c=>1,h=>5999,b=>4,g=>1,f=>0}
23004c007ed0a105bd5d0000
23004c007ed0a105bd5d0000
23004c007ed0a105bd5d0000
002384805a1d07e06ede0000
23004c007ed0a105bd5d0000
23004c007ed0a105bd5d0000
002384805a1d07e06ede0000
23004c007ed0a105bd5d0000
002384805a1d07e06ede0000
-
{e=>76168925,a=>-99,d=>0,c=>3,h=>6309,b=>6,g=>0,f=>6}
9dff1e00dd3e8a6494620000
9dff1e00dd3e8a6494620000
9dff1e00dd3e8a6494620000
ff9dcc0048a3eddc314a0000
9dff1e00dd3e8a6494620000
9dff1e00dd3e8a6494620000
ff9dcc0048a3eddc314a0000
9dff1e00dd3e8a6494620000
ff9dcc0048a3eddc314a0000
-
{e=>69639528,a=>-114,d=>1,c=>7,h=>2240,b=>2,g=>1,f=>7}
8eff7a00689d267401230000
8eff7a00689d267401230000
8eff7a00689d267401230000
ff8e5c804269d68e51800000
8eff7a00689d267401230000
8eff7a00689d267401230000
ff8e5c804269d68e51800000
8eff7a00689d267401230000
ff8e5c804269d68e51800000
-
{e=>138012526,a=>109,d=>3,c=>5,h=>7241,b=>3,g=>2,f=>0}
6d00eb006ee7390826710000
6d00eb006ee7390826710000
6d00eb006ee7390826710000
006d7580839e76e0b8920000
6d00eb006ee7390826710000
6d00eb006ee7390826710000
006d7580839e76e0b8920000
6d00eb006ee7390826710000
006d7580839e76e0b8920000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  unsigned char  i;
};
-
{e=>213997424,a=>12,d=>4,c=>5,h=>6891,b=>4,g=>0,f=>5,i=>155}
0c002c017057c15cac6b9b00
0c002c017057c15cac6b9b00
0c002c017057c15cac6b9b00
000c9600cc15770a35d69b00
0c002c017057c15cac6b9b00
0c002c017057c15cac6b9b00
000c9600cc15770a35d69b00
0c002c017057c15cac6b9b00
000c9600cc15770a35d69b00
-
{e=>80148154,a=>4,d=>3,c=>3,h=>5605,b=>4,g=>2,f=>7,i=>187}
0400dc00baf6c6749657bb00
0400dc00baf6c6749657bb00
0400dc00baf6c6749657bb00
00048d804c6f6baeabcabb00
0400dc00baf6c6749657bb00
0400dc00baf6c6749657bb00
00048d804c6f6baeabcabb00
0400dc00baf6c6749657bb00
00048d804c6f6baeabcabb00
-
{e=>17679511,a=>103,d=>4,c=>7,h=>793,b=>4,g=>1,f=>5,i=>154}
67003c0197c40d51650c9a00
67003c0197c40d51650c9a00
67003c0197c40d51650c9a00
00679e0010dc497a46329a00
67003c0197c40d51650c9a00
67003c0197c40d51650c9a00
00679e0010dc497a46329a00
67003c0197c40d51650c9a00
00679e0010dc497a46329a00
-
{e=>234963446,a=>-109,d=>7,c=>4,h=>4806,b=>2,g=>2,f=>0,i=>153}
93ffe201f641010e1a4b9900
93ffe201f641010e1a4b9900
93ffe201f641010e1a4b9900
ff935380e0141f60a58c9900
93ffe201f641010e1a4b9900
93ffe201f641010e1a4b9900
ff935380e0141f60a58c9900
93ffe201f641010e1a4b9900
ff935380e0141f60a58c9900
-
{e=>233686042,a=>26,d=>5,c=>3,h=>6938,b=>4,g=>1,f=>3,i=>229}
1a005c011ac4ed3d696ce500
1a005c011ac4ed3d696ce500
1a005c011ac4ed3d696ce500
001a8e80dedc41a67634e500
1a005c011ac4ed3d696ce500
1a005c011ac4ed3d696ce500
001a8e80dedc41a67634e500
1a005c011ac4ed3d696ce500
001a8e80dedc41a67634e500
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  int a;
  unsigned char  b:3;
};
-
{a=>-76,b=>0}
b4ffffff00000000
b4ffffff00000000
b4ffffff00000000
ffffffb400000000
b4ffffff00000000
b4ffffff00000000
ffffffb400000000
b4ffffff00000000
ffffffb400000000
-
{a=>-65,b=>4}
bfffffff04000000
bfffffff04000000
bfffffff04000000
ffffffbf80000000
bfffffff04000000
bfffffff04000000
ffffffbf80000000
bfffffff04000000
ffffffbf80000000
-
{a=>13,b=>3}
0d00000003000000
0d00000003000000
0d00000003000000
0000000d60000000
0d00000003000000
0d00000003000000
0000000d60000000
0d00000003000000
0000000d60000000
-
{a=>79,b=>5}
4f00000005000000
4f00000005000000
4f00000005000000
0000004fa0000000
4f00000005000000
4f00000005000000
0000004fa0000000
4f00000005000000
0000004fa0000000
-
{a=>-81,b=>4}
afffffff04000000
afffffff04000000
afffffff04000000
ffffffaf80000000
afffffff04000000
afffffff04000000
ffffffaf80000000
afffffff04000000
ffffffaf80000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>3,a=>84,b=>1}
5400000019000000
5400000019000000
5400000019000000
000000542c000000
5400000019000000
5400000019000000
000000542c000000
5400000019000000
000000542c000000
-
{c=>1,a=>127,b=>1}
7f00000009000000
7f00000009000000
7f00000009000000
0000007f24000000
7f00000009000000
7f00000009000000
0000007f24000000
7f00000009000000
0000007f24000000
-
{c=>5,a=>-114,b=>0}
8effffff28000000
8effffff28000000
8effffff28000000
ffffff8e14000000
8effffff28000000
8effffff28000000
ffffff8e14000000
8effffff28000000
ffffff8e14000000
-
{c=>3,a=>108,b=>1}
6c00000019000000
6c00000019000000
6c00000019000000
0000006c2c000000
6c00000019000000
6c00000019000000
0000006c2c000000
6c00000019000000
0000006c2c000000
-
{c=>7,a=>9,b=>1}
0900000039000000
0900000039000000
0900000039000000
000000093c000000
0900000039000000
0900000039000000
000000093c000000
0900000039000000
000000093c000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>6,a=>-62,b=>1,d=>4}
c2ffffff31010000
c2ffffff31010000
c2ffffff31010000
ffffffc23a000000
c2ffffff31010000
c2ffffff31010000
ffffffc23a000000
c2ffffff31010000
ffffffc23a000000
-
{c=>7,a=>74,b=>5,d=>0}
4a0000003d000000
4a0000003d000000
4a0000003d000000
0000004abc000000
4a0000003d000000
4a0000003d000000
0000004abc000000
4a0000003d000000
0000004abc000000
-
{c=>3,a=>-122,b=>2,d=>7}
86ffffffda010000
86ffffffda010000
86ffffffda010000
ffffff864f800000
86ffffffda010000
86ffffffda010000
ffffff864f800000
86ffffffda010000
ffffff864f800000
-
{c=>3,a=>-73,b=>7,d=>2}
b7ffffff9f000000
b7ffffff9f000000
b7ffffff9f000000
ffffffb7ed000000
b7ffffff9f000000
b7ffffff9f000000
ffffffb7ed000000
b7ffffff9f000000
ffffffb7ed000000
-
{c=>1,a=>13,b=>5,d=>2}
0d0000008d000000
0d0000008d000000
0d0000008d000000
0000000da5000000
0d0000008d000000
0d0000008d000000
0000000da5000000
0d0000008d000000
0000000da5000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>130106456,c=>4,a=>127,b=>7,d=>3}
7f000000e70000005844c107
7f000000e70000005844c107
7f000000e70000005844c107
0000007ff18000007c144580
7f000000e70000005844c107
7f000000e70000005844c107
0000007ff18000007c144580
7f000000e70000005844c107
0000007ff18000007c144580
-
{e=>228064205,c=>5,a=>28,b=>5,d=>3}
1c000000ed000000cdfb970d
1c000000ed000000cdfb970d
1c000000ed000000cdfb970d
0000001cb5800000d97fbcd0
1c000000ed000000cdfb970d
1c000000ed000000cdfb970d
0000001cb5800000d97fbcd0
1c000000ed000000cdfb970d
0000001cb5800000d97fbcd0
-
{e=>217906279,c=>1,a=>99,b=>0,d=>7}
63000000c801000067fcfc0c
63000000c801000067fcfc0c
63000000c801000067fcfc0c
0000006307800000cfcfc670
63000000c801000067fcfc0c
63000000c801000067fcfc0c
0000006307800000cfcfc670
63000000c801000067fcfc0c
0000006307800000cfcfc670
-
{e=>51712296,c=>5,a=>-8,b=>2,d=>6}
f8ffffffaa01000028111503
f8ffffffaa01000028111503
f8ffffffaa01000028111503
fffffff85700000031511280
f8ffffffaa01000028111503
f8ffffffaa01000028111503
fffffff85700000031511280
f8ffffffaa01000028111503
fffffff85700000031511280
-
{e=>211735696,c=>6,a=>78,b=>1,d=>0}
4e0000003100000090d49e0c
4e0000003100000090d49e0c
4e0000003100000090d49e0c
0000004e38000000c9ed4900
4e0000003100000090d49e0c
4e0000003100000090d49e0c
0000004e38000000c9ed4900
4e0000003100000090d49e0c
0000004e38000000c9ed4900
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>242564914,c=>0,a=>6,b=>0,d=>4,f=>4}
0600000000010000323f754e
0600000000010000323f754e
0600000000010000323f754e
0000000602000000e753f328
0600000000010000323f754e
0600000000010000323f754e
0000000602000000e753f328
0600000000010000323f754e
0000000602000000e753f328
-
{e=>142230259,c=>5,a=>-69,b=>3,d=>4,f=>0}
bbffffff2b010000f3427a08
bbffffff2b010000f3427a08
bbffffff2b010000f3427a08
ffffffbb7600000087a42f30
bbffffff2b010000f3427a08
bbffffff2b010000f3427a08
ffffffbb7600000087a42f30
bbffffff2b010000f3427a08
ffffffbb7600000087a42f30
-
{e=>40226599,c=>3,a=>-72,b=>3,d=>0,f=>0}
b8ffffff1b00000027cf6502
b8ffffff1b00000027cf6502
b8ffffff1b00000027cf6502
ffffffb86c000000265cf270
b8ffffff1b00000027cf6502
b8ffffff1b00000027cf6502
ffffffb86c000000265cf270
b8ffffff1b00000027cf6502
ffffffb86c000000265cf270
-
{e=>4604876,c=>0,a=>18,b=>5,d=>2,f=>5}
1200000085000000cc434650
1200000085000000cc434650
1200000085000000cc434650
00000012a100000004643cca
1200000085000000cc434650
1200000085000000cc434650
00000012a100000004643cca
1200000085000000cc434650
00000012a100000004643cca
-
{e=>209840252,c=>0,a=>-52,b=>3,d=>3,f=>2}
ccffffffc30000007ce8812c
ccffffffc30000007ce8812c
ccffffffc30000007ce8812c
ffffffcc61800000c81e87c4
ccffffffc30000007ce8812c
ccffffffc30000007ce8812c
ffffffcc61800000c81e87c4
ccffffffc30000007ce8812c
ffffffcc61800000c81e87c4
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>13259097,c=>3,a=>-63,g=>1,b=>5,d=>7,f=>3}
c1ffffffdd0100005951ca3001000000
c1ffffffdd0100005951ca3001000000
c1ffffffdd0100005951ca3001000000
ffffffc1af8000000ca5159640000000
c1ffffffdd0100005951ca3001000000
c1ffffffdd0100005951ca3001000000
ffffffc1af8000000ca5159640000000
c1ffffffdd0100005951ca3001000000
ffffffc1af8000000ca5159640000000
-
{e=>156908516,c=>4,a=>36,g=>0,b=>6,d=>0,f=>6}
2400000026000000e43b5a6900000000
2400000026000000e43b5a6900000000
2400000026000000e43b5a6900000000
00000024d000000095a3be4c00000000
2400000026000000e43b5a6900000000
2400000026000000e43b5a6900000000
00000024d000000095a3be4c00000000
2400000026000000e43b5a6900000000
00000024d000000095a3be4c00000000
-
{e=>59405293,c=>0,a=>117,g=>2,b=>5,d=>7,f=>7}
75000000c5010000ed738a7302000000
75000000c5010000ed738a7302000000
75000000c5010000ed738a7302000000
00000075a380000038a73ede80000000
75000000c5010000ed738a7302000000
75000000c5010000ed738a7302000000
00000075a380000038a73ede80000000
75000000c5010000ed738a7302000000
00000075a380000038a73ede80000000
-
{e=>247527189,c=>5,a=>66,g=>2,b=>2,d=>2,f=>1}
42000000aa00000015f7c01e02000000
42000000aa00000015f7c01e02000000
42000000aa00000015f7c01e02000000
0000004255000000ec0f715280000000
42000000aa00000015f7c01e02000000
42000000aa00000015f7c01e02000000
0000004255000000ec0f715280000000
42000000aa00000015f7c01e02000000
0000004255000000ec0f715280000000
-
{e=>80174753,c=>2,a=>-35,g=>1,b=>2,d=>0,f=>2}
ddffffff12000000a15ec72401000000
ddffffff12000000a15ec72401000000
ddffffff12000000a15ec72401000000
ffffffdd480000004c75ea1440000000
ddffffff12000000a15ec72401000000
ddffffff12000000a15ec72401000000
ffffffdd480000004c75ea1440000000
ddffffff12000000a15ec72401000000
ffffffdd480000004c75ea1440000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>79855944,a=>-79,d=>6,c=>0,h=>1469,b=>5,g=>1,f=>0}
b1ffffff850100004881c204f5160000
b1ffffff850100004881c204f5160000
b1ffffff850100004881c204f5160000
ffffffb1a30000004c2814804b7a0000
b1ffffff850100004881c204f5160000
b1ffffff850100004881c204f5160000
ffffffb1a30000004c2814804b7a0000
b1ffffff850100004881c204f5160000
ffffffb1a30000004c2814804b7a0000
-
{e=>55286286,a=>-110,d=>5,c=>5,h=>6486,b=>5,g=>1,f=>3}
92ffffff6d0100000e9a4b3359650000
92ffffff6d0100000e9a4b3359650000
92ffffff6d0100000e9a4b3359650000
ffffff92b680000034b9a0e672ac0000
92ffffff6d0100000e9a4b3359650000
92ffffff6d0100000e9a4b3359650000
ffffff92b680000034b9a0e672ac0000
92ffffff6d0100000e9a4b3359650000
ffffff92b680000034b9a0e672ac0000
-
{e=>230194727,a=>-49,d=>2,c=>2,h=>6812,b=>6,g=>1,f=>4}
cfffffff96000000277eb84d716a0000
cfffffff96000000277eb84d716a0000
cfffffff96000000277eb84d716a0000
ffffffcfc9000000db87e27875380000
cfffffff96000000277eb84d716a0000
cfffffff96000000277eb84d716a0000
ffffffcfc9000000db87e27875380000
cfffffff96000000277eb84d716a0000
ffffffcfc9000000db87e27875380000
-
{e=>191802023,a=>61,d=>7,c=>6,h=>7935,b=>4,g=>1,f=>2}
3d000000f4010000a7aa6e2bfd7b0000
3d000000f4010000a7aa6e2bfd7b0000
3d000000f4010000a7aa6e2bfd7b0000
0000003d9b800000b6eaaa747dfe0000
3d000000f4010000a7aa6e2bfd7b0000
3d000000f4010000a7aa6e2bfd7b0000
0000003d9b800000b6eaaa747dfe0000
3d000000f4010000a7aa6e2bfd7b0000
0000003d9b800000b6eaaa747dfe0000
-
{e=>31737331,a=>18,d=>6,c=>6,h=>5531,b=>3,g=>2,f=>2}
12000000b3010000f345e4216e560000
12000000b3010000f345e4216e560000
12000000b3010000f345e4216e560000
000000127b0000001e445f34ab360000
12000000b3010000f345e4216e560000
12000000b3010000f345e4216e560000
000000127b0000001e445f34ab360000
12000000b3010000f345e4216e560000
000000127b0000001e445f34ab360000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  unsigned char  i;
};
-
{e=>257753255,a=>78,d=>5,c=>1,h=>4307,b=>5,g=>1,f=>3,i=>23}
4e0000004d010000a7005d3f4d431700
4e0000004d010000a7005d3f4d431700
4e0000004d010000a7005d3f4d431700
0000004ea6800000f5d00a7661a61700
4e0000004d010000a7005d3f4d431700
4e0000004d010000a7005d3f4d431700
0000004ea6800000f5d00a7661a61700
4e0000004d010000a7005d3f4d431700
0000004ea6800000f5d00a7661a61700
-
{e=>154752796,a=>-128,d=>3,c=>3,h=>1857,b=>7,g=>2,f=>4,i=>149}
80ffffffdf0000001c573949061d9500
80ffffffdf0000001c573949061d9500
80ffffffdf0000001c573949061d9500
ffffff80ed800000939571c88e829500
80ffffffdf0000001c573949061d9500
80ffffffdf0000001c573949061d9500
ffffff80ed800000939571c88e829500
80ffffffdf0000001c573949061d9500
ffffff80ed800000939571c88e829500
-
{e=>48153402,a=>-86,d=>4,c=>5,h=>2443,b=>5,g=>1,f=>3,i=>106}
aaffffff2d0100003ac3de322d266a00
aaffffff2d0100003ac3de322d266a00
aaffffff2d0100003ac3de322d266a00
ffffffaab60000002dec33a653166a00
aaffffff2d0100003ac3de322d266a00
aaffffff2d0100003ac3de322d266a00
ffffffaab60000002dec33a653166a00
aaffffff2d0100003ac3de322d266a00
ffffffaab60000002dec33a653166a00
-
{e=>149056525,a=>-9,d=>6,c=>2,h=>4899,b=>0,g=>1,f=>2,i=>164}
f7ffffff900100000d6ce2288d4ca400
f7ffffff900100000d6ce2288d4ca400
f7ffffff900100000d6ce2288d4ca400
fffffff70b0000008e26c0d46646a400
f7ffffff900100000d6ce2288d4ca400
f7ffffff900100000d6ce2288d4ca400
fffffff70b0000008e26c0d46646a400
f7ffffff900100000d6ce2288d4ca400
fffffff70b0000008e26c0d46646a400
-
{e=>211134956,a=>118,d=>5,c=>1,h=>1779,b=>3,g=>1,f=>5,i=>234}
760000004b010000eca9955ccd1bea00
760000004b010000eca9955ccd1bea00
760000004b010000eca9955ccd1bea00
0000007666800000c95a9eca4de6ea00
760000004b010000eca9955ccd1bea00
760000004b010000eca9955ccd1bea00
0000007666800000c95a9eca4de6ea00
760000004b010000eca9955ccd1bea00
0000007666800000c95a9eca4de6ea00
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  long a;
  unsigned char  b:3;
};
-
{a=>83,b=>3}
5300000003000000
53000000000000000300000000000000
53000000000000000300000000000000
0000005360000000
5300000003000000
5300000003000000
00000000000000536000000000000000
5300000003000000
0000005360000000
-
{a=>118,b=>5}
7600000005000000
76000000000000000500000000000000
76000000000000000500000000000000
00000076a0000000
7600000005000000
7600000005000000
0000000000000076a000000000000000
7600000005000000
00000076a0000000
-
{a=>102,b=>4}
6600000004000000
66000000000000000400000000000000
66000000000000000400000000000000
0000006680000000
6600000004000000
6600000004000000
00000000000000668000000000000000
6600000004000000
0000006680000000
-
{a=>-46,b=>3}
d2ffffff03000000
d2ffffffffffffff0300000000000000
d2ffffffffffffff0300000000000000
ffffffd260000000
d2ffffff03000000
d2ffffff03000000
ffffffffffffffd26000000000000000
d2ffffff03000000
ffffffd260000000
-
{a=>-65,b=>5}
bfffffff05000000
bfffffffffffffff0500000000000000
bfffffffffffffff0500000000000000
ffffffbfa0000000
bfffffff05000000
bfffffff05000000
ffffffffffffffbfa000000000000000
bfffffff05000000
ffffffbfa0000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>6,a=>101,b=>1}
6500000031000000
65000000000000003100000000000000
65000000000000003100000000000000
0000006538000000
6500000031000000
6500000031000000
00000000000000653800000000000000
6500000031000000
0000006538000000
-
{c=>5,a=>32,b=>7}
200000002f000000
20000000000000002f00000000000000
20000000000000002f00000000000000
00000020f4000000
200000002f000000
200000002f000000
0000000000000020f400000000000000
200000002f000000
00000020f4000000
-
{c=>7,a=>-74,b=>2}
b6ffffff3a000000
b6ffffffffffffff3a00000000000000
b6ffffffffffffff3a00000000000000
ffffffb65c000000
b6ffffff3a000000
b6ffffff3a000000
ffffffffffffffb65c00000000000000
b6ffffff3a000000
ffffffb65c000000
-
{c=>4,a=>-84,b=>1}
acffffff21000000
acffffffffffffff2100000000000000
acffffffffffffff2100000000000000
ffffffac30000000
acffffff21000000
acffffff21000000
ffffffffffffffac3000000000000000
acffffff21000000
ffffffac30000000
-
{c=>3,a=>-100,b=>4}
9cffffff1c000000
9cffffffffffffff1c00000000000000
9cffffffffffffff1c00000000000000
ffffff9c8c000000
9cffffff1c000000
9cffffff1c000000
ffffffffffffff9c8c00000000000000
9cffffff1c000000
ffffff9c8c000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>3,a=>-18,b=>2,d=>4}
eeffffff1a010000
eeffffffffffffff1a01000000000000
eeffffffffffffff1a01000000000000
ffffffee4e000000
eeffffff1a010000
eeffffff1a010000
ffffffffffffffee4e00000000000000
eeffffff1a010000
ffffffee4e000000
-
{c=>0,a=>-123,b=>2,d=>3}
85ffffffc2000000
85ffffffffffffffc200000000000000
85ffffffffffffffc200000000000000
ffffff8541800000
85ffffffc2000000
85ffffffc2000000
ffffffffffffff854180000000000000
85ffffffc2000000
ffffff8541800000
-
{c=>5,a=>85,b=>2,d=>3}
55000000ea000000
5500000000000000ea00000000000000
5500000000000000ea00000000000000
0000005555800000
55000000ea000000
55000000ea000000
00000000000000555580000000000000
55000000ea000000
0000005555800000
-
{c=>5,a=>-113,b=>7,d=>6}
8fffffffaf010000
8fffffffffffffffaf01000000000000
8fffffffffffffffaf01000000000000
ffffff8ff7000000
8fffffffaf010000
8fffffffaf010000
ffffffffffffff8ff700000000000000
8fffffffaf010000
ffffff8ff7000000
-
{c=>3,a=>66,b=>0,d=>6}
4200000098010000
42000000000000009801000000000000
42000000000000009801000000000000
000000420f000000
4200000098010000
4200000098010000
00000000000000420f00000000000000
4200000098010000
000000420f000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>160937402,c=>7,a=>27,b=>7,d=>5}
1b0000007f010000bab59709
1b000000000000007f010000bab59709
1b000000000000007f010000bab59709
0000001bfe800000997b5ba0
1b0000007f010000bab59709
1b0000007f010000bab59709
000000000000001bfe800000997b5ba0
1b0000007f010000bab59709
0000001bfe800000997b5ba0
-
{e=>20048177,c=>3,a=>28,b=>7,d=>6}
1c0000009f01000031e93101
1c000000000000009f01000031e93101
1c000000000000009f01000031e93101
0000001cef000000131e9310
1c0000009f01000031e93101
1c0000009f01000031e93101
000000000000001cef000000131e9310
1c0000009f01000031e93101
0000001cef000000131e9310
-
{e=>246627849,c=>0,a=>-81,b=>4,d=>3}
afffffffc4000000093eb30e
afffffffffffffffc4000000093eb30e
afffffffffffffffc4000000093eb30e
ffffffaf81800000eb33e090
afffffffc4000000093eb30e
afffffffc4000000093eb30e
ffffffffffffffaf81800000eb33e090
afffffffc4000000093eb30e
ffffffaf81800000eb33e090
-
{e=>200039194,c=>5,a=>112,b=>2,d=>1}
700000006a0000001a5bec0b
70000000000000006a0000001a5bec0b
70000000000000006a0000001a5bec0b
0000007054800000bec5b1a0
700000006a0000001a5bec0b
700000006a0000001a5bec0b
000000000000007054800000bec5b1a0
700000006a0000001a5bec0b
0000007054800000bec5b1a0
-
{e=>250650060,c=>0,a=>124,b=>1,d=>6}
7c00000081010000cc9df00e
7c0000000000000081010000cc9df00e
7c0000000000000081010000cc9df00e
0000007c23000000ef09dcc0
7c00000081010000cc9df00e
7c00000081010000cc9df00e
000000000000007c23000000ef09dcc0
7c00000081010000cc9df00e
0000007c23000000ef09dcc0
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>164019807,c=>0,a=>-107,b=>4,d=>4,f=>4}
95ffffff040100005fbec649
95ffffffffffffff040100005fbec649
95ffffffffffffff040100005fbec649
ffffff95820000009c6be5f8
95ffffff040100005fbec649
95ffffff040100005fbec649
ffffffffffffff95820000009c6be5f8
95ffffff040100005fbec649
ffffff95820000009c6be5f8
-
{e=>148347054,c=>7,a=>122,b=>5,d=>4,f=>4}
7a0000003d010000ae98d748
7a000000000000003d010000ae98d748
7a000000000000003d010000ae98d748
0000007abe0000008d798ae8
7a0000003d010000ae98d748
7a0000003d010000ae98d748
000000000000007abe0000008d798ae8
7a0000003d010000ae98d748
0000007abe0000008d798ae8
-
{e=>201328566,c=>2,a=>-38,b=>2,d=>0,f=>5}
daffffff12000000b607005c
daffffffffffffff12000000b607005c
daffffffffffffff12000000b607005c
ffffffda48000000c0007b6a
daffffff12000000b607005c
daffffff12000000b607005c
ffffffffffffffda48000000c0007b6a
daffffff12000000b607005c
ffffffda48000000c0007b6a
-
{e=>17793067,c=>3,a=>62,b=>5,d=>1,f=>6}
3e0000005d0000002b800f61
3e000000000000005d0000002b800f61
3e000000000000005d0000002b800f61
0000003eac80000010f802bc
3e0000005d0000002b800f61
3e0000005d0000002b800f61
000000000000003eac80000010f802bc
3e0000005d0000002b800f61
0000003eac80000010f802bc
-
{e=>265362806,c=>3,a=>-81,b=>7,d=>0,f=>0}
afffffff1f000000761dd10f
afffffffffffffff1f000000761dd10f
afffffffffffffff1f000000761dd10f
ffffffafec000000fd11d760
afffffff1f000000761dd10f
afffffff1f000000761dd10f
ffffffffffffffafec000000fd11d760
afffffff1f000000761dd10f
ffffffafec000000fd11d760
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>119342936,c=>2,a=>-110,g=>0,b=>2,d=>6,f=>7}
92ffffff9201000058071d7700000000
92ffffffffffffff9201000058071d770000000000000000
92ffffffffffffff9201000058071d770000000000000000
ffffff924b00000071d0758e00000000
92ffffff9201000058071d7700000000
92ffffff9201000058071d7700000000
ffffffffffffff924b00000071d0758e0000000000000000
92ffffff9201000058071d7700000000
ffffff924b00000071d0758e00000000
-
{e=>62059604,c=>7,a=>-92,g=>3,b=>4,d=>4,f=>7}
a4ffffff3c01000054f4b27303000000
a4ffffffffffffff3c01000054f4b2730300000000000000
a4ffffffffffffff3c01000054f4b2730300000000000000
ffffffa49e0000003b2f454ec0000000
a4ffffff3c01000054f4b27303000000
a4ffffff3c01000054f4b27303000000
ffffffffffffffa49e0000003b2f454ec000000000000000
a4ffffff3c01000054f4b27303000000
ffffffa49e0000003b2f454ec0000000
-
{e=>174545826,c=>6,a=>-60,g=>3,b=>2,d=>3,f=>1}
c4fffffff2000000a25b671a03000000
c4fffffffffffffff2000000a25b671a0300000000000000
c4fffffffffffffff2000000a25b671a0300000000000000
ffffffc459800000a675ba22c0000000
c4fffffff2000000a25b671a03000000
c4fffffff2000000a25b671a03000000
ffffffffffffffc459800000a675ba22c000000000000000
c4fffffff2000000a25b671a03000000
ffffffc459800000a675ba22c0000000
-
{e=>133811322,c=>5,a=>106,g=>2,b=>2,d=>0,f=>4}
6a0000002a0000007accf94702000000
6a000000000000002a0000007accf9470200000000000000
6a000000000000002a0000007accf9470200000000000000
0000006a540000007f9cc7a880000000
6a0000002a0000007accf94702000000
6a0000002a0000007accf94702000000
000000000000006a540000007f9cc7a88000000000000000
6a0000002a0000007accf94702000000
0000006a540000007f9cc7a880000000
-
{e=>181399152,c=>6,a=>71,g=>3,b=>4,d=>7,f=>7}
47000000f401000070eecf7a03000000
4700000000000000f401000070eecf7a0300000000000000
4700000000000000f401000070eecf7a0300000000000000
000000479b800000acfee70ec0000000
47000000f401000070eecf7a03000000
47000000f401000070eecf7a03000000
00000000000000479b800000acfee70ec000000000000000
47000000f401000070eecf7a03000000
000000479b800000acfee70ec0000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>178239616,a=>-56,d=>2,c=>0,h=>947,b=>6,g=>2,f=>5}
c8ffffff8600000080b89f5ace0e0000
c8ffffffffffffff8600000080b89f5ace0e000000000000
c8ffffffffffffff8600000080b89f5ace0e000000000000
ffffffc8c1000000a9fb880a87660000
c8ffffff8600000080b89f5ace0e0000
c8ffffff8600000080b89f5ace0e0000
ffffffffffffffc8c1000000a9fb880a8766000000000000
c8ffffff8600000080b89f5ace0e0000
ffffffc8c1000000a9fb880a87660000
-
{e=>92807764,a=>66,d=>7,c=>0,h=>2391,b=>5,g=>2,f=>3}
42000000c5010000542288355e250000
4200000000000000c5010000542288355e25000000000000
4200000000000000c5010000542288355e25000000000000
00000042a38000005882254692ae0000
42000000c5010000542288355e250000
42000000c5010000542288355e250000
0000000000000042a38000005882254692ae000000000000
42000000c5010000542288355e250000
00000042a38000005882254692ae0000
-
{e=>217147655,a=>26,d=>5,c=>6,h=>7725,b=>4,g=>1,f=>2}
1a000000740100000769f12cb5780000
1a00000000000000740100000769f12cb578000000000000
1a00000000000000740100000769f12cb578000000000000
0000001a9a800000cf1690747c5a0000
1a000000740100000769f12cb5780000
1a000000740100000769f12cb5780000
000000000000001a9a800000cf1690747c5a000000000000
1a000000740100000769f12cb5780000
0000001a9a800000cf1690747c5a0000
-
{e=>94483661,a=>-122,d=>7,c=>6,h=>3773,b=>6,g=>2,f=>7}
86fffffff6010000cdb4a175f63a0000
86fffffffffffffff6010000cdb4a175f63a000000000000
86fffffffffffffff6010000cdb4a175f63a000000000000
ffffff86db8000005a1b4cde9d7a0000
86fffffff6010000cdb4a175f63a0000
86fffffff6010000cdb4a175f63a0000
ffffffffffffff86db8000005a1b4cde9d7a000000000000
86fffffff6010000cdb4a175f63a0000
ffffff86db8000005a1b4cde9d7a0000
-
{e=>255972856,a=>-65,d=>4,c=>6,h=>4167,b=>3,g=>2,f=>7}
bfffffff33010000f8d5417f1e410000
bfffffffffffffff33010000f8d5417f1e41000000000000
bfffffffffffffff33010000f8d5417f1e41000000000000
ffffffbf7a000000f41d5f8ea08e0000
bfffffff33010000f8d5417f1e410000
bfffffff33010000f8d5417f1e410000
ffffffffffffffbf7a000000f41d5f8ea08e000000000000
bfffffff33010000f8d5417f1e410000
ffffffbf7a000000f41d5f8ea08e0000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct umixed_pack_1 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  unsigned char  i;
};
-
{e=>236368736,a=>50,d=>0,c=>0,h=>550,b=>0,g=>3,f=>2,i=>115}
320000000000000060b3162e9b087300
32000000000000000000000060b3162e9b08730000000000
32000000000000000000000060b3162e9b08730000000000
0000003200000000e16b3604c44c7300
320000000000000060b3162e9b087300
320000000000000060b3162e9b087300
000000000000003200000000e16b3604c44c730000000000
320000000000000060b3162e9b087300
0000003200000000e16b3604c44c7300
-
{e=>88524857,a=>-90,d=>2,c=>1,h=>306,b=>4,g=>3,f=>5,i=>249}
a6ffffff8c00000039c84655cb04f900
a6ffffffffffffff8c00000039c84655cb04f90000000000
a6ffffffffffffff8c00000039c84655cb04f90000000000
ffffffa685000000546c839ac264f900
a6ffffff8c00000039c84655cb04f900
a6ffffff8c00000039c84655cb04f900
ffffffffffffffa685000000546c839ac264f90000000000
a6ffffff8c00000039c84655cb04f900
ffffffa685000000546c839ac264f900
-
{e=>192500988,a=>-84,d=>1,c=>2,h=>5667,b=>5,g=>0,f=>5,i=>178}
acffffff55000000fc54795b8c58b200
acffffffffffffff55000000fc54795b8c58b20000000000
acffffffffffffff55000000fc54795b8c58b20000000000
ffffffaca8800000b7954fca2c46b200
acffffff55000000fc54795b8c58b200
acffffff55000000fc54795b8c58b200
ffffffffffffffaca8800000b7954fca2c46b20000000000
acffffff55000000fc54795b8c58b200
ffffffaca8800000b7954fca2c46b200
-
{e=>102319901,a=>48,d=>6,c=>5,h=>4809,b=>5,g=>0,f=>5,i=>243}
30000000ad0100001d471956244bf300
3000000000000000ad0100001d471956244bf30000000000
3000000000000000ad0100001d471956244bf30000000000
00000030b7000000619471da2592f300
30000000ad0100001d471956244bf300
30000000ad0100001d471956244bf300
0000000000000030b7000000619471da2592f30000000000
30000000ad0100001d471956244bf300
00000030b7000000619471da2592f300
-
{e=>105125875,a=>-48,d=>6,c=>2,h=>3701,b=>4,g=>0,f=>6,i=>134}
d0ffffff94010000f3174466d4398600
d0ffffffffffffff94010000f3174466d439860000000000
d0ffffffffffffff94010000f3174466d439860000000000
ffffffd08b00000064417f3c1cea8600
d0ffffff94010000f3174466d4398600
d0ffffff94010000f3174466d4398600
ffffffffffffffd08b00000064417f3c1cea860000000000
d0ffffff94010000f3174466d4398600
ffffffd08b00000064417f3c1cea8600
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  unsigned char  a:3;
};
-
{a=>7}
07
07
07
e0
07000000
07
e0
07
e0
-
{a=>4}
04
04
04
80
04000000
04
80
04
80
-
{a=>4}
04
04
04
80
04000000
04
80
04
80
-
{a=>7}
07
07
07
e0
07000000
07
e0
07
e0
-
{a=>1}
01
01
01
20
01000000
01
20
01
20
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  unsigned char  a:3;
  unsigned char  b:3;
};
-
{a=>6,b=>7}
3e
3e
3e
dc
3e000000
3e
dc
3e
dc
-
{a=>6,b=>0}
06
06
06
c0
06000000
06
c0
06
c0
-
{a=>1,b=>6}
31
31
31
38
31000000
31
38
31
38
-
{a=>3,b=>4}
23
23
23
70
23000000
23
70
23
70
-
{a=>5,b=>5}
2d
2d
2d
b4
2d000000
2d
b4
2d
b4
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
};
-
{c=>6,a=>3,b=>3}
9b01
9b01
9b01
6f00
9b010000
9b01
6f00
9b01
6f00
-
{c=>2,a=>6,b=>1}
8e00
8e00
8e00
c500
8e000000
8e00
c500
8e00
c500
-
{c=>6,a=>4,b=>1}
8c01
8c01
8c01
8700
8c010000
8c01
8700
8c01
8700
-
{c=>2,a=>1,b=>0}
8100
8100
8100
2100
81000000
8100
2100
8100
2100
-
{c=>7,a=>4,b=>7}
fc01
fc01
fc01
9f80
fc010000
fc01
9f80
fc01
9f80
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
};
-
{c=>1,a=>4,b=>4,d=>133269742}
64000000ee88f107
64000000ee88f107
64000000ee88f107
908000007f188ee0
64000000ee88f107
64000000ee88f107
908000007f188ee0
64000000ee88f107
908000007f188ee0
-
{c=>3,a=>7,b=>1,d=>257081784}
cf000000b8c1520f
cf000000b8c1520f
cf000000b8c1520f
e5800000f52c1b80
cf000000b8c1520f
cf000000b8c1520f
e5800000f52c1b80
cf000000b8c1520f
e5800000f52c1b80
-
{c=>0,a=>7,b=>6,d=>258403104}
3700000020eb660f
3700000020eb660f
3700000020eb660f
f8000000f66eb200
3700000020eb660f
3700000020eb660f
f8000000f66eb200
3700000020eb660f
f8000000f66eb200
-
{c=>5,a=>7,b=>0,d=>128978242}
47010000420db007
47010000420db007
47010000420db007
e28000007b00d420
47010000420db007
47010000420db007
e28000007b00d420
47010000420db007
e28000007b00d420
-
{c=>5,a=>0,b=>4,d=>243031951}
600100008f5f7c0e
600100008f5f7c0e
600100008f5f7c0e
12800000e7c5f8f0
600100008f5f7c0e
600100008f5f7c0e
12800000e7c5f8f0
600100008f5f7c0e
12800000e7c5f8f0
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
};
-
{e=>0,c=>2,a=>6,b=>7,d=>33702724}
be00000044430202
be00000044430202
be00000044430202
dd00000020243440
be00000044430202
be00000044430202
dd00000020243440
be00000044430202
dd00000020243440
-
{e=>2,c=>5,a=>5,b=>2,d=>6095297}
55010000c1015d20
55010000c1015d20
55010000c1015d20
aa80000005d01c14
55010000c1015d20
55010000c1015d20
aa80000005d01c14
55010000c1015d20
aa80000005d01c14
-
{e=>4,c=>4,a=>4,b=>6,d=>213519559}
34010000c70cba4c
34010000c70cba4c
34010000c70cba4c
9a000000cba0cc78
34010000c70cba4c
34010000c70cba4c
9a000000cba0cc78
34010000c70cba4c
9a000000cba0cc78
-
{e=>5,c=>2,a=>7,b=>5,d=>18462540}
af0000004cb71951
af0000004cb71951
af0000004cb71951
f5000000119b74ca
af0000004cb71951
af0000004cb71951
f5000000119b74ca
af0000004cb71951
f5000000119b74ca
-
{e=>1,c=>6,a=>1,b=>7,d=>89059346}
b901000012f04e15
b901000012f04e15
b901000012f04e15
3f00000054ef0122
b901000012f04e15
b901000012f04e15
3f00000054ef0122
b901000012f04e15
3f00000054ef0122
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
  unsigned char  f:2;
};
-
{e=>5,c=>1,a=>7,b=>1,d=>136757511,f=>1}
4f00000007c1265801000000
4f00000007c1265801000000
4f00000007c1265801000000
e4800000826c107a40000000
4f00000007c1265801000000
4f00000007c1265801000000
e4800000826c107a40000000
4f00000007c1265801000000
e4800000826c107a40000000
-
{e=>0,c=>4,a=>7,b=>4,d=>125709169,f=>0}
27010000712b7e0700000000
27010000712b7e0700000000
27010000712b7e0700000000
f200000077e2b71000000000
27010000712b7e0700000000
27010000712b7e0700000000
f200000077e2b71000000000
27010000712b7e0700000000
f200000077e2b71000000000
-
{e=>4,c=>6,a=>4,b=>0,d=>58396282,f=>2}
840100007a0e7b4302000000
840100007a0e7b4302000000
840100007a0e7b4302000000
8300000037b0e7a880000000
840100007a0e7b4302000000
840100007a0e7b4302000000
8300000037b0e7a880000000
840100007a0e7b4302000000
8300000037b0e7a880000000
-
{e=>0,c=>7,a=>2,b=>1,d=>156900784,f=>0}
ca010000b01d5a0900000000
ca010000b01d5a0900000000
ca010000b01d5a0900000000
4780000095a1db0000000000
ca010000b01d5a0900000000
ca010000b01d5a0900000000
4780000095a1db0000000000
ca010000b01d5a0900000000
4780000095a1db0000000000
-
{e=>6,c=>5,a=>4,b=>0,d=>153791533,f=>0}
440100002dac2a6900000000
440100002dac2a6900000000
440100002dac2a6900000000
8280000092aac2dc00000000
440100002dac2a6900000000
440100002dac2a6900000000
8280000092aac2dc00000000
440100002dac2a6900000000
8280000092aac2dc00000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
  unsigned char  f:2;
  unsigned short g:13;
};
-
{e=>4,c=>6,a=>0,g=>3159,b=>3,d=>201444973,f=>3}
980100006dce014c5f310000
980100006dce014c5f310000
980100006dce014c5f310000
0f000000c01ce6d8d8ae0000
980100006dce014c5f310000
980100006dce014c5f310000
0f000000c01ce6d8d8ae0000
980100006dce014c5f310000
0f000000c01ce6d8d8ae0000
-
{e=>3,c=>5,a=>2,g=>1311,b=>0,d=>216985875,f=>0}
4201000013f1ee3c7c140000
4201000013f1ee3c7c140000
4201000013f1ee3c7c140000
42800000ceef11360a3e0000
4201000013f1ee3c7c140000
4201000013f1ee3c7c140000
42800000ceef11360a3e0000
4201000013f1ee3c7c140000
42800000ceef11360a3e0000
-
{e=>4,c=>1,a=>4,g=>4089,b=>3,d=>90392677,f=>2}
5c00000065486345e63f0000
5c00000065486345e63f0000
5c00000065486345e63f0000
8c800000563486589ff20000
5c00000065486345e63f0000
5c00000065486345e63f0000
8c800000563486589ff20000
5c00000065486345e63f0000
8c800000563486589ff20000
-
{e=>4,c=>6,a=>2,g=>6577,b=>0,d=>32952048,f=>2}
82010000f0cef641c6660000
82010000f0cef641c6660000
82010000f0cef641c6660000
430000001f6cef08b3620000
82010000f0cef641c6660000
82010000f0cef641c6660000
430000001f6cef08b3620000
82010000f0cef641c6660000
430000001f6cef08b3620000
-
{e=>6,c=>3,a=>2,g=>5134,b=>2,d=>70582675,f=>0}
d20000009301356438500000
d20000009301356438500000
d20000009301356438500000
498000004350193c281c0000
d20000009301356438500000
d20000009301356438500000
498000004350193c281c0000
d20000009301356438500000
498000004350193c281c0000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
  unsigned char  f:2;
  unsigned short g:13;
  unsigned char  h;
};
-
{e=>4,a=>7,d=>66200696,c=>5,h=>31,b=>4,g=>6484,f=>1}
670100007824f24351651f00
670100007824f24351651f00
670100007824f24351651f00
f28000003f22478872a81f00
670100007824f24351651f00
670100007824f24351651f00
f28000003f22478872a81f00
670100007824f24351651f00
f28000003f22478872a81f00
-
{e=>3,a=>0,d=>142854848,c=>3,h=>30,b=>3,g=>2350,f=>3}
d8000000c0ca8338bb241e00
d8000000c0ca8338bb241e00
d8000000c0ca8338bb241e00
0d800000883cac06d25c1e00
d8000000c0ca8338bb241e00
d8000000c0ca8338bb241e00
0d800000883cac06d25c1e00
d8000000c0ca8338bb241e00
0d800000883cac06d25c1e00
-
{e=>0,a=>3,d=>178180283,c=>3,h=>162,b=>2,g=>1577,f=>2}
d3000000bbd09e0aa618a200
d3000000bbd09e0aa618a200
d3000000bbd09e0aa618a200
69800000a9ed0bb08c52a200
d3000000bbd09e0aa618a200
d3000000bbd09e0aa618a200
69800000a9ed0bb08c52a200
d3000000bbd09e0aa618a200
69800000a9ed0bb08c52a200
-
{e=>7,a=>3,d=>71770977,c=>0,h=>159,b=>4,g=>2221,f=>2}
2300000061234774b6229f00
2300000061234774b6229f00
2300000061234774b6229f00
700000004472361e915a9f00
2300000061234774b6229f00
2300000061234774b6229f00
700000004472361e915a9f00
2300000061234774b6229f00
700000004472361e915a9f00
-
{e=>3,a=>7,d=>209718566,c=>4,h=>184,b=>0,g=>4011,f=>3}
07010000260d803caf3eb800
07010000260d803caf3eb800
07010000260d803caf3eb800
e2000000c800d266df56b800
07010000260d803caf3eb800
07010000260d803caf3eb800
e2000000c800d266df56b800
07010000260d803caf3eb800
e2000000c800d266df56b800
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  char a;
  unsigned char  b:3;
};
-
{a=>-101,b=>3}
9b03
9b03
9b03
9b60
9b030000
9b03
9b60
9b03
9b60
-
{a=>-121,b=>0}
8700
8700
8700
8700
87000000
8700
8700
8700
8700
-
{a=>49,b=>5}
3105
3105
3105
31a0
31050000
3105
31a0
3105
31a0
-
{a=>-18,b=>5}
ee05
ee05
ee05
eea0
ee050000
ee05
eea0
ee05
eea0
-
{a=>-28,b=>7}
e407
e407
e407
e4e0
e4070000
e407
e4e0
e407
e4e0
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>5,a=>-95,b=>6}
a12e
a12e
a12e
a1d4
a12e0000
a12e
a1d4
a12e
a1d4
-
{c=>3,a=>105,b=>5}
691d
691d
691d
69ac
691d0000
691d
69ac
691d
69ac
-
{c=>5,a=>-88,b=>7}
a82f
a82f
a82f
a8f4
a82f0000
a82f
a8f4
a82f
a8f4
-
{c=>3,a=>-100,b=>0}
9c18
9c18
9c18
9c0c
9c180000
9c18
9c0c
9c18
9c0c
-
{c=>0,a=>-15,b=>0}
f100
f100
f100
f100
f1000000
f100
f100
f100
f100
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>1,a=>78,b=>7,d=>5}
4e0f0500
4e0f0500
4e0f0500
4ee4a000
4e0f0500
4e0f0500
4ee4a000
4e0f0500
4ee4a000
-
{c=>4,a=>18,b=>5,d=>2}
12250200
12250200
12250200
12b04000
12250200
12250200
12b04000
12250200
12b04000
-
{c=>7,a=>56,b=>5,d=>0}
383d0000
383d0000
383d0000
38bc0000
383d0000
383d0000
38bc0000
383d0000
38bc0000
-
{c=>5,a=>-82,b=>5,d=>1}
ae2d0100
ae2d0100
ae2d0100
aeb42000
ae2d0100
ae2d0100
aeb42000
ae2d0100
aeb42000
-
{c=>7,a=>60,b=>6,d=>5}
3c3e0500
3c3e0500
3c3e0500
3cdca000
3c3e0500
3c3e0500
3cdca000
3c3e0500
3cdca000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>221131133,c=>6,a=>105,b=>3,d=>0}
693300007d312e0d
693300007d312e0d
693300007d312e0d
69780000d2e317d0
693300007d312e0d
693300007d312e0d
69780000d2e317d0
693300007d312e0d
69780000d2e317d0
-
{e=>105130068,c=>7,a=>43,b=>7,d=>4}
2b3f040054284406
2b3f040054284406
2b3f040054284406
2bfc800064428540
2b3f040054284406
2b3f040054284406
2bfc800064428540
2b3f040054284406
2bfc800064428540
-
{e=>200295387,c=>7,a=>95,b=>0,d=>4}
5f380400db43f00b
5f380400db43f00b
5f380400db43f00b
5f1c8000bf043db0
5f380400db43f00b
5f380400db43f00b
5f1c8000bf043db0
5f380400db43f00b
5f1c8000bf043db0
-
{e=>204864432,c=>4,a=>121,b=>0,d=>5}
79200500b0fb350c
79200500b0fb350c
79200500b0fb350c
7910a000c35fbb00
79200500b0fb350c
79200500b0fb350c
7910a000c35fbb00
79200500b0fb350c
7910a000c35fbb00
-
{e=>116121104,c=>3,a=>-77,b=>7,d=>7}
b31f070010deeb06
b31f070010deeb06
b31f070010deeb06
b3ece0006ebde100
b31f070010deeb06
b31f070010deeb06
b3ece0006ebde100
b31f070010deeb06
b3ece0006ebde100
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>172836301,c=>0,a=>32,b=>7,d=>6,f=>3}
20070600cd454d3a
20070600cd454d3a
20070600cd454d3a
20e0c000a4d45cd6
20070600cd454d3a
20070600cd454d3a
20e0c000a4d45cd6
20070600cd454d3a
20e0c000a4d45cd6
-
{e=>127428220,c=>5,a=>-44,b=>2,d=>7,f=>1}
d42a07007c669817
d42a07007c669817
d42a07007c669817
d454e000798667c2
d42a07007c669817
d42a07007c669817
d454e000798667c2
d42a07007c669817
d454e000798667c2
-
{e=>422562,c=>0,a=>60,b=>7,d=>1,f=>2}
3c070100a2720620
3c070100a2720620
3c070100a2720620
3ce0200000672a24
3c070100a2720620
3c070100a2720620
3ce0200000672a24
3c070100a2720620
3ce0200000672a24
-
{e=>96278787,c=>7,a=>3,b=>7,d=>2,f=>0}
033f02000319bd05
033f02000319bd05
033f02000319bd05
03fc40005bd19030
033f02000319bd05
033f02000319bd05
03fc40005bd19030
033f02000319bd05
03fc40005bd19030
-
{e=>241856194,c=>3,a=>-107,b=>0,d=>6,f=>5}
95180600c26e6a5e
95180600c26e6a5e
95180600c26e6a5e
950cc000e6a6ec2a
95180600c26e6a5e
95180600c26e6a5e
950cc000e6a6ec2a
95180600c26e6a5e
950cc000e6a6ec2a
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>239818291,c=>6,a=>50,g=>2,b=>1,d=>2,f=>7}
3231020033564b7e02000000
3231020033564b7e02000000
3231020033564b7e02000000
32384000e4b5633e80000000
3231020033564b7e02000000
3231020033564b7e02000000
32384000e4b5633e80000000
3231020033564b7e02000000
32384000e4b5633e80000000
-
{e=>27118579,c=>2,a=>-3,g=>0,b=>0,d=>4,f=>5}
fd100400f3cb9d5100000000
fd100400f3cb9d5100000000
fd100400f3cb9d5100000000
fd08800019dcbf3a00000000
fd100400f3cb9d5100000000
fd100400f3cb9d5100000000
fd08800019dcbf3a00000000
fd100400f3cb9d5100000000
fd08800019dcbf3a00000000
-
{e=>134242001,c=>3,a=>59,g=>3,b=>5,d=>5,f=>6}
3b1d0500d15e006803000000
3b1d0500d15e006803000000
3b1d0500d15e006803000000
3baca0008005ed1cc0000000
3b1d0500d15e006803000000
3b1d0500d15e006803000000
3baca0008005ed1cc0000000
3b1d0500d15e006803000000
3baca0008005ed1cc0000000
-
{e=>65328260,c=>1,a=>-116,g=>1,b=>5,d=>4,f=>3}
8c0d040084d4e43301000000
8c0d040084d4e43301000000
8c0d040084d4e43301000000
8ca480003e4d484640000000
8c0d040084d4e43301000000
8c0d040084d4e43301000000
8ca480003e4d484640000000
8c0d040084d4e43301000000
8ca480003e4d484640000000
-
{e=>139743207,c=>3,a=>-41,g=>1,b=>3,d=>1,f=>6}
d71b0100e74f546801000000
d71b0100e74f546801000000
d71b0100e74f546801000000
d76c20008544fe7c40000000
d71b0100e74f546801000000
d71b0100e74f546801000000
d76c20008544fe7c40000000
d71b0100e74f546801000000
d76c20008544fe7c40000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>230124716,a=>16,d=>7,c=>1,h=>3908,b=>7,g=>2,f=>7}
100f0700ac6cb77d123d0000
100f0700ac6cb77d123d0000
100f0700ac6cb77d123d0000
10e4e000db76cace9e880000
100f0700ac6cb77d123d0000
100f0700ac6cb77d123d0000
10e4e000db76cace9e880000
100f0700ac6cb77d123d0000
10e4e000db76cace9e880000
-
{e=>124232976,a=>64,d=>4,c=>0,h=>5030,b=>2,g=>3,f=>4}
4002040010a567479b4e0000
4002040010a567479b4e0000
4002040010a567479b4e0000
40408000767a5108e74c0000
4002040010a567479b4e0000
4002040010a567479b4e0000
40408000767a5108e74c0000
4002040010a567479b4e0000
40408000767a5108e74c0000
-
{e=>239963925,a=>67,d=>1,c=>5,h=>5257,b=>4,g=>2,f=>4}
432c0100158f4d4e26520000
432c0100158f4d4e26520000
432c0100158f4d4e26520000
43942000e4d8f158a9120000
432c0100158f4d4e26520000
432c0100158f4d4e26520000
43942000e4d8f158a9120000
432c0100158f4d4e26520000
43942000e4d8f158a9120000
-
{e=>119523408,a=>-65,d=>2,c=>5,h=>4247,b=>2,g=>2,f=>3}
bf2a020050c81f375e420000
bf2a020050c81f375e420000
bf2a020050c81f375e420000
bf54400071fc8506a12e0000
bf2a020050c81f375e420000
bf2a020050c81f375e420000
bf54400071fc8506a12e0000
bf2a020050c81f375e420000
bf54400071fc8506a12e0000
-
{e=>9728961,a=>51,d=>5,c=>0,h=>2851,b=>7,g=>0,f=>4}
33070500c17394408c2c0000
33070500c17394408c2c0000
33070500c17394408c2c0000
33e0a00009473c1816460000
33070500c17394408c2c0000
33070500c17394408c2c0000
33e0a00009473c1816460000
33070500c17394408c2c0000
33e0a00009473c1816460000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  unsigned char  i;
};
-
{e=>180027965,a=>92,d=>2,c=>4,h=>1057,b=>1,g=>1,f=>0,i=>60}
5c2102003d02bb0a85103c00
5c2102003d02bb0a85103c00
5c2102003d02bb0a85103c00
5c304000abb023d048423c00
5c2102003d02bb0a85103c00
5c2102003d02bb0a85103c00
5c304000abb023d048423c00
5c2102003d02bb0a85103c00
5c304000abb023d048423c00
-
{e=>231855491,a=>-124,d=>6,c=>4,h=>1682,b=>7,g=>0,f=>6,i=>222}
8427060083d5d16d481ade00
8427060083d5d16d481ade00
8427060083d5d16d481ade00
84f0c000dd1d583c0d24de00
8427060083d5d16d481ade00
8427060083d5d16d481ade00
84f0c000dd1d583c0d24de00
8427060083d5d16d481ade00
84f0c000dd1d583c0d24de00
-
{e=>14781907,a=>-124,d=>1,c=>0,h=>7235,b=>7,g=>0,f=>3,i=>179}
84070100d38de1300c71b300
84070100d38de1300c71b300
84070100d38de1300c71b300
84e020000e18dd363886b300
84070100d38de1300c71b300
84070100d38de1300c71b300
84e020000e18dd363886b300
84070100d38de1300c71b300
84e020000e18dd363886b300
-
{e=>268185659,a=>-127,d=>4,c=>0,h=>4094,b=>2,g=>3,f=>7,i=>166}
810204003b30fc7ffb3fa600
810204003b30fc7ffb3fa600
810204003b30fc7ffb3fa600
81408000ffc303bedffca600
810204003b30fc7ffb3fa600
810204003b30fc7ffb3fa600
81408000ffc303bedffca600
810204003b30fc7ffb3fa600
81408000ffc303bedffca600
-
{e=>102826413,a=>-10,d=>2,c=>6,h=>6758,b=>6,g=>2,f=>7,i=>80}
f6360200ad0121769a695000
f6360200ad0121769a695000
f6360200ad0121769a695000
f6d8400062101adeb4cc5000
f6360200ad0121769a695000
f6360200ad0121769a695000
f6d8400062101adeb4cc5000
f6360200ad0121769a695000
f6d8400062101adeb4cc5000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  short a;
  unsigned char  b:3;
};
-
{a=>-45,b=>6}
d3ff0600
d3ff0600
d3ff0600
ffd3c000
d3ff0600
d3ff0600
ffd3c000
d3ff0600
ffd3c000
-
{a=>-32,b=>7}
e0ff0700
e0ff0700
e0ff0700
ffe0e000
e0ff0700
e0ff0700
ffe0e000
e0ff0700
ffe0e000
-
{a=>43,b=>2}
2b000200
2b000200
2b000200
002b4000
2b000200
2b000200
002b4000
2b000200
002b4000
-
{a=>8,b=>3}
08000300
08000300
08000300
00086000
08000300
08000300
00086000
08000300
00086000
-
{a=>-1,b=>1}
ffff0100
ffff0100
ffff0100
ffff2000
ffff0100
ffff0100
ffff2000
ffff0100
ffff2000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>5,a=>126,b=>7}
7e002f00
7e002f00
7e002f00
007ef400
7e002f00
7e002f00
007ef400
7e002f00
007ef400
-
{c=>4,a=>-38,b=>6}
daff2600
daff2600
daff2600
ffdad000
daff2600
daff2600
ffdad000
daff2600
ffdad000
-
{c=>3,a=>-19,b=>2}
edff1a00
edff1a00
edff1a00
ffed4c00
edff1a00
edff1a00
ffed4c00
edff1a00
ffed4c00
-
{c=>0,a=>26,b=>4}
1a000400
1a000400
1a000400
001a8000
1a000400
1a000400
001a8000
1a000400
001a8000
-
{c=>4,a=>125,b=>4}
7d002400
7d002400
7d002400
007d9000
7d002400
7d002400
007d9000
7d002400
007d9000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>4,a=>66,b=>0,d=>6}
4200a001
4200a001
4200a001
00421300
4200a001
4200a001
00421300
4200a001
00421300
-
{c=>3,a=>-65,b=>7,d=>5}
bfff5f01
bfff5f01
bfff5f01
ffbfee80
bfff5f01
bfff5f01
ffbfee80
bfff5f01
ffbfee80
-
{c=>5,a=>42,b=>5,d=>4}
2a002d01
2a002d01
2a002d01
002ab600
2a002d01
2a002d01
002ab600
2a002d01
002ab600
-
{c=>1,a=>-96,b=>4,d=>5}
a0ff4c01
a0ff4c01
a0ff4c01
ffa08680
a0ff4c01
a0ff4c01
ffa08680
a0ff4c01
ffa08680
-
{c=>2,a=>-85,b=>0,d=>4}
abff1001
abff1001
abff1001
ffab0a00
abff1001
abff1001
ffab0a00
abff1001
ffab0a00
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>144118602,c=>6,a=>-68,b=>2,d=>5}
bcff72014a139708
bcff72014a139708
bcff72014a139708
ffbc5a80897134a0
bcff72014a139708
bcff72014a139708
ffbc5a80897134a0
bcff72014a139708
ffbc5a80897134a0
-
{e=>194550170,c=>1,a=>-13,b=>2,d=>6}
f3ff8a019a99980b
f3ff8a019a99980b
f3ff8a019a99980b
fff34700b98999a0
f3ff8a019a99980b
f3ff8a019a99980b
fff34700b98999a0
f3ff8a019a99980b
fff34700b98999a0
-
{e=>80715514,c=>4,a=>100,b=>3,d=>0}
64002300fa9ecf04
64002300fa9ecf04
64002300fa9ecf04
006470004cf9efa0
64002300fa9ecf04
64002300fa9ecf04
006470004cf9efa0
64002300fa9ecf04
006470004cf9efa0
-
{e=>265138084,c=>6,a=>37,b=>2,d=>0}
25003200a4afcd0f
25003200a4afcd0f
25003200a4afcd0f
00255800fcdafa40
25003200a4afcd0f
25003200a4afcd0f
00255800fcdafa40
25003200a4afcd0f
00255800fcdafa40
-
{e=>222887293,c=>6,a=>11,b=>1,d=>5}
0b0071017dfd480d
0b0071017dfd480d
0b0071017dfd480d
000b3a80d48fd7d0
0b0071017dfd480d
0b0071017dfd480d
000b3a80d48fd7d0
0b0071017dfd480d
000b3a80d48fd7d0
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>18626280,c=>1,a=>-46,b=>5,d=>7,f=>5}
d2ffcd01e8361c51
d2ffcd01e8361c51
d2ffcd01e8361c51
ffd2a78011c36e8a
d2ffcd01e8361c51
d2ffcd01e8361c51
ffd2a78011c36e8a
d2ffcd01e8361c51
ffd2a78011c36e8a
-
{e=>65331951,c=>5,a=>-123,b=>1,d=>4,f=>2}
85ff2901efe2e423
85ff2901efe2e423
85ff2901efe2e423
ff8536003e4e2ef4
85ff2901efe2e423
85ff2901efe2e423
ff8536003e4e2ef4
85ff2901efe2e423
ff8536003e4e2ef4
-
{e=>22199225,c=>6,a=>19,b=>2,d=>4,f=>0}
13003201b9bb5201
13003201b9bb5201
13003201b9bb5201
00135a00152bbb90
13003201b9bb5201
13003201b9bb5201
00135a00152bbb90
13003201b9bb5201
00135a00152bbb90
-
{e=>9181650,c=>6,a=>56,b=>1,d=>0,f=>5}
38003100d2198c50
38003100d2198c50
38003100d2198c50
0038380008c19d2a
38003100d2198c50
38003100d2198c50
0038380008c19d2a
38003100d2198c50
0038380008c19d2a
-
{e=>157034625,c=>6,a=>76,b=>0,d=>2,f=>5}
4c00b00081285c59
4c00b00081285c59
4c00b00081285c59
004c190095c2881a
4c00b00081285c59
4c00b00081285c59
004c190095c2881a
4c00b00081285c59
004c190095c2881a
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>267203857,c=>2,a=>90,g=>1,b=>5,d=>0,f=>2}
5a0015001135ed2f01000000
5a0015001135ed2f01000000
5a0015001135ed2f01000000
005aa800fed3511440000000
5a0015001135ed2f01000000
5a0015001135ed2f01000000
005aa800fed3511440000000
5a0015001135ed2f01000000
005aa800fed3511440000000
-
{e=>138564760,c=>2,a=>-49,g=>2,b=>4,d=>6,f=>3}
cfff94019854423802000000
cfff94019854423802000000
cfff94019854423802000000
ffcf8b008425498680000000
cfff94019854423802000000
cfff94019854423802000000
ffcf8b008425498680000000
cfff94019854423802000000
ffcf8b008425498680000000
-
{e=>91970329,c=>6,a=>-122,g=>1,b=>1,d=>3,f=>0}
86fff100195b7b0501000000
86fff100195b7b0501000000
86fff100195b7b0501000000
ff86398057b5b19040000000
86fff100195b7b0501000000
86fff100195b7b0501000000
ff86398057b5b19040000000
86fff100195b7b0501000000
ff86398057b5b19040000000
-
{e=>102576163,c=>7,a=>39,g=>1,b=>0,d=>2,f=>6}
2700b80023301d6601000000
2700b80023301d6601000000
2700b80023301d6601000000
00271d0061d3023c40000000
2700b80023301d6601000000
2700b80023301d6601000000
00271d0061d3023c40000000
2700b80023301d6601000000
00271d0061d3023c40000000
-
{e=>263662536,c=>3,a=>-27,g=>1,b=>3,d=>4,f=>5}
e5ff1b01c82bb75f01000000
e5ff1b01c82bb75f01000000
e5ff1b01c82bb75f01000000
ffe56e00fb72bc8a40000000
e5ff1b01c82bb75f01000000
e5ff1b01c82bb75f01000000
ffe56e00fb72bc8a40000000
e5ff1b01c82bb75f01000000
ffe56e00fb72bc8a40000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>194432513,a=>30,d=>2,c=>2,h=>1472,b=>2,g=>1,f=>3}
1e00920001ce963b01170000
1e00920001ce963b01170000
1e00920001ce963b01170000
001e4900b96ce0164b800000
1e00920001ce963b01170000
1e00920001ce963b01170000
001e4900b96ce0164b800000
1e00920001ce963b01170000
001e4900b96ce0164b800000
-
{e=>90729129,a=>18,d=>7,c=>0,h=>7366,b=>1,g=>1,f=>4}
1200c101a96a684519730000
1200c101a96a684519730000
1200c101a96a684519730000
001223805686aa98798c0000
1200c101a96a684519730000
1200c101a96a684519730000
001223805686aa98798c0000
1200c101a96a684519730000
001223805686aa98798c0000
-
{e=>241644573,a=>75,d=>6,c=>6,h=>2932,b=>7,g=>3,f=>1}
4b00b7011d34671ed32d0000
4b00b7011d34671ed32d0000
4b00b7011d34671ed32d0000
004bfb00e67341d2d6e80000
4b00b7011d34671ed32d0000
4b00b7011d34671ed32d0000
004bfb00e67341d2d6e80000
4b00b7011d34671ed32d0000
004bfb00e67341d2d6e80000
-
{e=>176079331,a=>31,d=>2,c=>1,h=>4829,b=>6,g=>2,f=>2}
1f008e00e3c17e2a764b0000
1f008e00e3c17e2a764b0000
1f008e00e3c17e2a764b0000
001fc500a7ec1e34a5ba0000
1f008e00e3c17e2a764b0000
1f008e00e3c17e2a764b0000
001fc500a7ec1e34a5ba0000
1f008e00e3c17e2a764b0000
001fc500a7ec1e34a5ba0000
-
{e=>239368188,a=>55,d=>5,c=>3,h=>1857,b=>6,g=>3,f=>7}
37005e01fc77447e071d0000
37005e01fc77447e071d0000
37005e01fc77447e071d0000
0037ce80e4477fcece820000
37005e01fc77447e071d0000
37005e01fc77447e071d0000
0037ce80e4477fcece820000
37005e01fc77447e071d0000
0037ce80e4477fcece820000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  unsigned char  i;
};
-
{e=>108438729,a=>58,d=>1,c=>1,h=>5562,b=>0,g=>0,f=>6,i=>192}
3a004800c9a47666e856c000
3a004800c9a47666e856c000
3a004800c9a47666e856c000
003a0480676a4c9c2b74c000
3a004800c9a47666e856c000
3a004800c9a47666e856c000
003a0480676a4c9c2b74c000
3a004800c9a47666e856c000
003a0480676a4c9c2b74c000
-
{e=>5753109,a=>98,d=>6,c=>2,h=>3842,b=>0,g=>1,f=>4,i=>170}
6200900115c95740093caa00
6200900115c95740093caa00
6200900115c95740093caa00
00620b00057c91585e04aa00
6200900115c95740093caa00
6200900115c95740093caa00
00620b00057c91585e04aa00
6200900115c95740093caa00
00620b00057c91585e04aa00
-
{e=>152483984,a=>118,d=>4,c=>6,h=>3538,b=>4,g=>1,f=>6,i=>229}
7600340190b816694937e500
7600340190b816694937e500
7600340190b816694937e500
00769a00916b890c5ba4e500
7600340190b816694937e500
7600340190b816694937e500
00769a00916b890c5ba4e500
7600340190b816694937e500
00769a00916b890c5ba4e500
-
{e=>54363077,a=>36,d=>6,c=>6,h=>7156,b=>2,g=>1,f=>3,i=>92}
2400b201c5833d33d16f5c00
2400b201c5833d33d16f5c00
2400b201c5833d33d16f5c00
00245b0033d83c5677e85c00
2400b201c5833d33d16f5c00
2400b201c5833d33d16f5c00
00245b0033d83c5677e85c00
2400b201c5833d33d16f5c00
00245b0033d83c5677e85c00
-
{e=>73602633,a=>-19,d=>3,c=>5,h=>1654,b=>6,g=>2,f=>6,i=>188}
edffee0049166364da19bc00
edffee0049166364da19bc00
edffee0049166364da19bc00
ffedd5804631649c8cecbc00
edffee0049166364da19bc00
edffee0049166364da19bc00
ffedd5804631649c8cecbc00
edffee0049166364da19bc00
ffedd5804631649c8cecbc00
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  int a;
  unsigned char  b:3;
};
-
{a=>31,b=>7}
1f00000007000000
1f00000007000000
1f00000007000000
0000001fe0000000
1f00000007000000
1f00000007000000
0000001fe0000000
1f00000007000000
0000001fe0000000
-
{a=>70,b=>7}
4600000007000000
4600000007000000
4600000007000000
00000046e0000000
4600000007000000
4600000007000000
00000046e0000000
4600000007000000
00000046e0000000
-
{a=>-101,b=>4}
9bffffff04000000
9bffffff04000000
9bffffff04000000
ffffff9b80000000
9bffffff04000000
9bffffff04000000
ffffff9b80000000
9bffffff04000000
ffffff9b80000000
-
{a=>111,b=>2}
6f00000002000000
6f00000002000000
6f00000002000000
0000006f40000000
6f00000002000000
6f00000002000000
0000006f40000000
6f00000002000000
0000006f40000000
-
{a=>-80,b=>3}
b0ffffff03000000
b0ffffff03000000
b0ffffff03000000
ffffffb060000000
b0ffffff03000000
b0ffffff03000000
ffffffb060000000
b0ffffff03000000
ffffffb060000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>7,a=>76,b=>1}
4c00000039000000
4c00000039000000
4c00000039000000
0000004c3c000000
4c00000039000000
4c00000039000000
0000004c3c000000
4c00000039000000
0000004c3c000000
-
{c=>6,a=>52,b=>5}
3400000035000000
3400000035000000
3400000035000000
00000034b8000000
3400000035000000
3400000035000000
00000034b8000000
3400000035000000
00000034b8000000
-
{c=>4,a=>-96,b=>4}
a0ffffff24000000
a0ffffff24000000
a0ffffff24000000
ffffffa090000000
a0ffffff24000000
a0ffffff24000000
ffffffa090000000
a0ffffff24000000
ffffffa090000000
-
{c=>4,a=>16,b=>5}
1000000025000000
1000000025000000
1000000025000000
00000010b0000000
1000000025000000
1000000025000000
00000010b0000000
1000000025000000
00000010b0000000
-
{c=>5,a=>-115,b=>3}
8dffffff2b000000
8dffffff2b000000
8dffffff2b000000
ffffff8d74000000
8dffffff2b000000
8dffffff2b000000
ffffff8d74000000
8dffffff2b000000
ffffff8d74000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>3,a=>-95,b=>1,d=>3}
a1ffffffd9000000
a1ffffffd9000000
a1ffffffd9000000
ffffffa12d800000
a1ffffffd9000000
a1ffffffd9000000
ffffffa12d800000
a1ffffffd9000000
ffffffa12d800000
-
{c=>1,a=>-30,b=>2,d=>7}
e2ffffffca010000
e2ffffffca010000
e2ffffffca010000
ffffffe247800000
e2ffffffca010000
e2ffffffca010000
ffffffe247800000
e2ffffffca010000
ffffffe247800000
-
{c=>3,a=>28,b=>7,d=>3}
1c000000df000000
1c000000df000000
1c000000df000000
0000001ced800000
1c000000df000000
1c000000df000000
0000001ced800000
1c000000df000000
0000001ced800000
-
{c=>1,a=>34,b=>1,d=>3}
22000000c9000000
22000000c9000000
22000000c9000000
0000002225800000
22000000c9000000
22000000c9000000
0000002225800000
22000000c9000000
0000002225800000
-
{c=>5,a=>88,b=>6,d=>1}
580000006e000000
580000006e000000
580000006e000000
00000058d4800000
580000006e000000
580000006e000000
00000058d4800000
580000006e000000
00000058d4800000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>228389954,c=>6,a=>10,b=>1,d=>3}
0a000000f100000042f49c0d
0a000000f100000042f49c0d
0a000000f100000042f49c0d
0000000a39800000d9cf4420
0a000000f100000042f49c0d
0a000000f100000042f49c0d
0000000a39800000d9cf4420
0a000000f100000042f49c0d
0000000a39800000d9cf4420
-
{e=>26173929,c=>1,a=>46,b=>7,d=>3}
2e000000cf000000e9618f01
2e000000cf000000e9618f01
2e000000cf000000e9618f01
0000002ee580000018f61e90
2e000000cf000000e9618f01
2e000000cf000000e9618f01
0000002ee580000018f61e90
2e000000cf000000e9618f01
0000002ee580000018f61e90
-
{e=>31378561,c=>1,a=>-102,b=>0,d=>0}
9affffff0800000081ccde01
9affffff0800000081ccde01
9affffff0800000081ccde01
ffffff9a040000001decc810
9affffff0800000081ccde01
9affffff0800000081ccde01
ffffff9a040000001decc810
9affffff0800000081ccde01
ffffff9a040000001decc810
-
{e=>133881414,c=>3,a=>83,b=>6,d=>6}
530000009e01000046defa07
530000009e01000046defa07
530000009e01000046defa07
00000053cf0000007fade460
530000009e01000046defa07
530000009e01000046defa07
00000053cf0000007fade460
530000009e01000046defa07
00000053cf0000007fade460
-
{e=>185498202,c=>4,a=>-46,b=>2,d=>4}
d2ffffff220100005a7a0e0b
d2ffffff220100005a7a0e0b
d2ffffff220100005a7a0e0b
ffffffd252000000b0e7a5a0
d2ffffff220100005a7a0e0b
d2ffffff220100005a7a0e0b
ffffffd252000000b0e7a5a0
d2ffffff220100005a7a0e0b
ffffffd252000000b0e7a5a0
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>108248036,c=>1,a=>-113,b=>3,d=>5,f=>4}
8fffffff4b010000e4bb7346
8fffffff4b010000e4bb7346
8fffffff4b010000e4bb7346
ffffff8f66800000673bbe48
8fffffff4b010000e4bb7346
8fffffff4b010000e4bb7346
ffffff8f66800000673bbe48
8fffffff4b010000e4bb7346
ffffff8f66800000673bbe48
-
{e=>244754857,c=>2,a=>53,b=>1,d=>6,f=>7}
3500000091010000a9a9967e
3500000091010000a9a9967e
3500000091010000a9a9967e
000000352b000000e96a9a9e
3500000091010000a9a9967e
3500000091010000a9a9967e
000000352b000000e96a9a9e
3500000091010000a9a9967e
000000352b000000e96a9a9e
-
{e=>82868130,c=>3,a=>-17,b=>3,d=>4,f=>1}
efffffff1b010000a277f014
efffffff1b010000a277f014
efffffff1b010000a277f014
ffffffef6e0000004f077a22
efffffff1b010000a277f014
efffffff1b010000a277f014
ffffffef6e0000004f077a22
efffffff1b010000a277f014
ffffffef6e0000004f077a22
-
{e=>128771168,c=>5,a=>-97,b=>6,d=>5,f=>6}
9fffffff6e01000060e4ac67
9fffffff6e01000060e4ac67
9fffffff6e01000060e4ac67
ffffff9fd68000007ace460c
9fffffff6e01000060e4ac67
9fffffff6e01000060e4ac67
ffffff9fd68000007ace460c
9fffffff6e01000060e4ac67
ffffff9fd68000007ace460c
-
{e=>201646189,c=>5,a=>87,b=>0,d=>1,f=>3}
57000000680000006de0043c
57000000680000006de0043c
57000000680000006de0043c
0000005714800000c04e06d6
57000000680000006de0043c
57000000680000006de0043c
0000005714800000c04e06d6
57000000680000006de0043c
0000005714800000c04e06d6
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>52201699,c=>3,a=>-21,g=>2,b=>2,d=>3,f=>7}
ebffffffda000000e3881c7302000000
ebffffffda000000e3881c7302000000
ebffffffda000000e3881c7302000000
ffffffeb4d80000031c88e3e80000000
ebffffffda000000e3881c7302000000
ebffffffda000000e3881c7302000000
ffffffeb4d80000031c88e3e80000000
ebffffffda000000e3881c7302000000
ffffffeb4d80000031c88e3e80000000
-
{e=>156859917,c=>7,a=>28,g=>2,b=>4,d=>1,f=>7}
1c0000007c0000000d7e597902000000
1c0000007c0000000d7e597902000000
1c0000007c0000000d7e597902000000
0000001c9c8000009597e0de80000000
1c0000007c0000000d7e597902000000
1c0000007c0000000d7e597902000000
0000001c9c8000009597e0de80000000
1c0000007c0000000d7e597902000000
0000001c9c8000009597e0de80000000
-
{e=>73487576,c=>2,a=>44,g=>3,b=>5,d=>4,f=>1}
2c00000015010000d854611403000000
2c00000015010000d854611403000000
2c00000015010000d854611403000000
0000002caa00000046154d82c0000000
2c00000015010000d854611403000000
2c00000015010000d854611403000000
0000002caa00000046154d82c0000000
2c00000015010000d854611403000000
0000002caa00000046154d82c0000000
-
{e=>172142530,c=>5,a=>101,g=>2,b=>7,d=>3,f=>5}
65000000ef000000c2af425a02000000
65000000ef000000c2af425a02000000
65000000ef000000c2af425a02000000
00000065f5800000a42afc2a80000000
65000000ef000000c2af425a02000000
65000000ef000000c2af425a02000000
00000065f5800000a42afc2a80000000
65000000ef000000c2af425a02000000
00000065f5800000a42afc2a80000000
-
{e=>150725544,c=>6,a=>71,g=>1,b=>6,d=>0,f=>3}
4700000036000000a8e3fb3801000000
4700000036000000a8e3fb3801000000
4700000036000000a8e3fb3801000000
00000047d80000008fbe3a8640000000
4700000036000000a8e3fb3801000000
4700000036000000a8e3fb3801000000
00000047d80000008fbe3a8640000000
4700000036000000a8e3fb3801000000
00000047d80000008fbe3a8640000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>165197259,a=>-34,d=>6,c=>6,h=>2543,b=>0,g=>1,f=>4}
deffffffb0010000cbb5d849bd270000
deffffffb0010000cbb5d849bd270000
deffffffb0010000cbb5d849bd270000
ffffffde1b0000009d8b5cb853de0000
deffffffb0010000cbb5d849bd270000
deffffffb0010000cbb5d849bd270000
ffffffde1b0000009d8b5cb853de0000
deffffffb0010000cbb5d849bd270000
ffffffde1b0000009d8b5cb853de0000
-
{e=>66930837,a=>-1,d=>4,c=>3,h=>8014,b=>5,g=>2,f=>1}
ffffffff1d0100009548fd133a7d0000
ffffffff1d0100009548fd133a7d0000
ffffffff1d0100009548fd133a7d0000
ffffffffae0000003fd48952be9c0000
ffffffff1d0100009548fd133a7d0000
ffffffff1d0100009548fd133a7d0000
ffffffffae0000003fd48952be9c0000
ffffffff1d0100009548fd133a7d0000
ffffffffae0000003fd48952be9c0000
-
{e=>133257048,a=>80,d=>2,c=>3,h=>7657,b=>4,g=>1,f=>2}
500000009c0000005857f127a5770000
500000009c0000005857f127a5770000
500000009c0000005857f127a5770000
000000508d0000007f1575847bd20000
500000009c0000005857f127a5770000
500000009c0000005857f127a5770000
000000508d0000007f1575847bd20000
500000009c0000005857f127a5770000
000000508d0000007f1575847bd20000
-
{e=>213734502,a=>-90,d=>4,c=>5,h=>5237,b=>1,g=>2,f=>0}
a6ffffff290100006654bd0cd6510000
a6ffffff290100006654bd0cd6510000
a6ffffff290100006654bd0cd6510000
ffffffa636000000cbd54660a8ea0000
a6ffffff290100006654bd0cd6510000
a6ffffff290100006654bd0cd6510000
ffffffa636000000cbd54660a8ea0000
a6ffffff290100006654bd0cd6510000
ffffffa636000000cbd54660a8ea0000
-
{e=>132335321,a=>121,d=>0,c=>3,h=>5451,b=>4,g=>0,f=>7}
790000001c000000d946e3772c550000
790000001c000000d946e3772c550000
790000001c000000d946e3772c550000
000000798c0000007e346d9e2a960000
790000001c000000d946e3772c550000
790000001c000000d946e3772c550000
000000798c0000007e346d9e2a960000
790000001c000000d946e3772c550000
000000798c0000007e346d9e2a960000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  unsigned char  i;
};
-
{e=>54142455,a=>-77,d=>3,c=>0,h=>5806,b=>5,g=>0,f=>1,i=>177}
b3ffffffc5000000f7253a13b85ab100
b3ffffffc5000000f7253a13b85ab100
b3ffffffc5000000f7253a13b85ab100
ffffffb3a180000033a25f722d5cb100
b3ffffffc5000000f7253a13b85ab100
b3ffffffc5000000f7253a13b85ab100
ffffffb3a180000033a25f722d5cb100
b3ffffffc5000000f7253a13b85ab100
ffffffb3a180000033a25f722d5cb100
-
{e=>146569251,a=>-111,d=>5,c=>1,h=>6377,b=>1,g=>3,f=>2,i=>217}
91ffffff490100002378bc28a763d900
91ffffff490100002378bc28a763d900
91ffffff490100002378bc28a763d900
ffffff91268000008bc78234f1d2d900
91ffffff490100002378bc28a763d900
91ffffff490100002378bc28a763d900
ffffff91268000008bc78234f1d2d900
91ffffff490100002378bc28a763d900
ffffff91268000008bc78234f1d2d900
-
{e=>103323231,a=>-35,d=>5,c=>3,h=>286,b=>0,g=>2,f=>5,i=>160}
ddffffff580100005f9628567a04a000
ddffffff580100005f9628567a04a000
ddffffff580100005f9628567a04a000
ffffffdd0e800000628965fa823ca000
ddffffff580100005f9628567a04a000
ddffffff580100005f9628567a04a000
ffffffdd0e800000628965fa823ca000
ddffffff580100005f9628567a04a000
ffffffdd0e800000628965fa823ca000
-
{e=>80135875,a=>-121,d=>4,c=>6,h=>4052,b=>0,g=>0,f=>6,i=>139}
87ffffff30010000c3c6c664503f8b00
87ffffff30010000c3c6c664503f8b00
87ffffff30010000c3c6c664503f8b00
ffffff871a0000004c6c6c3c1fa88b00
87ffffff30010000c3c6c664503f8b00
87ffffff30010000c3c6c664503f8b00
ffffff871a0000004c6c6c3c1fa88b00
87ffffff30010000c3c6c664503f8b00
ffffff871a0000004c6c6c3c1fa88b00
-
{e=>212259421,a=>46,d=>5,c=>2,h=>3423,b=>7,g=>2,f=>4,i=>165}
2e000000570100005dd2a64c7e35a500
2e000000570100005dd2a64c7e35a500
2e000000570100005dd2a64c7e35a500
0000002eea800000ca6d25d89abea500
2e000000570100005dd2a64c7e35a500
2e000000570100005dd2a64c7e35a500
0000002eea800000ca6d25d89abea500
2e000000570100005dd2a64c7e35a500
0000002eea800000ca6d25d89abea500
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  long a;
  unsigned char  b:3;
};
-
{a=>-17,b=>1}
efffffff01000000
efffffffffffffff0100000000000000
efffffffffffffff0100000000000000
ffffffef20000000
efffffff01000000
efffffff01000000
ffffffffffffffef2000000000000000
efffffff01000000
ffffffef20000000
-
{a=>-21,b=>5}
ebffffff05000000
ebffffffffffffff0500000000000000
ebffffffffffffff0500000000000000
ffffffeba0000000
ebffffff05000000
ebffffff05000000
ffffffffffffffeba000000000000000
ebffffff05000000
ffffffeba0000000
-
{a=>117,b=>4}
7500000004000000
75000000000000000400000000000000
75000000000000000400000000000000
0000007580000000
7500000004000000
7500000004000000
00000000000000758000000000000000
7500000004000000
0000007580000000
-
{a=>90,b=>5}
5a00000005000000
5a000000000000000500000000000000
5a000000000000000500000000000000
0000005aa0000000
5a00000005000000
5a00000005000000
000000000000005aa000000000000000
5a00000005000000
0000005aa0000000
-
{a=>48,b=>4}
3000000004000000
30000000000000000400000000000000
30000000000000000400000000000000
0000003080000000
3000000004000000
3000000004000000
00000000000000308000000000000000
3000000004000000
0000003080000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>0,a=>16,b=>5}
1000000005000000
10000000000000000500000000000000
10000000000000000500000000000000
00000010a0000000
1000000005000000
1000000005000000
0000000000000010a000000000000000
1000000005000000
00000010a0000000
-
{c=>6,a=>123,b=>0}
7b00000030000000
7b000000000000003000000000000000
7b000000000000003000000000000000
0000007b18000000
7b00000030000000
7b00000030000000
000000000000007b1800000000000000
7b00000030000000
0000007b18000000
-
{c=>4,a=>92,b=>2}
5c00000022000000
5c000000000000002200000000000000
5c000000000000002200000000000000
0000005c50000000
5c00000022000000
5c00000022000000
000000000000005c5000000000000000
5c00000022000000
0000005c50000000
-
{c=>4,a=>64,b=>0}
4000000020000000
40000000000000002000000000000000
40000000000000002000000000000000
0000004010000000
4000000020000000
4000000020000000
00000000000000401000000000000000
4000000020000000
0000004010000000
-
{c=>0,a=>-8,b=>0}
f8ffffff00000000
f8ffffffffffffff0000000000000000
f8ffffffffffffff0000000000000000
fffffff800000000
f8ffffff00000000
f8ffffff00000000
fffffffffffffff80000000000000000
f8ffffff00000000
fffffff800000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>6,a=>124,b=>2,d=>6}
7c000000b2010000
7c00000000000000b201000000000000
7c00000000000000b201000000000000
0000007c5b000000
7c000000b2010000
7c000000b2010000
000000000000007c5b00000000000000
7c000000b2010000
0000007c5b000000
-
{c=>2,a=>-19,b=>2,d=>0}
edffffff12000000
edffffffffffffff1200000000000000
edffffffffffffff1200000000000000
ffffffed48000000
edffffff12000000
edffffff12000000
ffffffffffffffed4800000000000000
edffffff12000000
ffffffed48000000
-
{c=>5,a=>55,b=>0,d=>1}
3700000068000000
37000000000000006800000000000000
37000000000000006800000000000000
0000003714800000
3700000068000000
3700000068000000
00000000000000371480000000000000
3700000068000000
0000003714800000
-
{c=>5,a=>-44,b=>0,d=>7}
d4ffffffe8010000
d4ffffffffffffffe801000000000000
d4ffffffffffffffe801000000000000
ffffffd417800000
d4ffffffe8010000
d4ffffffe8010000
ffffffffffffffd41780000000000000
d4ffffffe8010000
ffffffd417800000
-
{c=>6,a=>-50,b=>1,d=>4}
ceffffff31010000
ceffffffffffffff3101000000000000
ceffffffffffffff3101000000000000
ffffffce3a000000
ceffffff31010000
ceffffff31010000
ffffffffffffffce3a00000000000000
ceffffff31010000
ffffffce3a000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>95288597,c=>5,a=>-109,b=>2,d=>7}
93ffffffea01000015fdad05
93ffffffffffffffea01000015fdad05
93ffffffffffffffea01000015fdad05
ffffff93578000005adfd150
93ffffffea01000015fdad05
93ffffffea01000015fdad05
ffffffffffffff93578000005adfd150
93ffffffea01000015fdad05
ffffff93578000005adfd150
-
{e=>135290620,c=>4,a=>117,b=>5,d=>5}
7500000065010000fc5e1008
750000000000000065010000fc5e1008
750000000000000065010000fc5e1008
00000075b28000008105efc0
7500000065010000fc5e1008
7500000065010000fc5e1008
0000000000000075b28000008105efc0
7500000065010000fc5e1008
00000075b28000008105efc0
-
{e=>60560071,c=>0,a=>38,b=>6,d=>3}
26000000c6000000c7129c03
2600000000000000c6000000c7129c03
2600000000000000c6000000c7129c03
00000026c180000039c12c70
26000000c6000000c7129c03
26000000c6000000c7129c03
0000000000000026c180000039c12c70
26000000c6000000c7129c03
00000026c180000039c12c70
-
{e=>3218489,c=>7,a=>-111,b=>2,d=>3}
91fffffffa000000391c3100
91fffffffffffffffa000000391c3100
91fffffffffffffffa000000391c3100
ffffff915d8000000311c390
91fffffffa000000391c3100
91fffffffa000000391c3100
ffffffffffffff915d8000000311c390
91fffffffa000000391c3100
ffffff915d8000000311c390
-
{e=>124836907,c=>6,a=>-119,b=>3,d=>2}
89ffffffb30000002bdc7007
89ffffffffffffffb30000002bdc7007
89ffffffffffffffb30000002bdc7007
ffffff8979000000770dc2b0
89ffffffb30000002bdc7007
89ffffffb30000002bdc7007
ffffffffffffff8979000000770dc2b0
89ffffffb30000002bdc7007
ffffff8979000000770dc2b0
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>12389401,c=>4,a=>83,b=>0,d=>1,f=>1}
5300000060000000190cbd10
530000000000000060000000190cbd10
530000000000000060000000190cbd10
00000053108000000bd0c192
5300000060000000190cbd10
5300000060000000190cbd10
0000000000000053108000000bd0c192
5300000060000000190cbd10
00000053108000000bd0c192
-
{e=>142083432,c=>7,a=>-99,b=>5,d=>3,f=>3}
9dfffffffd00000068057838
9dfffffffffffffffd00000068057838
9dfffffffffffffffd00000068057838
ffffff9dbd80000087805686
9dfffffffd00000068057838
9dfffffffd00000068057838
ffffffffffffff9dbd80000087805686
9dfffffffd00000068057838
ffffff9dbd80000087805686
-
{e=>187721880,c=>2,a=>52,b=>6,d=>5,f=>2}
34000000560100009868302b
3400000000000000560100009868302b
3400000000000000560100009868302b
00000034ca800000b3068984
34000000560100009868302b
34000000560100009868302b
0000000000000034ca800000b3068984
34000000560100009868302b
00000034ca800000b3068984
-
{e=>48069462,c=>5,a=>48,b=>0,d=>2,f=>4}
30000000a8000000567bdd42
3000000000000000a8000000567bdd42
3000000000000000a8000000567bdd42
00000030150000002dd7b568
30000000a8000000567bdd42
30000000a8000000567bdd42
0000000000000030150000002dd7b568
30000000a8000000567bdd42
00000030150000002dd7b568
-
{e=>65320048,c=>4,a=>2,b=>6,d=>4,f=>3}
020000002601000070b4e433
02000000000000002601000070b4e433
02000000000000002601000070b4e433
00000002d20000003e4b4706
020000002601000070b4e433
020000002601000070b4e433
0000000000000002d20000003e4b4706
020000002601000070b4e433
00000002d20000003e4b4706
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>260512924,c=>0,a=>13,g=>3,b=>2,d=>7,f=>5}
0d000000c20100009c1c875f03000000
0d00000000000000c20100009c1c875f0300000000000000
0d00000000000000c20100009c1c875f0300000000000000
0000000d43800000f871c9cac0000000
0d000000c20100009c1c875f03000000
0d000000c20100009c1c875f03000000
000000000000000d43800000f871c9cac000000000000000
0d000000c20100009c1c875f03000000
0000000d43800000f871c9cac0000000
-
{e=>57231972,c=>0,a=>50,g=>1,b=>1,d=>1,f=>1}
3200000041000000644a691301000000
320000000000000041000000644a69130100000000000000
320000000000000041000000644a69130100000000000000
00000032208000003694a64240000000
3200000041000000644a691301000000
3200000041000000644a691301000000
0000000000000032208000003694a6424000000000000000
3200000041000000644a691301000000
00000032208000003694a64240000000
-
{e=>202592947,c=>7,a=>-82,g=>2,b=>0,d=>0,f=>6}
aeffffff38000000b352136c02000000
aeffffffffffffff38000000b352136c0200000000000000
aeffffffffffffff38000000b352136c0200000000000000
ffffffae1c000000c1352b3c80000000
aeffffff38000000b352136c02000000
aeffffff38000000b352136c02000000
ffffffffffffffae1c000000c1352b3c8000000000000000
aeffffff38000000b352136c02000000
ffffffae1c000000c1352b3c80000000
-
{e=>222000348,c=>7,a=>-76,g=>2,b=>4,d=>4,f=>5}
b4ffffff3c010000dc743b5d02000000
b4ffffffffffffff3c010000dc743b5d0200000000000000
b4ffffffffffffff3c010000dc743b5d0200000000000000
ffffffb49e000000d3b74dca80000000
b4ffffff3c010000dc743b5d02000000
b4ffffff3c010000dc743b5d02000000
ffffffffffffffb49e000000d3b74dca8000000000000000
b4ffffff3c010000dc743b5d02000000
ffffffb49e000000d3b74dca80000000
-
{e=>259177945,c=>7,a=>-89,g=>3,b=>2,d=>4,f=>1}
a7ffffff3a010000d9bd721f03000000
a7ffffffffffffff3a010000d9bd721f0300000000000000
a7ffffffffffffff3a010000d9bd721f0300000000000000
ffffffa75e000000f72bdd92c0000000
a7ffffff3a010000d9bd721f03000000
a7ffffff3a010000d9bd721f03000000
ffffffffffffffa75e000000f72bdd92c000000000000000
a7ffffff3a010000d9bd721f03000000
ffffffa75e000000f72bdd92c0000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>83948314,a=>-39,d=>7,c=>7,h=>5026,b=>2,g=>2,f=>5}
d9fffffffa0100001af300558a4e0000
d9fffffffffffffffa0100001af300558a4e000000000000
d9fffffffffffffffa0100001af300558a4e000000000000
ffffffd95f800000500f31aaa7440000
d9fffffffa0100001af300558a4e0000
d9fffffffa0100001af300558a4e0000
ffffffffffffffd95f800000500f31aaa744000000000000
d9fffffffa0100001af300558a4e0000
ffffffd95f800000500f31aaa7440000
-
{e=>263712322,a=>73,d=>0,c=>3,h=>5678,b=>2,g=>3,f=>7}
490000001a00000042eeb77fbb580000
49000000000000001a00000042eeb77fbb58000000000000
49000000000000001a00000042eeb77fbb58000000000000
000000494c000000fb7ee42eec5c0000
490000001a00000042eeb77fbb580000
490000001a00000042eeb77fbb580000
00000000000000494c000000fb7ee42eec5c000000000000
490000001a00000042eeb77fbb580000
000000494c000000fb7ee42eec5c0000
-
{e=>29595889,a=>-74,d=>7,c=>3,h=>3087,b=>2,g=>3,f=>4}
b6ffffffda010000f198c3413f300000
b6ffffffffffffffda010000f198c3413f30000000000000
b6ffffffffffffffda010000f198c3413f30000000000000
ffffffb64f8000001c398f18d81e0000
b6ffffffda010000f198c3413f300000
b6ffffffda010000f198c3413f300000
ffffffffffffffb64f8000001c398f18d81e000000000000
b6ffffffda010000f198c3413f300000
ffffffb64f8000001c398f18d81e0000
-
{e=>229616258,a=>-13,d=>2,c=>2,h=>5537,b=>5,g=>2,f=>6}
f3ffffff9500000082aaaf6d86560000
f3ffffffffffffff9500000082aaaf6d8656000000000000
f3ffffffffffffff9500000082aaaf6d8656000000000000
fffffff3a9000000dafaa82cab420000
f3ffffff9500000082aaaf6d86560000
f3ffffff9500000082aaaf6d86560000
fffffffffffffff3a9000000dafaa82cab42000000000000
f3ffffff9500000082aaaf6d86560000
fffffff3a9000000dafaa82cab420000
-
{e=>192578723,a=>-50,d=>5,c=>7,h=>779,b=>7,g=>0,f=>1}
ceffffff7f010000a3847a1b2c0c0000
ceffffffffffffff7f010000a3847a1b2c0c000000000000
ceffffffffffffff7f010000a3847a1b2c0c000000000000
ffffffcefe800000b7a84a3206160000
ceffffff7f010000a3847a1b2c0c0000
ceffffff7f010000a3847a1b2c0c0000
ffffffffffffffcefe800000b7a84a320616000000000000
ceffffff7f010000a3847a1b2c0c0000
ffffffcefe800000b7a84a3206160000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct umixed_pack_2 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  unsigned char  i;
};
-
{e=>53556282,a=>93,d=>1,c=>0,h=>6233,b=>5,g=>2,f=>6,i=>8}
5d000000450000003a34316366610800
5d00000000000000450000003a3431636661080000000000
5d00000000000000450000003a3431636661080000000000
0000005da0800000331343acb0b20800
5d000000450000003a34316366610800
5d000000450000003a34316366610800
000000000000005da0800000331343acb0b2080000000000
5d000000450000003a34316366610800
0000005da0800000331343acb0b20800
-
{e=>177717941,a=>-92,d=>4,c=>4,h=>2021,b=>5,g=>1,f=>5,i=>247}
a4ffffff25010000b5c2975a951ff700
a4ffffffffffffff25010000b5c2975a951ff70000000000
a4ffffffffffffff25010000b5c2975a951ff70000000000
ffffffa4b2000000a97c2b5a4fcaf700
a4ffffff25010000b5c2975a951ff700
a4ffffff25010000b5c2975a951ff700
ffffffffffffffa4b2000000a97c2b5a4fcaf70000000000
a4ffffff25010000b5c2975a951ff700
ffffffa4b2000000a97c2b5a4fcaf700
-
{e=>182845399,a=>88,d=>7,c=>0,h=>1885,b=>2,g=>0,f=>7,i=>153}
58000000c2010000d7ffe57a741d9900
5800000000000000c2010000d7ffe57a741d990000000000
5800000000000000c2010000d7ffe57a741d990000000000
0000005843800000ae5ffd7e0eba9900
58000000c2010000d7ffe57a741d9900
58000000c2010000d7ffe57a741d9900
000000000000005843800000ae5ffd7e0eba990000000000
58000000c2010000d7ffe57a741d9900
0000005843800000ae5ffd7e0eba9900
-
{e=>88054627,a=>92,d=>5,c=>7,h=>765,b=>5,g=>0,f=>1,i=>252}
5c0000007d010000639b3f15f40bfc00
5c000000000000007d010000639b3f15f40bfc0000000000
5c000000000000007d010000639b3f15f40bfc0000000000
0000005cbe80000053f9b63205fafc00
5c0000007d010000639b3f15f40bfc00
5c0000007d010000639b3f15f40bfc00
000000000000005cbe80000053f9b63205fafc0000000000
5c0000007d010000639b3f15f40bfc00
0000005cbe80000053f9b63205fafc00
-
{e=>77656705,a=>-32,d=>0,c=>0,h=>6746,b=>6,g=>3,f=>4,i=>4}
e0ffffff0600000081f2a0446b690400
e0ffffffffffffff0600000081f2a0446b69040000000000
e0ffffffffffffff0600000081f2a0446b69040000000000
ffffffe0c00000004a0f2818f4b40400
e0ffffff0600000081f2a0446b690400
e0ffffff0600000081f2a0446b690400
ffffffffffffffe0c00000004a0f2818f4b4040000000000
e0ffffff0600000081f2a0446b690400
ffffffe0c00000004a0f2818f4b40400
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  unsigned char  a:3;
};
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>2}
02
02
02
40
02000000
02
40
02
40
-
{a=>3}
03
03
03
60
03000000
03
60
03
60
-
{a=>4}
04
04
04
80
04000000
04
80
04
80
-
{a=>1}
01
01
01
20
01000000
01
20
01
20
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  unsigned char  a:3;
  unsigned char  b:3;
};
-
{a=>1,b=>7}
39
39
39
3c
39000000
39
3c
39
3c
-
{a=>5,b=>4}
25
25
25
b0
25000000
25
b0
25
b0
-
{a=>2,b=>6}
32
32
32
58
32000000
32
58
32
58
-
{a=>6,b=>0}
06
06
06
c0
06000000
06
c0
06
c0
-
{a=>6,b=>3}
1e
1e
1e
cc
1e000000
1e
cc
1e
cc
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
};
-
{c=>7,a=>2,b=>3}
da01
da01
da01
4f80
da010000
da01
4f80
da01
4f80
-
{c=>7,a=>5,b=>5}
ed01
ed01
ed01
b780
ed010000
ed01
b780
ed01
b780
-
{c=>6,a=>2,b=>1}
8a01
8a01
8a01
4700
8a010000
8a01
4700
8a01
4700
-
{c=>2,a=>0,b=>4}
a000
a000
a000
1100
a0000000
a000
1100
a000
1100
-
{c=>2,a=>0,b=>0}
8000
8000
8000
0100
80000000
8000
0100
8000
0100
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
};
-
{c=>3,a=>7,b=>1,d=>50028689}
cf0000009160fb02
cf0000009160fb02
cf0000009160fb02
e58000002fb60910
cf0000009160fb02
cf0000009160fb02
e58000002fb60910
cf0000009160fb02
e58000002fb60910
-
{c=>0,a=>6,b=>4,d=>214060677}
26000000854ec20c
26000000854ec20c
26000000854ec20c
d0000000cc24e850
26000000854ec20c
26000000854ec20c
d0000000cc24e850
26000000854ec20c
d0000000cc24e850
-
{c=>5,a=>3,b=>2,d=>195763511}
53010000371dab0b
53010000371dab0b
53010000371dab0b
6a800000bab1d370
53010000371dab0b
53010000371dab0b
6a800000bab1d370
53010000371dab0b
6a800000bab1d370
-
{c=>3,a=>3,b=>6,d=>63439012}
f3000000a400c803
f3000000a400c803
f3000000a400c803
798000003c800a40
f3000000a400c803
f3000000a400c803
798000003c800a40
f3000000a400c803
798000003c800a40
-
{c=>0,a=>5,b=>5,d=>244764352}
2d000000c0ce960e
2d000000c0ce960e
2d000000c0ce960e
b4000000e96cec00
2d000000c0ce960e
2d000000c0ce960e
b4000000e96cec00
2d000000c0ce960e
b4000000e96cec00
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
};
-
{e=>3,c=>2,a=>4,b=>7,d=>224624247}
bc000000777e633d
bc000000777e633d
bc000000777e633d
9d000000d637e776
bc000000777e633d
bc000000777e633d
9d000000d637e776
bc000000777e633d
9d000000d637e776
-
{e=>0,c=>1,a=>5,b=>1,d=>177052414}
4d000000fe9a8d0a
4d000000fe9a8d0a
4d000000fe9a8d0a
a4800000a8d9afe0
4d000000fe9a8d0a
4d000000fe9a8d0a
a4800000a8d9afe0
4d000000fe9a8d0a
a4800000a8d9afe0
-
{e=>0,c=>0,a=>2,b=>5,d=>246117108}
2a000000f472ab0e
2a000000f472ab0e
2a000000f472ab0e
54000000eab72f40
2a000000f472ab0e
2a000000f472ab0e
54000000eab72f40
2a000000f472ab0e
54000000eab72f40
-
{e=>6,c=>6,a=>5,b=>7,d=>185373738}
bd0100002a940c6b
bd0100002a940c6b
bd0100002a940c6b
bf000000b0c942ac
bd0100002a940c6b
bd0100002a940c6b
bf000000b0c942ac
bd0100002a940c6b
bf000000b0c942ac
-
{e=>5,c=>3,a=>4,b=>5,d=>54818930}
ec00000072784453
ec00000072784453
ec00000072784453
958000003447872a
ec00000072784453
ec00000072784453
958000003447872a
ec00000072784453
958000003447872a
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
  unsigned char  f:2;
};
-
{e=>3,c=>4,a=>4,b=>0,d=>79628885,f=>3}
04010000550abf3403000000
04010000550abf3403000000
04010000550abf3403000000
820000004bf0a556c0000000
04010000550abf3403000000
04010000550abf3403000000
820000004bf0a556c0000000
04010000550abf3403000000
820000004bf0a556c0000000
-
{e=>2,c=>4,a=>1,b=>5,d=>144152264,f=>2}
29010000c896972802000000
29010000c896972802000000
29010000c896972802000000
3600000089796c8480000000
29010000c896972802000000
29010000c896972802000000
3600000089796c8480000000
29010000c896972802000000
3600000089796c8480000000
-
{e=>5,c=>6,a=>2,b=>0,d=>26710878,f=>3}
820100005e93975103000000
820100005e93975103000000
820100005e93975103000000
43000000197935eac0000000
820100005e93975103000000
820100005e93975103000000
43000000197935eac0000000
820100005e93975103000000
43000000197935eac0000000
-
{e=>5,c=>6,a=>7,b=>4,d=>34004101,f=>1}
a701000085dc065201000000
a701000085dc065201000000
a701000085dc065201000000
f3000000206dc85a40000000
a701000085dc065201000000
a701000085dc065201000000
f3000000206dc85a40000000
a701000085dc065201000000
f3000000206dc85a40000000
-
{e=>0,c=>4,a=>2,b=>1,d=>16933732,f=>1}
0a0100006463020101000000
0a0100006463020101000000
0a0100006463020101000000
460000001026364040000000
0a0100006463020101000000
0a0100006463020101000000
460000001026364040000000
0a0100006463020101000000
460000001026364040000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
  unsigned char  f:2;
  unsigned short g:13;
};
-
{e=>6,c=>4,a=>7,g=>5071,b=>0,d=>231122139,f=>3}
07010000dba4c66d3f4f0000
07010000dba4c66d3f4f0000
07010000dba4c66d3f4f0000
e2000000dc6a4dbce79e0000
07010000dba4c66d3f4f0000
07010000dba4c66d3f4f0000
e2000000dc6a4dbce79e0000
07010000dba4c66d3f4f0000
e2000000dc6a4dbce79e0000
-
{e=>6,c=>2,a=>7,g=>456,b=>3,d=>180080748,f=>0}
9f0000006cd0bb6a20070000
9f0000006cd0bb6a20070000
9f0000006cd0bb6a20070000
ed000000abbd06cc03900000
9f0000006cd0bb6a20070000
9f0000006cd0bb6a20070000
ed000000abbd06cc03900000
9f0000006cd0bb6a20070000
ed000000abbd06cc03900000
-
{e=>2,c=>3,a=>3,g=>5849,b=>3,d=>79209729,f=>3}
db00000001a5b824675b0000
db00000001a5b824675b0000
db00000001a5b824675b0000
6d8000004b8a5014edb20000
db00000001a5b824675b0000
db00000001a5b824675b0000
6d8000004b8a5014edb20000
db00000001a5b824675b0000
6d8000004b8a5014edb20000
-
{e=>1,c=>3,a=>7,g=>2821,b=>0,d=>127280147,f=>3}
c700000013249617172c0000
c700000013249617172c0000
c700000013249617172c0000
e180000079624132d60a0000
c700000013249617172c0000
c700000013249617172c0000
e180000079624132d60a0000
c700000013249617172c0000
e180000079624132d60a0000
-
{e=>3,c=>1,a=>1,g=>507,b=>0,d=>255482069,f=>1}
41000000d5583a3fed070000
41000000d5583a3fed070000
41000000d5583a3fed070000
20800000f3a58d5643f60000
41000000d5583a3fed070000
41000000d5583a3fed070000
20800000f3a58d5643f60000
41000000d5583a3fed070000
20800000f3a58d5643f60000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  unsigned char  a:3;
  unsigned char  b:3;
  unsigned short c:3;
  unsigned int   d:28;
  unsigned char  e:3;
  unsigned char  f:2;
  unsigned short g:13;
  unsigned char  h;
};
-
{e=>6,a=>7,d=>257420570,c=>7,h=>84,b=>1,g=>1915,f=>3}
cf0100001aed576fef1d5400
cf0100001aed576fef1d5400
cf0100001aed576fef1d5400
e7800000f57ed1accef65400
cf0100001aed576fef1d5400
cf0100001aed576fef1d5400
e7800000f57ed1accef65400
cf0100001aed576fef1d5400
e7800000f57ed1accef65400
-
{e=>5,a=>5,d=>71066412,c=>2,h=>226,b=>3,g=>1456,f=>3}
9d0000002c633c54c316e200
9d0000002c633c54c316e200
9d0000002c633c54c316e200
ad00000043c632cacb60e200
9d0000002c633c54c316e200
9d0000002c633c54c316e200
ad00000043c632cacb60e200
9d0000002c633c54c316e200
ad00000043c632cacb60e200
-
{e=>5,a=>0,d=>136880796,c=>4,h=>149,b=>6,g=>7356,f=>2}
300100009ca22858f2729500
300100009ca22858f2729500
300100009ca22858f2729500
1a000000828a29cab9789500
300100009ca22858f2729500
300100009ca22858f2729500
1a000000828a29cab9789500
300100009ca22858f2729500
1a000000828a29cab9789500
-
{e=>4,a=>2,d=>230323768,c=>1,h=>107,b=>2,g=>1870,f=>0}
520000003876ba4d381d6b00
520000003876ba4d381d6b00
520000003876ba4d381d6b00
48800000dba763880e9c6b00
520000003876ba4d381d6b00
520000003876ba4d381d6b00
48800000dba763880e9c6b00
520000003876ba4d381d6b00
48800000dba763880e9c6b00
-
{e=>0,a=>1,d=>100150911,c=>2,h=>68,b=>6,g=>5875,f=>1}
b10000007f2ef805cd5b4400
b10000007f2ef805cd5b4400
b10000007f2ef805cd5b4400
390000005f82e7f06de64400
b10000007f2ef805cd5b4400
b10000007f2ef805cd5b4400
390000005f82e7f06de64400
b10000007f2ef805cd5b4400
390000005f82e7f06de64400
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  char a;
  unsigned char  b:3;
};
-
{a=>65,b=>3}
4103
4103
4103
4160
41030000
4103
4160
4103
4160
-
{a=>6,b=>0}
0600
0600
0600
0600
06000000
0600
0600
0600
0600
-
{a=>95,b=>6}
5f06
5f06
5f06
5fc0
5f060000
5f06
5fc0
5f06
5fc0
-
{a=>-19,b=>1}
ed01
ed01
ed01
ed20
ed010000
ed01
ed20
ed01
ed20
-
{a=>69,b=>7}
4507
4507
4507
45e0
45070000
4507
45e0
4507
45e0
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>6,a=>-76,b=>3}
b433
b433
b433
b478
b4330000
b433
b478
b433
b478
-
{c=>6,a=>58,b=>2}
3a32
3a32
3a32
3a58
3a320000
3a32
3a58
3a32
3a58
-
{c=>0,a=>-87,b=>7}
a907
a907
a907
a9e0
a9070000
a907
a9e0
a907
a9e0
-
{c=>5,a=>95,b=>6}
5f2e
5f2e
5f2e
5fd4
5f2e0000
5f2e
5fd4
5f2e
5fd4
-
{c=>6,a=>69,b=>2}
4532
4532
4532
4558
45320000
4532
4558
4532
4558
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>3,a=>-39,b=>1,d=>1}
d9190100
d9190100
d9190100
d92c2000
d9190100
d9190100
d92c2000
d9190100
d92c2000
-
{c=>0,a=>-41,b=>0,d=>0}
d7000000
d7000000
d7000000
d7000000
d7000000
d7000000
d7000000
d7000000
d7000000
-
{c=>4,a=>98,b=>0,d=>0}
62200000
62200000
62200000
62100000
62200000
62200000
62100000
62200000
62100000
-
{c=>0,a=>-29,b=>1,d=>5}
e3010500
e3010500
e3010500
e320a000
e3010500
e3010500
e320a000
e3010500
e320a000
-
{c=>3,a=>-22,b=>1,d=>5}
ea190500
ea190500
ea190500
ea2ca000
ea190500
ea190500
ea2ca000
ea190500
ea2ca000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>124299546,c=>2,a=>-99,b=>6,d=>6}
9d1606001aa96807
9d1606001aa96807
9d1606001aa96807
9dc8c000768a91a0
9d1606001aa96807
9d1606001aa96807
9dc8c000768a91a0
9d1606001aa96807
9dc8c000768a91a0
-
{e=>146480008,c=>7,a=>77,b=>1,d=>1}
4d390100881bbb08
4d390100881bbb08
4d390100881bbb08
4d3c20008bb1b880
4d390100881bbb08
4d390100881bbb08
4d3c20008bb1b880
4d390100881bbb08
4d3c20008bb1b880
-
{e=>114844914,c=>3,a=>-69,b=>7,d=>6}
bb1f0600f264d806
bb1f0600f264d806
bb1f0600f264d806
bbecc0006d864f20
bb1f0600f264d806
bb1f0600f264d806
bbecc0006d864f20
bb1f0600f264d806
bbecc0006d864f20
-
{e=>66012636,c=>0,a=>-38,b=>2,d=>6}
da020600dc45ef03
da020600dc45ef03
da020600dc45ef03
da40c0003ef45dc0
da020600dc45ef03
da020600dc45ef03
da40c0003ef45dc0
da020600dc45ef03
da40c0003ef45dc0
-
{e=>262518736,c=>0,a=>20,b=>2,d=>0}
14020000d0b7a50f
14020000d0b7a50f
14020000d0b7a50f
14400000fa5b7d00
14020000d0b7a50f
14020000d0b7a50f
14400000fa5b7d00
14020000d0b7a50f
14400000fa5b7d00
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>262442666,c=>5,a=>-46,b=>1,d=>0,f=>1}
d2290000aa8ea41f
d2290000aa8ea41f
d2290000aa8ea41f
d2340000fa48eaa2
d2290000aa8ea41f
d2290000aa8ea41f
d2340000fa48eaa2
d2290000aa8ea41f
d2340000fa48eaa2
-
{e=>51404586,c=>7,a=>-117,b=>0,d=>7,f=>2}
8b3807002a5f1023
8b3807002a5f1023
8b3807002a5f1023
8b1ce0003105f2a4
8b3807002a5f1023
8b3807002a5f1023
8b1ce0003105f2a4
8b3807002a5f1023
8b1ce0003105f2a4
-
{e=>62750320,c=>6,a=>103,b=>6,d=>5,f=>7}
67360500707ebd73
67360500707ebd73
67360500707ebd73
67d8a0003bd7e70e
67360500707ebd73
67360500707ebd73
67d8a0003bd7e70e
67360500707ebd73
67d8a0003bd7e70e
-
{e=>224998807,c=>7,a=>-64,b=>3,d=>6,f=>1}
c03b06009735691d
c03b06009735691d
c03b06009735691d
c07cc000d6935972
c03b06009735691d
c03b06009735691d
c07cc000d6935972
c03b06009735691d
c07cc000d6935972
-
{e=>147103397,c=>2,a=>51,b=>5,d=>5,f=>6}
33150500a59ec468
33150500a59ec468
33150500a59ec468
33a8a0008c49ea5c
33150500a59ec468
33150500a59ec468
33a8a0008c49ea5c
33150500a59ec468
33a8a0008c49ea5c
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>126791030,c=>2,a=>62,g=>0,b=>5,d=>3,f=>3}
3e15030076ad8e3700000000
3e15030076ad8e3700000000
3e15030076ad8e3700000000
3ea8600078ead76600000000
3e15030076ad8e3700000000
3e15030076ad8e3700000000
3ea8600078ead76600000000
3e15030076ad8e3700000000
3ea8600078ead76600000000
-
{e=>121945673,c=>5,a=>14,g=>2,b=>7,d=>0,f=>6}
0e2f000049be446702000000
0e2f000049be446702000000
0e2f000049be446702000000
0ef40000744be49c80000000
0e2f000049be446702000000
0e2f000049be446702000000
0ef40000744be49c80000000
0e2f000049be446702000000
0ef40000744be49c80000000
-
{e=>144073686,c=>3,a=>96,g=>1,b=>3,d=>3,f=>6}
601b0300d663966801000000
601b0300d663966801000000
601b0300d663966801000000
606c600089663d6c40000000
601b0300d663966801000000
601b0300d663966801000000
606c600089663d6c40000000
601b0300d663966801000000
606c600089663d6c40000000
-
{e=>215969518,c=>7,a=>-47,g=>2,b=>4,d=>4,f=>2}
d13c0400ee6edf2c02000000
d13c0400ee6edf2c02000000
d13c0400ee6edf2c02000000
d19c8000cdf6eee480000000
d13c0400ee6edf2c02000000
d13c0400ee6edf2c02000000
d19c8000cdf6eee480000000
d13c0400ee6edf2c02000000
d19c8000cdf6eee480000000
-
{e=>140309850,c=>5,a=>-50,g=>1,b=>5,d=>2,f=>0}
ce2d02005af55c0801000000
ce2d02005af55c0801000000
ce2d02005af55c0801000000
ceb4400085cf55a040000000
ce2d02005af55c0801000000
ce2d02005af55c0801000000
ceb4400085cf55a040000000
ce2d02005af55c0801000000
ceb4400085cf55a040000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>255150489,a=>50,d=>2,c=>3,h=>5131,b=>7,g=>0,f=>5}
321f02009949355f2c500000
321f02009949355f2c500000
321f02009949355f2c500000
32ec4000f354999a28160000
321f02009949355f2c500000
321f02009949355f2c500000
32ec4000f354999a28160000
321f02009949355f2c500000
32ec4000f354999a28160000
-
{e=>88288107,a=>30,d=>5,c=>2,h=>508,b=>1,g=>1,f=>4}
1e1105006b2b4345f1070000
1e1105006b2b4345f1070000
1e1105006b2b4345f1070000
1e28a0005432b6b843f80000
1e1105006b2b4345f1070000
1e1105006b2b4345f1070000
1e28a0005432b6b843f80000
1e1105006b2b4345f1070000
1e28a0005432b6b843f80000
-
{e=>69089767,a=>-51,d=>7,c=>1,h=>2817,b=>4,g=>0,f=>1}
cd0c0700e7391e14042c0000
cd0c0700e7391e14042c0000
cd0c0700e7391e14042c0000
cd84e00041e39e7216020000
cd0c0700e7391e14042c0000
cd0c0700e7391e14042c0000
cd84e00041e39e7216020000
cd0c0700e7391e14042c0000
cd84e00041e39e7216020000
-
{e=>181343856,a=>45,d=>0,c=>7,h=>8181,b=>5,g=>0,f=>3}
2d3d00007016cf3ad47f0000
2d3d00007016cf3ad47f0000
2d3d00007016cf3ad47f0000
2dbc0000acf167063fea0000
2d3d00007016cf3ad47f0000
2d3d00007016cf3ad47f0000
2dbc0000acf167063fea0000
2d3d00007016cf3ad47f0000
2dbc0000acf167063fea0000
-
{e=>255383303,a=>-26,d=>0,c=>4,h=>6731,b=>2,g=>0,f=>2}
e622000007d7382f2c690000
e622000007d7382f2c690000
e622000007d7382f2c690000
e6500000f38d707434960000
e622000007d7382f2c690000
e622000007d7382f2c690000
e6500000f38d707434960000
e622000007d7382f2c690000
e6500000f38d707434960000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  char a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  unsigned char  i;
};
-
{e=>166068539,a=>7,d=>5,c=>2,h=>5695,b=>7,g=>1,f=>6,i=>154}
071705003b01e669fd589a00
071705003b01e669fd589a00
071705003b01e669fd589a00
07e8a0009e6013bc6c7e9a00
071705003b01e669fd589a00
071705003b01e669fd589a00
07e8a0009e6013bc6c7e9a00
071705003b01e669fd589a00
07e8a0009e6013bc6c7e9a00
-
{e=>33996722,a=>19,d=>3,c=>1,h=>5872,b=>0,g=>3,f=>4,i=>109}
13080300b2bf0642c35b6d00
13080300b2bf0642c35b6d00
13080300b2bf0642c35b6d00
13046000206bfb28ede06d00
13080300b2bf0642c35b6d00
13080300b2bf0642c35b6d00
13046000206bfb28ede06d00
13080300b2bf0642c35b6d00
13046000206bfb28ede06d00
-
{e=>233609477,a=>33,d=>2,c=>7,h=>5345,b=>1,g=>1,f=>4,i=>42}
213902000599ec4d85532a00
213902000599ec4d85532a00
213902000599ec4d85532a00
213c4000dec9905869c22a00
213902000599ec4d85532a00
213902000599ec4d85532a00
213c4000dec9905869c22a00
213902000599ec4d85532a00
213c4000dec9905869c22a00
-
{e=>221295631,a=>68,d=>4,c=>7,h=>2330,b=>4,g=>0,f=>7,i=>18}
443c04000fb4307d68241200
443c04000fb4307d68241200
443c04000fb4307d68241200
449c8000d30b40fe12341200
443c04000fb4307d68241200
443c04000fb4307d68241200
449c8000d30b40fe12341200
443c04000fb4307d68241200
449c8000d30b40fe12341200
-
{e=>91575618,a=>-124,d=>7,c=>1,h=>4394,b=>5,g=>0,f=>3,i=>236}
840d070042557535a844ec00
840d070042557535a844ec00
840d070042557535a844ec00
84a4e000575554262254ec00
840d070042557535a844ec00
840d070042557535a844ec00
84a4e000575554262254ec00
840d070042557535a844ec00
84a4e000575554262254ec00
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  short a;
  unsigned char  b:3;
};
-
{a=>116,b=>5}
74000500
74000500
74000500
0074a000
74000500
74000500
0074a000
74000500
0074a000
-
{a=>71,b=>2}
47000200
47000200
47000200
00474000
47000200
47000200
00474000
47000200
00474000
-
{a=>-124,b=>5}
84ff0500
84ff0500
84ff0500
ff84a000
84ff0500
84ff0500
ff84a000
84ff0500
ff84a000
-
{a=>80,b=>5}
50000500
50000500
50000500
0050a000
50000500
50000500
0050a000
50000500
0050a000
-
{a=>-89,b=>4}
a7ff0400
a7ff0400
a7ff0400
ffa78000
a7ff0400
a7ff0400
ffa78000
a7ff0400
ffa78000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>3,a=>-17,b=>0}
efff1800
efff1800
efff1800
ffef0c00
efff1800
efff1800
ffef0c00
efff1800
ffef0c00
-
{c=>1,a=>-2,b=>7}
feff0f00
feff0f00
feff0f00
fffee400
feff0f00
feff0f00
fffee400
feff0f00
fffee400
-
{c=>1,a=>-91,b=>5}
a5ff0d00
a5ff0d00
a5ff0d00
ffa5a400
a5ff0d00
a5ff0d00
ffa5a400
a5ff0d00
ffa5a400
-
{c=>0,a=>68,b=>4}
44000400
44000400
44000400
00448000
44000400
44000400
00448000
44000400
00448000
-
{c=>7,a=>-51,b=>2}
cdff3a00
cdff3a00
cdff3a00
ffcd5c00
cdff3a00
cdff3a00
ffcd5c00
cdff3a00
ffcd5c00
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>5,a=>-102,b=>5,d=>2}
9affad00
9affad00
9affad00
ff9ab500
9affad00
9affad00
ff9ab500
9affad00
ff9ab500
-
{c=>4,a=>79,b=>5,d=>3}
4f00e500
4f00e500
4f00e500
004fb180
4f00e500
4f00e500
004fb180
4f00e500
004fb180
-
{c=>7,a=>67,b=>7,d=>4}
43003f01
43003f01
43003f01
0043fe00
43003f01
43003f01
0043fe00
43003f01
0043fe00
-
{c=>1,a=>57,b=>7,d=>4}
39000f01
39000f01
39000f01
0039e600
39000f01
39000f01
0039e600
39000f01
0039e600
-
{c=>7,a=>56,b=>4,d=>2}
3800bc00
3800bc00
3800bc00
00389d00
3800bc00
3800bc00
00389d00
3800bc00
00389d00
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>13432198,c=>4,a=>37,b=>0,d=>6}
2500a00186f5cc00
2500a00186f5cc00
2500a00186f5cc00
002513000ccf5860
2500a00186f5cc00
2500a00186f5cc00
002513000ccf5860
2500a00186f5cc00
002513000ccf5860
-
{e=>56807926,c=>1,a=>40,b=>5,d=>2}
28008d00f6d16203
28008d00f6d16203
28008d00f6d16203
0028a500362d1f60
28008d00f6d16203
28008d00f6d16203
0028a500362d1f60
28008d00f6d16203
0028a500362d1f60
-
{e=>135705606,c=>5,a=>-117,b=>1,d=>2}
8bffa90006b41608
8bffa90006b41608
8bffa90006b41608
ff8b3500816b4060
8bffa90006b41608
8bffa90006b41608
ff8b3500816b4060
8bffa90006b41608
ff8b3500816b4060
-
{e=>57461598,c=>5,a=>-92,b=>1,d=>0}
a4ff29005ecb6c03
a4ff29005ecb6c03
a4ff29005ecb6c03
ffa4340036ccb5e0
a4ff29005ecb6c03
a4ff29005ecb6c03
ffa4340036ccb5e0
a4ff29005ecb6c03
ffa4340036ccb5e0
-
{e=>47673734,c=>0,a=>-17,b=>2,d=>4}
efff02018671d702
efff02018671d702
efff02018671d702
ffef42002d771860
efff02018671d702
efff02018671d702
ffef42002d771860
efff02018671d702
ffef42002d771860
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>161341178,c=>6,a=>41,b=>3,d=>6,f=>4}
2900b301fade9d49
2900b301fade9d49
2900b301fade9d49
00297b0099ddefa8
2900b301fade9d49
2900b301fade9d49
00297b0099ddefa8
2900b301fade9d49
00297b0099ddefa8
-
{e=>17636513,c=>4,a=>97,b=>1,d=>0,f=>7}
61002100a11c0d71
61002100a11c0d71
61002100a11c0d71
0061300010d1ca1e
61002100a11c0d71
61002100a11c0d71
0061300010d1ca1e
61002100a11c0d71
0061300010d1ca1e
-
{e=>71589661,c=>4,a=>83,b=>1,d=>4,f=>3}
530021011d5f4434
530021011d5f4434
530021011d5f4434
005332004445f1d6
530021011d5f4434
530021011d5f4434
005332004445f1d6
530021011d5f4434
005332004445f1d6
-
{e=>130474327,c=>1,a=>95,b=>0,d=>6,f=>2}
5f00880157e1c627
5f00880157e1c627
5f00880157e1c627
005f07007c6e1574
5f00880157e1c627
5f00880157e1c627
005f07007c6e1574
5f00880157e1c627
005f07007c6e1574
-
{e=>97397382,c=>1,a=>47,b=>1,d=>2,f=>2}
2f008900862ace25
2f008900862ace25
2f008900862ace25
002f25005ce2a864
2f008900862ace25
2f008900862ace25
002f25005ce2a864
2f008900862ace25
002f25005ce2a864
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>212274530,c=>6,a=>61,g=>1,b=>5,d=>1,f=>6}
3d007500620da76c01000000
3d007500620da76c01000000
3d007500620da76c01000000
003db880ca70d62c40000000
3d007500620da76c01000000
3d007500620da76c01000000
003db880ca70d62c40000000
3d007500620da76c01000000
003db880ca70d62c40000000
-
{e=>84374245,c=>6,a=>105,g=>1,b=>3,d=>2,f=>4}
6900b300e572074501000000
6900b300e572074501000000
6900b300e572074501000000
0069790050772e5840000000
6900b300e572074501000000
6900b300e572074501000000
0069790050772e5840000000
6900b300e572074501000000
0069790050772e5840000000
-
{e=>59588346,c=>5,a=>-128,g=>1,b=>7,d=>7,f=>2}
80ffef01fa3e8d2301000000
80ffef01fa3e8d2301000000
80ffef01fa3e8d2301000000
ff80f78038d3efa440000000
80ffef01fa3e8d2301000000
80ffef01fa3e8d2301000000
ff80f78038d3efa440000000
80ffef01fa3e8d2301000000
ff80f78038d3efa440000000
-
{e=>183955461,c=>3,a=>33,g=>3,b=>6,d=>7,f=>3}
2100de0105f0f63a03000000
2100de0105f0f63a03000000
2100de0105f0f63a03000000
0021cf80af6f0056c0000000
2100de0105f0f63a03000000
2100de0105f0f63a03000000
0021cf80af6f0056c0000000
2100de0105f0f63a03000000
0021cf80af6f0056c0000000
-
{e=>192083138,c=>3,a=>-69,g=>3,b=>4,d=>0,f=>2}
bbff1c00c2f4722b03000000
bbff1c00c2f4722b03000000
bbff1c00c2f4722b03000000
ffbb8c00b72f4c24c0000000
bbff1c00c2f4722b03000000
bbff1c00c2f4722b03000000
ffbb8c00b72f4c24c0000000
bbff1c00c2f4722b03000000
ffbb8c00b72f4c24c0000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>113601201,a=>91,d=>3,c=>3,h=>3432,b=>1,g=>0,f=>2}
5b00d900b16ac526a0350000
5b00d900b16ac526a0350000
5b00d900b16ac526a0350000
005b2d806c56ab141ad00000
5b00d900b16ac526a0350000
5b00d900b16ac526a0350000
005b2d806c56ab141ad00000
5b00d900b16ac526a0350000
005b2d806c56ab141ad00000
-
{e=>203592947,a=>15,d=>7,c=>1,h=>5527,b=>6,g=>0,f=>7}
0f00ce01f394227c5c560000
0f00ce01f394227c5c560000
0f00ce01f394227c5c560000
000fc780c2294f3e2b2e0000
0f00ce01f394227c5c560000
0f00ce01f394227c5c560000
000fc780c2294f3e2b2e0000
0f00ce01f394227c5c560000
000fc780c2294f3e2b2e0000
-
{e=>20997174,a=>-60,d=>7,c=>4,h=>6515,b=>6,g=>0,f=>0}
c4ffe60136644001cc650000
c4ffe60136644001cc650000
c4ffe60136644001cc650000
ffc4d3801406436032e60000
c4ffe60136644001cc650000
c4ffe60136644001cc650000
ffc4d3801406436032e60000
c4ffe60136644001cc650000
ffc4d3801406436032e60000
-
{e=>235268567,a=>-47,d=>5,c=>4,h=>1813,b=>6,g=>2,f=>7}
d1ff6601d7e9057e561c0000
d1ff6601d7e9057e561c0000
d1ff6601d7e9057e561c0000
ffd1d280e05e9d7e8e2a0000
d1ff6601d7e9057e561c0000
d1ff6601d7e9057e561c0000
ffd1d280e05e9d7e8e2a0000
d1ff6601d7e9057e561c0000
ffd1d280e05e9d7e8e2a0000
-
{e=>104426910,a=>-85,d=>3,c=>1,h=>4758,b=>4,g=>2,f=>1}
abffcc009e6d39165a4a0000
abffcc009e6d39165a4a0000
abffcc009e6d39165a4a0000
ffab85806396d9e2a52c0000
abffcc009e6d39165a4a0000
abffcc009e6d39165a4a0000
ffab85806396d9e2a52c0000
abffcc009e6d39165a4a0000
ffab85806396d9e2a52c0000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  short a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  unsigned char  i;
};
-
{e=>12539432,a=>-13,d=>1,c=>5,h=>262,b=>4,g=>3,f=>0,i=>197}
f3ff6c002856bf001b04c500
f3ff6c002856bf001b04c500
f3ff6c002856bf001b04c500
fff394800bf56280c20cc500
f3ff6c002856bf001b04c500
f3ff6c002856bf001b04c500
fff394800bf56280c20cc500
f3ff6c002856bf001b04c500
fff394800bf56280c20cc500
-
{e=>121930746,a=>112,d=>4,c=>3,h=>1222,b=>7,g=>1,f=>5,i=>13}
70001f01fa83445719130d00
70001f01fa83445719130d00
70001f01fa83445719130d00
0070ee0074483faa498c0d00
70001f01fa83445719130d00
70001f01fa83445719130d00
0070ee0074483faa498c0d00
70001f01fa83445719130d00
0070ee0074483faa498c0d00
-
{e=>212968800,a=>104,d=>5,c=>7,h=>2223,b=>4,g=>2,f=>6,i=>9}
68007c0160a5b16cbe220900
68007c0160a5b16cbe220900
68007c0160a5b16cbe220900
00689e80cb1a560c915e0900
68007c0160a5b16cbe220900
68007c0160a5b16cbe220900
00689e80cb1a560c915e0900
68007c0160a5b16cbe220900
00689e80cb1a560c915e0900
-
{e=>48555818,a=>-18,d=>2,c=>7,h=>3063,b=>4,g=>1,f=>1,i=>165}
eeffbc002ae7e412dd2fa500
eeffbc002ae7e412dd2fa500
eeffbc002ae7e412dd2fa500
ffee9d002e4e72a257eea500
eeffbc002ae7e412dd2fa500
eeffbc002ae7e412dd2fa500
ffee9d002e4e72a257eea500
eeffbc002ae7e412dd2fa500
ffee9d002e4e72a257eea500
-
{e=>204417579,a=>18,d=>3,c=>6,h=>3751,b=>6,g=>1,f=>5,i=>20}
1200f6002b2a2f5c9d3a1400
1200f6002b2a2f5c9d3a1400
1200f6002b2a2f5c9d3a1400
0012d980c2f2a2ba5d4e1400
1200f6002b2a2f5c9d3a1400
1200f6002b2a2f5c9d3a1400
0012d980c2f2a2ba5d4e1400
1200f6002b2a2f5c9d3a1400
0012d980c2f2a2ba5d4e1400
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  int a;
  unsigned char  b:3;
};
-
{a=>3,b=>1}
0300000001000000
0300000001000000
0300000001000000
0000000320000000
0300000001000000
0300000001000000
0000000320000000
0300000001000000
0000000320000000
-
{a=>-79,b=>0}
b1ffffff00000000
b1ffffff00000000
b1ffffff00000000
ffffffb100000000
b1ffffff00000000
b1ffffff00000000
ffffffb100000000
b1ffffff00000000
ffffffb100000000
-
{a=>22,b=>0}
1600000000000000
1600000000000000
1600000000000000
0000001600000000
1600000000000000
1600000000000000
0000001600000000
1600000000000000
0000001600000000
-
{a=>-61,b=>4}
c3ffffff04000000
c3ffffff04000000
c3ffffff04000000
ffffffc380000000
c3ffffff04000000
c3ffffff04000000
ffffffc380000000
c3ffffff04000000
ffffffc380000000
-
{a=>4,b=>5}
0400000005000000
0400000005000000
0400000005000000
00000004a0000000
0400000005000000
0400000005000000
00000004a0000000
0400000005000000
00000004a0000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>1,a=>15,b=>2}
0f0000000a000000
0f0000000a000000
0f0000000a000000
0000000f44000000
0f0000000a000000
0f0000000a000000
0000000f44000000
0f0000000a000000
0000000f44000000
-
{c=>6,a=>8,b=>1}
0800000031000000
0800000031000000
0800000031000000
0000000838000000
0800000031000000
0800000031000000
0000000838000000
0800000031000000
0000000838000000
-
{c=>7,a=>20,b=>5}
140000003d000000
140000003d000000
140000003d000000
00000014bc000000
140000003d000000
140000003d000000
00000014bc000000
140000003d000000
00000014bc000000
-
{c=>2,a=>65,b=>6}
4100000016000000
4100000016000000
4100000016000000
00000041c8000000
4100000016000000
4100000016000000
00000041c8000000
4100000016000000
00000041c8000000
-
{c=>6,a=>27,b=>7}
1b00000037000000
1b00000037000000
1b00000037000000
0000001bf8000000
1b00000037000000
1b00000037000000
0000001bf8000000
1b00000037000000
0000001bf8000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>4,a=>121,b=>6,d=>0}
7900000026000000
7900000026000000
7900000026000000
00000079d0000000
7900000026000000
7900000026000000
00000079d0000000
7900000026000000
00000079d0000000
-
{c=>7,a=>-95,b=>4,d=>6}
a1ffffffbc010000
a1ffffffbc010000
a1ffffffbc010000
ffffffa19f000000
a1ffffffbc010000
a1ffffffbc010000
ffffffa19f000000
a1ffffffbc010000
ffffffa19f000000
-
{c=>5,a=>-88,b=>5,d=>4}
a8ffffff2d010000
a8ffffff2d010000
a8ffffff2d010000
ffffffa8b6000000
a8ffffff2d010000
a8ffffff2d010000
ffffffa8b6000000
a8ffffff2d010000
ffffffa8b6000000
-
{c=>6,a=>101,b=>5,d=>1}
6500000075000000
6500000075000000
6500000075000000
00000065b8800000
6500000075000000
6500000075000000
00000065b8800000
6500000075000000
00000065b8800000
-
{c=>7,a=>24,b=>5,d=>6}
18000000bd010000
18000000bd010000
18000000bd010000
00000018bf000000
18000000bd010000
18000000bd010000
00000018bf000000
18000000bd010000
00000018bf000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>169306690,c=>2,a=>21,b=>0,d=>6}
1500000090010000426a170a
1500000090010000426a170a
1500000090010000426a170a
000000150b000000a176a420
1500000090010000426a170a
1500000090010000426a170a
000000150b000000a176a420
1500000090010000426a170a
000000150b000000a176a420
-
{e=>49555571,c=>7,a=>7,b=>1,d=>7}
07000000f90100007328f402
07000000f90100007328f402
07000000f90100007328f402
000000073f8000002f428730
07000000f90100007328f402
07000000f90100007328f402
000000073f8000002f428730
07000000f90100007328f402
000000073f8000002f428730
-
{e=>137008742,c=>3,a=>-69,b=>1,d=>4}
bbffffff1901000066962a08
bbffffff1901000066962a08
bbffffff1901000066962a08
ffffffbb2e00000082a96660
bbffffff1901000066962a08
bbffffff1901000066962a08
ffffffbb2e00000082a96660
bbffffff1901000066962a08
ffffffbb2e00000082a96660
-
{e=>85806609,c=>1,a=>-17,b=>5,d=>3}
efffffffcd000000114e1d05
efffffffcd000000114e1d05
efffffffcd000000114e1d05
ffffffefa580000051d4e110
efffffffcd000000114e1d05
efffffffcd000000114e1d05
ffffffefa580000051d4e110
efffffffcd000000114e1d05
ffffffefa580000051d4e110
-
{e=>133506977,c=>6,a=>93,b=>0,d=>6}
5d000000b0010000a127f507
5d000000b0010000a127f507
5d000000b0010000a127f507
0000005d1b0000007f527a10
5d000000b0010000a127f507
5d000000b0010000a127f507
0000005d1b0000007f527a10
5d000000b0010000a127f507
0000005d1b0000007f527a10
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>156208632,c=>7,a=>-84,b=>2,d=>2,f=>2}
acffffffba000000f88d4f29
acffffffba000000f88d4f29
acffffffba000000f88d4f29
ffffffac5d00000094f8df84
acffffffba000000f88d4f29
acffffffba000000f88d4f29
ffffffac5d00000094f8df84
acffffffba000000f88d4f29
ffffffac5d00000094f8df84
-
{e=>130617554,c=>4,a=>-17,b=>6,d=>7,f=>0}
efffffffe6010000d210c907
efffffffe6010000d210c907
efffffffe6010000d210c907
ffffffefd38000007c910d20
efffffffe6010000d210c907
efffffffe6010000d210c907
ffffffefd38000007c910d20
efffffffe6010000d210c907
ffffffefd38000007c910d20
-
{e=>95191856,c=>5,a=>65,b=>4,d=>6,f=>6}
41000000ac0100003083ac65
41000000ac0100003083ac65
41000000ac0100003083ac65
00000041970000005ac8330c
41000000ac0100003083ac65
41000000ac0100003083ac65
00000041970000005ac8330c
41000000ac0100003083ac65
00000041970000005ac8330c
-
{e=>142523577,c=>4,a=>114,b=>5,d=>2,f=>1}
72000000a5000000b9bc7e18
72000000a5000000b9bc7e18
72000000a5000000b9bc7e18
00000072b100000087ebcb92
72000000a5000000b9bc7e18
72000000a5000000b9bc7e18
00000072b100000087ebcb92
72000000a5000000b9bc7e18
00000072b100000087ebcb92
-
{e=>122537461,c=>7,a=>-44,b=>5,d=>0,f=>2}
d4ffffff3d000000f5c54d27
d4ffffff3d000000f5c54d27
d4ffffff3d000000f5c54d27
ffffffd4bc00000074dc5f54
d4ffffff3d000000f5c54d27
d4ffffff3d000000f5c54d27
ffffffd4bc00000074dc5f54
d4ffffff3d000000f5c54d27
ffffffd4bc00000074dc5f54
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>144539243,c=>5,a=>29,g=>2,b=>5,d=>0,f=>6}
1d0000002d0000006b7e9d6802000000
1d0000002d0000006b7e9d6802000000
1d0000002d0000006b7e9d6802000000
0000001db400000089d7e6bc80000000
1d0000002d0000006b7e9d6802000000
1d0000002d0000006b7e9d6802000000
0000001db400000089d7e6bc80000000
1d0000002d0000006b7e9d6802000000
0000001db400000089d7e6bc80000000
-
{e=>139635304,c=>6,a=>123,g=>2,b=>7,d=>7,f=>3}
7b000000f701000068aa523802000000
7b000000f701000068aa523802000000
7b000000f701000068aa523802000000
0000007bfb800000852aa68680000000
7b000000f701000068aa523802000000
7b000000f701000068aa523802000000
0000007bfb800000852aa68680000000
7b000000f701000068aa523802000000
0000007bfb800000852aa68680000000
-
{e=>8969412,c=>7,a=>-110,g=>2,b=>1,d=>2,f=>2}
92ffffffb9000000c4dc882002000000
92ffffffb9000000c4dc882002000000
92ffffffb9000000c4dc882002000000
ffffff923d000000088dcc4480000000
92ffffffb9000000c4dc882002000000
92ffffffb9000000c4dc882002000000
ffffff923d000000088dcc4480000000
92ffffffb9000000c4dc882002000000
ffffff923d000000088dcc4480000000
-
{e=>110093836,c=>0,a=>-32,g=>3,b=>2,d=>0,f=>5}
e0ffffff020000000ce68f5603000000
e0ffffff020000000ce68f5603000000
e0ffffff020000000ce68f5603000000
ffffffe04000000068fe60cac0000000
e0ffffff020000000ce68f5603000000
e0ffffff020000000ce68f5603000000
ffffffe04000000068fe60cac0000000
e0ffffff020000000ce68f5603000000
ffffffe04000000068fe60cac0000000
-
{e=>18345492,c=>1,a=>14,g=>2,b=>0,d=>1,f=>1}
0e0000004800000014ee171102000000
0e0000004800000014ee171102000000
0e0000004800000014ee171102000000
0000000e04800000117ee14280000000
0e0000004800000014ee171102000000
0e0000004800000014ee171102000000
0000000e04800000117ee14280000000
0e0000004800000014ee171102000000
0000000e04800000117ee14280000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>243213622,a=>-120,d=>4,c=>7,h=>7881,b=>7,g=>3,f=>2}
88ffffff3f01000036257f2e277b0000
88ffffff3f01000036257f2e277b0000
88ffffff3f01000036257f2e277b0000
ffffff88fe000000e7f25364fd920000
88ffffff3f01000036257f2e277b0000
88ffffff3f01000036257f2e277b0000
ffffff88fe000000e7f25364fd920000
88ffffff3f01000036257f2e277b0000
ffffff88fe000000e7f25364fd920000
-
{e=>86919501,a=>53,d=>5,c=>5,h=>380,b=>0,g=>0,f=>0}
35000000680100004d492e05f0050000
35000000680100004d492e05f0050000
35000000680100004d492e05f0050000
000000351680000052e494d002f80000
35000000680100004d492e05f0050000
35000000680100004d492e05f0050000
000000351680000052e494d002f80000
35000000680100004d492e05f0050000
000000351680000052e494d002f80000
-
{e=>147012077,a=>32,d=>1,c=>6,h=>2230,b=>1,g=>2,f=>7}
2000000071000000ed39c378da220000
2000000071000000ed39c378da220000
2000000071000000ed39c378da220000
00000020388000008c339ede916c0000
2000000071000000ed39c378da220000
2000000071000000ed39c378da220000
00000020388000008c339ede916c0000
2000000071000000ed39c378da220000
00000020388000008c339ede916c0000
-
{e=>23638499,a=>-48,d=>3,c=>7,h=>5753,b=>7,g=>2,f=>6}
d0ffffffff000000e3b16861e6590000
d0ffffffff000000e3b16861e6590000
d0ffffffff000000e3b16861e6590000
ffffffd0fd800000168b1e3cacf20000
d0ffffffff000000e3b16861e6590000
d0ffffffff000000e3b16861e6590000
ffffffd0fd800000168b1e3cacf20000
d0ffffffff000000e3b16861e6590000
ffffffd0fd800000168b1e3cacf20000
-
{e=>136927608,a=>-38,d=>6,c=>7,h=>773,b=>3,g=>2,f=>5}
daffffffbb01000078592958160c0000
daffffffbb01000078592958160c0000
daffffffbb01000078592958160c0000
ffffffda7f0000008295978a860a0000
daffffffbb01000078592958160c0000
daffffffbb01000078592958160c0000
ffffffda7f0000008295978a860a0000
daffffffbb01000078592958160c0000
ffffffda7f0000008295978a860a0000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  int a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  unsigned char  i;
};
-
{e=>145884245,a=>43,d=>4,c=>7,h=>3698,b=>4,g=>0,f=>0,i=>117}
2b0000003c0100005504b208c8397500
2b0000003c0100005504b208c8397500
2b0000003c0100005504b208c8397500
0000002b9e0000008b2045501ce47500
2b0000003c0100005504b208c8397500
2b0000003c0100005504b208c8397500
0000002b9e0000008b2045501ce47500
2b0000003c0100005504b208c8397500
0000002b9e0000008b2045501ce47500
-
{e=>148618604,a=>-115,d=>5,c=>6,h=>3263,b=>7,g=>2,f=>1,i=>253}
8dffffff770100006cbddb18fe32fd00
8dffffff770100006cbddb18fe32fd00
8dffffff770100006cbddb18fe32fd00
ffffff8dfa8000008dbbd6c2997efd00
8dffffff770100006cbddb18fe32fd00
8dffffff770100006cbddb18fe32fd00
ffffff8dfa8000008dbbd6c2997efd00
8dffffff770100006cbddb18fe32fd00
ffffff8dfa8000008dbbd6c2997efd00
-
{e=>226652794,a=>48,d=>5,c=>2,h=>2101,b=>4,g=>1,f=>3,i=>16}
30000000540100007a72823dd5201000
30000000540100007a72823dd5201000
30000000540100007a72823dd5201000
000000308a800000d82727a6506a1000
30000000540100007a72823dd5201000
30000000540100007a72823dd5201000
000000308a800000d82727a6506a1000
30000000540100007a72823dd5201000
000000308a800000d82727a6506a1000
-
{e=>137257539,a=>-126,d=>4,c=>7,h=>3963,b=>0,g=>3,f=>1,i=>27}
82ffffff3801000043622e18ef3d1b00
82ffffff3801000043622e18ef3d1b00
82ffffff3801000043622e18ef3d1b00
ffffff821e00000082e62432def61b00
82ffffff3801000043622e18ef3d1b00
82ffffff3801000043622e18ef3d1b00
ffffff821e00000082e62432def61b00
82ffffff3801000043622e18ef3d1b00
ffffff821e00000082e62432def61b00
-
{e=>106849035,a=>-61,d=>5,c=>4,h=>1757,b=>7,g=>1,f=>5,i=>42}
c3ffffff670100000b635e56751b2a00
c3ffffff670100000b635e56751b2a00
c3ffffff670100000b635e56751b2a00
ffffffc3f280000065e630ba4dba2a00
c3ffffff670100000b635e56751b2a00
c3ffffff670100000b635e56751b2a00
ffffffc3f280000065e630ba4dba2a00
c3ffffff670100000b635e56751b2a00
ffffffc3f280000065e630ba4dba2a00
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  long a;
  unsigned char  b:3;
};
-
{a=>72,b=>5}
4800000005000000
48000000000000000500000000000000
48000000000000000500000000000000
00000048a0000000
4800000005000000
4800000005000000
0000000000000048a000000000000000
4800000005000000
00000048a0000000
-
{a=>-71,b=>1}
b9ffffff01000000
b9ffffffffffffff0100000000000000
b9ffffffffffffff0100000000000000
ffffffb920000000
b9ffffff01000000
b9ffffff01000000
ffffffffffffffb92000000000000000
b9ffffff01000000
ffffffb920000000
-
{a=>-67,b=>4}
bdffffff04000000
bdffffffffffffff0400000000000000
bdffffffffffffff0400000000000000
ffffffbd80000000
bdffffff04000000
bdffffff04000000
ffffffffffffffbd8000000000000000
bdffffff04000000
ffffffbd80000000
-
{a=>-126,b=>2}
82ffffff02000000
82ffffffffffffff0200000000000000
82ffffffffffffff0200000000000000
ffffff8240000000
82ffffff02000000
82ffffff02000000
ffffffffffffff824000000000000000
82ffffff02000000
ffffff8240000000
-
{a=>126,b=>2}
7e00000002000000
7e000000000000000200000000000000
7e000000000000000200000000000000
0000007e40000000
7e00000002000000
7e00000002000000
000000000000007e4000000000000000
7e00000002000000
0000007e40000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
};
-
{c=>2,a=>122,b=>0}
7a00000010000000
7a000000000000001000000000000000
7a000000000000001000000000000000
0000007a08000000
7a00000010000000
7a00000010000000
000000000000007a0800000000000000
7a00000010000000
0000007a08000000
-
{c=>7,a=>-32,b=>1}
e0ffffff39000000
e0ffffffffffffff3900000000000000
e0ffffffffffffff3900000000000000
ffffffe03c000000
e0ffffff39000000
e0ffffff39000000
ffffffffffffffe03c00000000000000
e0ffffff39000000
ffffffe03c000000
-
{c=>1,a=>33,b=>2}
210000000a000000
21000000000000000a00000000000000
21000000000000000a00000000000000
0000002144000000
210000000a000000
210000000a000000
00000000000000214400000000000000
210000000a000000
0000002144000000
-
{c=>2,a=>-13,b=>6}
f3ffffff16000000
f3ffffffffffffff1600000000000000
f3ffffffffffffff1600000000000000
fffffff3c8000000
f3ffffff16000000
f3ffffff16000000
fffffffffffffff3c800000000000000
f3ffffff16000000
fffffff3c8000000
-
{c=>6,a=>-22,b=>1}
eaffffff31000000
eaffffffffffffff3100000000000000
eaffffffffffffff3100000000000000
ffffffea38000000
eaffffff31000000
eaffffff31000000
ffffffffffffffea3800000000000000
eaffffff31000000
ffffffea38000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
};
-
{c=>4,a=>-120,b=>1,d=>6}
88ffffffa1010000
88ffffffffffffffa101000000000000
88ffffffffffffffa101000000000000
ffffff8833000000
88ffffffa1010000
88ffffffa1010000
ffffffffffffff883300000000000000
88ffffffa1010000
ffffff8833000000
-
{c=>6,a=>-100,b=>5,d=>5}
9cffffff75010000
9cffffffffffffff7501000000000000
9cffffffffffffff7501000000000000
ffffff9cba800000
9cffffff75010000
9cffffff75010000
ffffffffffffff9cba80000000000000
9cffffff75010000
ffffff9cba800000
-
{c=>7,a=>70,b=>5,d=>2}
46000000bd000000
4600000000000000bd00000000000000
4600000000000000bd00000000000000
00000046bd000000
46000000bd000000
46000000bd000000
0000000000000046bd00000000000000
46000000bd000000
00000046bd000000
-
{c=>5,a=>-124,b=>3,d=>0}
84ffffff2b000000
84ffffffffffffff2b00000000000000
84ffffffffffffff2b00000000000000
ffffff8474000000
84ffffff2b000000
84ffffff2b000000
ffffffffffffff847400000000000000
84ffffff2b000000
ffffff8474000000
-
{c=>7,a=>106,b=>6,d=>3}
6a000000fe000000
6a00000000000000fe00000000000000
6a00000000000000fe00000000000000
0000006add800000
6a000000fe000000
6a000000fe000000
000000000000006add80000000000000
6a000000fe000000
0000006add800000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
};
-
{e=>238948103,c=>0,a=>46,b=>1,d=>7}
2e000000c1010000070f3e0e
2e00000000000000c1010000070f3e0e
2e00000000000000c1010000070f3e0e
0000002e23800000e3e0f070
2e000000c1010000070f3e0e
2e000000c1010000070f3e0e
000000000000002e23800000e3e0f070
2e000000c1010000070f3e0e
0000002e23800000e3e0f070
-
{e=>85833411,c=>2,a=>41,b=>3,d=>7}
29000000d3010000c3b61d05
2900000000000000d3010000c3b61d05
2900000000000000d3010000c3b61d05
000000296b80000051db6c30
29000000d3010000c3b61d05
29000000d3010000c3b61d05
00000000000000296b80000051db6c30
29000000d3010000c3b61d05
000000296b80000051db6c30
-
{e=>85862305,c=>4,a=>-94,b=>6,d=>4}
a2ffffff26010000a1271e05
a2ffffffffffffff26010000a1271e05
a2ffffffffffffff26010000a1271e05
ffffffa2d200000051e27a10
a2ffffff26010000a1271e05
a2ffffff26010000a1271e05
ffffffffffffffa2d200000051e27a10
a2ffffff26010000a1271e05
ffffffa2d200000051e27a10
-
{e=>89255584,c=>4,a=>26,b=>1,d=>0}
1a00000021000000a0ee5105
1a0000000000000021000000a0ee5105
1a0000000000000021000000a0ee5105
0000001a30000000551eea00
1a00000021000000a0ee5105
1a00000021000000a0ee5105
000000000000001a30000000551eea00
1a00000021000000a0ee5105
0000001a30000000551eea00
-
{e=>218745112,c=>5,a=>-41,b=>3,d=>0}
d7ffffff2b00000018c9090d
d7ffffffffffffff2b00000018c9090d
d7ffffffffffffff2b00000018c9090d
ffffffd774000000d09c9180
d7ffffff2b00000018c9090d
d7ffffff2b00000018c9090d
ffffffffffffffd774000000d09c9180
d7ffffff2b00000018c9090d
ffffffd774000000d09c9180
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
};
-
{e=>181902780,c=>3,a=>-112,b=>6,d=>7,f=>4}
90ffffffde010000bc9dd74a
90ffffffffffffffde010000bc9dd74a
90ffffffffffffffde010000bc9dd74a
ffffff90cf800000ad79dbc8
90ffffffde010000bc9dd74a
90ffffffde010000bc9dd74a
ffffffffffffff90cf800000ad79dbc8
90ffffffde010000bc9dd74a
ffffff90cf800000ad79dbc8
-
{e=>243947917,c=>2,a=>-87,b=>0,d=>1,f=>7}
a9ffffff500000008d598a7e
a9ffffffffffffff500000008d598a7e
a9ffffffffffffff500000008d598a7e
ffffffa908800000e8a598de
a9ffffff500000008d598a7e
a9ffffff500000008d598a7e
ffffffffffffffa908800000e8a598de
a9ffffff500000008d598a7e
ffffffa908800000e8a598de
-
{e=>87380681,c=>3,a=>-46,b=>2,d=>3,f=>1}
d2ffffffda000000c9523515
d2ffffffffffffffda000000c9523515
d2ffffffffffffffda000000c9523515
ffffffd24d80000053552c92
d2ffffffda000000c9523515
d2ffffffda000000c9523515
ffffffffffffffd24d80000053552c92
d2ffffffda000000c9523515
ffffffd24d80000053552c92
-
{e=>23417204,c=>4,a=>50,b=>3,d=>0,f=>5}
320000002300000074516551
32000000000000002300000074516551
32000000000000002300000074516551
00000032700000001655174a
320000002300000074516551
320000002300000074516551
0000000000000032700000001655174a
320000002300000074516551
00000032700000001655174a
-
{e=>33123043,c=>0,a=>116,b=>6,d=>0,f=>4}
7400000006000000e36af941
740000000000000006000000e36af941
740000000000000006000000e36af941
00000074c00000001f96ae38
7400000006000000e36af941
7400000006000000e36af941
0000000000000074c00000001f96ae38
7400000006000000e36af941
00000074c00000001f96ae38
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
};
-
{e=>84208039,c=>0,a=>14,g=>1,b=>2,d=>1,f=>0}
0e00000042000000a7e9040501000000
0e0000000000000042000000a7e904050100000000000000
0e0000000000000042000000a7e904050100000000000000
0000000e40800000504e9a7040000000
0e00000042000000a7e9040501000000
0e00000042000000a7e9040501000000
000000000000000e40800000504e9a704000000000000000
0e00000042000000a7e9040501000000
0000000e40800000504e9a7040000000
-
{e=>116421098,c=>1,a=>-89,g=>2,b=>6,d=>4,f=>6}
a7ffffff0e010000ea71f06602000000
a7ffffffffffffff0e010000ea71f0660200000000000000
a7ffffffffffffff0e010000ea71f0660200000000000000
ffffffa7c60000006f071eac80000000
a7ffffff0e010000ea71f06602000000
a7ffffff0e010000ea71f06602000000
ffffffffffffffa7c60000006f071eac8000000000000000
a7ffffff0e010000ea71f06602000000
ffffffa7c60000006f071eac80000000
-
{e=>233446560,c=>1,a=>-126,g=>0,b=>7,d=>1,f=>0}
82ffffff4f000000a01cea0d00000000
82ffffffffffffff4f000000a01cea0d0000000000000000
82ffffffffffffff4f000000a01cea0d0000000000000000
ffffff82e4800000dea1ca0000000000
82ffffff4f000000a01cea0d00000000
82ffffff4f000000a01cea0d00000000
ffffffffffffff82e4800000dea1ca000000000000000000
82ffffff4f000000a01cea0d00000000
ffffff82e4800000dea1ca0000000000
-
{e=>196256397,c=>2,a=>-106,g=>1,b=>1,d=>5,f=>0}
96ffffff510100008da2b20b01000000
96ffffffffffffff510100008da2b20b0100000000000000
96ffffffffffffff510100008da2b20b0100000000000000
ffffff962a800000bb2a28d040000000
96ffffff510100008da2b20b01000000
96ffffff510100008da2b20b01000000
ffffffffffffff962a800000bb2a28d04000000000000000
96ffffff510100008da2b20b01000000
ffffff962a800000bb2a28d040000000
-
{e=>98949361,c=>1,a=>69,g=>3,b=>4,d=>4,f=>0}
450000000c010000f1d8e50503000000
45000000000000000c010000f1d8e5050300000000000000
45000000000000000c010000f1d8e5050300000000000000
00000045860000005e5d8f10c0000000
450000000c010000f1d8e50503000000
450000000c010000f1d8e50503000000
0000000000000045860000005e5d8f10c000000000000000
450000000c010000f1d8e50503000000
00000045860000005e5d8f10c0000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
};
-
{e=>154431445,a=>-110,d=>6,c=>7,h=>5540,b=>6,g=>1,f=>7}
92ffffffbe010000d56f347991560000
92ffffffffffffffbe010000d56f34799156000000000000
92ffffffffffffffbe010000d56f34799156000000000000
ffffff92df0000009346fd5e6b480000
92ffffffbe010000d56f347991560000
92ffffffbe010000d56f347991560000
ffffffffffffff92df0000009346fd5e6b48000000000000
92ffffffbe010000d56f347991560000
ffffff92df0000009346fd5e6b480000
-
{e=>175556692,a=>-125,d=>1,c=>1,h=>2798,b=>5,g=>2,f=>5}
83ffffff4d00000054c8765aba2b0000
83ffffffffffffff4d00000054c8765aba2b000000000000
83ffffffffffffff4d00000054c8765aba2b000000000000
ffffff83a4800000a76c854a95dc0000
83ffffff4d00000054c8765aba2b0000
83ffffff4d00000054c8765aba2b0000
ffffffffffffff83a4800000a76c854a95dc000000000000
83ffffff4d00000054c8765aba2b0000
ffffff83a4800000a76c854a95dc0000
-
{e=>165973282,a=>-23,d=>2,c=>0,h=>4321,b=>0,g=>0,f=>0}
e9ffffff80000000228de40984430000
e9ffffffffffffff80000000228de4098443000000000000
e9ffffffffffffff80000000228de4098443000000000000
ffffffe9010000009e48d22021c20000
e9ffffff80000000228de40984430000
e9ffffff80000000228de40984430000
ffffffffffffffe9010000009e48d22021c2000000000000
e9ffffff80000000228de40984430000
ffffffe9010000009e48d22021c20000
-
{e=>13388635,a=>38,d=>7,c=>3,h=>3576,b=>1,g=>1,f=>0}
26000000d90100005b4bcc00e1370000
2600000000000000d90100005b4bcc00e137000000000000
2600000000000000d90100005b4bcc00e137000000000000
000000262f8000000cc4b5b05bf00000
26000000d90100005b4bcc00e1370000
26000000d90100005b4bcc00e1370000
00000000000000262f8000000cc4b5b05bf0000000000000
26000000d90100005b4bcc00e1370000
000000262f8000000cc4b5b05bf00000
-
{e=>21214690,a=>-124,d=>3,c=>4,h=>6149,b=>0,g=>3,f=>3}
84ffffffe0000000e2b5433117600000
84ffffffffffffffe0000000e2b543311760000000000000
84ffffffffffffffe0000000e2b543311760000000000000
ffffff8411800000143b5e26f00a0000
84ffffffe0000000e2b5433117600000
84ffffffe0000000e2b5433117600000
ffffffffffffff8411800000143b5e26f00a000000000000
84ffffffe0000000e2b5433117600000
ffffff8411800000143b5e26f00a0000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct umixed_pack_4 {
  long a;
  unsigned char  b:3;
  unsigned char  c:3;
  unsigned short d:3;
  unsigned int   e:28;
  unsigned char  f:3;
  unsigned char  g:2;
  unsigned short h:13;
  unsigned char  i;
};
-
{e=>130293957,a=>-6,d=>3,c=>0,h=>3224,b=>7,g=>2,f=>1,i=>96}
faffffffc7000000c520c41762326000
faffffffffffffffc7000000c520c4176232600000000000
faffffffffffffffc7000000c520c4176232600000000000
fffffffae18000007c420c5299306000
faffffffc7000000c520c41762326000
faffffffc7000000c520c41762326000
fffffffffffffffae18000007c420c529930600000000000
faffffffc7000000c520c41762326000
fffffffae18000007c420c5299306000
-
{e=>22275050,a=>24,d=>7,c=>6,h=>4511,b=>7,g=>0,f=>3,i=>194}
18000000f7010000eae353317c46c200
1800000000000000f7010000eae353317c46c20000000000
1800000000000000f7010000eae353317c46c20000000000
00000018fb800000153e3ea6233ec200
18000000f7010000eae353317c46c200
18000000f7010000eae353317c46c200
0000000000000018fb800000153e3ea6233ec20000000000
18000000f7010000eae353317c46c200
00000018fb800000153e3ea6233ec200
-
{e=>185744049,a=>-60,d=>7,c=>6,h=>1844,b=>6,g=>0,f=>2,i=>56}
c4fffffff6010000b13a122bd01c3800
c4fffffffffffffff6010000b13a122bd01c380000000000
c4fffffffffffffff6010000b13a122bd01c380000000000
ffffffc4db800000b123ab140e683800
c4fffffff6010000b13a122bd01c3800
c4fffffff6010000b13a122bd01c3800
ffffffffffffffc4db800000b123ab140e68380000000000
c4fffffff6010000b13a122bd01c3800
ffffffc4db800000b123ab140e683800
-
{e=>260322633,a=>-58,d=>5,c=>5,h=>6201,b=>7,g=>2,f=>2,i=>199}
c6ffffff6f0100004935842fe660c700
c6ffffffffffffff6f0100004935842fe660c70000000000
c6ffffffffffffff6f0100004935842fe660c70000000000
ffffffc6f6800000f8435494b072c700
c6ffffff6f0100004935842fe660c700
c6ffffff6f0100004935842fe660c700
ffffffffffffffc6f6800000f8435494b072c70000000000
c6ffffff6f0100004935842fe660c700
ffffffc6f6800000f8435494b072c700
-
{e=>148496573,a=>-115,d=>0,c=>0,h=>7411,b=>3,g=>0,f=>7,i=>14}
8dffffff03000000bde0d978cc730e00
8dffffffffffffff03000000bde0d978cc730e0000000000
8dffffffffffffff03000000bde0d978cc730e0000000000
ffffff8d600000008d9e0bde39e60e00
8dffffff03000000bde0d978cc730e00
8dffffff03000000bde0d978cc730e00
ffffffffffffff8d600000008d9e0bde39e60e0000000000
8dffffff03000000bde0d978cc730e00
ffffff8d600000008d9e0bde39e60e00
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
};
-
{a=>7}
07000000
07000000
07000000
e0000000
07000000
07000000
e0000000
07000000
e0000000
-
{a=>5}
05000000
05000000
05000000
a0000000
05000000
05000000
a0000000
05000000
a0000000
-
{a=>5}
05000000
05000000
05000000
a0000000
05000000
05000000
a0000000
05000000
a0000000
-
{a=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
-
{a=>7}
07000000
07000000
07000000
e0000000
07000000
07000000
e0000000
07000000
e0000000
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
};
-
{a=>5,b=>3}
1d000000
1d000000
1d000000
ac000000
1d000000
1d000000
ac000000
1d000000
ac000000
-
{a=>6,b=>-4}
26000000
26000000
26000000
d0000000
26000000
26000000
d0000000
26000000
d0000000
-
{a=>7,b=>1}
0f000000
0f000000
0f000000
e4000000
0f000000
0f000000
e4000000
0f000000
e4000000
-
{a=>4,b=>2}
14000000
14000000
14000000
88000000
14000000
14000000
88000000
14000000
88000000
-
{a=>3,b=>2}
13000000
13000000
13000000
68000000
13000000
13000000
68000000
13000000
68000000
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
};
-
{c=>1,a=>6,b=>-4}
66000000
66000000
66000000
d0800000
66000000
66000000
d0800000
66000000
d0800000
-
{c=>3,a=>2,b=>0}
c2000000
c2000000
c2000000
41800000
c2000000
c2000000
41800000
c2000000
41800000
-
{c=>1,a=>4,b=>-3}
6c000000
6c000000
6c000000
94800000
6c000000
6c000000
94800000
6c000000
94800000
-
{c=>-4,a=>2,b=>-4}
22010000
22010000
22010000
52000000
22010000
22010000
52000000
22010000
52000000
-
{c=>-3,a=>4,b=>-3}
6c010000
6c010000
6c010000
96800000
6c010000
6c010000
96800000
6c010000
96800000
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
};
-
{c=>-3,a=>0,b=>-3,d=>3}
68070000
68070000
68070000
16b00000
68070000
68070000
16b00000
68070000
16b00000
-
{c=>-4,a=>3,b=>3,d=>4}
1b090000
1b090000
1b090000
6e400000
1b090000
1b090000
6e400000
1b090000
6e400000
-
{c=>-4,a=>4,b=>3,d=>1}
1c030000
1c030000
1c030000
8e100000
1c030000
1c030000
8e100000
1c030000
8e100000
-
{c=>-1,a=>6,b=>-3,d=>0}
ee010000
ee010000
ee010000
d7800000
ee010000
ee010000
d7800000
ee010000
d7800000
-
{c=>0,a=>5,b=>2,d=>2}
15040000
15040000
15040000
a8200000
15040000
15040000
a8200000
15040000
a8200000
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
};
-
{e=>0,c=>2,a=>1,b=>2,d=>6}
910c0000
910c0000
910c0000
29600000
910c0000
910c0000
29600000
910c0000
29600000
-
{e=>-1,c=>-2,a=>6,b=>3,d=>7}
9e7f0000
9e7f0000
9e7f0000
cf7e0000
9e7f0000
9e7f0000
cf7e0000
9e7f0000
cf7e0000
-
{e=>-1,c=>-2,a=>0,b=>0,d=>2}
80750000
80750000
80750000
032e0000
80750000
80750000
032e0000
80750000
032e0000
-
{e=>0,c=>3,a=>6,b=>-1,d=>0}
fe000000
fe000000
fe000000
dd800000
fe000000
fe000000
dd800000
fe000000
dd800000
-
{e=>3,c=>-2,a=>1,b=>0,d=>7}
813f0000
813f0000
813f0000
23760000
813f0000
813f0000
23760000
813f0000
23760000
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
};
-
{e=>2,c=>1,a=>2,b=>-4,d=>3,f=>6}
62260300
62260300
62260300
50b58000
62260300
62260300
50b58000
62260300
50b58000
-
{e=>-2,c=>-2,a=>6,b=>1,d=>6,f=>0}
8e6d0000
8e6d0000
8e6d0000
c76c0000
8e6d0000
8e6d0000
c76c0000
8e6d0000
c76c0000
-
{e=>1,c=>1,a=>3,b=>-4,d=>7,f=>5}
639e0200
639e0200
639e0200
70f34000
639e0200
639e0200
70f34000
639e0200
70f34000
-
{e=>2,c=>2,a=>0,b=>-1,d=>3,f=>2}
b8260100
b8260100
b8260100
1d348000
b8260100
b8260100
1d348000
b8260100
1d348000
-
{e=>0,c=>3,a=>5,b=>2,d=>5,f=>2}
d50a0100
d50a0100
d50a0100
a9d08000
d50a0100
d50a0100
a9d08000
d50a0100
a9d08000
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
};
-
{e=>3,c=>-4,a=>1,b=>2,d=>1,f=>1}
11b30000
11b30000
11b30000
2a164000
11b30000
11b30000
2a164000
11b30000
2a164000
-
{e=>-1,c=>-2,a=>5,b=>-1,d=>7,f=>2}
bd7f0100
bd7f0100
bd7f0100
bf7e8000
bd7f0100
bd7f0100
bf7e8000
bd7f0100
bf7e8000
-
{e=>-3,c=>-2,a=>2,b=>-2,d=>2,f=>3}
b2d50100
b2d50100
b2d50100
5b2ac000
b2d50100
b2d50100
5b2ac000
b2d50100
5b2ac000
-
{e=>-1,c=>-1,a=>7,b=>-1,d=>3,f=>1}
fff70000
fff70000
fff70000
ffbe4000
fff70000
fff70000
ffbe4000
fff70000
ffbe4000
-
{e=>-3,c=>2,a=>7,b=>-2,d=>5,f=>0}
b75a0000
b75a0000
b75a0000
f95a0000
b75a0000
b75a0000
f95a0000
b75a0000
f95a0000
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
};
-
{e=>0,c=>3,a=>3,g=>2,b=>0,d=>2,f=>7}
c384030002000000
c384030002000000
c384030002000000
61a1c00040000000
c384030002000000
c384030002000000
61a1c00040000000
c384030002000000
61a1c00040000000
-
{e=>1,c=>3,a=>0,g=>7,b=>1,d=>1,f=>4}
c812020007000000
c812020007000000
c812020007000000
05930000e0000000
c812020007000000
c812020007000000
05930000e0000000
c812020007000000
05930000e0000000
-
{e=>0,c=>3,a=>7,g=>0,b=>-2,d=>7,f=>2}
f70e010000000000
f70e010000000000
f70e010000000000
f9f0800000000000
f70e010000000000
f70e010000000000
f9f0800000000000
f70e010000000000
f9f0800000000000
-
{e=>-2,c=>3,a=>1,g=>2,b=>0,d=>2,f=>0}
c164000002000000
c164000002000000
c164000002000000
21ac000040000000
c164000002000000
c164000002000000
21ac000040000000
c164000002000000
21ac000040000000
-
{e=>2,c=>-1,a=>7,g=>5,b=>-2,d=>6,f=>7}
f7ad030005000000
f7ad030005000000
f7ad030005000000
fbe5c000a0000000
f7ad030005000000
f7ad030005000000
fbe5c000a0000000
f7ad030005000000
fbe5c000a0000000
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
};
-
{e=>1,a=>0,d=>6,c=>-1,h=>3,b=>-1,g=>7,f=>6}
f81d03001f000000
f81d03001f000000
f81d03001f000000
1fe38000ec000000
f81d03001f000000
f81d03001f000000
1fe38000ec000000
f81d03001f000000
1fe38000ec000000
-
{e=>-4,a=>1,d=>3,c=>-4,h=>2,b=>2,g=>0,f=>5}
11c7020010000000
11c7020010000000
11c7020010000000
2a39400008000000
11c7020010000000
11c7020010000000
2a39400008000000
11c7020010000000
2a39400008000000
-
{e=>2,a=>3,d=>1,c=>-4,h=>0,b=>-1,g=>0,f=>2}
3b23010000000000
3b23010000000000
3b23010000000000
7e14800000000000
3b23010000000000
3b23010000000000
7e14800000000000
3b23010000000000
7e14800000000000
-
{e=>-2,a=>4,d=>4,c=>2,h=>-3,b=>-4,g=>7,f=>1}
a4e800002f000000
a4e800002f000000
a4e800002f000000
914c4000f4000000
a4e800002f000000
a4e800002f000000
914c4000f4000000
a4e800002f000000
914c4000f4000000
-
{e=>-2,a=>1,d=>2,c=>-1,h=>0,b=>-2,g=>5,f=>6}
f165030005000000
f165030005000000
f165030005000000
3bad8000a0000000
f165030005000000
f165030005000000
3bad8000a0000000
f165030005000000
3bad8000a0000000
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
};
-
{e=>0,a=>3,d=>4,c=>-1,h=>3,b=>-2,g=>3,f=>4,i=>1}
f30902005b000000
f30902005b000000
f30902005b000000
7bc100006c800000
f30902005b000000
f30902005b000000
7bc100006c800000
f30902005b000000
7bc100006c800000
-
{e=>2,a=>5,d=>2,c=>1,h=>2,b=>-3,g=>4,f=>0,i=>3}
6d240000d4000000
6d240000d4000000
6d240000d4000000
b4a4000089800000
6d240000d4000000
6d240000d4000000
b4a4000089800000
6d240000d4000000
b4a4000089800000
-
{e=>0,a=>5,d=>3,c=>2,h=>-3,b=>-1,g=>7,f=>7,i=>4}
bd8603002f010000
bd8603002f010000
bd8603002f010000
bd31c000f6000000
bd8603002f010000
bd8603002f010000
bd31c000f6000000
bd8603002f010000
bd31c000f6000000
-
{e=>-3,a=>5,d=>1,c=>1,h=>3,b=>-1,g=>3,f=>2,i=>6}
7d5201009b010000
7d5201009b010000
7d5201009b010000
bc9a80006f000000
7d5201009b010000
7d5201009b010000
bc9a80006f000000
7d5201009b010000
bc9a80006f000000
-
{e=>3,a=>3,d=>6,c=>1,h=>0,b=>0,g=>3,f=>2,i=>7}
433c0100c3010000
433c0100c3010000
433c0100c3010000
60e6800063800000
433c0100c3010000
433c0100c3010000
60e6800063800000
433c0100c3010000
60e6800063800000
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
};
-
{e=>-1,a=>4,d=>4,j=>-12,c=>2,h=>1,b=>-1,g=>7,f=>7,i=>0}
bcf803000f00f400
bcf803000f00f400
bcf803000f00f400
9d4fc000e400f400
bcf803000f00f400
bcf803000f00f400
9d4fc000e400f400
bcf803000f00f400
9d4fc000e400f400
-
{e=>3,a=>4,d=>1,j=>93,c=>-1,h=>3,b=>-4,g=>3,f=>2,i=>6}
e43301009b015d00
e43301009b015d00
e43301009b015d00
939680006f005d00
e43301009b015d00
e43301009b015d00
939680006f005d00
e43301009b015d00
939680006f005d00
-
{e=>1,a=>1,d=>6,j=>58,c=>-2,h=>-3,b=>3,g=>7,f=>5,i=>6}
999d0200af013a00
999d0200af013a00
999d0200af013a00
2f634000f7003a00
999d0200af013a00
999d0200af013a00
2f634000f7003a00
999d0200af013a00
2f634000f7003a00
-
{e=>-2,a=>4,d=>4,j=>96,c=>3,h=>3,b=>-3,g=>6,f=>0,i=>1}
ec6800005e006000
ec6800005e006000
ec6800005e006000
95cc0000cc806000
ec6800005e006000
ec6800005e006000
95cc0000cc806000
ec6800005e006000
95cc0000cc806000
-
{e=>-4,a=>6,d=>7,j=>-52,c=>-2,h=>-2,b=>2,g=>5,f=>4,i=>7}
964f0200f501cc00
964f0200f501cc00
964f0200f501cc00
cb790000bb80cc00
964f0200f501cc00
964f0200f501cc00
cb790000bb80cc00
964f0200f501cc00
cb790000bb80cc00
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
  unsigned char k:3;
};
-
{e=>-4,a=>4,d=>6,j=>-110,c=>3,k=>1,h=>3,b=>-4,g=>4,f=>2,i=>5}
e44c01005c019201
e44c01005c019201
e44c01005c019201
91e880008e809220
e44c01005c019201
e44c01005c019201
91e880008e809220
e44c01005c019201
91e880008e809220
-
{e=>1,a=>1,d=>5,j=>-28,c=>-3,k=>4,h=>-4,b=>2,g=>2,f=>4,i=>2}
511b0200a200e404
511b0200a200e404
511b0200a200e404
2ad300005100e480
511b0200a200e404
511b0200a200e404
2ad300005100e480
511b0200a200e404
2ad300005100e480
-
{e=>1,a=>0,d=>1,j=>83,c=>2,k=>7,h=>0,b=>1,g=>6,f=>5,i=>0}
8892020006005307
8892020006005307
8892020006005307
05134000c00053e0
8892020006005307
8892020006005307
05134000c00053e0
8892020006005307
05134000c00053e0
-
{e=>3,a=>7,d=>1,j=>-110,c=>2,k=>0,h=>0,b=>-3,g=>0,f=>4,i=>6}
af32020080019200
af32020080019200
af32020080019200
f517000003009200
af32020080019200
af32020080019200
f517000003009200
af32020080019200
f517000003009200
-
{e=>-4,a=>5,d=>6,j=>-88,c=>1,k=>7,h=>-3,b=>0,g=>5,f=>2,i=>2}
454c0100ad00a807
454c0100ad00a807
454c0100ad00a807
a0e88000b500a8e0
454c0100ad00a807
454c0100ad00a807
a0e88000b500a8e0
454c0100ad00a807
a0e88000b500a8e0
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
};
-
{e=>1,a=>1,d=>5,j=>101,l=>-3,c=>-4,k=>2,h=>-2,b=>3,g=>1,f=>1,i=>2}
199b0000b100652a
199b0000b100652a
199b0000b100652a
2e52400039006554
199b0000b100652a
199b0000b100652a
2e52400039006554
199b0000b100652a
2e52400039006554
-
{e=>1,a=>6,d=>2,j=>-74,l=>0,c=>-4,k=>2,h=>-2,b=>2,g=>2,f=>0,i=>4}
161500003201b602
161500003201b602
161500003201b602
ca2200005a00b640
161500003201b602
161500003201b602
ca2200005a00b640
161500003201b602
ca2200005a00b640
-
{e=>3,a=>7,d=>2,j=>30,l=>2,c=>3,k=>6,h=>0,b=>-4,g=>2,f=>7,i=>6}
e7b4030082011e16
e7b4030082011e16
e7b4030082011e16
f1a7c00043001ec8
e7b4030082011e16
e7b4030082011e16
f1a7c00043001ec8
e7b4030082011e16
f1a7c00043001ec8
-
{e=>-2,a=>7,d=>0,j=>-4,l=>-2,c=>-4,k=>5,h=>0,b=>0,g=>4,f=>7,i=>4}
07e103000401fc35
07e103000401fc35
07e103000401fc35
e20dc0008200fcb8
07e103000401fc35
07e103000401fc35
e20dc0008200fcb8
07e103000401fc35
e20dc0008200fcb8
-
{e=>2,a=>0,d=>6,j=>65,l=>1,c=>-3,k=>6,h=>-3,b=>-2,g=>3,f=>1,i=>6}
70ad0000ab01410e
70ad0000ab01410e
70ad0000ab01410e
1ae44000770041c4
70ad0000ab01410e
70ad0000ab01410e
1ae44000770041c4
70ad0000ab01410e
1ae44000770041c4
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
  unsigned int  m:3;
};
-
{e=>-4,a=>6,m=>1,d=>1,j=>55,l=>-2,c=>0,k=>7,h=>-2,b=>-4,g=>1,f=>0,i=>1}
264200007100373701000000
264200007100373701000000
264200007100373701000000
d0180000388037f820000000
264200007100373701000000
264200007100373701000000
d0180000388037f820000000
264200007100373701000000
d0180000388037f820000000
-
{e=>3,a=>1,m=>6,d=>6,j=>-117,l=>-4,c=>-1,k=>5,h=>-4,b=>0,g=>2,f=>6,i=>7}
c13d0300e2018b2506000000
c13d0300e2018b2506000000
c13d0300e2018b2506000000
23e7800053808bb0c0000000
c13d0300e2018b2506000000
c13d0300e2018b2506000000
23e7800053808bb0c0000000
c13d0300e2018b2506000000
23e7800053808bb0c0000000
-
{e=>2,a=>2,m=>4,d=>7,j=>-36,l=>3,c=>-1,k=>7,h=>3,b=>3,g=>3,f=>5,i=>5}
daaf02005b01dc1f04000000
daaf02005b01dc1f04000000
daaf02005b01dc1f04000000
4ff540006e80dcec80000000
daaf02005b01dc1f04000000
daaf02005b01dc1f04000000
4ff540006e80dcec80000000
daaf02005b01dc1f04000000
4ff540006e80dcec80000000
-
{e=>1,a=>0,m=>7,d=>6,j=>-99,l=>-1,c=>0,k=>7,h=>-4,b=>1,g=>0,f=>3,i=>1}
089c010060009d3f07000000
089c010060009d3f07000000
089c010060009d3f07000000
0462c00010809dfce0000000
089c010060009d3f07000000
089c010060009d3f07000000
0462c00010809dfce0000000
089c010060009d3f07000000
0462c00010809dfce0000000
-
{e=>1,a=>2,m=>1,d=>3,j=>57,l=>-1,c=>0,k=>5,h=>3,b=>-4,g=>4,f=>4,i=>6}
221602009c01393d01000000
221602009c01393d01000000
221602009c01393d01000000
503300008f0039bc20000000
221602009c01393d01000000
221602009c01393d01000000
503300008f0039bc20000000
221602009c01393d01000000
503300008f0039bc20000000
=
typedef int foo;

struct mixed_no_pack {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
  unsigned int  m:3;
  unsigned char n;
};
-
{e=>0,n=>177,a=>4,m=>2,d=>0,j=>-5,l=>-2,c=>3,k=>3,h=>-3,b=>0,g=>7,f=>7,i=>3}
c4800300ef00fb3302b10000
c4800300ef00fb3302b10000
c4800300ef00fb3302b10000
8181c000f580fb7840b10000
c4800300ef00fb3302b10000
c4800300ef00fb3302b10000
8181c000f580fb7840b10000
c4800300ef00fb3302b10000
8181c000f580fb7840b10000
-
{e=>-3,n=>5,a=>7,m=>4,d=>0,j=>90,l=>-1,c=>-1,k=>6,h=>-4,b=>3,g=>6,f=>3,i=>2}
dfd10100a6005a3e04050000
dfd10100a6005a3e04050000
dfd10100a6005a3e04050000
ef8ac000d1005adc80050000
dfd10100a6005a3e04050000
dfd10100a6005a3e04050000
ef8ac000d1005adc80050000
dfd10100a6005a3e04050000
ef8ac000d1005adc80050000
-
{e=>-2,n=>218,a=>6,m=>2,d=>3,j=>122,l=>-3,c=>0,k=>7,h=>-3,b=>-2,g=>0,f=>1,i=>0}
36e6000028007a2f02da0000
36e6000028007a2f02da0000
36e6000028007a2f02da0000
d83c400014007af440da0000
36e6000028007a2f02da0000
36e6000028007a2f02da0000
d83c400014007af440da0000
36e6000028007a2f02da0000
d83c400014007af440da0000
-
{e=>-2,n=>245,a=>5,m=>7,d=>2,j=>-67,l=>-1,c=>3,k=>0,h=>3,b=>-2,g=>3,f=>5,i=>0}
f5e402001b00bd3807f50000
f5e402001b00bd3807f50000
f5e402001b00bd3807f50000
b9ad40006c00bd1ce0f50000
f5e402001b00bd3807f50000
f5e402001b00bd3807f50000
b9ad40006c00bd1ce0f50000
f5e402001b00bd3807f50000
b9ad40006c00bd1ce0f50000
-
{e=>3,n=>3,a=>5,m=>6,d=>6,j=>-78,l=>3,c=>-1,k=>5,h=>2,b=>2,g=>4,f=>7,i=>5}
d5bd03005401b21d06030000
d5bd03005401b21d06030000
d5bd03005401b21d06030000
abe7c0008a80b2acc0030000
d5bd03005401b21d06030000
d5bd03005401b21d06030000
abe7c0008a80b2acc0030000
d5bd03005401b21d06030000
abe7c0008a80b2acc0030000
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
};
-
{a=>13,b=>7}
0d070000
0d070000
0d070000
0de00000
0d070000
0d070000
0de00000
0d070000
0de00000
-
{a=>-33,b=>1}
df010000
df010000
df010000
df200000
df010000
df010000
df200000
df010000
df200000
-
{a=>-85,b=>1}
ab010000
ab010000
ab010000
ab200000
ab010000
ab010000
ab200000
ab010000
ab200000
-
{a=>58,b=>4}
3a040000
3a040000
3a040000
3a800000
3a040000
3a040000
3a800000
3a040000
3a800000
-
{a=>18,b=>6}
12060000
12060000
12060000
12c00000
12060000
12060000
12c00000
12060000
12c00000
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>-4,a=>8,b=>7}
08270000
08270000
08270000
08f00000
08270000
08270000
08f00000
08270000
08f00000
-
{c=>2,a=>-98,b=>6}
9e160000
9e160000
9e160000
9ec80000
9e160000
9e160000
9ec80000
9e160000
9ec80000
-
{c=>-4,a=>-119,b=>6}
89260000
89260000
89260000
89d00000
89260000
89260000
89d00000
89260000
89d00000
-
{c=>3,a=>-114,b=>0}
8e180000
8e180000
8e180000
8e0c0000
8e180000
8e180000
8e0c0000
8e180000
8e0c0000
-
{c=>-4,a=>104,b=>7}
68270000
68270000
68270000
68f00000
68270000
68270000
68f00000
68270000
68f00000
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>2,a=>90,b=>5,d=>-3}
5a550100
5a550100
5a550100
5aaa8000
5a550100
5a550100
5aaa8000
5a550100
5aaa8000
-
{c=>-3,a=>-24,b=>2,d=>-1}
e8ea0100
e8ea0100
e8ea0100
e8578000
e8ea0100
e8ea0100
e8578000
e8ea0100
e8578000
-
{c=>0,a=>-46,b=>4,d=>-4}
d2040100
d2040100
d2040100
d2820000
d2040100
d2040100
d2820000
d2040100
d2820000
-
{c=>1,a=>-95,b=>5,d=>-3}
a14d0100
a14d0100
a14d0100
a1a68000
a14d0100
a14d0100
a1a68000
a14d0100
a1a68000
-
{c=>3,a=>-50,b=>5,d=>-3}
ce5d0100
ce5d0100
ce5d0100
ceae8000
ce5d0100
ce5d0100
ceae8000
ce5d0100
ceae8000
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>2,c=>3,a=>-67,b=>0,d=>-1}
bdd80500
bdd80500
bdd80500
bd0fa000
bdd80500
bdd80500
bd0fa000
bdd80500
bd0fa000
-
{e=>6,c=>0,a=>-85,b=>0,d=>3}
abc00c00
abc00c00
abc00c00
ab01e000
abc00c00
abc00c00
ab01e000
abc00c00
ab01e000
-
{e=>1,c=>-4,a=>27,b=>3,d=>3}
1be30200
1be30200
1be30200
1b719000
1be30200
1be30200
1b719000
1be30200
1b719000
-
{e=>3,c=>1,a=>-53,b=>7,d=>3}
cbcf0600
cbcf0600
cbcf0600
cbe5b000
cbcf0600
cbcf0600
cbe5b000
cbcf0600
cbe5b000
-
{e=>4,c=>3,a=>-28,b=>2,d=>-4}
e41a0900
e41a0900
e41a0900
e44e4000
e41a0900
e41a0900
e44e4000
e41a0900
e44e4000
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
};
-
{e=>1,c=>-1,a=>54,b=>0,d=>-1,f=>-4}
36f84300
36f84300
36f84300
361f9800
36f84300
36f84300
361f9800
36f84300
361f9800
-
{e=>5,c=>-2,a=>43,b=>2,d=>-2,f=>-4}
2bb24b00
2bb24b00
2bb24b00
2b5b5800
2bb24b00
2bb24b00
2b5b5800
2bb24b00
2b5b5800
-
{e=>2,c=>-1,a=>57,b=>7,d=>0,f=>-3}
393f5400
393f5400
393f5400
39fc2a00
393f5400
393f5400
39fc2a00
393f5400
39fc2a00
-
{e=>2,c=>-4,a=>-86,b=>0,d=>-4,f=>2}
aa202500
aa202500
aa202500
aa122400
aa202500
aa202500
aa122400
aa202500
aa122400
-
{e=>5,c=>-4,a=>36,b=>6,d=>-2,f=>1}
24a61b00
24a61b00
24a61b00
24d35200
24a61b00
24a61b00
24d35200
24a61b00
24d35200
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
};
-
{e=>1,c=>-1,a=>-59,g=>1,b=>7,d=>-1,f=>1}
c5ff9300
c5ff9300
c5ff9300
c5ff9240
c5ff9300
c5ff9300
c5ff9240
c5ff9300
c5ff9240
-
{e=>0,c=>-3,a=>-42,g=>3,b=>3,d=>-1,f=>3}
d6ebb101
d6ebb101
d6ebb101
d67786c0
d6ebb101
d6ebb101
d67786c0
d6ebb101
d67786c0
-
{e=>1,c=>-3,a=>-91,g=>5,b=>1,d=>1,f=>2}
a569a202
a569a202
a569a202
a5349540
a569a202
a569a202
a5349540
a569a202
a5349540
-
{e=>3,c=>-2,a=>3,g=>0,b=>1,d=>0,f=>-1}
03317600
03317600
03317600
03383e00
03317600
03317600
03383e00
03317600
03383e00
-
{e=>1,c=>-2,a=>-94,g=>1,b=>0,d=>-1,f=>2}
a2f0a300
a2f0a300
a2f0a300
a21b9440
a2f0a300
a2f0a300
a21b9440
a2f0a300
a21b9440
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>3,c=>3,a=>-87,g=>4,b=>0,d=>2,f=>2}
a9982602
a9982602
a9982602
a90d3500
a9982602
a9982602
a90d3500
a9982602
a90d3500
-
{e=>3,c=>2,a=>-100,g=>0,b=>7,d=>-2,f=>-4}
9c974700
9c974700
9c974700
9ceb3800
9c974700
9c974700
9ceb3800
9c974700
9ceb3800
-
{e=>4,c=>3,a=>30,g=>4,b=>0,d=>3,f=>-3}
1ed85802
1ed85802
1ed85802
1e0dcb00
1ed85802
1ed85802
1e0dcb00
1ed85802
1e0dcb00
-
{e=>3,c=>3,a=>117,g=>7,b=>3,d=>-3,f=>1}
755b9703
755b9703
755b9703
756eb3c0
755b9703
755b9703
756eb3c0
755b9703
756eb3c0
-
{e=>4,c=>-2,a=>-117,g=>5,b=>2,d=>-1,f=>0}
8bf28902
8bf28902
8bf28902
8b5bc140
8bf28902
8bf28902
8b5bc140
8bf28902
8b5bc140
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>3,a=>5,d=>-4,c=>1,h=>7,b=>0,g=>0,f=>-1}
0508770007000000
0508770007000000
0508770007000000
05063e00e0000000
0508770007000000
0508770007000000
05063e00e0000000
0508770007000000
05063e00e0000000
-
{e=>5,a=>30,d=>-4,c=>3,h=>3,b=>7,g=>4,f=>-1}
1e1f7b0203000000
1e1f7b0203000000
1e1f7b0203000000
1eee5f0060000000
1e1f7b0203000000
1e1f7b0203000000
1eee5f0060000000
1e1f7b0203000000
1eee5f0060000000
-
{e=>7,a=>0,d=>-3,c=>1,h=>0,b=>7,g=>2,f=>-1}
004f7f0100000000
004f7f0100000000
004f7f0100000000
00e6fe8000000000
004f7f0100000000
004f7f0100000000
00e6fe8000000000
004f7f0100000000
00e6fe8000000000
-
{e=>0,a=>126,d=>-3,c=>0,h=>0,b=>2,g=>5,f=>-1}
7e42f10200000000
7e42f10200000000
7e42f10200000000
7e428f4000000000
7e42f10200000000
7e42f10200000000
7e428f4000000000
7e42f10200000000
7e428f4000000000
-
{e=>0,a=>4,d=>-1,c=>-3,h=>7,b=>2,g=>4,f=>3}
04ea310207000000
04ea310207000000
04ea310207000000
04578700e0000000
04ea310207000000
04ea310207000000
04578700e0000000
04ea310207000000
04578700e0000000
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>2,a=>55,d=>-4,c=>-4,h=>0,b=>6,g=>4,f=>2,i=>-3}
3726250228000000
3726250228000000
3726250228000000
37d2250014000000
3726250228000000
3726250228000000
37d2250014000000
3726250228000000
37d2250014000000
-
{e=>5,a=>43,d=>1,c=>1,h=>1,b=>3,g=>7,f=>-3,i=>1}
2b4bda0309000000
2b4bda0309000000
2b4bda0309000000
2b64dbc024000000
2b4bda0309000000
2b4bda0309000000
2b64dbc024000000
2b4bda0309000000
2b64dbc024000000
-
{e=>2,a=>-68,d=>-4,c=>-1,h=>6,b=>2,g=>5,f=>-3,i=>-3}
bc3ad5022e000000
bc3ad5022e000000
bc3ad5022e000000
bc5e2b40d4000000
bc3ad5022e000000
bc3ad5022e000000
bc5e2b40d4000000
bc3ad5022e000000
bc5e2b40d4000000
-
{e=>3,a=>-9,d=>2,c=>-4,h=>6,b=>3,g=>7,f=>-3,i=>1}
f7a3d6030e000000
f7a3d6030e000000
f7a3d6030e000000
f7713bc0c4000000
f7a3d6030e000000
f7a3d6030e000000
f7713bc0c4000000
f7a3d6030e000000
f7713bc0c4000000
-
{e=>6,a=>-80,d=>1,c=>-2,h=>3,b=>1,g=>5,f=>3,i=>-3}
b071bc022b000000
b071bc022b000000
b071bc022b000000
b038e74074000000
b071bc022b000000
b071bc022b000000
b038e74074000000
b071bc022b000000
b038e74074000000
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
};
-
{e=>5,a=>114,d=>-4,j=>4,c=>3,h=>6,b=>2,g=>0,f=>-4,i=>2}
721a4b0016010000
721a4b0016010000
721a4b0016010000
724e5800ca000000
721a4b0016010000
721a4b0016010000
724e5800ca000000
721a4b0016010000
724e5800ca000000
-
{e=>3,a=>-15,d=>-2,j=>6,c=>-1,h=>1,b=>0,g=>2,f=>2,i=>0}
f1b8270181010000
f1b8270181010000
f1b8270181010000
f11f348023000000
f1b8270181010000
f1b8270181010000
f11f348023000000
f1b8270181010000
f11f348023000000
-
{e=>6,a=>-68,d=>-2,j=>5,c=>-3,h=>1,b=>4,g=>0,f=>-1,i=>2}
bcac7d0051010000
bcac7d0051010000
bcac7d0051010000
bc976e002a800000
bcac7d0051010000
bcac7d0051010000
bc976e002a800000
bcac7d0051010000
bc976e002a800000
-
{e=>4,a=>-102,d=>0,j=>1,c=>1,h=>4,b=>1,g=>0,f=>1,i=>-3}
9a0918006c000000
9a0918006c000000
9a0918006c000000
9a24420094800000
9a0918006c000000
9a0918006c000000
9a24420094800000
9a0918006c000000
9a24420094800000
-
{e=>7,a=>-118,d=>-4,j=>3,c=>-2,h=>3,b=>3,g=>4,f=>1,i=>-1}
8a331f02fb000000
8a331f02fb000000
8a331f02fb000000
8a7a73007d800000
8a331f02fb000000
8a331f02fb000000
8a7a73007d800000
8a331f02fb000000
8a7a73007d800000
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
};
-
{e=>4,a=>36,d=>-2,j=>7,c=>1,k=>-85,h=>7,b=>5,g=>7,f=>-4,i=>-3}
248dc903ef01ab00
248dc903ef01ab00
248dc903ef01ab00
24a749c0f780ab00
248dc903ef01ab00
248dc903ef01ab00
24a749c0f780ab00
248dc903ef01ab00
24a749c0f780ab00
-
{e=>2,a=>57,d=>2,j=>6,c=>0,k=>-127,h=>0,b=>5,g=>5,f=>1,i=>-1}
39859402b8018100
39859402b8018100
39859402b8018100
39a123401f008100
39859402b8018100
39859402b8018100
39a123401f008100
39859402b8018100
39a123401f008100
-
{e=>7,a=>-85,d=>1,j=>0,c=>-2,k=>-9,h=>1,b=>1,g=>4,f=>0,i=>-2}
ab710e023100f700
ab710e023100f700
ab710e023100f700
ab38f1003800f700
ab710e023100f700
ab710e023100f700
ab38f1003800f700
ab710e023100f700
ab38f1003800f700
-
{e=>6,a=>12,d=>3,j=>2,c=>-1,k=>-109,h=>0,b=>1,g=>1,f=>3,i=>-2}
0cf9bc00b0009300
0cf9bc00b0009300
0cf9bc00b0009300
0c3de64019009300
0cf9bc00b0009300
0cf9bc00b0009300
0c3de64019009300
0cf9bc00b0009300
0c3de64019009300
-
{e=>3,a=>-93,d=>-3,j=>3,c=>0,k=>38,h=>2,b=>4,g=>2,f=>-3,i=>-3}
a3445701ea002600
a3445701ea002600
a3445701ea002600
a382ba8055802600
a3445701ea002600
a3445701ea002600
a382ba8055802600
a3445701ea002600
a382ba8055802600
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>1,a=>-121,d=>0,j=>7,l=>7,c=>-2,k=>104,h=>5,b=>5,g=>2,f=>-1,i=>-1}
87357201fd016807
87357201fd016807
87357201fd016807
87b81e80bf8068e0
87357201fd016807
87357201fd016807
87b81e80bf8068e0
87357201fd016807
87b81e80bf8068e0
-
{e=>4,a=>-69,d=>0,j=>7,l=>3,c=>3,k=>116,h=>2,b=>5,g=>0,f=>2,i=>3}
bb1d2800da017403
bb1d2800da017403
bb1d2800da017403
bbac44004f807460
bb1d2800da017403
bb1d2800da017403
bbac44004f807460
bb1d2800da017403
bbac44004f807460
-
{e=>7,a=>-88,d=>3,j=>2,l=>6,c=>-2,k=>94,h=>0,b=>1,g=>0,f=>-2,i=>2}
a8f16e0090005e06
a8f16e0090005e06
a8f16e0090005e06
a839fc0009005ec0
a8f16e0090005e06
a8f16e0090005e06
a839fc0009005ec0
a8f16e0090005e06
a839fc0009005ec0
-
{e=>7,a=>41,d=>1,j=>2,l=>2,c=>-2,k=>-6,h=>1,b=>4,g=>1,f=>-3,i=>2}
2974de009100fa02
2974de009100fa02
2974de009100fa02
2998fa402900fa40
2974de009100fa02
2974de009100fa02
2998fa402900fa40
2974de009100fa02
2998fa402900fa40
-
{e=>1,a=>-123,d=>-2,j=>3,l=>7,c=>3,k=>82,h=>1,b=>6,g=>6,f=>0,i=>-3}
859e0303e9005207
859e0303e9005207
859e0303e9005207
85cf1180358052e0
859e0303e9005207
859e0303e9005207
85cf1180358052e0
859e0303e9005207
85cf1180358052e0
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>4,a=>-121,m=>2,d=>-2,j=>6,l=>3,c=>0,k=>-106,h=>5,b=>7,g=>4,f=>3,i=>2}
8787390295019613
8787390295019613
8787390295019613
87e34700ab009668
8787390295019613
8787390295019613
87e34700ab009668
8787390295019613
87e34700ab009668
-
{e=>7,a=>-56,m=>1,d=>-1,j=>2,l=>7,c=>3,k=>102,h=>6,b=>0,g=>6,f=>-4,i=>-3}
c8d84f03ae00660f
c8d84f03ae00660f
c8d84f03ae00660f
c80ff980d50066e4
c8d84f03ae00660f
c8d84f03ae00660f
c80ff980d50066e4
c8d84f03ae00660f
c80ff980d50066e4
-
{e=>3,a=>-72,m=>-4,d=>-1,j=>6,l=>2,c=>-1,k=>-50,h=>4,b=>2,g=>1,f=>1,i=>-3}
b8fa9700ac01ce22
b8fa9700ac01ce22
b8fa9700ac01ce22
b85fb2409700ce50
b8fa9700ac01ce22
b8fa9700ac01ce22
b85fb2409700ce50
b8fa9700ac01ce22
b85fb2409700ce50
-
{e=>5,a=>84,m=>-4,d=>-2,j=>4,l=>0,c=>1,k=>-79,h=>5,b=>6,g=>1,f=>3,i=>1}
548ebb000d01b120
548ebb000d01b120
548ebb000d01b120
54c75640a600b110
548ebb000d01b120
548ebb000d01b120
54c75640a600b110
548ebb000d01b120
54c75640a600b110
-
{e=>6,a=>-18,m=>-2,d=>-4,j=>7,l=>4,c=>-1,k=>-2,h=>1,b=>1,g=>4,f=>3,i=>-3}
ee393d02e901fe34
ee393d02e901fe34
ee393d02e901fe34
ee3e67003780fe98
ee393d02e901fe34
ee393d02e901fe34
ee3e67003780fe98
ee393d02e901fe34
ee3e67003780fe98
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>5,n=>6,a=>-112,m=>3,d=>-1,j=>2,l=>0,c=>-3,k=>39,h=>4,b=>6,g=>4,f=>3,i=>2}
90ee3b029400271806000000
90ee3b029400271806000000
90ee3b029400271806000000
90d7d7008900270cc0000000
90ee3b029400271806000000
90ee3b029400271806000000
90d7d7008900270cc0000000
90ee3b029400271806000000
90d7d7008900270cc0000000
-
{e=>1,n=>2,a=>93,m=>-2,d=>2,j=>5,l=>5,c=>2,k=>-95,h=>1,b=>6,g=>0,f=>-1,i=>-3}
5d9672006901a13502000000
5d9672006901a13502000000
5d9672006901a13502000000
5dc91e003680a1b840000000
5d9672006901a13502000000
5d9672006901a13502000000
5dc91e003680a1b840000000
5d9672006901a13502000000
5dc91e003680a1b840000000
-
{e=>2,n=>1,a=>55,m=>2,d=>-2,j=>0,l=>0,c=>-2,k=>-97,h=>1,b=>7,g=>1,f=>3,i=>3}
37b7b50019009f1001000000
37b7b50019009f1001000000
37b7b50019009f1001000000
37fb26402c009f0820000000
37b7b50019009f1001000000
37b7b50019009f1001000000
37fb26402c009f0820000000
37b7b50019009f1001000000
37fb26402c009f0820000000
-
{e=>6,n=>2,a=>2,m=>2,d=>0,j=>7,l=>5,c=>-1,k=>-32,h=>7,b=>0,g=>5,f=>-2,i=>2}
0238ec02d701e01502000000
0238ec02d701e01502000000
0238ec02d701e01502000000
021c6d40eb80e0a840000000
0238ec02d701e01502000000
0238ec02d701e01502000000
021c6d40eb80e0a840000000
0238ec02d701e01502000000
021c6d40eb80e0a840000000
-
{e=>1,n=>2,a=>-65,m=>0,d=>-3,j=>5,l=>6,c=>-1,k=>10,h=>2,b=>2,g=>3,f=>-4,i=>2}
bf7ac30152010a0602000000
bf7ac30152010a0602000000
bf7ac30152010a0602000000
bf5e98c04a800ac040000000
bf7ac30152010a0602000000
bf7ac30152010a0602000000
bf5e98c04a800ac040000000
bf7ac30152010a0602000000
bf5e98c04a800ac040000000
=
typedef int foo;

struct mixed_no_pack {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>4,n=>4,a=>96,m=>-1,d=>-4,j=>2,l=>1,c=>-2,k=>-106,h=>1,b=>4,g=>2,f=>-2,o=>172,i=>3}
603469019900963904ac0000
603469019900963904ac0000
603469019900963904ac0000
609a4c802d00963c80ac0000
603469019900963904ac0000
603469019900963904ac0000
609a4c802d00963c80ac0000
603469019900963904ac0000
609a4c802d00963c80ac0000
-
{e=>3,n=>3,a=>-103,m=>-2,d=>-1,j=>6,l=>2,c=>-3,k=>-23,h=>7,b=>7,g=>4,f=>-3,o=>204,i=>0}
99ef57028701e93203cc0000
99ef57028701e93203cc0000
99ef57028701e93203cc0000
99f7bb00e300e95860cc0000
99ef57028701e93203cc0000
99ef57028701e93203cc0000
99f7bb00e300e95860cc0000
99ef57028701e93203cc0000
99f7bb00e300e95860cc0000
-
{e=>7,n=>2,a=>-104,m=>3,d=>2,j=>7,l=>5,c=>2,k=>49,h=>2,b=>0,g=>0,f=>3,o=>143,i=>0}
98903e00c201311d028f0000
98903e00c201311d028f0000
98903e00c201311d028f0000
98097600438031ac408f0000
98903e00c201311d028f0000
98903e00c201311d028f0000
98097600438031ac408f0000
98903e00c201311d028f0000
98097600438031ac408f0000
-
{e=>7,n=>0,a=>-12,m=>1,d=>2,j=>3,l=>2,c=>3,k=>73,h=>6,b=>0,g=>3,f=>-2,o=>165,i=>-3}
f498ee01ee00490a00a50000
f498ee01ee00490a00a50000
f498ee01ee00490a00a50000
f40d7cc0d580494400a50000
f498ee01ee00490a00a50000
f498ee01ee00490a00a50000
f40d7cc0d580494400a50000
f498ee01ee00490a00a50000
f40d7cc0d580494400a50000
-
{e=>2,n=>6,a=>-124,m=>-3,d=>-3,j=>1,l=>3,c=>-4,k=>109,h=>1,b=>5,g=>0,f=>-2,o=>55,i=>-3}
8465650069006d2b06370000
8465650069006d2b06370000
8465650069006d2b06370000
84b2ac0034806d74c0370000
8465650069006d2b06370000
8465650069006d2b06370000
84b2ac0034806d74c0370000
8465650069006d2b06370000
84b2ac0034806d74c0370000
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
};
-
{a=>92,b=>1}
5c000100
5c000100
5c000100
005c2000
5c000100
5c000100
005c2000
5c000100
005c2000
-
{a=>51,b=>4}
33000400
33000400
33000400
00338000
33000400
33000400
00338000
33000400
00338000
-
{a=>-66,b=>3}
beff0300
beff0300
beff0300
ffbe6000
beff0300
beff0300
ffbe6000
beff0300
ffbe6000
-
{a=>-113,b=>2}
8fff0200
8fff0200
8fff0200
ff8f4000
8fff0200
8fff0200
ff8f4000
8fff0200
ff8f4000
-
{a=>10,b=>0}
0a000000
0a000000
0a000000
000a0000
0a000000
0a000000
000a0000
0a000000
000a0000
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>0,a=>-103,b=>5}
99ff0500
99ff0500
99ff0500
ff99a000
99ff0500
99ff0500
ff99a000
99ff0500
ff99a000
-
{c=>0,a=>-75,b=>2}
b5ff0200
b5ff0200
b5ff0200
ffb54000
b5ff0200
b5ff0200
ffb54000
b5ff0200
ffb54000
-
{c=>-4,a=>-81,b=>3}
afff2300
afff2300
afff2300
ffaf7000
afff2300
afff2300
ffaf7000
afff2300
ffaf7000
-
{c=>-2,a=>14,b=>7}
0e003700
0e003700
0e003700
000ef800
0e003700
0e003700
000ef800
0e003700
000ef800
-
{c=>0,a=>94,b=>1}
5e000100
5e000100
5e000100
005e2000
5e000100
5e000100
005e2000
5e000100
005e2000
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>-1,a=>-100,b=>5,d=>1}
9cff7d00
9cff7d00
9cff7d00
ff9cbc80
9cff7d00
9cff7d00
ff9cbc80
9cff7d00
ff9cbc80
-
{c=>3,a=>107,b=>2,d=>-4}
6b001a01
6b001a01
6b001a01
006b4e00
6b001a01
6b001a01
006b4e00
6b001a01
006b4e00
-
{c=>1,a=>-24,b=>1,d=>1}
e8ff4900
e8ff4900
e8ff4900
ffe82480
e8ff4900
e8ff4900
ffe82480
e8ff4900
ffe82480
-
{c=>-2,a=>-62,b=>0,d=>2}
c2ffb000
c2ffb000
c2ffb000
ffc21900
c2ffb000
c2ffb000
ffc21900
c2ffb000
ffc21900
-
{c=>0,a=>-40,b=>6,d=>-1}
d8ffc601
d8ffc601
d8ffc601
ffd8c380
d8ffc601
d8ffc601
ffd8c380
d8ffc601
ffd8c380
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>4,c=>-4,a=>-8,b=>5,d=>3}
f8ffe508
f8ffe508
f8ffe508
fff8b1c0
f8ffe508
f8ffe508
fff8b1c0
f8ffe508
fff8b1c0
-
{e=>4,c=>-3,a=>-46,b=>4,d=>2}
d2ffac08
d2ffac08
d2ffac08
ffd29540
d2ffac08
d2ffac08
ffd29540
d2ffac08
ffd29540
-
{e=>2,c=>0,a=>-15,b=>0,d=>-2}
f1ff8005
f1ff8005
f1ff8005
fff10320
f1ff8005
f1ff8005
fff10320
f1ff8005
fff10320
-
{e=>6,c=>3,a=>97,b=>1,d=>-1}
6100d90d
6100d90d
6100d90d
00612fe0
6100d90d
6100d90d
00612fe0
6100d90d
00612fe0
-
{e=>5,c=>1,a=>86,b=>2,d=>-1}
5600ca0b
5600ca0b
5600ca0b
005647d0
5600ca0b
5600ca0b
005647d0
5600ca0b
005647d0
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
};
-
{e=>2,c=>-4,a=>-30,b=>0,d=>2,f=>-4}
e2ffa044
e2ffa044
e2ffa044
ffe21128
e2ffa044
e2ffa044
ffe21128
e2ffa044
ffe21128
-
{e=>3,c=>-2,a=>58,b=>7,d=>3,f=>-2}
3a00f766
3a00f766
3a00f766
003af9bc
3a00f766
3a00f766
003af9bc
3a00f766
003af9bc
-
{e=>3,c=>2,a=>-93,b=>0,d=>1,f=>2}
a3ff5026
a3ff5026
a3ff5026
ffa308b4
a3ff5026
a3ff5026
ffa308b4
a3ff5026
ffa308b4
-
{e=>2,c=>3,a=>17,b=>1,d=>-3,f=>2}
11005925
11005925
11005925
00112ea4
11005925
11005925
00112ea4
11005925
00112ea4
-
{e=>3,c=>2,a=>-36,b=>3,d=>-1,f=>1}
dcffd317
dcffd317
dcffd317
ffdc6bb2
dcffd317
dcffd317
ffdc6bb2
dcffd317
ffdc6bb2
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
};
-
{e=>6,c=>3,a=>-5,g=>1,b=>4,d=>-4,f=>-4}
fbff1c4d01000000
fbff1c4d01000000
fbff1c4d01000000
fffb8e6820000000
fbff1c4d01000000
fbff1c4d01000000
fffb8e6820000000
fbff1c4d01000000
fffb8e6820000000
-
{e=>1,c=>0,a=>5,g=>5,b=>6,d=>-1,f=>-3}
0500c65305000000
0500c65305000000
0500c65305000000
0005c39aa0000000
0500c65305000000
0500c65305000000
0005c39aa0000000
0500c65305000000
0005c39aa0000000
-
{e=>5,c=>-3,a=>94,g=>6,b=>0,d=>-1,f=>2}
5e00e82b06000000
5e00e82b06000000
5e00e82b06000000
005e17d4c0000000
5e00e82b06000000
5e00e82b06000000
005e17d4c0000000
5e00e82b06000000
005e17d4c0000000
-
{e=>5,c=>-3,a=>-86,g=>4,b=>3,d=>2,f=>2}
aaffab2a04000000
aaffab2a04000000
aaffab2a04000000
ffaa755480000000
aaffab2a04000000
aaffab2a04000000
ffaa755480000000
aaffab2a04000000
ffaa755480000000
-
{e=>6,c=>0,a=>-114,g=>6,b=>6,d=>-3,f=>-4}
8eff464d06000000
8eff464d06000000
8eff464d06000000
ff8ec2e8c0000000
8eff464d06000000
8eff464d06000000
ff8ec2e8c0000000
8eff464d06000000
ff8ec2e8c0000000
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>7,c=>-1,a=>-26,g=>4,b=>2,d=>-1,f=>-2}
e6fffa6f04000000
e6fffa6f04000000
e6fffa6f04000000
ffe65ffc80000000
e6fffa6f04000000
e6fffa6f04000000
ffe65ffc80000000
e6fffa6f04000000
ffe65ffc80000000
-
{e=>3,c=>-3,a=>-39,g=>5,b=>5,d=>2,f=>3}
d9ffad3605000000
d9ffad3605000000
d9ffad3605000000
ffd9b536a0000000
d9ffad3605000000
d9ffad3605000000
ffd9b536a0000000
d9ffad3605000000
ffd9b536a0000000
-
{e=>2,c=>-1,a=>-108,g=>4,b=>7,d=>1,f=>0}
94ff7f0404000000
94ff7f0404000000
94ff7f0404000000
ff94fca080000000
94ff7f0404000000
94ff7f0404000000
ff94fca080000000
94ff7f0404000000
ff94fca080000000
-
{e=>1,c=>3,a=>36,g=>7,b=>4,d=>1,f=>-4}
24005c4207000000
24005c4207000000
24005c4207000000
00248c98e0000000
24005c4207000000
24005c4207000000
00248c98e0000000
24005c4207000000
00248c98e0000000
-
{e=>0,c=>1,a=>-70,g=>2,b=>0,d=>-3,f=>0}
baff480102000000
baff480102000000
baff480102000000
ffba068040000000
baff480102000000
baff480102000000
ffba068040000000
baff480102000000
ffba068040000000
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>1,a=>-73,d=>3,c=>-4,h=>3,b=>3,g=>5,f=>-2}
b7ffe3620500000003000000
b7ffe3620500000003000000
b7ffe3620500000003000000
ffb7719ca000000060000000
b7ffe3620500000003000000
b7ffe3620500000003000000
ffb7719ca000000060000000
b7ffe3620500000003000000
ffb7719ca000000060000000
-
{e=>2,a=>106,d=>3,c=>-1,h=>4,b=>0,g=>6,f=>-2}
6a00f8640600000004000000
6a00f8640600000004000000
6a00f8640600000004000000
006a1dacc000000080000000
6a00f8640600000004000000
6a00f8640600000004000000
006a1dacc000000080000000
6a00f8640600000004000000
006a1dacc000000080000000
-
{e=>2,a=>-78,d=>3,c=>3,h=>6,b=>0,g=>0,f=>-1}
b2ffd8740000000006000000
b2ffd8740000000006000000
b2ffd8740000000006000000
ffb20dae00000000c0000000
b2ffd8740000000006000000
b2ffd8740000000006000000
ffb20dae00000000c0000000
b2ffd8740000000006000000
ffb20dae00000000c0000000
-
{e=>4,a=>-84,d=>-2,c=>3,h=>4,b=>3,g=>5,f=>-3}
acff9b590500000004000000
acff9b590500000004000000
acff9b590500000004000000
ffac6f4aa000000080000000
acff9b590500000004000000
acff9b590500000004000000
ffac6f4aa000000080000000
acff9b590500000004000000
ffac6f4aa000000080000000
-
{e=>7,a=>-108,d=>1,c=>-4,h=>2,b=>4,g=>5,f=>-4}
94ff644e0500000002000000
94ff644e0500000002000000
94ff644e0500000002000000
ff9490f8a000000040000000
94ff644e0500000002000000
94ff644e0500000002000000
ff9490f8a000000040000000
94ff644e0500000002000000
ff9490f8a000000040000000
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>4,a=>113,d=>3,c=>2,h=>4,b=>1,g=>6,f=>2,i=>3}
7100d128060000001c000000
7100d128060000001c000000
7100d128060000001c000000
007129c4c00000008c000000
7100d128060000001c000000
7100d128060000001c000000
007129c4c00000008c000000
7100d128060000001c000000
007129c4c00000008c000000
-
{e=>7,a=>83,d=>-1,c=>3,h=>0,b=>0,g=>4,f=>-3,i=>-2}
5300d85f0400000030000000
5300d85f0400000030000000
5300d85f0400000030000000
00530ffa8000000018000000
5300d85f0400000030000000
5300d85f0400000030000000
00530ffa8000000018000000
5300d85f0400000030000000
00530ffa8000000018000000
-
{e=>2,a=>-34,d=>3,c=>-4,h=>4,b=>4,g=>0,f=>1,i=>-3}
deffe414000000002c000000
deffe414000000002c000000
deffe414000000002c000000
ffde91a20000000094000000
deffe414000000002c000000
deffe414000000002c000000
ffde91a20000000094000000
deffe414000000002c000000
ffde91a20000000094000000
-
{e=>1,a=>87,d=>1,c=>0,h=>1,b=>7,g=>0,f=>1,i=>-1}
570047120000000039000000
570047120000000039000000
570047120000000039000000
0057e092000000003c000000
570047120000000039000000
570047120000000039000000
0057e092000000003c000000
570047120000000039000000
0057e092000000003c000000
-
{e=>1,a=>-63,d=>3,c=>-1,h=>2,b=>1,g=>6,f=>1,i=>-3}
c1fff912060000002a000000
c1fff912060000002a000000
c1fff912060000002a000000
ffc13d92c000000054000000
c1fff912060000002a000000
c1fff912060000002a000000
ffc13d92c000000054000000
c1fff912060000002a000000
ffc13d92c000000054000000
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
};
-
{e=>0,a=>-8,d=>3,j=>1,c=>-3,h=>0,b=>1,g=>7,f=>3,i=>2}
f8ffe9300700000050000000
f8ffe9300700000050000000
f8ffe9300700000050000000
fff83586e000000008800000
f8ffe9300700000050000000
f8ffe9300700000050000000
fff83586e000000008800000
f8ffe9300700000050000000
fff83586e000000008800000
-
{e=>1,a=>-18,d=>-3,j=>7,c=>-4,h=>4,b=>2,g=>0,f=>3,i=>-2}
eeff623300000000f4010000
eeff623300000000f4010000
eeff623300000000f4010000
ffee5296000000009b800000
eeff623300000000f4010000
eeff623300000000f4010000
ffee5296000000009b800000
eeff623300000000f4010000
ffee5296000000009b800000
-
{e=>7,a=>-19,d=>0,j=>4,c=>2,h=>1,b=>3,g=>3,f=>-4,i=>3}
edff134e0300000019010000
edff134e0300000019010000
edff134e0300000019010000
ffed6878600000002e000000
edff134e0300000019010000
edff134e0300000019010000
ffed6878600000002e000000
edff134e0300000019010000
ffed6878600000002e000000
-
{e=>4,a=>43,d=>-3,j=>6,c=>-4,h=>4,b=>0,g=>5,f=>3,i=>-3}
2b00603905000000ac010000
2b00603905000000ac010000
2b00603905000000ac010000
002b12c6a000000097000000
2b00603905000000ac010000
2b00603905000000ac010000
002b12c6a000000097000000
2b00603905000000ac010000
002b12c6a000000097000000
-
{e=>3,a=>-3,d=>0,j=>5,c=>1,h=>7,b=>6,g=>0,f=>2,i=>1}
fdff0e26000000004f010000
fdff0e26000000004f010000
fdff0e26000000004f010000
fffdc43400000000e6800000
fdff0e26000000004f010000
fdff0e26000000004f010000
fffdc43400000000e6800000
fdff0e26000000004f010000
fffdc43400000000e6800000
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
};
-
{e=>1,a=>29,d=>-1,j=>7,c=>-3,k=>-108,h=>1,b=>7,g=>6,f=>2,i=>-1}
1d00ef2306000000f9019400
1d00ef2306000000f9019400
1d00ef2306000000f9019400
001df794c00000003f809400
1d00ef2306000000f9019400
1d00ef2306000000f9019400
001df794c00000003f809400
1d00ef2306000000f9019400
001df794c00000003f809400
-
{e=>3,a=>48,d=>1,j=>5,c=>1,k=>-74,h=>0,b=>5,g=>7,f=>-2,i=>-2}
30004d66070000007001b600
30004d66070000007001b600
30004d66070000007001b600
0030a4bce00000001a80b600
30004d66070000007001b600
30004d66070000007001b600
0030a4bce00000001a80b600
30004d66070000007001b600
0030a4bce00000001a80b600
-
{e=>7,a=>-122,d=>2,j=>0,c=>-3,k=>14,h=>2,b=>1,g=>4,f=>-4,i=>0}
86ffa94e0400000002000e00
86ffa94e0400000002000e00
86ffa94e0400000002000e00
ff8635788000000040000e00
86ffa94e0400000002000e00
86ffa94e0400000002000e00
ff8635788000000040000e00
86ffa94e0400000002000e00
ff8635788000000040000e00
-
{e=>5,a=>-32,d=>-4,j=>2,c=>3,k=>-91,h=>7,b=>0,g=>3,f=>0,i=>2}
e0ff180b030000009700a500
e0ff180b030000009700a500
e0ff180b030000009700a500
ffe00e5060000000e900a500
e0ff180b030000009700a500
e0ff180b030000009700a500
ffe00e5060000000e900a500
e0ff180b030000009700a500
ffe00e5060000000e900a500
-
{e=>4,a=>-6,d=>2,j=>0,c=>-4,k=>-31,h=>6,b=>7,g=>4,f=>1,i=>0}
faffa718040000000600e100
faffa718040000000600e100
faffa718040000000600e100
fffaf14280000000c000e100
faffa718040000000600e100
faffa718040000000600e100
fffaf14280000000c000e100
faffa718040000000600e100
fffaf14280000000c000e100
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>1,a=>100,d=>-3,j=>2,l=>1,c=>-3,k=>17,h=>3,b=>6,g=>3,f=>3,i=>3}
64006e33030000009b001101
64006e33030000009b001101
64006e33030000009b001101
0064d696600000006d001120
64006e33030000009b001101
64006e33030000009b001101
0064d696600000006d001120
64006e33030000009b001101
0064d696600000006d001120
-
{e=>3,a=>46,d=>-4,j=>5,l=>3,c=>1,k=>-95,h=>7,b=>4,g=>7,f=>0,i=>1}
2e000c07070000004f01a103
2e000c07070000004f01a103
2e000c07070000004f01a103
002e8630e0000000e680a160
2e000c07070000004f01a103
2e000c07070000004f01a103
002e8630e0000000e680a160
2e000c07070000004f01a103
002e8630e0000000e680a160
-
{e=>3,a=>-72,d=>0,j=>6,l=>7,c=>-2,k=>41,h=>2,b=>2,g=>2,f=>2,i=>-3}
b8ff322602000000aa012907
b8ff322602000000aa012907
b8ff322602000000aa012907
ffb8583440000000570029e0
b8ff322602000000aa012907
b8ff322602000000aa012907
ffb8583440000000570029e0
b8ff322602000000aa012907
ffb8583440000000570029e0
-
{e=>5,a=>84,d=>-1,j=>6,l=>5,c=>2,k=>95,h=>3,b=>4,g=>4,f=>2,i=>-4}
5400d42b04000000a3015f05
5400d42b04000000a3015f05
5400d42b04000000a3015f05
00548bd48000000073005fa0
5400d42b04000000a3015f05
5400d42b04000000a3015f05
00548bd48000000073005fa0
5400d42b04000000a3015f05
00548bd48000000073005fa0
-
{e=>1,a=>13,d=>-2,j=>3,l=>0,c=>-3,k=>-14,h=>2,b=>5,g=>0,f=>1,i=>-4}
0d00ad1300000000e200f200
0d00ad1300000000e200f200
0d00ad1300000000e200f200
000db712000000005180f200
0d00ad1300000000e200f200
0d00ad1300000000e200f200
000db712000000005180f200
0d00ad1300000000e200f200
000db712000000005180f200
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>7,a=>-88,m=>2,d=>0,j=>2,l=>5,c=>0,k=>96,h=>5,b=>0,g=>7,f=>2,i=>3}
a8ff002e070000009d006015
a8ff002e070000009d006015
a8ff002e070000009d006015
ffa80074e0000000ad0060a8
a8ff002e070000009d006015
a8ff002e070000009d006015
ffa80074e0000000ad0060a8
a8ff002e070000009d006015
ffa80074e0000000ad0060a8
-
{e=>2,a=>-64,m=>1,d=>-2,j=>2,l=>0,c=>0,k=>83,h=>6,b=>7,g=>5,f=>-3,i=>1}
c0ff8755050000008e005308
c0ff8755050000008e005308
c0ff8755050000008e005308
ffc0e32aa0000000c5005304
c0ff8755050000008e005308
c0ff8755050000008e005308
ffc0e32aa0000000c5005304
c0ff8755050000008e005308
ffc0e32aa0000000c5005304
-
{e=>1,a=>50,m=>3,d=>0,j=>6,l=>6,c=>-4,k=>20,h=>4,b=>1,g=>7,f=>0,i=>-2}
3200210207000000b401141e
3200210207000000b401141e
3200210207000000b401141e
00323010e00000009b0014cc
3200210207000000b401141e
3200210207000000b401141e
00323010e00000009b0014cc
3200210207000000b401141e
00323010e00000009b0014cc
-
{e=>3,a=>-2,m=>1,d=>-1,j=>4,l=>0,c=>-1,k=>106,h=>4,b=>2,g=>6,f=>-3,i=>0}
fefffa570600000004016a08
fefffa570600000004016a08
fefffa570600000004016a08
fffe5fbac000000082006a04
fefffa570600000004016a08
fefffa570600000004016a08
fffe5fbac000000082006a04
fefffa570600000004016a08
fffe5fbac000000082006a04
-
{e=>3,a=>126,m=>2,d=>-4,j=>7,l=>2,c=>-4,k=>-75,h=>0,b=>2,g=>7,f=>-3,i=>-2}
7e00225707000000f001b512
7e00225707000000f001b512
7e00225707000000f001b512
007e523ae00000001b80b548
7e00225707000000f001b512
7e00225707000000f001b512
007e523ae00000001b80b548
7e00225707000000f001b512
007e523ae00000001b80b548
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>0,n=>3,a=>114,m=>2,d=>1,j=>4,l=>2,c=>0,k=>-114,h=>1,b=>5,g=>1,f=>1,i=>2}
720045100100000011018e1203000000
720045100100000011018e1203000000
720045100100000011018e1203000000
0072a082200000002a008e4860000000
720045100100000011018e1203000000
720045100100000011018e1203000000
0072a082200000002a008e4860000000
720045100100000011018e1203000000
0072a082200000002a008e4860000000
-
{e=>0,n=>2,a=>11,m=>1,d=>-2,j=>4,l=>7,c=>-4,k=>-117,h=>6,b=>1,g=>5,f=>1,i=>3}
0b00a111050000001e018b0f02000000
0b00a111050000001e018b0f02000000
0b00a111050000001e018b0f02000000
000b3302a0000000ce008be440000000
0b00a111050000001e018b0f02000000
0b00a111050000001e018b0f02000000
000b3302a0000000ce008be440000000
0b00a111050000001e018b0f02000000
000b3302a0000000ce008be440000000
-
{e=>5,n=>4,a=>8,m=>0,d=>2,j=>7,l=>3,c=>3,k=>71,h=>7,b=>2,g=>4,f=>-4,i=>2}
08009a4a04000000d701470304000000
08009a4a04000000d701470304000000
08009a4a04000000d701470304000000
00084d5880000000eb80476080000000
08009a4a04000000d701470304000000
08009a4a04000000d701470304000000
00084d5880000000eb80476080000000
08009a4a04000000d701470304000000
00084d5880000000eb80476080000000
-
{e=>4,n=>5,a=>25,m=>1,d=>2,j=>3,l=>7,c=>-1,k=>-69,h=>4,b=>5,g=>6,f=>1,i=>-1}
1900bd1806000000fc00bb0f05000000
1900bd1806000000fc00bb0f05000000
1900bd1806000000fc00bb0f05000000
0019bd42c00000009d80bbe4a0000000
1900bd1806000000fc00bb0f05000000
1900bd1806000000fc00bb0f05000000
0019bd42c00000009d80bbe4a0000000
1900bd1806000000fc00bb0f05000000
0019bd42c00000009d80bbe4a0000000
-
{e=>1,n=>3,a=>71,m=>3,d=>-1,j=>0,l=>0,c=>-2,k=>28,h=>1,b=>7,g=>3,f=>0,i=>1}
4700f7030300000009001c1803000000
4700f7030300000009001c1803000000
4700f7030300000009001c1803000000
0047fb906000000024001c0c60000000
4700f7030300000009001c1803000000
4700f7030300000009001c1803000000
0047fb906000000024001c0c60000000
4700f7030300000009001c1803000000
0047fb906000000024001c0c60000000
=
typedef int foo;

struct mixed_no_pack {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>2,n=>2,a=>-53,m=>-1,d=>2,j=>2,l=>6,c=>-3,k=>-55,h=>7,b=>3,g=>6,f=>3,o=>97,i=>-4}
cbffab3406000000a700c93e02610000
cbffab3406000000a700c93e02610000
cbffab3406000000a700c93e02610000
ffcb7526c0000000f100c9dc40610000
cbffab3406000000a700c93e02610000
cbffab3406000000a700c93e02610000
ffcb7526c0000000f100c9dc40610000
cbffab3406000000a700c93e02610000
ffcb7526c0000000f100c9dc40610000
-
{e=>0,n=>6,a=>-59,m=>1,d=>0,j=>6,l=>4,c=>0,k=>75,h=>2,b=>6,g=>7,f=>3,o=>144,i=>2}
c5ff06300700000092014b0c06900000
c5ff06300700000092014b0c06900000
c5ff06300700000092014b0c06900000
ffc5c006e00000004b004b84c0900000
c5ff06300700000092014b0c06900000
c5ff06300700000092014b0c06900000
ffc5c006e00000004b004b84c0900000
c5ff06300700000092014b0c06900000
ffc5c006e00000004b004b84c0900000
-
{e=>1,n=>1,a=>66,m=>2,d=>-3,j=>0,l=>3,c=>1,k=>103,h=>4,b=>3,g=>7,f=>-1,o=>216,i=>-2}
42004b73070000003400671301d80000
42004b73070000003400671301d80000
42004b73070000003400671301d80000
0042669ee00000009800676820d80000
42004b73070000003400671301d80000
42004b73070000003400671301d80000
0042669ee00000009800676820d80000
42004b73070000003400671301d80000
0042669ee00000009800676820d80000
-
{e=>2,n=>1,a=>-81,m=>-1,d=>3,j=>0,l=>3,c=>-2,k=>98,h=>2,b=>1,g=>3,f=>-2,o=>209,i=>-3}
affff164030000002a00623b01d10000
affff164030000002a00623b01d10000
affff164030000002a00623b01d10000
ffaf39ac600000005400627c20d10000
affff164030000002a00623b01d10000
affff164030000002a00623b01d10000
ffaf39ac600000005400627c20d10000
affff164030000002a00623b01d10000
ffaf39ac600000005400627c20d10000
-
{e=>1,n=>5,a=>-91,m=>-1,d=>-1,j=>3,l=>5,c=>-1,k=>-46,h=>2,b=>4,g=>6,f=>-2,o=>161,i=>-3}
a5fffc6306000000ea00d23d05a10000
a5fffc6306000000ea00d23d05a10000
a5fffc6306000000ea00d23d05a10000
ffa59f9cc00000005580d2bca0a10000
a5fffc6306000000ea00d23d05a10000
a5fffc6306000000ea00d23d05a10000
ffa59f9cc00000005580d2bca0a10000
a5fffc6306000000ea00d23d05a10000
ffa59f9cc00000005580d2bca0a10000
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
};
-
{a=>55,b=>2}
3700000002000000
3700000002000000
3700000002000000
0000003740000000
3700000002000000
3700000002000000
0000003740000000
3700000002000000
0000003740000000
-
{a=>62,b=>5}
3e00000005000000
3e00000005000000
3e00000005000000
0000003ea0000000
3e00000005000000
3e00000005000000
0000003ea0000000
3e00000005000000
0000003ea0000000
-
{a=>127,b=>2}
7f00000002000000
7f00000002000000
7f00000002000000
0000007f40000000
7f00000002000000
7f00000002000000
0000007f40000000
7f00000002000000
0000007f40000000
-
{a=>-95,b=>4}
a1ffffff04000000
a1ffffff04000000
a1ffffff04000000
ffffffa180000000
a1ffffff04000000
a1ffffff04000000
ffffffa180000000
a1ffffff04000000
ffffffa180000000
-
{a=>-58,b=>4}
c6ffffff04000000
c6ffffff04000000
c6ffffff04000000
ffffffc680000000
c6ffffff04000000
c6ffffff04000000
ffffffc680000000
c6ffffff04000000
ffffffc680000000
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>1,a=>-70,b=>7}
baffffff0f000000
baffffff0f000000
baffffff0f000000
ffffffbae4000000
baffffff0f000000
baffffff0f000000
ffffffbae4000000
baffffff0f000000
ffffffbae4000000
-
{c=>0,a=>-56,b=>5}
c8ffffff05000000
c8ffffff05000000
c8ffffff05000000
ffffffc8a0000000
c8ffffff05000000
c8ffffff05000000
ffffffc8a0000000
c8ffffff05000000
ffffffc8a0000000
-
{c=>-2,a=>-48,b=>2}
d0ffffff32000000
d0ffffff32000000
d0ffffff32000000
ffffffd058000000
d0ffffff32000000
d0ffffff32000000
ffffffd058000000
d0ffffff32000000
ffffffd058000000
-
{c=>1,a=>31,b=>2}
1f0000000a000000
1f0000000a000000
1f0000000a000000
0000001f44000000
1f0000000a000000
1f0000000a000000
0000001f44000000
1f0000000a000000
0000001f44000000
-
{c=>3,a=>120,b=>2}
780000001a000000
780000001a000000
780000001a000000
000000784c000000
780000001a000000
780000001a000000
000000784c000000
780000001a000000
000000784c000000
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>-4,a=>-120,b=>6,d=>0}
88ffffff26000000
88ffffff26000000
88ffffff26000000
ffffff88d0000000
88ffffff26000000
88ffffff26000000
ffffff88d0000000
88ffffff26000000
ffffff88d0000000
-
{c=>0,a=>118,b=>7,d=>3}
76000000c7000000
76000000c7000000
76000000c7000000
00000076e1800000
76000000c7000000
76000000c7000000
00000076e1800000
76000000c7000000
00000076e1800000
-
{c=>-2,a=>-76,b=>5,d=>2}
b4ffffffb5000000
b4ffffffb5000000
b4ffffffb5000000
ffffffb4b9000000
b4ffffffb5000000
b4ffffffb5000000
ffffffb4b9000000
b4ffffffb5000000
ffffffb4b9000000
-
{c=>3,a=>-39,b=>6,d=>3}
d9ffffffde000000
d9ffffffde000000
d9ffffffde000000
ffffffd9cd800000
d9ffffffde000000
d9ffffffde000000
ffffffd9cd800000
d9ffffffde000000
ffffffd9cd800000
-
{c=>-3,a=>9,b=>5,d=>1}
090000006d000000
090000006d000000
090000006d000000
00000009b4800000
090000006d000000
090000006d000000
00000009b4800000
090000006d000000
00000009b4800000
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>3,c=>3,a=>-74,b=>2,d=>3}
b6ffffffda060000
b6ffffffda060000
b6ffffffda060000
ffffffb64db00000
b6ffffffda060000
b6ffffffda060000
ffffffb64db00000
b6ffffffda060000
ffffffb64db00000
-
{e=>4,c=>2,a=>16,b=>7,d=>2}
1000000097080000
1000000097080000
1000000097080000
00000010e9400000
1000000097080000
1000000097080000
00000010e9400000
1000000097080000
00000010e9400000
-
{e=>2,c=>0,a=>48,b=>5,d=>-3}
3000000045050000
3000000045050000
3000000045050000
00000030a2a00000
3000000045050000
3000000045050000
00000030a2a00000
3000000045050000
00000030a2a00000
-
{e=>5,c=>2,a=>77,b=>3,d=>1}
4d000000530a0000
4d000000530a0000
4d000000530a0000
0000004d68d00000
4d000000530a0000
4d000000530a0000
0000004d68d00000
4d000000530a0000
0000004d68d00000
-
{e=>0,c=>-2,a=>78,b=>5,d=>1}
4e00000075000000
4e00000075000000
4e00000075000000
0000004eb8800000
4e00000075000000
4e00000075000000
0000004eb8800000
4e00000075000000
0000004eb8800000
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
};
-
{e=>1,c=>2,a=>80,b=>4,d=>1,f=>0}
5000000054020000
5000000054020000
5000000054020000
0000005088900000
5000000054020000
5000000054020000
0000005088900000
5000000054020000
0000005088900000
-
{e=>6,c=>2,a=>-27,b=>4,d=>3,f=>-4}
e5ffffffd44c0000
e5ffffffd44c0000
e5ffffffd44c0000
ffffffe589e80000
e5ffffffd44c0000
e5ffffffd44c0000
ffffffe589e80000
e5ffffffd44c0000
ffffffe589e80000
-
{e=>0,c=>2,a=>-111,b=>5,d=>3,f=>-4}
91ffffffd5400000
91ffffffd5400000
91ffffffd5400000
ffffff91a9880000
91ffffffd5400000
91ffffffd5400000
ffffff91a9880000
91ffffffd5400000
ffffff91a9880000
-
{e=>7,c=>1,a=>-42,b=>7,d=>1,f=>3}
d6ffffff4f3e0000
d6ffffff4f3e0000
d6ffffff4f3e0000
ffffffd6e4f60000
d6ffffff4f3e0000
d6ffffff4f3e0000
ffffffd6e4f60000
d6ffffff4f3e0000
ffffffd6e4f60000
-
{e=>5,c=>0,a=>90,b=>4,d=>0,f=>0}
5a000000040a0000
5a000000040a0000
5a000000040a0000
0000005a80500000
5a000000040a0000
5a000000040a0000
0000005a80500000
5a000000040a0000
0000005a80500000
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
};
-
{e=>3,c=>0,a=>0,g=>3,b=>3,d=>1,f=>-3}
0000000043d60100
0000000043d60100
0000000043d60100
0000000060bac000
0000000043d60100
0000000043d60100
0000000060bac000
0000000043d60100
0000000060bac000
-
{e=>3,c=>-4,a=>-62,g=>6,b=>1,d=>-3,f=>1}
c2ffffff61170300
c2ffffff61170300
c2ffffff61170300
ffffffc232b38000
c2ffffff61170300
c2ffffff61170300
ffffffc232b38000
c2ffffff61170300
ffffffc232b38000
-
{e=>2,c=>-3,a=>26,g=>5,b=>3,d=>0,f=>-4}
1a0000002bc40200
1a0000002bc40200
1a0000002bc40200
0000001a74294000
1a0000002bc40200
1a0000002bc40200
0000001a74294000
1a0000002bc40200
0000001a74294000
-
{e=>3,c=>3,a=>-96,g=>7,b=>7,d=>-3,f=>3}
a0ffffff5fb70300
a0ffffff5fb70300
a0ffffff5fb70300
ffffffa0eeb7c000
a0ffffff5fb70300
a0ffffff5fb70300
ffffffa0eeb7c000
a0ffffff5fb70300
ffffffa0eeb7c000
-
{e=>6,c=>2,a=>-81,g=>5,b=>1,d=>-1,f=>3}
afffffffd1bd0200
afffffffd1bd0200
afffffffd1bd0200
ffffffaf2be74000
afffffffd1bd0200
afffffffd1bd0200
ffffffaf2be74000
afffffffd1bd0200
ffffffaf2be74000
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>4,c=>2,a=>21,g=>1,b=>4,d=>-4,f=>3}
1500000014b90000
1500000014b90000
1500000014b90000
000000158a464000
1500000014b90000
1500000014b90000
000000158a464000
1500000014b90000
000000158a464000
-
{e=>3,c=>-4,a=>82,g=>4,b=>5,d=>3,f=>1}
52000000e5160200
52000000e5160200
52000000e5160200
00000052b1b30000
52000000e5160200
52000000e5160200
00000052b1b30000
52000000e5160200
00000052b1b30000
-
{e=>2,c=>-3,a=>28,g=>5,b=>2,d=>0,f=>-4}
1c0000002ac40200
1c0000002ac40200
1c0000002ac40200
0000001c54294000
1c0000002ac40200
1c0000002ac40200
0000001c54294000
1c0000002ac40200
0000001c54294000
-
{e=>4,c=>2,a=>116,g=>2,b=>3,d=>-2,f=>0}
7400000093090100
7400000093090100
7400000093090100
000000746b408000
7400000093090100
7400000093090100
000000746b408000
7400000093090100
000000746b408000
-
{e=>5,c=>-2,a=>77,g=>7,b=>6,d=>-1,f=>3}
4d000000f6bb0300
4d000000f6bb0300
4d000000f6bb0300
0000004ddbd7c000
4d000000f6bb0300
4d000000f6bb0300
0000004ddbd7c000
4d000000f6bb0300
0000004ddbd7c000
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>6,a=>-106,d=>0,c=>-3,h=>5,b=>4,g=>2,f=>0}
96ffffff2c0c010005000000
96ffffff2c0c010005000000
96ffffff2c0c010005000000
ffffff9694608000a0000000
96ffffff2c0c010005000000
96ffffff2c0c010005000000
ffffff9694608000a0000000
96ffffff2c0c010005000000
ffffff9694608000a0000000
-
{e=>2,a=>41,d=>-3,c=>-3,h=>1,b=>0,g=>7,f=>-4}
2900000068c5030001000000
2900000068c5030001000000
2900000068c5030001000000
0000002916a9c00020000000
2900000068c5030001000000
2900000068c5030001000000
0000002916a9c00020000000
2900000068c5030001000000
0000002916a9c00020000000
-
{e=>7,a=>-97,d=>2,c=>2,h=>5,b=>3,g=>1,f=>-3}
9fffffff93de000005000000
9fffffff93de000005000000
9fffffff93de000005000000
ffffff9f697a4000a0000000
9fffffff93de000005000000
9fffffff93de000005000000
ffffff9f697a4000a0000000
9fffffff93de000005000000
ffffff9f697a4000a0000000
-
{e=>2,a=>-90,d=>-1,c=>-4,h=>4,b=>0,g=>0,f=>3}
a6ffffffe035000004000000
a6ffffffe035000004000000
a6ffffffe035000004000000
ffffffa613a6000080000000
a6ffffffe035000004000000
a6ffffffe035000004000000
ffffffa613a6000080000000
a6ffffffe035000004000000
ffffffa613a6000080000000
-
{e=>6,a=>106,d=>-3,c=>2,h=>7,b=>7,g=>4,f=>-3}
6a000000575d020007000000
6a000000575d020007000000
6a000000575d020007000000
0000006aeaeb0000e0000000
6a000000575d020007000000
6a000000575d020007000000
0000006aeaeb0000e0000000
6a000000575d020007000000
0000006aeaeb0000e0000000
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>6,a=>-65,d=>-4,c=>-4,h=>6,b=>0,g=>5,f=>3,i=>-4}
bfffffff20bd020026000000
bfffffff20bd020026000000
bfffffff20bd020026000000
ffffffbf12674000d0000000
bfffffff20bd020026000000
bfffffff20bd020026000000
ffffffbf12674000d0000000
bfffffff20bd020026000000
ffffffbf12674000d0000000
-
{e=>5,a=>-32,d=>-2,c=>1,h=>1,b=>6,g=>1,f=>0,i=>1}
e0ffffff8e8b000009000000
e0ffffff8e8b000009000000
e0ffffff8e8b000009000000
ffffffe0c750400024000000
e0ffffff8e8b000009000000
e0ffffff8e8b000009000000
ffffffe0c750400024000000
e0ffffff8e8b000009000000
ffffffe0c750400024000000
-
{e=>5,a=>-95,d=>-3,c=>2,h=>7,b=>5,g=>2,f=>3,i=>-3}
a1ffffff553b01002f000000
a1ffffff553b01002f000000
a1ffffff553b01002f000000
ffffffa1aad68000f4000000
a1ffffff553b01002f000000
a1ffffff553b01002f000000
ffffffa1aad68000f4000000
a1ffffff553b01002f000000
ffffffa1aad68000f4000000
-
{e=>3,a=>-22,d=>-1,c=>-1,h=>6,b=>6,g=>7,f=>-4,i=>-3}
eafffffffec703002e000000
eafffffffec703002e000000
eafffffffec703002e000000
ffffffeadfb9c000d4000000
eafffffffec703002e000000
eafffffffec703002e000000
ffffffeadfb9c000d4000000
eafffffffec703002e000000
ffffffeadfb9c000d4000000
-
{e=>6,a=>-103,d=>-1,c=>0,h=>2,b=>2,g=>7,f=>-2,i=>-4}
99ffffffc2ed030022000000
99ffffffc2ed030022000000
99ffffffc2ed030022000000
ffffff9943edc00050000000
99ffffffc2ed030022000000
99ffffffc2ed030022000000
ffffff9943edc00050000000
99ffffffc2ed030022000000
ffffff9943edc00050000000
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
};
-
{e=>7,a=>87,d=>-2,j=>7,c=>-2,h=>2,b=>2,g=>2,f=>-2,i=>2}
57000000b26f0100d2010000
57000000b26f0100d2010000
57000000b26f0100d2010000
000000575b7c80004b800000
57000000b26f0100d2010000
57000000b26f0100d2010000
000000575b7c80004b800000
57000000b26f0100d2010000
000000575b7c80004b800000
-
{e=>3,a=>-126,d=>-4,j=>4,c=>0,h=>0,b=>6,g=>1,f=>-2,i=>-4}
82ffffff06e7000020010000
82ffffff06e7000020010000
82ffffff06e7000020010000
ffffff82c23c400012000000
82ffffff06e7000020010000
82ffffff06e7000020010000
ffffff82c23c400012000000
82ffffff06e7000020010000
ffffff82c23c400012000000
-
{e=>5,a=>90,d=>0,j=>7,c=>3,h=>0,b=>5,g=>6,f=>-1,i=>-1}
5a0000001d7a0300f8010000
5a0000001d7a0300f8010000
5a0000001d7a0300f8010000
0000005aac5f80001f800000
5a0000001d7a0300f8010000
5a0000001d7a0300f8010000
0000005aac5f80001f800000
5a0000001d7a0300f8010000
0000005aac5f80001f800000
-
{e=>6,a=>-47,d=>1,j=>3,c=>1,h=>4,b=>7,g=>7,f=>3,i=>-1}
d1ffffff4fbc0300fc000000
d1ffffff4fbc0300fc000000
d1ffffff4fbc0300fc000000
ffffffd1e4e7c0009d800000
d1ffffff4fbc0300fc000000
d1ffffff4fbc0300fc000000
ffffffd1e4e7c0009d800000
d1ffffff4fbc0300fc000000
ffffffd1e4e7c0009d800000
-
{e=>6,a=>47,d=>2,j=>7,c=>1,h=>4,b=>6,g=>1,f=>0,i=>-4}
2f0000008e8c0000e4010000
2f0000008e8c0000e4010000
2f0000008e8c0000e4010000
0000002fc560400093800000
2f0000008e8c0000e4010000
2f0000008e8c0000e4010000
0000002fc560400093800000
2f0000008e8c0000e4010000
0000002fc560400093800000
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
};
-
{e=>4,a=>-69,d=>1,j=>5,c=>-2,k=>-25,h=>4,b=>3,g=>1,f=>3,i=>1}
bbffffff73b800004c01e700
bbffffff73b800004c01e700
bbffffff73b800004c01e700
ffffffbb78c640008680e700
bbffffff73b800004c01e700
bbffffff73b800004c01e700
ffffffbb78c640008680e700
bbffffff73b800004c01e700
ffffffbb78c640008680e700
-
{e=>1,a=>116,d=>0,j=>4,c=>2,k=>45,h=>6,b=>3,g=>3,f=>-2,i=>3}
7400000013e201001e012d00
7400000013e201001e012d00
7400000013e201001e012d00
00000074681cc000ce002d00
7400000013e201001e012d00
7400000013e201001e012d00
00000074681cc000ce002d00
7400000013e201001e012d00
00000074681cc000ce002d00
-
{e=>3,a=>-113,d=>1,j=>1,c=>0,k=>-27,h=>5,b=>5,g=>6,f=>-3,i=>-2}
8fffffff455603007500e500
8fffffff455603007500e500
8fffffff455603007500e500
ffffff8fa0bb8000b880e500
8fffffff455603007500e500
8fffffff455603007500e500
ffffff8fa0bb8000b880e500
8fffffff455603007500e500
ffffff8fa0bb8000b880e500
-
{e=>3,a=>49,d=>3,j=>2,c=>-2,k=>3,h=>1,b=>0,g=>2,f=>2,i=>2}
31000000f026010091000300
31000000f026010091000300
31000000f026010091000300
0000003119b4800029000300
31000000f026010091000300
31000000f026010091000300
0000003119b4800029000300
31000000f026010091000300
0000003119b4800029000300
-
{e=>0,a=>105,d=>-1,j=>3,c=>-3,k=>-114,h=>6,b=>5,g=>7,f=>-2,i=>3}
69000000ede10300de008e00
69000000ede10300de008e00
69000000ede10300de008e00
00000069b78dc000cd808e00
69000000ede10300de008e00
69000000ede10300de008e00
00000069b78dc000cd808e00
69000000ede10300de008e00
00000069b78dc000cd808e00
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>4,a=>-33,d=>-3,j=>2,l=>4,c=>2,k=>-127,h=>2,b=>1,g=>3,f=>0,i=>3}
dfffffff518901009a008104
dfffffff518901009a008104
dfffffff518901009a008104
ffffffdf2ac0c0004d008180
dfffffff518901009a008104
dfffffff518901009a008104
ffffffdf2ac0c0004d008180
dfffffff518901009a008104
ffffffdf2ac0c0004d008180
-
{e=>1,a=>30,d=>0,j=>3,l=>5,c=>-2,k=>-10,h=>5,b=>0,g=>3,f=>2,i=>-2}
1e00000030a20100f500f605
1e00000030a20100f500f605
1e00000030a20100f500f605
0000001e1814c000b980f6a0
1e00000030a20100f500f605
1e00000030a20100f500f605
0000001e1814c000b980f6a0
1e00000030a20100f500f605
0000001e1814c000b980f6a0
-
{e=>0,a=>87,d=>-1,j=>5,l=>6,c=>-2,k=>-45,h=>2,b=>7,g=>1,f=>3,i=>-2}
57000000f7b100007201d306
57000000f7b100007201d306
57000000f7b100007201d306
00000057fb8640005a80d3c0
57000000f7b100007201d306
57000000f7b100007201d306
00000057fb8640005a80d3c0
57000000f7b100007201d306
00000057fb8640005a80d3c0
-
{e=>1,a=>-27,d=>2,j=>3,l=>0,c=>1,k=>36,h=>0,b=>0,g=>5,f=>0,i=>-1}
e5ffffff88820200f8002400
e5ffffff88820200f8002400
e5ffffff88820200f8002400
ffffffe5051140001d802400
e5ffffff88820200f8002400
e5ffffff88820200f8002400
ffffffe5051140001d802400
e5ffffff88820200f8002400
ffffffe5051140001d802400
-
{e=>7,a=>38,d=>2,j=>1,l=>5,c=>-2,k=>37,h=>5,b=>5,g=>5,f=>1,i=>-1}
26000000b59e02007d002505
26000000b59e02007d002505
26000000b59e02007d002505
00000026b9734000bc8025a0
26000000b59e02007d002505
26000000b59e02007d002505
00000026b9734000bc8025a0
26000000b59e02007d002505
00000026b9734000bc8025a0
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>4,a=>-77,m=>-1,d=>-4,j=>3,l=>6,c=>0,k=>2,h=>7,b=>7,g=>3,f=>1,i=>1}
b3ffffff07990100cf00023e
b3ffffff07990100cf00023e
b3ffffff07990100cf00023e
ffffffb3e242c000e58002dc
b3ffffff07990100cf00023e
b3ffffff07990100cf00023e
ffffffb3e242c000e58002dc
b3ffffff07990100cf00023e
ffffffb3e242c000e58002dc
-
{e=>6,a=>-85,m=>-1,d=>0,j=>6,l=>2,c=>2,k=>121,h=>4,b=>0,g=>5,f=>-4,i=>3}
abffffff10cc02009c01793a
abffffff10cc02009c01793a
abffffff10cc02009c01793a
ffffffab086940008f00795c
abffffff10cc02009c01793a
abffffff10cc02009c01793a
ffffffab086940008f00795c
abffffff10cc02009c01793a
ffffffab086940008f00795c
-
{e=>0,a=>63,m=>-1,d=>3,j=>3,l=>1,c=>-1,k=>54,h=>5,b=>0,g=>0,f=>1,i=>-4}
3f000000f8100000e5003639
3f000000f8100000e5003639
3f000000f8100000e5003639
0000003f1d820000b180363c
3f000000f8100000e5003639
3f000000f8100000e5003639
0000003f1d820000b180363c
3f000000f8100000e5003639
0000003f1d820000b180363c
-
{e=>5,a=>3,m=>-4,d=>1,j=>0,l=>5,c=>-3,k=>-15,h=>4,b=>6,g=>2,f=>1,i=>1}
030000006e1a01000c00f125
030000006e1a01000c00f125
030000006e1a01000c00f125
00000003d4d280008400f1b0
030000006e1a01000c00f125
030000006e1a01000c00f125
00000003d4d280008400f1b0
030000006e1a01000c00f125
00000003d4d280008400f1b0
-
{e=>1,a=>93,m=>0,d=>3,j=>0,l=>2,c=>0,k=>57,h=>6,b=>0,g=>4,f=>-1,i=>2}
5d000000c072020016003902
5d000000c072020016003902
5d000000c072020016003902
0000005d019f0000c8003940
5d000000c072020016003902
5d000000c072020016003902
0000005d019f0000c8003940
5d000000c072020016003902
0000005d019f0000c8003940
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>6,n=>5,a=>93,m=>1,d=>1,j=>3,l=>1,c=>-2,k=>115,h=>3,b=>0,g=>2,f=>1,i=>1}
5d000000701c0100cb00730905000000
5d000000701c0100cb00730905000000
5d000000701c0100cb00730905000000
0000005d18e2800065807324a0000000
5d000000701c0100cb00730905000000
5d000000701c0100cb00730905000000
0000005d18e2800065807324a0000000
5d000000701c0100cb00730905000000
0000005d18e2800065807324a0000000
-
{e=>7,n=>6,a=>-112,m=>1,d=>-2,j=>2,l=>1,c=>-1,k=>66,h=>1,b=>5,g=>3,f=>-4,i=>3}
90ffffffbdcf01009900420906000000
90ffffffbdcf01009900420906000000
90ffffffbdcf01009900420906000000
ffffff90bf78c0002d004224c0000000
90ffffffbdcf01009900420906000000
90ffffffbdcf01009900420906000000
ffffff90bf78c0002d004224c0000000
90ffffffbdcf01009900420906000000
ffffff90bf78c0002d004224c0000000
-
{e=>7,n=>1,a=>102,m=>3,d=>3,j=>3,l=>6,c=>1,k=>-50,h=>5,b=>6,g=>7,f=>1,i=>1}
66000000ce9e0300cd00ce1e01000000
66000000ce9e0300cd00ce1e01000000
66000000ce9e0300cd00ce1e01000000
00000066c5f3c000a580cecc20000000
66000000ce9e0300cd00ce1e01000000
66000000ce9e0300cd00ce1e01000000
00000066c5f3c000a580cecc20000000
66000000ce9e0300cd00ce1e01000000
00000066c5f3c000a580cecc20000000
-
{e=>3,n=>6,a=>-108,m=>1,d=>-4,j=>4,l=>4,c=>-3,k=>85,h=>3,b=>7,g=>7,f=>-1,i=>1}
94ffffff2ff703000b01550c06000000
94ffffff2ff703000b01550c06000000
94ffffff2ff703000b01550c06000000
ffffff94f63fc00066005584c0000000
94ffffff2ff703000b01550c06000000
94ffffff2ff703000b01550c06000000
ffffff94f63fc00066005584c0000000
94ffffff2ff703000b01550c06000000
ffffff94f63fc00066005584c0000000
-
{e=>3,n=>5,a=>103,m=>1,d=>-3,j=>3,l=>2,c=>0,k=>103,h=>3,b=>4,g=>1,f=>1,i=>0}
6700000044970000c300670a05000000
6700000044970000c300670a05000000
6700000044970000c300670a05000000
0000006782b2400061806744a0000000
6700000044970000c300670a05000000
6700000044970000c300670a05000000
0000006782b2400061806744a0000000
6700000044970000c300670a05000000
0000006782b2400061806744a0000000
=
typedef int foo;

struct mixed_no_pack {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>6,n=>5,a=>-4,m=>-2,d=>-1,j=>4,l=>2,c=>-1,k=>-4,h=>5,b=>5,g=>2,f=>-2,o=>251,i=>1}
fcfffffffd6d01000d01fc3205fb0000
fcfffffffd6d01000d01fc3205fb0000
fcfffffffd6d01000d01fc3205fb0000
fffffffcbfec8000a600fc58a0fb0000
fcfffffffd6d01000d01fc3205fb0000
fcfffffffd6d01000d01fc3205fb0000
fffffffcbfec8000a600fc58a0fb0000
fcfffffffd6d01000d01fc3205fb0000
fffffffcbfec8000a600fc58a0fb0000
-
{e=>5,n=>7,a=>100,m=>-4,d=>-4,j=>4,l=>2,c=>0,k=>-86,h=>1,b=>5,g=>0,f=>2,o=>180,i=>-2}
64000000052b00003101aa2207b40000
64000000052b00003101aa2207b40000
64000000052b00003101aa2207b40000
00000064a25400003a00aa50e0b40000
64000000052b00003101aa2207b40000
64000000052b00003101aa2207b40000
00000064a25400003a00aa50e0b40000
64000000052b00003101aa2207b40000
00000064a25400003a00aa50e0b40000
-
{e=>6,n=>7,a=>-56,m=>-2,d=>-3,j=>5,l=>0,c=>-3,k=>122,h=>4,b=>7,g=>2,f=>1,o=>254,i=>0}
c8ffffff6f1d010044017a3007fe0000
c8ffffff6f1d010044017a3007fe0000
c8ffffff6f1d010044017a3007fe0000
ffffffc8f6e2800082807a18e0fe0000
c8ffffff6f1d010044017a3007fe0000
c8ffffff6f1d010044017a3007fe0000
ffffffc8f6e2800082807a18e0fe0000
c8ffffff6f1d010044017a3007fe0000
ffffffc8f6e2800082807a18e0fe0000
-
{e=>1,n=>5,a=>-64,m=>-2,d=>1,j=>0,l=>1,c=>-3,k=>77,h=>7,b=>1,g=>4,f=>-1,o=>3,i=>-2}
c0ffffff6972020037004d3105030000
c0ffffff6972020037004d3105030000
c0ffffff6972020037004d3105030000
ffffffc0349f0000f8004d38a0030000
c0ffffff6972020037004d3105030000
c0ffffff6972020037004d3105030000
ffffffc0349f0000f8004d38a0030000
c0ffffff6972020037004d3105030000
ffffffc0349f0000f8004d38a0030000
-
{e=>5,n=>6,a=>-59,m=>-3,d=>0,j=>4,l=>3,c=>-3,k=>47,h=>3,b=>7,g=>0,f=>0,o=>16,i=>2}
c5ffffff2f0a000013012f2b06100000
c5ffffff2f0a000013012f2b06100000
c5ffffff2f0a000013012f2b06100000
ffffffc5f45000006a002f74c0100000
c5ffffff2f0a000013012f2b06100000
c5ffffff2f0a000013012f2b06100000
ffffffc5f45000006a002f74c0100000
c5ffffff2f0a000013012f2b06100000
ffffffc5f45000006a002f74c0100000
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
};
-
{a=>-106,b=>7}
96ffffff07000000
96ffffffffffffff0700000000000000
96ffffffffffffff0700000000000000
ffffff96e0000000
96ffffff07000000
96ffffff07000000
ffffffffffffff96e000000000000000
96ffffff07000000
ffffff96e0000000
-
{a=>-127,b=>2}
81ffffff02000000
81ffffffffffffff0200000000000000
81ffffffffffffff0200000000000000
ffffff8140000000
81ffffff02000000
81ffffff02000000
ffffffffffffff814000000000000000
81ffffff02000000
ffffff8140000000
-
{a=>-66,b=>6}
beffffff06000000
beffffffffffffff0600000000000000
beffffffffffffff0600000000000000
ffffffbec0000000
beffffff06000000
beffffff06000000
ffffffffffffffbec000000000000000
beffffff06000000
ffffffbec0000000
-
{a=>49,b=>6}
3100000006000000
31000000000000000600000000000000
31000000000000000600000000000000
00000031c0000000
3100000006000000
3100000006000000
0000000000000031c000000000000000
3100000006000000
00000031c0000000
-
{a=>107,b=>7}
6b00000007000000
6b000000000000000700000000000000
6b000000000000000700000000000000
0000006be0000000
6b00000007000000
6b00000007000000
000000000000006be000000000000000
6b00000007000000
0000006be0000000
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>0,a=>-18,b=>6}
eeffffff06000000
eeffffffffffffff0600000000000000
eeffffffffffffff0600000000000000
ffffffeec0000000
eeffffff06000000
eeffffff06000000
ffffffffffffffeec000000000000000
eeffffff06000000
ffffffeec0000000
-
{c=>-3,a=>-10,b=>6}
f6ffffff2e000000
f6ffffffffffffff2e00000000000000
f6ffffffffffffff2e00000000000000
fffffff6d4000000
f6ffffff2e000000
f6ffffff2e000000
fffffffffffffff6d400000000000000
f6ffffff2e000000
fffffff6d4000000
-
{c=>2,a=>40,b=>4}
2800000014000000
28000000000000001400000000000000
28000000000000001400000000000000
0000002888000000
2800000014000000
2800000014000000
00000000000000288800000000000000
2800000014000000
0000002888000000
-
{c=>-2,a=>-97,b=>3}
9fffffff33000000
9fffffffffffffff3300000000000000
9fffffffffffffff3300000000000000
ffffff9f78000000
9fffffff33000000
9fffffff33000000
ffffffffffffff9f7800000000000000
9fffffff33000000
ffffff9f78000000
-
{c=>0,a=>-24,b=>3}
e8ffffff03000000
e8ffffffffffffff0300000000000000
e8ffffffffffffff0300000000000000
ffffffe860000000
e8ffffff03000000
e8ffffff03000000
ffffffffffffffe86000000000000000
e8ffffff03000000
ffffffe860000000
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>2,a=>-99,b=>5,d=>-3}
9dffffff55010000
9dffffffffffffff5501000000000000
9dffffffffffffff5501000000000000
ffffff9daa800000
9dffffff55010000
9dffffff55010000
ffffffffffffff9daa80000000000000
9dffffff55010000
ffffff9daa800000
-
{c=>-3,a=>102,b=>4,d=>1}
660000006c000000
66000000000000006c00000000000000
66000000000000006c00000000000000
0000006694800000
660000006c000000
660000006c000000
00000000000000669480000000000000
660000006c000000
0000006694800000
-
{c=>-4,a=>108,b=>1,d=>2}
6c000000a1000000
6c00000000000000a100000000000000
6c00000000000000a100000000000000
0000006c31000000
6c000000a1000000
6c000000a1000000
000000000000006c3100000000000000
6c000000a1000000
0000006c31000000
-
{c=>1,a=>-81,b=>6,d=>3}
afffffffce000000
afffffffffffffffce00000000000000
afffffffffffffffce00000000000000
ffffffafc5800000
afffffffce000000
afffffffce000000
ffffffffffffffafc580000000000000
afffffffce000000
ffffffafc5800000
-
{c=>2,a=>-53,b=>2,d=>2}
cbffffff92000000
cbffffffffffffff9200000000000000
cbffffffffffffff9200000000000000
ffffffcb49000000
cbffffff92000000
cbffffff92000000
ffffffffffffffcb4900000000000000
cbffffff92000000
ffffffcb49000000
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>2,c=>2,a=>62,b=>7,d=>0}
3e00000017040000
3e000000000000001704000000000000
3e000000000000001704000000000000
0000003ee8200000
3e00000017040000
3e00000017040000
000000000000003ee820000000000000
3e00000017040000
0000003ee8200000
-
{e=>0,c=>1,a=>-91,b=>7,d=>1}
a5ffffff4f000000
a5ffffffffffffff4f00000000000000
a5ffffffffffffff4f00000000000000
ffffffa5e4800000
a5ffffff4f000000
a5ffffff4f000000
ffffffffffffffa5e480000000000000
a5ffffff4f000000
ffffffa5e4800000
-
{e=>3,c=>-1,a=>50,b=>3,d=>0}
320000003b060000
32000000000000003b06000000000000
32000000000000003b06000000000000
000000327c300000
320000003b060000
320000003b060000
00000000000000327c30000000000000
320000003b060000
000000327c300000
-
{e=>2,c=>-1,a=>-68,b=>2,d=>2}
bcffffffba040000
bcffffffffffffffba04000000000000
bcffffffffffffffba04000000000000
ffffffbc5d200000
bcffffffba040000
bcffffffba040000
ffffffffffffffbc5d20000000000000
bcffffffba040000
ffffffbc5d200000
-
{e=>5,c=>2,a=>67,b=>4,d=>1}
43000000540a0000
4300000000000000540a000000000000
4300000000000000540a000000000000
0000004388d00000
43000000540a0000
43000000540a0000
000000000000004388d0000000000000
43000000540a0000
0000004388d00000
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
};
-
{e=>1,c=>3,a=>-33,b=>2,d=>-3,f=>-3}
dfffffff5a530000
dfffffffffffffff5a53000000000000
dfffffffffffffff5a53000000000000
ffffffdf4e9a0000
dfffffff5a530000
dfffffff5a530000
ffffffffffffffdf4e9a000000000000
dfffffff5a530000
ffffffdf4e9a0000
-
{e=>6,c=>-4,a=>-3,b=>1,d=>-3,f=>1}
fdffffff611d0000
fdffffffffffffff611d000000000000
fdffffffffffffff611d000000000000
fffffffd32e20000
fdffffff611d0000
fdffffff611d0000
fffffffffffffffd32e2000000000000
fdffffff611d0000
fffffffd32e20000
-
{e=>5,c=>-2,a=>-125,b=>1,d=>-3,f=>-3}
83ffffff715b0000
83ffffffffffffff715b000000000000
83ffffffffffffff715b000000000000
ffffff833ada0000
83ffffff715b0000
83ffffff715b0000
ffffffffffffff833ada000000000000
83ffffff715b0000
ffffff833ada0000
-
{e=>7,c=>-2,a=>101,b=>3,d=>-2,f=>-1}
65000000b37f0000
6500000000000000b37f000000000000
6500000000000000b37f000000000000
000000657b7e0000
65000000b37f0000
65000000b37f0000
00000000000000657b7e000000000000
65000000b37f0000
000000657b7e0000
-
{e=>1,c=>-2,a=>71,b=>4,d=>3,f=>2}
47000000f4220000
4700000000000000f422000000000000
4700000000000000f422000000000000
0000004799940000
47000000f4220000
47000000f4220000
00000000000000479994000000000000
47000000f4220000
0000004799940000
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
};
-
{e=>5,c=>0,a=>56,g=>7,b=>1,d=>-1,f=>2}
38000000c1ab0300
3800000000000000c1ab030000000000
3800000000000000c1ab030000000000
0000003823d5c000
38000000c1ab0300
38000000c1ab0300
000000000000003823d5c00000000000
38000000c1ab0300
0000003823d5c000
-
{e=>6,c=>-4,a=>-45,g=>2,b=>2,d=>-1,f=>-1}
d3ffffffe27d0100
d3ffffffffffffffe27d010000000000
d3ffffffffffffffe27d010000000000
ffffffd353ee8000
d3ffffffe27d0100
d3ffffffe27d0100
ffffffffffffffd353ee800000000000
d3ffffffe27d0100
ffffffd353ee8000
-
{e=>7,c=>-4,a=>-101,g=>3,b=>1,d=>1,f=>-3}
9bffffff61de0100
9bffffffffffffff61de010000000000
9bffffffffffffff61de010000000000
ffffff9b30fac000
9bffffff61de0100
9bffffff61de0100
ffffffffffffff9b30fac00000000000
9bffffff61de0100
ffffff9b30fac000
-
{e=>0,c=>3,a=>62,g=>5,b=>2,d=>-3,f=>-4}
3e0000005ac10200
3e000000000000005ac1020000000000
3e000000000000005ac1020000000000
0000003e4e894000
3e0000005ac10200
3e0000005ac10200
000000000000003e4e89400000000000
3e0000005ac10200
0000003e4e894000
-
{e=>6,c=>3,a=>102,g=>2,b=>6,d=>1,f=>-1}
660000005e7c0100
66000000000000005e7c010000000000
66000000000000005e7c010000000000
00000066ccee8000
660000005e7c0100
660000005e7c0100
0000000000000066ccee800000000000
660000005e7c0100
00000066ccee8000
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>0,c=>-3,a=>-101,g=>1,b=>2,d=>0,f=>-3}
9bffffff2ad00000
9bffffffffffffff2ad0000000000000
9bffffffffffffff2ad0000000000000
ffffff9b540a4000
9bffffff2ad00000
9bffffff2ad00000
ffffffffffffff9b540a400000000000
9bffffff2ad00000
ffffff9b540a4000
-
{e=>5,c=>-4,a=>-95,g=>4,b=>4,d=>-4,f=>-1}
a1ffffff247b0200
a1ffffffffffffff247b020000000000
a1ffffffffffffff247b020000000000
ffffffa1925f0000
a1ffffff247b0200
a1ffffff247b0200
ffffffffffffffa1925f000000000000
a1ffffff247b0200
ffffffa1925f0000
-
{e=>0,c=>0,a=>60,g=>4,b=>4,d=>2,f=>-3}
3c00000084500200
3c000000000000008450020000000000
3c000000000000008450020000000000
0000003c810b0000
3c00000084500200
3c00000084500200
000000000000003c810b000000000000
3c00000084500200
0000003c810b0000
-
{e=>4,c=>2,a=>-72,g=>5,b=>2,d=>1,f=>-2}
b8ffffff52e80200
b8ffffffffffffff52e8020000000000
b8ffffffffffffff52e8020000000000
ffffffb848cd4000
b8ffffff52e80200
b8ffffff52e80200
ffffffffffffffb848cd400000000000
b8ffffff52e80200
ffffffb848cd4000
-
{e=>4,c=>1,a=>-29,g=>7,b=>2,d=>-1,f=>2}
e3ffffffcaa90300
e3ffffffffffffffcaa9030000000000
e3ffffffffffffffcaa9030000000000
ffffffe347c5c000
e3ffffffcaa90300
e3ffffffcaa90300
ffffffffffffffe347c5c00000000000
e3ffffffcaa90300
ffffffe347c5c000
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>1,a=>23,d=>2,c=>-2,h=>0,b=>2,g=>4,f=>-3}
17000000b252020000000000
1700000000000000b252020000000000
1700000000000000b252020000000000
00000017591b000000000000
17000000b252020000000000
17000000b252020000000000
0000000000000017591b000000000000
17000000b252020000000000
00000017591b000000000000
-
{e=>7,a=>-108,d=>3,c=>0,h=>1,b=>7,g=>7,f=>-2}
94ffffffc7ee030001000000
94ffffffffffffffc7ee030001000000
94ffffffffffffffc7ee030001000000
ffffff94e1fdc00020000000
94ffffffc7ee030001000000
94ffffffc7ee030001000000
ffffffffffffff94e1fdc00020000000
94ffffffc7ee030001000000
ffffff94e1fdc00020000000
-
{e=>5,a=>-126,d=>2,c=>1,h=>3,b=>4,g=>0,f=>3}
82ffffff8c3a000003000000
82ffffffffffffff8c3a000003000000
82ffffffffffffff8c3a000003000000
ffffff828556000060000000
82ffffff8c3a000003000000
82ffffff8c3a000003000000
ffffffffffffff828556000060000000
82ffffff8c3a000003000000
ffffff828556000060000000
-
{e=>4,a=>-62,d=>3,c=>-4,h=>1,b=>2,g=>2,f=>-3}
c2ffffffe258010001000000
c2ffffffffffffffe258010001000000
c2ffffffffffffffe258010001000000
ffffffc251ca800020000000
c2ffffffe258010001000000
c2ffffffe258010001000000
ffffffffffffffc251ca800020000000
c2ffffffe258010001000000
ffffffc251ca800020000000
-
{e=>0,a=>89,d=>-3,c=>3,h=>0,b=>7,g=>3,f=>2}
590000005fa1010000000000
59000000000000005fa1010000000000
59000000000000005fa1010000000000
00000059ee84c00000000000
590000005fa1010000000000
590000005fa1010000000000
0000000000000059ee84c00000000000
590000005fa1010000000000
00000059ee84c00000000000
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>6,a=>16,d=>1,c=>-4,h=>1,b=>7,g=>3,f=>-3,i=>0}
1000000067dc010001000000
100000000000000067dc010001000000
100000000000000067dc010001000000
00000010f0eac00020000000
1000000067dc010001000000
1000000067dc010001000000
0000000000000010f0eac00020000000
1000000067dc010001000000
00000010f0eac00020000000
-
{e=>6,a=>62,d=>0,c=>1,h=>2,b=>0,g=>5,f=>-3,i=>2}
3e00000008dc020012000000
3e0000000000000008dc020012000000
3e0000000000000008dc020012000000
0000003e046b400048000000
3e00000008dc020012000000
3e00000008dc020012000000
000000000000003e046b400048000000
3e00000008dc020012000000
0000003e046b400048000000
-
{e=>3,a=>-95,d=>-2,c=>3,h=>7,b=>3,g=>7,f=>-4,i=>0}
a1ffffff9bc7030007000000
a1ffffffffffffff9bc7030007000000
a1ffffffffffffff9bc7030007000000
ffffffa16f39c000e0000000
a1ffffff9bc7030007000000
a1ffffff9bc7030007000000
ffffffffffffffa16f39c000e0000000
a1ffffff9bc7030007000000
ffffffa16f39c000e0000000
-
{e=>6,a=>-45,d=>1,c=>0,h=>1,b=>6,g=>3,f=>-1,i=>1}
d3ffffff46fc010009000000
d3ffffffffffffff46fc010009000000
d3ffffffffffffff46fc010009000000
ffffffd3c0eec00024000000
d3ffffff46fc010009000000
d3ffffff46fc010009000000
ffffffffffffffd3c0eec00024000000
d3ffffff46fc010009000000
ffffffd3c0eec00024000000
-
{e=>1,a=>-122,d=>1,c=>0,h=>4,b=>1,g=>4,f=>0,i=>3}
86ffffff410202001c000000
86ffffffffffffff410202001c000000
86ffffffffffffff410202001c000000
ffffff86209100008c000000
86ffffff410202001c000000
86ffffff410202001c000000
ffffffffffffff86209100008c000000
86ffffff410202001c000000
ffffff86209100008c000000
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
};
-
{e=>1,a=>-114,d=>2,j=>5,c=>1,h=>4,b=>1,g=>6,f=>2,i=>-4}
8effffff8922030064010000
8effffffffffffff8922030064010000
8effffffffffffff8922030064010000
ffffff8e2515800092800000
8effffff8922030064010000
8effffff8922030064010000
ffffffffffffff8e2515800092800000
8effffff8922030064010000
ffffff8e2515800092800000
-
{e=>2,a=>-60,d=>-3,j=>3,c=>-1,h=>6,b=>2,g=>1,f=>3,i=>0}
c4ffffff7ab50000c6000000
c4ffffffffffffff7ab50000c6000000
c4ffffffffffffff7ab50000c6000000
ffffffc45ea64000c1800000
c4ffffff7ab50000c6000000
c4ffffff7ab50000c6000000
ffffffffffffffc45ea64000c1800000
c4ffffff7ab50000c6000000
ffffffc45ea64000c1800000
-
{e=>3,a=>51,d=>1,j=>5,c=>-4,h=>6,b=>7,g=>3,f=>2,i=>2}
3300000067a6010056010000
330000000000000067a6010056010000
330000000000000067a6010056010000
00000033f0b4c000ca800000
3300000067a6010056010000
3300000067a6010056010000
0000000000000033f0b4c000ca800000
3300000067a6010056010000
00000033f0b4c000ca800000
-
{e=>4,a=>-121,d=>-1,j=>3,c=>-3,h=>5,b=>3,g=>5,f=>1,i=>-1}
87ffffffeb990200fd000000
87ffffffffffffffeb990200fd000000
87ffffffffffffffeb990200fd000000
ffffff8777c34000bd800000
87ffffffeb990200fd000000
87ffffffeb990200fd000000
ffffffffffffff8777c34000bd800000
87ffffffeb990200fd000000
ffffff8777c34000bd800000
-
{e=>4,a=>80,d=>3,j=>5,c=>-1,h=>2,b=>0,g=>4,f=>-2,i=>0}
50000000f868020042010000
5000000000000000f868020042010000
5000000000000000f868020042010000
000000501dcd000042800000
50000000f868020042010000
50000000f868020042010000
00000000000000501dcd000042800000
50000000f868020042010000
000000501dcd000042800000
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
};
-
{e=>6,a=>-88,d=>3,j=>5,c=>-3,k=>-40,h=>0,b=>6,g=>6,f=>1,i=>-2}
a8ffffffee1c03007001d800
a8ffffffffffffffee1c03007001d800
a8ffffffffffffffee1c03007001d800
ffffffa8d5e380001a80d800
a8ffffffee1c03007001d800
a8ffffffee1c03007001d800
ffffffffffffffa8d5e380001a80d800
a8ffffffee1c03007001d800
ffffffa8d5e380001a80d800
-
{e=>2,a=>100,d=>-2,j=>0,c=>-2,k=>126,h=>4,b=>0,g=>2,f=>-3,i=>-4}
64000000b055010024007e00
6400000000000000b055010024007e00
6400000000000000b055010024007e00
000000641b2a800090007e00
64000000b055010024007e00
64000000b055010024007e00
00000000000000641b2a800090007e00
64000000b055010024007e00
000000641b2a800090007e00
-
{e=>3,a=>-69,d=>2,j=>7,c=>2,k=>33,h=>6,b=>6,g=>0,f=>1,i=>-1}
bbffffff96160000fe012100
bbffffffffffffff96160000fe012100
bbffffffffffffff96160000fe012100
ffffffbbc9320000df802100
bbffffff96160000fe012100
bbffffff96160000fe012100
ffffffffffffffbbc9320000df802100
bbffffff96160000fe012100
ffffffbbc9320000df802100
-
{e=>4,a=>68,d=>0,j=>5,c=>-1,k=>-97,h=>7,b=>4,g=>1,f=>-1,i=>3}
440000003cf800005f019f00
44000000000000003cf800005f019f00
44000000000000003cf800005f019f00
000000449c4e4000ee809f00
440000003cf800005f019f00
440000003cf800005f019f00
00000000000000449c4e4000ee809f00
440000003cf800005f019f00
000000449c4e4000ee809f00
-
{e=>3,a=>-64,d=>-4,j=>1,c=>0,k=>-12,h=>3,b=>3,g=>2,f=>2,i=>0}
c0ffffff032701004300f400
c0ffffffffffffff032701004300f400
c0ffffffffffffff032701004300f400
ffffffc0623480006080f400
c0ffffff032701004300f400
c0ffffff032701004300f400
ffffffffffffffc0623480006080f400
c0ffffff032701004300f400
ffffffc0623480006080f400
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>7,a=>19,d=>-2,j=>6,l=>1,c=>3,k=>-48,h=>6,b=>3,g=>4,f=>2,i=>3}
130000009b2f02009e01d001
13000000000000009b2f02009e01d001
13000000000000009b2f02009e01d001
000000136f750000cf00d020
130000009b2f02009e01d001
130000009b2f02009e01d001
00000000000000136f750000cf00d020
130000009b2f02009e01d001
000000136f750000cf00d020
-
{e=>2,a=>-64,d=>-1,j=>0,l=>2,c=>-4,k=>-102,h=>5,b=>4,g=>0,f=>-4,i=>0}
c0ffffffe445000005009a02
c0ffffffffffffffe445000005009a02
c0ffffffffffffffe445000005009a02
ffffffc093a80000a0009a40
c0ffffffe445000005009a02
c0ffffffe445000005009a02
ffffffffffffffc093a80000a0009a40
c0ffffffe445000005009a02
ffffffc093a80000a0009a40
-
{e=>6,a=>32,d=>3,j=>6,l=>7,c=>0,k=>-18,h=>6,b=>2,g=>6,f=>3,i=>-4}
20000000c23c0300a601ee07
2000000000000000c23c0300a601ee07
2000000000000000c23c0300a601ee07
0000002041e78000d300eee0
20000000c23c0300a601ee07
20000000c23c0300a601ee07
000000000000002041e78000d300eee0
20000000c23c0300a601ee07
0000002041e78000d300eee0
-
{e=>4,a=>12,d=>0,j=>4,l=>0,c=>1,k=>-60,h=>6,b=>2,g=>0,f=>3,i=>-4}
0c0000000a3800002601c400
0c000000000000000a3800002601c400
0c000000000000000a3800002601c400
0000000c44460000d200c400
0c0000000a3800002601c400
0c0000000a3800002601c400
000000000000000c44460000d200c400
0c0000000a3800002601c400
0000000c44460000d200c400
-
{e=>1,a=>126,d=>-3,j=>3,l=>3,c=>-2,k=>127,h=>6,b=>2,g=>7,f=>3,i=>-2}
7e00000072b30300f6007f03
7e0000000000000072b30300f6007f03
7e0000000000000072b30300f6007f03
0000007e5a97c000d9807f60
7e00000072b30300f6007f03
7e00000072b30300f6007f03
000000000000007e5a97c000d9807f60
7e00000072b30300f6007f03
0000007e5a97c000d9807f60
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>7,a=>41,m=>-2,d=>-2,j=>7,l=>3,c=>-2,k=>100,h=>7,b=>4,g=>4,f=>3,i=>2}
29000000b43f0200d7016433
2900000000000000b43f0200d7016433
2900000000000000b43f0200d7016433
000000299b770000eb806478
29000000b43f0200d7016433
29000000b43f0200d7016433
00000000000000299b770000eb806478
29000000b43f0200d7016433
000000299b770000eb806478
-
{e=>0,a=>-34,m=>-1,d=>-1,j=>1,l=>4,c=>-4,k=>120,h=>0,b=>4,g=>1,f=>0,i=>1}
deffffffe48100004800783c
deffffffffffffffe48100004800783c
deffffffffffffffe48100004800783c
ffffffde938040000480789c
deffffffe48100004800783c
deffffffe48100004800783c
ffffffffffffffde938040000480789c
deffffffe48100004800783c
ffffffde938040000480789c
-
{e=>6,a=>29,m=>1,d=>-2,j=>2,l=>1,c=>-2,k=>-104,h=>4,b=>7,g=>2,f=>0,i=>-1}
1d000000b70d0100bc009809
1d00000000000000b70d0100bc009809
1d00000000000000b70d0100bc009809
0000001dfb6080009d009824
1d000000b70d0100bc009809
1d000000b70d0100bc009809
000000000000001dfb6080009d009824
1d000000b70d0100bc009809
0000001dfb6080009d009824
-
{e=>5,a=>-81,m=>3,d=>3,j=>2,l=>6,c=>-2,k=>-76,h=>3,b=>4,g=>4,f=>-1,i=>-3}
affffffff47a0200ab00b41e
affffffffffffffff47a0200ab00b41e
affffffffffffffff47a0200ab00b41e
ffffffaf99df00007500b4cc
affffffff47a0200ab00b41e
affffffff47a0200ab00b41e
ffffffffffffffaf99df00007500b4cc
affffffff47a0200ab00b41e
ffffffaf99df00007500b4cc
-
{e=>3,a=>-14,m=>2,d=>-1,j=>5,l=>2,c=>3,k=>77,h=>2,b=>0,g=>7,f=>0,i=>1}
f2ffffffd88703004a014d12
f2ffffffffffffffd88703004a014d12
f2ffffffffffffffd88703004a014d12
fffffff20fb1c00046804d48
f2ffffffd88703004a014d12
f2ffffffd88703004a014d12
fffffffffffffff20fb1c00046804d48
f2ffffffd88703004a014d12
fffffff20fb1c00046804d48
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>0,n=>2,a=>99,m=>-3,d=>-4,j=>1,l=>6,c=>-3,k=>5,h=>5,b=>2,g=>5,f=>3,i=>0}
630000002ab102004500052e02000000
63000000000000002ab102004500052e0200000000000000
63000000000000002ab102004500052e0200000000000000
0000006356074000a08005d440000000
630000002ab102004500052e02000000
630000002ab102004500052e02000000
000000000000006356074000a08005d44000000000000000
630000002ab102004500052e02000000
0000006356074000a08005d440000000
-
{e=>7,n=>4,a=>56,m=>-1,d=>0,j=>4,l=>6,c=>3,k=>123,h=>3,b=>0,g=>0,f=>-1,i=>1}
38000000187e00000b017b3e04000000
3800000000000000187e00000b017b3e0400000000000000
3800000000000000187e00000b017b3e0400000000000000
000000380c7e000066007bdc80000000
38000000187e00000b017b3e04000000
38000000187e00000b017b3e04000000
00000000000000380c7e000066007bdc8000000000000000
38000000187e00000b017b3e04000000
000000380c7e000066007bdc80000000
-
{e=>1,n=>0,a=>-72,m=>-1,d=>1,j=>2,l=>5,c=>-2,k=>29,h=>1,b=>1,g=>1,f=>2,i=>-3}
b8ffffff71a20000a9001d3d00000000
b8ffffffffffffff71a20000a9001d3d0000000000000000
b8ffffffffffffff71a20000a9001d3d0000000000000000
ffffffb83894400035001dbc00000000
b8ffffff71a20000a9001d3d00000000
b8ffffff71a20000a9001d3d00000000
ffffffffffffffb83894400035001dbc0000000000000000
b8ffffff71a20000a9001d3d00000000
ffffffb83894400035001dbc00000000
-
{e=>6,n=>5,a=>-35,m=>-3,d=>-2,j=>5,l=>6,c=>-1,k=>87,h=>4,b=>7,g=>0,f=>1,i=>-1}
ddffffffbf1d00007c01572e05000000
ddffffffffffffffbf1d00007c01572e0500000000000000
ddffffffffffffffbf1d00007c01572e0500000000000000
ffffffddff6200009e8057d4a0000000
ddffffffbf1d00007c01572e05000000
ddffffffbf1d00007c01572e05000000
ffffffffffffffddff6200009e8057d4a000000000000000
ddffffffbf1d00007c01572e05000000
ffffffddff6200009e8057d4a0000000
-
{e=>0,n=>1,a=>-32,m=>-1,d=>0,j=>6,l=>3,c=>1,k=>-26,h=>3,b=>1,g=>4,f=>-1,i=>3}
e0ffffff097002009b01e63b01000000
e0ffffffffffffff097002009b01e63b0100000000000000
e0ffffffffffffff097002009b01e63b0100000000000000
ffffffe0240f00006f00e67c20000000
e0ffffff097002009b01e63b01000000
e0ffffff097002009b01e63b01000000
ffffffffffffffe0240f00006f00e67c2000000000000000
e0ffffff097002009b01e63b01000000
ffffffe0240f00006f00e67c20000000
=
typedef int foo;

struct mixed_no_pack {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>4,n=>5,a=>-63,m=>0,d=>-4,j=>0,l=>3,c=>2,k=>0,h=>4,b=>6,g=>3,f=>0,o=>255,i=>1}
c1ffffff168901000c00000305ff0000
c1ffffffffffffff168901000c00000305ff000000000000
c1ffffffffffffff168901000c00000305ff000000000000
ffffffc1ca40c00084000060a0ff0000
c1ffffff168901000c00000305ff0000
c1ffffff168901000c00000305ff0000
ffffffffffffffc1ca40c00084000060a0ff000000000000
c1ffffff168901000c00000305ff0000
ffffffc1ca40c00084000060a0ff0000
-
{e=>4,n=>4,a=>-45,m=>-1,d=>-3,j=>5,l=>4,c=>-3,k=>-116,h=>7,b=>7,g=>0,f=>1,o=>47,i=>3}
d3ffffff6f1900005f018c3c042f0000
d3ffffffffffffff6f1900005f018c3c042f000000000000
d3ffffffffffffff6f1900005f018c3c042f000000000000
ffffffd3f6c20000ee808c9c802f0000
d3ffffff6f1900005f018c3c042f0000
d3ffffff6f1900005f018c3c042f0000
ffffffffffffffd3f6c20000ee808c9c802f000000000000
d3ffffff6f1900005f018c3c042f0000
ffffffd3f6c20000ee808c9c802f0000
-
{e=>2,n=>7,a=>37,m=>3,d=>2,j=>5,l=>5,c=>-2,k=>86,h=>3,b=>7,g=>5,f=>-2,o=>120,i=>-2}
25000000b7e402007301561d07780000
2500000000000000b7e402007301561d0778000000000000
2500000000000000b7e402007301561d0778000000000000
00000025f92d40007a8056ace0780000
25000000b7e402007301561d07780000
25000000b7e402007301561d07780000
0000000000000025f92d40007a8056ace078000000000000
25000000b7e402007301561d07780000
00000025f92d40007a8056ace0780000
-
{e=>7,n=>3,a=>-38,m=>-4,d=>0,j=>4,l=>5,c=>0,k=>30,h=>7,b=>7,g=>0,f=>3,o=>182,i=>-2}
daffffff073e000037011e2503b60000
daffffffffffffff073e000037011e2503b6000000000000
daffffffffffffff073e000037011e2503b6000000000000
ffffffdae0760000fa001eb060b60000
daffffff073e000037011e2503b60000
daffffff073e000037011e2503b60000
ffffffffffffffdae0760000fa001eb060b6000000000000
daffffff073e000037011e2503b60000
ffffffdae0760000fa001eb060b60000
-
{e=>4,n=>1,a=>-127,m=>0,d=>-4,j=>1,l=>7,c=>0,k=>-88,h=>1,b=>4,g=>3,f=>-2,o=>194,i=>-2}
81ffffff04e901007100a80701c20000
81ffffffffffffff04e901007100a80701c2000000000000
81ffffffffffffff04e901007100a80701c2000000000000
ffffff81824cc0003880a8e020c20000
81ffffff04e901007100a80701c20000
81ffffff04e901007100a80701c20000
ffffffffffffff81824cc0003880a8e020c2000000000000
81ffffff04e901007100a80701c20000
ffffff81824cc0003880a8e020c20000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
};
-
{a=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
-
{a=>5}
05000000
05000000
05000000
a0000000
05000000
05000000
a0000000
05000000
a0000000
-
{a=>5}
05000000
05000000
05000000
a0000000
05000000
05000000
a0000000
05000000
a0000000
-
{a=>4}
04000000
04000000
04000000
80000000
04000000
04000000
80000000
04000000
80000000
-
{a=>1}
01000000
01000000
01000000
20000000
01000000
01000000
20000000
01000000
20000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
};
-
{a=>0,b=>-1}
38000000
38000000
38000000
1c000000
38000000
38000000
1c000000
38000000
1c000000
-
{a=>0,b=>2}
10000000
10000000
10000000
08000000
10000000
10000000
08000000
10000000
08000000
-
{a=>1,b=>0}
01000000
01000000
01000000
20000000
01000000
01000000
20000000
01000000
20000000
-
{a=>0,b=>3}
18000000
18000000
18000000
0c000000
18000000
18000000
0c000000
18000000
0c000000
-
{a=>5,b=>-1}
3d000000
3d000000
3d000000
bc000000
3d000000
3d000000
bc000000
3d000000
bc000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
};
-
{c=>3,a=>0,b=>-3}
e8000000
e8000000
e8000000
15800000
e8000000
e8000000
15800000
e8000000
15800000
-
{c=>3,a=>7,b=>-4}
e7000000
e7000000
e7000000
f1800000
e7000000
e7000000
f1800000
e7000000
f1800000
-
{c=>2,a=>3,b=>3}
9b000000
9b000000
9b000000
6d000000
9b000000
9b000000
6d000000
9b000000
6d000000
-
{c=>0,a=>3,b=>-3}
2b000000
2b000000
2b000000
74000000
2b000000
2b000000
74000000
2b000000
74000000
-
{c=>-1,a=>3,b=>2}
d3010000
d3010000
d3010000
6b800000
d3010000
d3010000
6b800000
d3010000
6b800000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
};
-
{c=>3,a=>7,b=>-4,d=>7}
e70e0000
e70e0000
e70e0000
f1f00000
e70e0000
e70e0000
f1f00000
e70e0000
f1f00000
-
{c=>1,a=>2,b=>1,d=>0}
4a000000
4a000000
4a000000
44800000
4a000000
4a000000
44800000
4a000000
44800000
-
{c=>-1,a=>1,b=>-4,d=>5}
e10b0000
e10b0000
e10b0000
33d00000
e10b0000
e10b0000
33d00000
e10b0000
33d00000
-
{c=>3,a=>6,b=>-1,d=>0}
fe000000
fe000000
fe000000
dd800000
fe000000
fe000000
dd800000
fe000000
dd800000
-
{c=>1,a=>4,b=>-2,d=>0}
74000000
74000000
74000000
98800000
74000000
74000000
98800000
74000000
98800000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
};
-
{e=>2,c=>-2,a=>3,b=>-2,d=>6}
b32d0000
b32d0000
b32d0000
7b640000
b32d0000
b32d0000
7b640000
b32d0000
7b640000
-
{e=>-2,c=>-1,a=>3,b=>-3,d=>2}
eb650000
eb650000
eb650000
77ac0000
eb650000
eb650000
77ac0000
eb650000
77ac0000
-
{e=>3,c=>1,a=>7,b=>-1,d=>3}
7f360000
7f360000
7f360000
fcb60000
7f360000
7f360000
fcb60000
7f360000
fcb60000
-
{e=>-4,c=>-2,a=>5,b=>-4,d=>1}
a5430000
a5430000
a5430000
b3180000
a5430000
a5430000
b3180000
a5430000
b3180000
-
{e=>1,c=>-2,a=>4,b=>-2,d=>4}
b4190000
b4190000
b4190000
9b420000
b4190000
b4190000
9b420000
b4190000
9b420000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
};
-
{e=>-3,c=>1,a=>4,b=>-1,d=>2,f=>2}
7c540100
7c540100
7c540100
9caa8000
7c540100
7c540100
9caa8000
7c540100
9caa8000
-
{e=>3,c=>2,a=>5,b=>-1,d=>0,f=>4}
bd300200
bd300200
bd300200
bd070000
bd300200
bd300200
bd070000
bd300200
bd070000
-
{e=>1,c=>-3,a=>3,b=>0,d=>6,f=>6}
431d0300
431d0300
431d0300
62e38000
431d0300
431d0300
62e38000
431d0300
62e38000
-
{e=>2,c=>0,a=>1,b=>-3,d=>1,f=>6}
29220300
29220300
29220300
34158000
29220300
29220300
34158000
29220300
34158000
-
{e=>2,c=>1,a=>4,b=>3,d=>0,f=>4}
5c200200
5c200200
5c200200
8c850000
5c200200
5c200200
8c850000
5c200200
8c850000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
};
-
{e=>-4,c=>0,a=>2,b=>2,d=>2,f=>3}
12c40100
12c40100
12c40100
4828c000
12c40100
12c40100
4828c000
12c40100
4828c000
-
{e=>2,c=>-4,a=>0,b=>2,d=>4,f=>2}
10290100
10290100
10290100
0a448000
10290100
10290100
0a448000
10290100
0a448000
-
{e=>-2,c=>-4,a=>4,b=>0,d=>3,f=>0}
04670000
04670000
04670000
823c0000
04670000
04670000
823c0000
04670000
823c0000
-
{e=>-1,c=>1,a=>2,b=>3,d=>7,f=>0}
5a7e0000
5a7e0000
5a7e0000
4cfe0000
5a7e0000
5a7e0000
4cfe0000
5a7e0000
4cfe0000
-
{e=>0,c=>-1,a=>1,b=>-3,d=>0,f=>5}
e9810200
e9810200
e9810200
37814000
e9810200
e9810200
37814000
e9810200
37814000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
};
-
{e=>3,c=>1,a=>1,g=>6,b=>0,d=>5,f=>2}
413a010006000000
413a010006000000
413a010006000000
20d68000c0000000
413a010006000000
413a010006000000
20d68000c0000000
413a010006000000
20d68000c0000000
-
{e=>-2,c=>-2,a=>3,g=>0,b=>3,d=>0,f=>7}
9be1030000000000
9be1030000000000
9be1030000000000
6f0dc00000000000
9be1030000000000
9be1030000000000
6f0dc00000000000
9be1030000000000
6f0dc00000000000
-
{e=>-2,c=>-4,a=>6,g=>3,b=>-4,d=>6,f=>3}
26ed010003000000
26ed010003000000
26ed010003000000
d26cc00060000000
26ed010003000000
26ed010003000000
d26cc00060000000
26ed010003000000
d26cc00060000000
-
{e=>-2,c=>1,a=>7,g=>4,b=>3,d=>7,f=>3}
5fee010004000000
5fee010004000000
5fee010004000000
ecfcc00080000000
5fee010004000000
5fee010004000000
ecfcc00080000000
5fee010004000000
ecfcc00080000000
-
{e=>-2,c=>-3,a=>0,g=>1,b=>-3,d=>7,f=>5}
68ef020001000000
68ef020001000000
68ef020001000000
16fd400020000000
68ef020001000000
68ef020001000000
16fd400020000000
68ef020001000000
16fd400020000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
};
-
{e=>-2,a=>2,d=>0,c=>-4,h=>1,b=>-4,g=>0,f=>0}
2261000008000000
2261000008000000
2261000008000000
520c000004000000
2261000008000000
2261000008000000
520c000004000000
2261000008000000
520c000004000000
-
{e=>-1,a=>0,d=>5,c=>-2,h=>-3,b=>2,g=>2,f=>7}
90fb03002a000000
90fb03002a000000
90fb03002a000000
0b5fc00054000000
90fb03002a000000
90fb03002a000000
0b5fc00054000000
90fb03002a000000
0b5fc00054000000
-
{e=>3,a=>4,d=>0,c=>2,h=>-3,b=>3,g=>2,f=>7}
9cb003002a000000
9cb003002a000000
9cb003002a000000
8d07c00054000000
9cb003002a000000
9cb003002a000000
8d07c00054000000
9cb003002a000000
8d07c00054000000
-
{e=>2,a=>7,d=>5,c=>2,h=>1,b=>0,g=>0,f=>2}
872a010008000000
872a010008000000
872a010008000000
e154800004000000
872a010008000000
872a010008000000
e154800004000000
872a010008000000
e154800004000000
-
{e=>-3,a=>3,d=>6,c=>2,h=>0,b=>-1,g=>7,f=>4}
bb5c020007000000
bb5c020007000000
bb5c020007000000
7d6b0000e0000000
bb5c020007000000
bb5c020007000000
7d6b0000e0000000
bb5c020007000000
7d6b0000e0000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
};
-
{e=>2,a=>3,d=>4,c=>1,h=>-4,b=>-1,g=>4,f=>2,i=>7}
7b280100e4010000
7b280100e4010000
7b280100e4010000
7cc4800093800000
7b280100e4010000
7b280100e4010000
7cc4800093800000
7b280100e4010000
7cc4800093800000
-
{e=>2,a=>7,d=>2,c=>-3,h=>2,b=>-1,g=>6,f=>7,i=>5}
7fa5030056010000
7fa5030056010000
7fa5030056010000
fea5c000ca800000
7fa5030056010000
7fa5030056010000
fea5c000ca800000
7fa5030056010000
fea5c000ca800000
-
{e=>2,a=>2,d=>5,c=>-2,h=>0,b=>-1,g=>0,f=>6,i=>7}
ba2b0300c0010000
ba2b0300c0010000
ba2b0300c0010000
5f55800003800000
ba2b0300c0010000
ba2b0300c0010000
5f55800003800000
ba2b0300c0010000
5f55800003800000
-
{e=>-4,a=>0,d=>7,c=>0,h=>1,b=>3,g=>6,f=>0,i=>2}
184e00008e000000
184e00008e000000
184e00008e000000
0c780000c5000000
184e00008e000000
184e00008e000000
0c780000c5000000
184e00008e000000
0c780000c5000000
-
{e=>0,a=>4,d=>3,c=>-1,h=>-4,b=>-4,g=>3,f=>6,i=>7}
e4070300e3010000
e4070300e3010000
e4070300e3010000
93b1800073800000
e4070300e3010000
e4070300e3010000
93b1800073800000
e4070300e3010000
93b1800073800000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
};
-
{e=>-3,a=>2,d=>5,j=>51,c=>-3,h=>-4,b=>-1,g=>5,f=>7,i=>4}
7adb030025013300
7adb030025013300
7adb030025013300
5edbc000b2003300
7adb030025013300
7adb030025013300
5edbc000b2003300
7adb030025013300
5edbc000b2003300
-
{e=>2,a=>5,d=>0,j=>-45,c=>-2,h=>2,b=>-1,g=>6,f=>3,i=>2}
bda101009600d300
bda101009600d300
bda101009600d300
bf04c000c900d300
bda101009600d300
bda101009600d300
bf04c000c900d300
bda101009600d300
bf04c000c900d300
-
{e=>-1,a=>3,d=>4,j=>-26,c=>2,h=>3,b=>0,g=>1,f=>5,i=>0}
83f802001900e600
83f802001900e600
83f802001900e600
614f40002c00e600
83f802001900e600
83f802001900e600
614f40002c00e600
83f802001900e600
614f40002c00e600
-
{e=>1,a=>4,d=>0,j=>-56,c=>1,h=>3,b=>2,g=>2,f=>3,i=>4}
549001001a01c800
549001001a01c800
549001001a01c800
8882c0004e00c800
549001001a01c800
549001001a01c800
8882c0004e00c800
549001001a01c800
8882c0004e00c800
-
{e=>2,a=>7,d=>4,j=>-122,c=>-4,h=>1,b=>-2,g=>1,f=>4,i=>6}
3729020089018600
3729020089018600
3729020089018600
fa45000027008600
3729020089018600
3729020089018600
fa45000027008600
3729020089018600
fa45000027008600
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
  unsigned char k:3;
};
-
{e=>3,a=>6,d=>7,j=>112,c=>0,k=>2,h=>-4,b=>-3,g=>3,f=>7,i=>5}
2ebe030063017002
2ebe030063017002
2ebe030063017002
d477c00072807040
2ebe030063017002
2ebe030063017002
d477c00072807040
2ebe030063017002
d477c00072807040
-
{e=>-3,a=>1,d=>7,j=>-86,c=>3,k=>2,h=>3,b=>-4,g=>7,f=>0,i=>3}
e15e0000df00aa02
e15e0000df00aa02
e15e0000df00aa02
31fa0000ed80aa40
e15e0000df00aa02
e15e0000df00aa02
31fa0000ed80aa40
e15e0000df00aa02
31fa0000ed80aa40
-
{e=>-2,a=>0,d=>6,j=>-117,c=>-3,k=>7,h=>0,b=>-1,g=>6,f=>7,i=>2}
78ed030086008b07
78ed030086008b07
78ed030086008b07
1eedc000c1008be0
78ed030086008b07
78ed030086008b07
1eedc000c1008be0
78ed030086008b07
1eedc000c1008be0
-
{e=>1,a=>5,d=>5,j=>-119,c=>-2,k=>6,h=>1,b=>2,g=>3,f=>2,i=>0}
951b01000b008906
951b01000b008906
951b01000b008906
ab528000640089c0
951b01000b008906
951b01000b008906
ab528000640089c0
951b01000b008906
ab528000640089c0
-
{e=>3,a=>6,d=>6,j=>-128,c=>-2,k=>0,h=>2,b=>-4,g=>3,f=>3,i=>5}
a6bd010053018000
a6bd010053018000
a6bd010053018000
d366c0006a808000
a6bd010053018000
a6bd010053018000
d366c0006a808000
a6bd010053018000
d366c0006a808000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
};
-
{e=>-1,a=>1,d=>3,j=>90,l=>-1,c=>2,k=>4,h=>0,b=>-2,g=>5,f=>4,i=>3}
b1760200c5005a3c
b1760200c5005a3c
b1760200c5005a3c
393f0000a1805a9c
b1760200c5005a3c
b1760200c5005a3c
393f0000a1805a9c
b1760200c5005a3c
393f0000a1805a9c
-
{e=>3,a=>0,d=>3,j=>27,l=>-2,c=>-3,k=>5,h=>0,b=>-1,g=>2,f=>1,i=>5}
78b7000042011b35
78b7000042011b35
78b7000042011b35
1eb6400042801bb8
78b7000042011b35
78b7000042011b35
1eb6400042801bb8
78b7000042011b35
1eb6400042801bb8
-
{e=>1,a=>1,d=>3,j=>-13,l=>-4,c=>-3,k=>5,h=>2,b=>-2,g=>6,f=>1,i=>1}
719700005600f325
719700005600f325
719700005600f325
3ab24000c880f3b0
719700005600f325
719700005600f325
3ab24000c880f3b0
719700005600f325
3ab24000c880f3b0
-
{e=>2,a=>3,d=>7,j=>-47,l=>-2,c=>-3,k=>1,h=>3,b=>-3,g=>6,f=>3,i=>6}
6baf01009e01d131
6baf01009e01d131
6baf01009e01d131
76f4c000cf00d138
6baf01009e01d131
6baf01009e01d131
76f4c000cf00d138
6baf01009e01d131
76f4c000cf00d138
-
{e=>1,a=>3,d=>4,j=>20,l=>2,c=>-4,k=>3,h=>-3,b=>2,g=>4,f=>0,i=>4}
131900002c011413
131900002c011413
131900002c011413
6a42000096001468
131900002c011413
131900002c011413
6a42000096001468
131900002c011413
6a42000096001468
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
  unsigned int  m:3;
};
-
{e=>-2,a=>2,m=>1,d=>3,j=>66,l=>2,c=>1,k=>7,h=>0,b=>3,g=>3,f=>3,i=>4}
5ae601000301421701000000
5ae601000301421701000000
5ae601000301421701000000
4cbcc000620042e820000000
5ae601000301421701000000
5ae601000301421701000000
4cbcc000620042e820000000
5ae601000301421701000000
4cbcc000620042e820000000
-
{e=>3,a=>7,m=>5,d=>2,j=>87,l=>-2,c=>-4,k=>4,h=>0,b=>1,g=>4,f=>1,i=>1}
0fb500004400573405000000
0fb500004400573405000000
0fb500004400573405000000
e626400080805798a0000000
0fb500004400573405000000
0fb500004400573405000000
e626400080805798a0000000
0fb500004400573405000000
e626400080805798a0000000
-
{e=>0,a=>3,m=>7,d=>4,j=>2,l=>-3,c=>2,k=>7,h=>-4,b=>-2,g=>0,f=>4,i=>1}
b30802006000022f07000000
b30802006000022f07000000
b30802006000022f07000000
79410000108002f4e0000000
b30802006000022f07000000
b30802006000022f07000000
79410000108002f4e0000000
b30802006000022f07000000
79410000108002f4e0000000
-
{e=>0,a=>6,m=>1,d=>0,j=>-127,l=>0,c=>0,k=>2,h=>-3,b=>-2,g=>3,f=>2,i=>1}
360001006b00810201000000
360001006b00810201000000
360001006b00810201000000
d80080007480814020000000
360001006b00810201000000
360001006b00810201000000
d80080007480814020000000
360001006b00810201000000
d80080007480814020000000
-
{e=>-1,a=>4,m=>4,d=>0,j=>-10,l=>-3,c=>0,k=>4,h=>-4,b=>1,g=>6,f=>3,i=>0}
0cf001002600f62c04000000
0cf001002600f62c04000000
0cf001002600f62c04000000
840ec000d000f69480000000
0cf001002600f62c04000000
0cf001002600f62c04000000
840ec000d000f69480000000
0cf001002600f62c04000000
840ec000d000f69480000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
  unsigned int  m:3;
  unsigned char n;
};
-
{e=>-3,n=>71,a=>1,m=>5,d=>3,j=>-14,l=>-1,c=>0,k=>5,h=>-3,b=>0,g=>0,f=>5,i=>5}
01d602006801f23d05470000
01d602006801f23d05470000
01d602006801f23d05470000
203b40001680f2bca0470000
01d602006801f23d05470000
01d602006801f23d05470000
203b40001680f2bca0470000
01d602006801f23d05470000
203b40001680f2bca0470000
-
{e=>1,n=>212,a=>5,m=>3,d=>1,j=>-32,l=>3,c=>-2,k=>5,h=>-2,b=>-3,g=>4,f=>0,i=>4}
ad1300003401e01d03d40000
ad1300003401e01d03d40000
ad1300003401e01d03d40000
b71200009a00e0ac60d40000
ad1300003401e01d03d40000
ad1300003401e01d03d40000
b71200009a00e0ac60d40000
ad1300003401e01d03d40000
b71200009a00e0ac60d40000
-
{e=>-1,n=>32,a=>4,m=>3,d=>1,j=>-40,l=>-2,c=>-1,k=>3,h=>-1,b=>2,g=>0,f=>5,i=>5}
d4f302007801d83303200000
d4f302007801d83303200000
d4f302007801d83303200000
8b9f40001e80d87860200000
d4f302007801d83303200000
d4f302007801d83303200000
8b9f40001e80d87860200000
d4f302007801d83303200000
8b9f40001e80d87860200000
-
{e=>-1,n=>95,a=>2,m=>6,d=>6,j=>-84,l=>0,c=>2,k=>0,h=>2,b=>-3,g=>2,f=>3,i=>2}
aafc01009200ac00065f0000
aafc01009200ac00065f0000
aafc01009200ac00065f0000
556ec0004900ac00c05f0000
aafc01009200ac00065f0000
aafc01009200ac00065f0000
556ec0004900ac00c05f0000
aafc01009200ac00065f0000
556ec0004900ac00c05f0000
-
{e=>0,n=>37,a=>4,m=>6,d=>1,j=>46,l=>2,c=>-3,k=>7,h=>0,b=>3,g=>0,f=>7,i=>0}
5c83030000002e1706250000
5c83030000002e1706250000
5c83030000002e1706250000
8e91c00000002ee8c0250000
5c83030000002e1706250000
5c83030000002e1706250000
8e91c00000002ee8c0250000
5c83030000002e1706250000
8e91c00000002ee8c0250000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
};
-
{a=>106,b=>0}
6a000000
6a000000
6a000000
6a000000
6a000000
6a000000
6a000000
6a000000
6a000000
-
{a=>-10,b=>0}
f6000000
f6000000
f6000000
f6000000
f6000000
f6000000
f6000000
f6000000
f6000000
-
{a=>12,b=>6}
0c060000
0c060000
0c060000
0cc00000
0c060000
0c060000
0cc00000
0c060000
0cc00000
-
{a=>-86,b=>1}
aa010000
aa010000
aa010000
aa200000
aa010000
aa010000
aa200000
aa010000
aa200000
-
{a=>-33,b=>2}
df020000
df020000
df020000
df400000
df020000
df020000
df400000
df020000
df400000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>-3,a=>-108,b=>2}
942a0000
942a0000
942a0000
94540000
942a0000
942a0000
94540000
942a0000
94540000
-
{c=>1,a=>96,b=>5}
600d0000
600d0000
600d0000
60a40000
600d0000
600d0000
60a40000
600d0000
60a40000
-
{c=>3,a=>-121,b=>6}
871e0000
871e0000
871e0000
87cc0000
871e0000
871e0000
87cc0000
871e0000
87cc0000
-
{c=>-1,a=>-58,b=>1}
c6390000
c6390000
c6390000
c63c0000
c6390000
c6390000
c63c0000
c6390000
c63c0000
-
{c=>2,a=>62,b=>2}
3e120000
3e120000
3e120000
3e480000
3e120000
3e120000
3e480000
3e120000
3e480000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>-4,a=>40,b=>3,d=>-2}
28a30100
28a30100
28a30100
28730000
28a30100
28a30100
28730000
28a30100
28730000
-
{c=>-3,a=>68,b=>4,d=>-3}
446c0100
446c0100
446c0100
44968000
446c0100
446c0100
44968000
446c0100
44968000
-
{c=>-3,a=>21,b=>0,d=>3}
15e80000
15e80000
15e80000
15158000
15e80000
15e80000
15158000
15e80000
15158000
-
{c=>-3,a=>-98,b=>2,d=>-1}
9eea0100
9eea0100
9eea0100
9e578000
9eea0100
9eea0100
9e578000
9eea0100
9e578000
-
{c=>-3,a=>74,b=>7,d=>1}
4a6f0000
4a6f0000
4a6f0000
4af48000
4a6f0000
4a6f0000
4af48000
4a6f0000
4af48000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>3,c=>-2,a=>4,b=>0,d=>-4}
04300700
04300700
04300700
041a3000
04300700
04300700
041a3000
04300700
041a3000
-
{e=>4,c=>-1,a=>44,b=>0,d=>2}
2cb80800
2cb80800
2cb80800
2c1d4000
2cb80800
2cb80800
2c1d4000
2cb80800
2c1d4000
-
{e=>7,c=>-1,a=>-108,b=>5,d=>-2}
94bd0f00
94bd0f00
94bd0f00
94bf7000
94bd0f00
94bd0f00
94bf7000
94bd0f00
94bf7000
-
{e=>3,c=>2,a=>-123,b=>0,d=>3}
85d00600
85d00600
85d00600
8509b000
85d00600
85d00600
8509b000
85d00600
8509b000
-
{e=>3,c=>0,a=>-85,b=>5,d=>0}
ab050600
ab050600
ab050600
aba03000
ab050600
ab050600
aba03000
ab050600
aba03000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
};
-
{e=>2,c=>-3,a=>-86,b=>1,d=>-3,f=>3}
aa693500
aa693500
aa693500
aa36a600
aa693500
aa693500
aa36a600
aa693500
aa36a600
-
{e=>4,c=>1,a=>-10,b=>0,d=>0,f=>3}
f6083800
f6083800
f6083800
f6044600
f6083800
f6083800
f6044600
f6083800
f6044600
-
{e=>7,c=>-2,a=>18,b=>2,d=>-2,f=>-1}
12b27f00
12b27f00
12b27f00
125b7e00
12b27f00
12b27f00
125b7e00
12b27f00
125b7e00
-
{e=>2,c=>3,a=>-8,b=>5,d=>1,f=>2}
f85d2400
f85d2400
f85d2400
f8aca400
f85d2400
f85d2400
f8aca400
f85d2400
f8aca400
-
{e=>1,c=>0,a=>-98,b=>0,d=>1,f=>0}
9e400200
9e400200
9e400200
9e009000
9e400200
9e400200
9e009000
9e400200
9e009000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
};
-
{e=>3,c=>1,a=>126,g=>5,b=>0,d=>0,f=>3}
7e08b602
7e08b602
7e08b602
7e043740
7e08b602
7e08b602
7e043740
7e08b602
7e043740
-
{e=>0,c=>-4,a=>-72,g=>4,b=>2,d=>-1,f=>2}
b8e22102
b8e22102
b8e22102
b8538500
b8e22102
b8e22102
b8538500
b8e22102
b8538500
-
{e=>4,c=>-2,a=>-68,g=>1,b=>6,d=>3,f=>3}
bcf6b800
bcf6b800
bcf6b800
bcd9c640
bcf6b800
bcf6b800
bcd9c640
bcf6b800
bcd9c640
-
{e=>1,c=>-2,a=>34,g=>4,b=>7,d=>-4,f=>-4}
22374302
22374302
22374302
22fa1900
22374302
22374302
22fa1900
22374302
22fa1900
-
{e=>2,c=>3,a=>13,g=>1,b=>3,d=>2,f=>-3}
0d9bd400
0d9bd400
0d9bd400
0d6d2a40
0d9bd400
0d9bd400
0d6d2a40
0d9bd400
0d6d2a40
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>6,c=>2,a=>-126,g=>7,b=>4,d=>-3,f=>2}
8254ad03
8254ad03
8254ad03
828ae5c0
8254ad03
8254ad03
828ae5c0
8254ad03
828ae5c0
-
{e=>7,c=>-3,a=>-72,g=>3,b=>6,d=>-4,f=>-3}
b82edf01
b82edf01
b82edf01
b8d67ac0
b82edf01
b82edf01
b8d67ac0
b82edf01
b8d67ac0
-
{e=>6,c=>-3,a=>67,g=>7,b=>6,d=>-1,f=>-4}
43eecd03
43eecd03
43eecd03
43d7e9c0
43eecd03
43eecd03
43d7e9c0
43eecd03
43d7e9c0
-
{e=>4,c=>-2,a=>-37,g=>6,b=>2,d=>3,f=>3}
dbf23803
dbf23803
dbf23803
db59c780
dbf23803
dbf23803
db59c780
dbf23803
db59c780
-
{e=>4,c=>3,a=>23,g=>7,b=>1,d=>2,f=>2}
1799a803
1799a803
1799a803
172d45c0
1799a803
1799a803
172d45c0
1799a803
172d45c0
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>3,a=>106,d=>0,c=>1,h=>0,b=>6,g=>3,f=>3}
6a0eb60100000000
6a0eb60100000000
6a0eb60100000000
6ac436c000000000
6a0eb60100000000
6a0eb60100000000
6ac436c000000000
6a0eb60100000000
6ac436c000000000
-
{e=>0,a=>102,d=>-2,c=>-2,h=>0,b=>5,g=>0,f=>2}
66b5210000000000
66b5210000000000
66b5210000000000
66bb040000000000
66b5210000000000
66b5210000000000
66bb040000000000
66b5210000000000
66bb040000000000
-
{e=>1,a=>-118,d=>2,c=>-3,h=>1,b=>1,g=>6,f=>3}
8aa9320301000000
8aa9320301000000
8aa9320301000000
8a35178020000000
8aa9320301000000
8aa9320301000000
8a35178020000000
8aa9320301000000
8a35178020000000
-
{e=>0,a=>60,d=>-3,c=>2,h=>0,b=>3,g=>0,f=>0}
3c53010000000000
3c53010000000000
3c53010000000000
3c6a800000000000
3c53010000000000
3c53010000000000
3c6a800000000000
3c53010000000000
3c6a800000000000
-
{e=>5,a=>19,d=>-2,c=>3,h=>1,b=>2,g=>4,f=>3}
139a3b0201000000
139a3b0201000000
139a3b0201000000
134f570020000000
139a3b0201000000
139a3b0201000000
134f570020000000
139a3b0201000000
134f570020000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>4,a=>126,d=>2,c=>1,h=>5,b=>4,g=>6,f=>3,i=>-4}
7e8c380325000000
7e8c380325000000
7e8c380325000000
7e854780b0000000
7e8c380325000000
7e8c380325000000
7e854780b0000000
7e8c380325000000
7e854780b0000000
-
{e=>7,a=>-19,d=>0,c=>1,h=>2,b=>3,g=>5,f=>0,i=>-3}
ed0b8e022a000000
ed0b8e022a000000
ed0b8e022a000000
ed64714054000000
ed0b8e022a000000
ed0b8e022a000000
ed64714054000000
ed0b8e022a000000
ed64714054000000
-
{e=>0,a=>122,d=>3,c=>3,h=>2,b=>4,g=>2,f=>-2,i=>2}
7adc600112000000
7adc600112000000
7adc600112000000
7a8d8c8048000000
7adc600112000000
7adc600112000000
7a8d8c8048000000
7adc600112000000
7a8d8c8048000000
-
{e=>2,a=>62,d=>-4,c=>-4,h=>6,b=>3,g=>5,f=>-2,i=>3}
3e23e5021e000000
3e23e5021e000000
3e23e5021e000000
3e722d40cc000000
3e23e5021e000000
3e23e5021e000000
3e722d40cc000000
3e23e5021e000000
3e722d40cc000000
-
{e=>1,a=>64,d=>-3,c=>-4,h=>0,b=>3,g=>1,f=>-4,i=>-4}
4063c30020000000
4063c30020000000
4063c30020000000
4072984010000000
4063c30020000000
4063c30020000000
4072984010000000
4063c30020000000
4072984010000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
};
-
{e=>6,a=>-51,d=>2,j=>2,c=>1,h=>0,b=>4,g=>2,f=>0,i=>-3}
cd8c0c01a8000000
cd8c0c01a8000000
cd8c0c01a8000000
cd85608015000000
cd8c0c01a8000000
cd8c0c01a8000000
cd85608015000000
cd8c0c01a8000000
cd85608015000000
-
{e=>3,a=>36,d=>-4,j=>7,c=>3,h=>7,b=>5,g=>6,f=>0,i=>-2}
241d0703f7010000
241d0703f7010000
241d0703f7010000
24ae3180fb800000
241d0703f7010000
241d0703f7010000
24ae3180fb800000
241d0703f7010000
24ae3180fb800000
-
{e=>3,a=>-65,d=>-2,j=>7,c=>-1,h=>5,b=>0,g=>5,f=>3,i=>-1}
bfb8b702fd010000
bfb8b702fd010000
bfb8b702fd010000
bf1f3740bf800000
bfb8b702fd010000
bfb8b702fd010000
bf1f3740bf800000
bfb8b702fd010000
bf1f3740bf800000
-
{e=>3,a=>-4,d=>2,j=>4,c=>1,h=>1,b=>5,g=>1,f=>-1,i=>1}
fc8df60009010000
fc8df60009010000
fc8df60009010000
fca53e4026000000
fc8df60009010000
fc8df60009010000
fca53e4026000000
fc8df60009010000
fca53e4026000000
-
{e=>5,a=>114,d=>2,j=>0,c=>1,h=>2,b=>7,g=>2,f=>-3,i=>-3}
728f5a012a000000
728f5a012a000000
728f5a012a000000
72e55a8054000000
728f5a012a000000
728f5a012a000000
72e55a8054000000
728f5a012a000000
72e55a8054000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
};
-
{e=>6,a=>66,d=>1,j=>3,c=>3,k=>-88,h=>4,b=>5,g=>0,f=>3,i=>1}
425d3c00cc00a800
425d3c00cc00a800
425d3c00cc00a800
42ace6008580a800
425d3c00cc00a800
425d3c00cc00a800
42ace6008580a800
425d3c00cc00a800
42ace6008580a800
-
{e=>3,a=>-27,d=>3,j=>3,c=>-4,k=>-71,h=>2,b=>6,g=>1,f=>1,i=>-3}
e5e69600ea00b900
e5e69600ea00b900
e5e69600ea00b900
e5d1b2405580b900
e5e69600ea00b900
e5e69600ea00b900
e5d1b2405580b900
e5e69600ea00b900
e5d1b2405580b900
-
{e=>7,a=>-4,d=>-3,j=>1,c=>-3,k=>-71,h=>5,b=>0,g=>3,f=>2,i=>-4}
fc68af016500b900
fc68af016500b900
fc68af016500b900
fc16f4c0b080b900
fc68af016500b900
fc68af016500b900
fc16f4c0b080b900
fc68af016500b900
fc16f4c0b080b900
-
{e=>7,a=>-35,d=>-3,j=>6,c=>2,k=>50,h=>5,b=>5,g=>6,f=>1,i=>2}
dd551f0395013200
dd551f0395013200
dd551f0395013200
ddaaf380ab003200
dd551f0395013200
dd551f0395013200
ddaaf380ab003200
dd551f0395013200
ddaaf380ab003200
-
{e=>5,a=>-47,d=>0,j=>3,c=>3,k=>-120,h=>3,b=>2,g=>7,f=>2,i=>1}
d11aaa03cb008800
d11aaa03cb008800
d11aaa03cb008800
d14c55c065808800
d11aaa03cb008800
d11aaa03cb008800
d14c55c065808800
d11aaa03cb008800
d14c55c065808800
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>2,a=>-32,d=>-4,j=>1,l=>2,c=>-4,k=>-17,h=>5,b=>0,g=>3,f=>1,i=>-3}
e02095016d00ef02
e02095016d00ef02
e02095016d00ef02
e01222c0b480ef40
e02095016d00ef02
e02095016d00ef02
e01222c0b480ef40
e02095016d00ef02
e01222c0b480ef40
-
{e=>7,a=>-51,d=>2,j=>0,l=>7,c=>-1,k=>-66,h=>1,b=>5,g=>3,f=>1,i=>-1}
cdbd9e013900be07
cdbd9e013900be07
cdbd9e013900be07
cdbd72c03c00bee0
cdbd9e013900be07
cdbd9e013900be07
cdbd72c03c00bee0
cdbd9e013900be07
cdbd72c03c00bee0
-
{e=>5,a=>73,d=>2,j=>4,l=>7,c=>-3,k=>-107,h=>4,b=>6,g=>4,f=>-2,i=>-4}
49ae6a0224019507
49ae6a0224019507
49ae6a0224019507
49d55d00920095e0
49ae6a0224019507
49ae6a0224019507
49d55d00920095e0
49ae6a0224019507
49d55d00920095e0
-
{e=>7,a=>-32,d=>0,j=>2,l=>6,c=>1,k=>-119,h=>6,b=>7,g=>0,f=>-4,i=>0}
e00f4e0086008906
e00f4e0086008906
e00f4e0086008906
e0e47800c10089c0
e00f4e0086008906
e00f4e0086008906
e0e47800c10089c0
e00f4e0086008906
e0e47800c10089c0
-
{e=>7,a=>70,d=>1,j=>3,l=>0,c=>2,k=>-78,h=>4,b=>1,g=>4,f=>3,i=>-1}
46513e02fc00b200
46513e02fc00b200
46513e02fc00b200
4628f7009d80b200
46513e02fc00b200
46513e02fc00b200
4628f7009d80b200
46513e02fc00b200
4628f7009d80b200
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>5,a=>82,m=>1,d=>-4,j=>4,l=>4,c=>2,k=>75,h=>1,b=>7,g=>3,f=>-2,i=>2}
5217eb0111014b0c
5217eb0111014b0c
5217eb0111014b0c
52ea5cc02a004b84
5217eb0111014b0c
5217eb0111014b0c
52ea5cc02a004b84
5217eb0111014b0c
52ea5cc02a004b84
-
{e=>1,a=>65,m=>0,d=>-2,j=>6,l=>6,c=>1,k=>10,h=>7,b=>6,g=>6,f=>1,i=>3}
418e13039f010a06
418e13039f010a06
418e13039f010a06
41c71380ef000ac0
418e13039f010a06
418e13039f010a06
41c71380ef000ac0
418e13039f010a06
41c71380ef000ac0
-
{e=>1,a=>50,m=>0,d=>-1,j=>4,l=>1,c=>3,k=>-39,h=>4,b=>5,g=>1,f=>3,i=>2}
32ddb3001401d901
32ddb3001401d901
32ddb3001401d901
32af96408a00d920
32ddb3001401d901
32ddb3001401d901
32af96408a00d920
32ddb3001401d901
32af96408a00d920
-
{e=>1,a=>-30,m=>-3,d=>-3,j=>4,l=>3,c=>0,k=>-58,h=>2,b=>2,g=>4,f=>-3,i=>-1}
e24253023a01c62b
e24253023a01c62b
e24253023a01c62b
e2429b005e00c674
e24253023a01c62b
e24253023a01c62b
e2429b005e00c674
e24253023a01c62b
e2429b005e00c674
-
{e=>6,a=>-8,m=>-1,d=>-4,j=>1,l=>7,c=>1,k=>-96,h=>4,b=>1,g=>2,f=>-4,i=>3}
f8094d015c00a03f
f8094d015c00a03f
f8094d015c00a03f
f82668808c80a0fc
f8094d015c00a03f
f8094d015c00a03f
f82668808c80a0fc
f8094d015c00a03f
f82668808c80a0fc
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>6,n=>7,a=>127,m=>-3,d=>2,j=>1,l=>4,c=>3,k=>113,h=>7,b=>0,g=>3,f=>-2,i=>1}
7f98ec014f00712c07000000
7f98ec014f00712c07000000
7f98ec014f00712c07000000
7f0d6cc0e4807194e0000000
7f98ec014f00712c07000000
7f98ec014f00712c07000000
7f0d6cc0e4807194e0000000
7f98ec014f00712c07000000
7f0d6cc0e4807194e0000000
-
{e=>4,n=>0,a=>91,m=>2,d=>-1,j=>4,l=>6,c=>0,k=>7,h=>3,b=>0,g=>3,f=>2,i=>2}
5bc0a9011301071600000000
5bc0a9011301071600000000
5bc0a9011301071600000000
5b03c4c06a0007c800000000
5bc0a9011301071600000000
5bc0a9011301071600000000
5b03c4c06a0007c800000000
5bc0a9011301071600000000
5b03c4c06a0007c800000000
-
{e=>3,n=>7,a=>-20,m=>-1,d=>-3,j=>0,l=>1,c=>3,k=>18,h=>1,b=>6,g=>4,f=>2,i=>-2}
ec5e27023100123907000000
ec5e27023100123907000000
ec5e27023100123907000000
ecceb5003800123ce0000000
ec5e27023100123907000000
ec5e27023100123907000000
ecceb5003800123ce0000000
ec5e27023100123907000000
ecceb5003800123ce0000000
-
{e=>6,n=>4,a=>46,m=>-4,d=>-2,j=>7,l=>6,c=>-3,k=>27,h=>0,b=>6,g=>7,f=>2,i=>3}
2eaead03d8011b2604000000
2eaead03d8011b2604000000
2eaead03d8011b2604000000
2ed765c00f801bd080000000
2eaead03d8011b2604000000
2eaead03d8011b2604000000
2ed765c00f801bd080000000
2eaead03d8011b2604000000
2ed765c00f801bd080000000
-
{e=>6,n=>5,a=>47,m=>-1,d=>-4,j=>7,l=>6,c=>-3,k=>-66,h=>0,b=>6,g=>0,f=>-4,i=>0}
2f2e4d00c001be3e05000000
2f2e4d00c001be3e05000000
2f2e4d00c001be3e05000000
2fd668000380bedca0000000
2f2e4d00c001be3e05000000
2f2e4d00c001be3e05000000
2fd668000380bedca0000000
2f2e4d00c001be3e05000000
2fd668000380bedca0000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>7,n=>3,a=>90,m=>-1,d=>-4,j=>1,l=>4,c=>2,k=>65,h=>5,b=>7,g=>5,f=>1,o=>24,i=>2}
5a179f025500413c03180000
5a179f025500413c03180000
5a179f025500413c03180000
5aea7340a880419c60180000
5a179f025500413c03180000
5a179f025500413c03180000
5aea7340a880419c60180000
5a179f025500413c03180000
5aea7340a880419c60180000
-
{e=>2,n=>4,a=>119,m=>3,d=>-2,j=>6,l=>0,c=>-4,k=>51,h=>3,b=>6,g=>7,f=>-4,o=>208,i=>-4}
77a6c503a301331804d00000
77a6c503a301331804d00000
77a6c503a301331804d00000
77d329c07300330c80d00000
77a6c503a301331804d00000
77a6c503a301331804d00000
77d329c07300330c80d00000
77a6c503a301331804d00000
77d329c07300330c80d00000
-
{e=>7,n=>2,a=>-108,m=>-3,d=>2,j=>4,l=>7,c=>-1,k=>14,h=>5,b=>7,g=>3,f=>3,o=>186,i=>3}
94bfbe011d010e2f02ba0000
94bfbe011d010e2f02ba0000
94bfbe011d010e2f02ba0000
94fd76c0ae000ef440ba0000
94bfbe011d010e2f02ba0000
94bfbe011d010e2f02ba0000
94fd76c0ae000ef440ba0000
94bfbe011d010e2f02ba0000
94fd76c0ae000ef440ba0000
-
{e=>6,n=>0,a=>-25,m=>-1,d=>1,j=>2,l=>3,c=>-1,k=>-23,h=>6,b=>5,g=>5,f=>2,o=>143,i=>2}
e77dac029600e93b008f0000
e77dac029600e93b008f0000
e77dac029600e93b008f0000
e7bce540c900e97c008f0000
e77dac029600e93b008f0000
e77dac029600e93b008f0000
e7bce540c900e97c008f0000
e77dac029600e93b008f0000
e7bce540c900e97c008f0000
-
{e=>3,n=>2,a=>-24,m=>0,d=>-1,j=>4,l=>3,c=>3,k=>57,h=>3,b=>7,g=>0,f=>-2,o=>223,i=>2}
e8df67001301390302df0000
e8df67001301390302df0000
e8df67001301390302df0000
e8efbc006a00396040df0000
e8df67001301390302df0000
e8df67001301390302df0000
e8efbc006a00396040df0000
e8df67001301390302df0000
e8efbc006a00396040df0000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
};
-
{a=>-22,b=>5}
eaff0500
eaff0500
eaff0500
ffeaa000
eaff0500
eaff0500
ffeaa000
eaff0500
ffeaa000
-
{a=>45,b=>7}
2d000700
2d000700
2d000700
002de000
2d000700
2d000700
002de000
2d000700
002de000
-
{a=>-48,b=>5}
d0ff0500
d0ff0500
d0ff0500
ffd0a000
d0ff0500
d0ff0500
ffd0a000
d0ff0500
ffd0a000
-
{a=>-29,b=>0}
e3ff0000
e3ff0000
e3ff0000
ffe30000
e3ff0000
e3ff0000
ffe30000
e3ff0000
ffe30000
-
{a=>124,b=>1}
7c000100
7c000100
7c000100
007c2000
7c000100
7c000100
007c2000
7c000100
007c2000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>0,a=>-68,b=>0}
bcff0000
bcff0000
bcff0000
ffbc0000
bcff0000
bcff0000
ffbc0000
bcff0000
ffbc0000
-
{c=>0,a=>-11,b=>4}
f5ff0400
f5ff0400
f5ff0400
fff58000
f5ff0400
f5ff0400
fff58000
f5ff0400
fff58000
-
{c=>-4,a=>-111,b=>3}
91ff2300
91ff2300
91ff2300
ff917000
91ff2300
91ff2300
ff917000
91ff2300
ff917000
-
{c=>-1,a=>-105,b=>0}
97ff3800
97ff3800
97ff3800
ff971c00
97ff3800
97ff3800
ff971c00
97ff3800
ff971c00
-
{c=>0,a=>-96,b=>4}
a0ff0400
a0ff0400
a0ff0400
ffa08000
a0ff0400
a0ff0400
ffa08000
a0ff0400
ffa08000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>-4,a=>-55,b=>7,d=>1}
c9ff6700
c9ff6700
c9ff6700
ffc9f080
c9ff6700
c9ff6700
ffc9f080
c9ff6700
ffc9f080
-
{c=>3,a=>59,b=>3,d=>-2}
3b009b01
3b009b01
3b009b01
003b6f00
3b009b01
3b009b01
003b6f00
3b009b01
003b6f00
-
{c=>-1,a=>-48,b=>3,d=>0}
d0ff3b00
d0ff3b00
d0ff3b00
ffd07c00
d0ff3b00
d0ff3b00
ffd07c00
d0ff3b00
ffd07c00
-
{c=>-1,a=>-29,b=>6,d=>3}
e3fffe00
e3fffe00
e3fffe00
ffe3dd80
e3fffe00
e3fffe00
ffe3dd80
e3fffe00
ffe3dd80
-
{c=>-3,a=>32,b=>0,d=>1}
20006800
20006800
20006800
00201480
20006800
20006800
00201480
20006800
00201480
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>4,c=>-3,a=>20,b=>1,d=>-3}
14006909
14006909
14006909
001436c0
14006909
14006909
001436c0
14006909
001436c0
-
{e=>3,c=>2,a=>-60,b=>0,d=>-2}
c4ff9007
c4ff9007
c4ff9007
ffc40b30
c4ff9007
c4ff9007
ffc40b30
c4ff9007
ffc40b30
-
{e=>5,c=>-3,a=>-102,b=>3,d=>-4}
9aff2b0b
9aff2b0b
9aff2b0b
ff9a7650
9aff2b0b
9aff2b0b
ff9a7650
9aff2b0b
ff9a7650
-
{e=>3,c=>-4,a=>5,b=>0,d=>1}
05006006
05006006
05006006
000510b0
05006006
05006006
000510b0
05006006
000510b0
-
{e=>4,c=>0,a=>-80,b=>6,d=>0}
b0ff0608
b0ff0608
b0ff0608
ffb0c040
b0ff0608
b0ff0608
ffb0c040
b0ff0608
ffb0c040
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
};
-
{e=>5,c=>-1,a=>-102,b=>0,d=>1,f=>0}
9aff780a
9aff780a
9aff780a
ff9a1cd0
9aff780a
9aff780a
ff9a1cd0
9aff780a
ff9a1cd0
-
{e=>4,c=>2,a=>7,b=>4,d=>-4,f=>-1}
07001479
07001479
07001479
00078a4e
07001479
07001479
00078a4e
07001479
00078a4e
-
{e=>4,c=>-1,a=>99,b=>1,d=>1,f=>-1}
63007978
63007978
63007978
00633cce
63007978
63007978
00633cce
63007978
00633cce
-
{e=>3,c=>-2,a=>-105,b=>7,d=>-4,f=>-3}
97ff3757
97ff3757
97ff3757
ff97fa3a
97ff3757
97ff3757
ff97fa3a
97ff3757
ff97fa3a
-
{e=>6,c=>-2,a=>102,b=>7,d=>-4,f=>-1}
6600377d
6600377d
6600377d
0066fa6e
6600377d
6600377d
0066fa6e
6600377d
0066fa6e
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
};
-
{e=>4,c=>0,a=>106,g=>0,b=>1,d=>-3,f=>1}
6a00411900000000
6a00411900000000
6a00411900000000
006a22c200000000
6a00411900000000
6a00411900000000
006a22c200000000
6a00411900000000
006a22c200000000
-
{e=>6,c=>-4,a=>-47,g=>4,b=>0,d=>2,f=>-1}
d1ffa07c04000000
d1ffa07c04000000
d1ffa07c04000000
ffd1116e80000000
d1ffa07c04000000
d1ffa07c04000000
ffd1116e80000000
d1ffa07c04000000
ffd1116e80000000
-
{e=>2,c=>0,a=>28,g=>2,b=>3,d=>-4,f=>-1}
1c00037502000000
1c00037502000000
1c00037502000000
001c622e40000000
1c00037502000000
1c00037502000000
001c622e40000000
1c00037502000000
001c622e40000000
-
{e=>2,c=>2,a=>8,g=>0,b=>4,d=>-3,f=>1}
0800541500000000
0800541500000000
0800541500000000
00088aa200000000
0800541500000000
0800541500000000
00088aa200000000
0800541500000000
00088aa200000000
-
{e=>7,c=>1,a=>-41,g=>1,b=>6,d=>-3,f=>-3}
d7ff4e5f01000000
d7ff4e5f01000000
d7ff4e5f01000000
ffd7c6fa20000000
d7ff4e5f01000000
d7ff4e5f01000000
ffd7c6fa20000000
d7ff4e5f01000000
ffd7c6fa20000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>2,c=>2,a=>57,g=>4,b=>4,d=>-3,f=>-3}
3900545504000000
3900545504000000
3900545504000000
00398aaa80000000
3900545504000000
3900545504000000
00398aaa80000000
3900545504000000
00398aaa80000000
-
{e=>5,c=>-1,a=>108,g=>7,b=>2,d=>-1,f=>-3}
6c00fa5b07000000
6c00fa5b07000000
6c00fa5b07000000
006c5fdae0000000
6c00fa5b07000000
6c00fa5b07000000
006c5fdae0000000
6c00fa5b07000000
006c5fdae0000000
-
{e=>3,c=>-3,a=>59,g=>1,b=>5,d=>1,f=>-2}
3b006d6601000000
3b006d6601000000
3b006d6601000000
003bb4bc20000000
3b006d6601000000
3b006d6601000000
003bb4bc20000000
3b006d6601000000
003bb4bc20000000
-
{e=>3,c=>-2,a=>82,g=>7,b=>1,d=>-1,f=>-1}
5200f17707000000
5200f17707000000
5200f17707000000
00523bbee0000000
5200f17707000000
5200f17707000000
00523bbee0000000
5200f17707000000
00523bbee0000000
-
{e=>1,c=>-1,a=>12,g=>2,b=>6,d=>3,f=>-1}
0c00fe7202000000
0c00fe7202000000
0c00fe7202000000
000cdd9e40000000
0c00fe7202000000
0c00fe7202000000
000cdd9e40000000
0c00fe7202000000
000cdd9e40000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>1,a=>50,d=>-3,c=>-2,h=>0,b=>7,g=>4,f=>-2}
320077630400000000000000
320077630400000000000000
320077630400000000000000
0032fa9c8000000000000000
320077630400000000000000
320077630400000000000000
0032fa9c8000000000000000
320077630400000000000000
0032fa9c8000000000000000
-
{e=>5,a=>40,d=>-3,c=>-4,h=>2,b=>3,g=>0,f=>3}
2800633b0000000002000000
2800633b0000000002000000
2800633b0000000002000000
002872d60000000040000000
2800633b0000000002000000
2800633b0000000002000000
002872d60000000040000000
2800633b0000000002000000
002872d60000000040000000
-
{e=>6,a=>21,d=>-1,c=>3,h=>2,b=>6,g=>7,f=>-1}
1500de7d0700000002000000
1500de7d0700000002000000
1500de7d0700000002000000
0015cfeee000000040000000
1500de7d0700000002000000
1500de7d0700000002000000
0015cfeee000000040000000
1500de7d0700000002000000
0015cfeee000000040000000
-
{e=>0,a=>-119,d=>0,c=>-1,h=>6,b=>1,g=>7,f=>3}
89ff39300700000006000000
89ff39300700000006000000
89ff39300700000006000000
ff893c06e0000000c0000000
89ff39300700000006000000
89ff39300700000006000000
ff893c06e0000000c0000000
89ff39300700000006000000
ff893c06e0000000c0000000
-
{e=>4,a=>-45,d=>2,c=>1,h=>2,b=>7,g=>7,f=>0}
d3ff8f080700000002000000
d3ff8f080700000002000000
d3ff8f080700000002000000
ffd3e540e000000040000000
d3ff8f080700000002000000
d3ff8f080700000002000000
ffd3e540e000000040000000
d3ff8f080700000002000000
ffd3e540e000000040000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>2,a=>95,d=>0,c=>-2,h=>1,b=>4,g=>3,f=>0,i=>-1}
5f0034040300000039000000
5f0034040300000039000000
5f0034040300000039000000
005f9820600000003c000000
5f0034040300000039000000
5f0034040300000039000000
005f9820600000003c000000
5f0034040300000039000000
005f9820600000003c000000
-
{e=>4,a=>34,d=>0,c=>3,h=>3,b=>2,g=>1,f=>0,i=>-1}
22001a08010000003b000000
22001a08010000003b000000
22001a08010000003b000000
00224c40200000007c000000
22001a08010000003b000000
22001a08010000003b000000
00224c40200000007c000000
22001a08010000003b000000
00224c40200000007c000000
-
{e=>7,a=>40,d=>-2,c=>-2,h=>0,b=>3,g=>1,f=>2,i=>1}
2800b32f0100000008000000
2800b32f0100000008000000
2800b32f0100000008000000
00287b742000000004000000
2800b32f0100000008000000
2800b32f0100000008000000
00287b742000000004000000
2800b32f0100000008000000
00287b742000000004000000
-
{e=>2,a=>-13,d=>-3,c=>1,h=>1,b=>0,g=>5,f=>3,i=>-2}
f3ff48350500000031000000
f3ff48350500000031000000
f3ff48350500000031000000
fff306a6a000000038000000
f3ff48350500000031000000
f3ff48350500000031000000
fff306a6a000000038000000
f3ff48350500000031000000
fff306a6a000000038000000
-
{e=>6,a=>-50,d=>0,c=>1,h=>6,b=>6,g=>5,f=>-3,i=>-2}
ceff0e5c0500000036000000
ceff0e5c0500000036000000
ceff0e5c0500000036000000
ffcec46aa0000000d8000000
ceff0e5c0500000036000000
ceff0e5c0500000036000000
ffcec46aa0000000d8000000
ceff0e5c0500000036000000
ffcec46aa0000000d8000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
};
-
{e=>0,a=>-78,d=>-2,j=>4,c=>-1,h=>1,b=>3,g=>6,f=>-3,i=>-2}
b2ffbb510600000031010000
b2ffbb510600000031010000
b2ffbb510600000031010000
ffb27f0ac00000003a000000
b2ffbb510600000031010000
b2ffbb510600000031010000
ffb27f0ac00000003a000000
b2ffbb510600000031010000
ffb27f0ac00000003a000000
-
{e=>7,a=>76,d=>-2,j=>1,c=>-4,h=>5,b=>6,g=>3,f=>-4,i=>2}
4c00a64f0300000055000000
4c00a64f0300000055000000
4c00a64f0300000055000000
004cd37860000000a8800000
4c00a64f0300000055000000
4c00a64f0300000055000000
004cd37860000000a8800000
4c00a64f0300000055000000
004cd37860000000a8800000
-
{e=>7,a=>88,d=>0,j=>0,c=>1,h=>1,b=>1,g=>1,f=>1,i=>2}
5800091e0100000011000000
5800091e0100000011000000
5800091e0100000011000000
005824722000000028000000
5800091e0100000011000000
5800091e0100000011000000
005824722000000028000000
5800091e0100000011000000
005824722000000028000000
-
{e=>7,a=>-27,d=>0,j=>7,c=>-1,h=>1,b=>0,g=>0,f=>-4,i=>-1}
e5ff384e00000000f9010000
e5ff384e00000000f9010000
e5ff384e00000000f9010000
ffe51c78000000003f800000
e5ff384e00000000f9010000
e5ff384e00000000f9010000
ffe51c78000000003f800000
e5ff384e00000000f9010000
ffe51c78000000003f800000
-
{e=>1,a=>-99,d=>-3,j=>3,c=>1,h=>5,b=>1,g=>6,f=>3,i=>3}
9dff493306000000dd000000
9dff493306000000dd000000
9dff493306000000dd000000
ff9d2696c0000000ad800000
9dff493306000000dd000000
9dff493306000000dd000000
ff9d2696c0000000ad800000
9dff493306000000dd000000
ff9d2696c0000000ad800000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
};
-
{e=>2,a=>4,d=>1,j=>5,c=>-3,k=>75,h=>5,b=>0,g=>2,f=>3,i=>-1}
04006834020000007d014b00
04006834020000007d014b00
04006834020000007d014b00
000414a640000000be804b00
04006834020000007d014b00
04006834020000007d014b00
000414a640000000be804b00
04006834020000007d014b00
000414a640000000be804b00
-
{e=>5,a=>7,d=>-2,j=>1,c=>0,k=>19,h=>4,b=>6,g=>6,f=>3,i=>1}
0700863b060000004c001300
0700863b060000004c001300
0700863b060000004c001300
0007c356c000000084801300
0700863b060000004c001300
0700863b060000004c001300
0007c356c000000084801300
0700863b060000004c001300
0007c356c000000084801300
-
{e=>2,a=>57,d=>1,j=>0,c=>1,k=>89,h=>1,b=>3,g=>6,f=>3,i=>1}
39004b340600000009005900
39004b340600000009005900
39004b340600000009005900
003964a6c000000024005900
39004b340600000009005900
39004b340600000009005900
003964a6c000000024005900
39004b340600000009005900
003964a6c000000024005900
-
{e=>4,a=>7,d=>0,j=>2,c=>-1,k=>-8,h=>3,b=>7,g=>4,f=>-1,i=>-4}
07003f7804000000a300f800
07003f7804000000a300f800
07003f7804000000a300f800
0007fc4e800000007100f800
07003f7804000000a300f800
07003f7804000000a300f800
0007fc4e800000007100f800
07003f7804000000a300f800
0007fc4e800000007100f800
-
{e=>5,a=>105,d=>3,j=>1,c=>3,k=>119,h=>7,b=>7,g=>0,f=>0,i=>-2}
6900df0a0000000077007700
6900df0a0000000077007700
6900df0a0000000077007700
0069edd000000000f8807700
6900df0a0000000077007700
6900df0a0000000077007700
0069edd000000000f8807700
6900df0a0000000077007700
0069edd000000000f8807700
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>3,a=>-68,d=>3,j=>1,l=>0,c=>-3,k=>40,h=>5,b=>6,g=>0,f=>0,i=>2}
bcffee060000000055002800
bcffee060000000055002800
bcffee060000000055002800
ffbcd5b000000000a8802800
bcffee060000000055002800
bcffee060000000055002800
ffbcd5b000000000a8802800
bcffee060000000055002800
ffbcd5b000000000a8802800
-
{e=>6,a=>84,d=>-4,j=>4,l=>0,c=>1,k=>100,h=>2,b=>1,g=>6,f=>3,i=>2}
5400093d0600000012016400
5400093d0600000012016400
5400093d0600000012016400
00542666c00000004a006400
5400093d0600000012016400
5400093d0600000012016400
00542666c00000004a006400
5400093d0600000012016400
00542666c00000004a006400
-
{e=>2,a=>-8,d=>-4,j=>2,l=>4,c=>-2,k=>-68,h=>2,b=>6,g=>5,f=>-1,i=>-1}
f8ff367505000000ba00bc04
f8ff367505000000ba00bc04
f8ff367505000000ba00bc04
fff8da2ea00000005d00bc80
f8ff367505000000ba00bc04
f8ff367505000000ba00bc04
fff8da2ea00000005d00bc80
f8ff367505000000ba00bc04
fff8da2ea00000005d00bc80
-
{e=>0,a=>-64,d=>3,j=>4,l=>1,c=>-4,k=>-2,h=>3,b=>1,g=>4,f=>-3,i=>-3}
c0ffe150040000002b01fe01
c0ffe150040000002b01fe01
c0ffe150040000002b01fe01
ffc0318a800000007600fe20
c0ffe150040000002b01fe01
c0ffe150040000002b01fe01
ffc0318a800000007600fe20
c0ffe150040000002b01fe01
ffc0318a800000007600fe20
-
{e=>5,a=>64,d=>-4,j=>6,l=>7,c=>0,k=>13,h=>2,b=>4,g=>7,f=>-4,i=>3}
4000044b070000009a010d07
4000044b070000009a010d07
4000044b070000009a010d07
00408258e00000004f000de0
4000044b070000009a010d07
4000044b070000009a010d07
00408258e00000004f000de0
4000044b070000009a010d07
00408258e00000004f000de0
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>2,a=>-53,m=>2,d=>0,j=>4,l=>6,c=>0,k=>-28,h=>4,b=>1,g=>0,f=>0,i=>-1}
cbff0104000000003c01e416
cbff0104000000003c01e416
cbff0104000000003c01e416
ffcb2020000000009e00e4c8
cbff0104000000003c01e416
cbff0104000000003c01e416
ffcb2020000000009e00e4c8
cbff0104000000003c01e416
ffcb2020000000009e00e4c8
-
{e=>2,a=>-58,m=>-4,d=>-3,j=>7,l=>1,c=>1,k=>-110,h=>4,b=>2,g=>5,f=>-2,i=>1}
c6ff4a6505000000cc019221
c6ff4a6505000000cc019221
c6ff4a6505000000cc019221
ffc646aca000000087809230
c6ff4a6505000000cc019221
c6ff4a6505000000cc019221
ffc646aca000000087809230
c6ff4a6505000000cc019221
ffc646aca000000087809230
-
{e=>2,a=>-95,m=>1,d=>2,j=>3,l=>1,c=>2,k=>47,h=>7,b=>5,g=>2,f=>3,i=>0}
a1ff953402000000c7002f09
a1ff953402000000c7002f09
a1ff953402000000c7002f09
ffa1a92640000000e1802f24
a1ff953402000000c7002f09
a1ff953402000000c7002f09
ffa1a92640000000e1802f24
a1ff953402000000c7002f09
ffa1a92640000000e1802f24
-
{e=>2,a=>86,m=>0,d=>-1,j=>3,l=>0,c=>3,k=>-1,h=>4,b=>3,g=>1,f=>0,i=>-3}
5600db0501000000ec00ff00
5600db0501000000ec00ff00
5600db0501000000ec00ff00
00566fa0200000009580ff00
5600db0501000000ec00ff00
5600db0501000000ec00ff00
00566fa0200000009580ff00
5600db0501000000ec00ff00
00566fa0200000009580ff00
-
{e=>5,a=>31,m=>-3,d=>1,j=>4,l=>5,c=>1,k=>1,h=>6,b=>1,g=>2,f=>2,i=>-4}
1f00492a020000002601012d
1f00492a020000002601012d
1f00492a020000002601012d
001f24d440000000d20001b4
1f00492a020000002601012d
1f00492a020000002601012d
001f24d440000000d20001b4
1f00492a020000002601012d
001f24d440000000d20001b4
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>4,n=>3,a=>-119,m=>-2,d=>0,j=>0,l=>0,c=>3,k=>127,h=>3,b=>3,g=>0,f=>-3,i=>-3}
89ff1b58000000002b007f3003000000
89ff1b58000000002b007f3003000000
89ff1b58000000002b007f3003000000
ff896c4a0000000074007f1860000000
89ff1b58000000002b007f3003000000
89ff1b58000000002b007f3003000000
ff896c4a0000000074007f1860000000
89ff1b58000000002b007f3003000000
ff896c4a0000000074007f1860000000
-
{e=>2,n=>3,a=>47,m=>-4,d=>1,j=>6,l=>7,c=>1,k=>-126,h=>6,b=>1,g=>2,f=>-2,i=>-4}
2f00496402000000a601822703000000
2f00496402000000a601822703000000
2f00496402000000a601822703000000
002f24ac40000000d30082f060000000
2f00496402000000a601822703000000
2f00496402000000a601822703000000
002f24ac40000000d30082f060000000
2f00496402000000a601822703000000
002f24ac40000000d30082f060000000
-
{e=>6,n=>4,a=>-16,m=>3,d=>-4,j=>3,l=>3,c=>2,k=>-100,h=>4,b=>4,g=>3,f=>-1,i=>3}
f0ff147d03000000dc009c1b04000000
f0ff147d03000000dc009c1b04000000
f0ff147d03000000dc009c1b04000000
fff08a6e600000008d809c6c80000000
f0ff147d03000000dc009c1b04000000
f0ff147d03000000dc009c1b04000000
fff08a6e600000008d809c6c80000000
f0ff147d03000000dc009c1b04000000
fff08a6e600000008d809c6c80000000
-
{e=>0,n=>3,a=>99,m=>-3,d=>-4,j=>4,l=>1,c=>-1,k=>-77,h=>3,b=>1,g=>0,f=>-2,i=>3}
63003961000000001b01b32903000000
63003961000000001b01b32903000000
63003961000000001b01b32903000000
00633e0c000000006e00b33460000000
63003961000000001b01b32903000000
63003961000000001b01b32903000000
00633e0c000000006e00b33460000000
63003961000000001b01b32903000000
00633e0c000000006e00b33460000000
-
{e=>5,n=>0,a=>-106,m=>-2,d=>-4,j=>7,l=>7,c=>-3,k=>-97,h=>3,b=>3,g=>2,f=>1,i=>-3}
96ff2b1b02000000eb019f3700000000
96ff2b1b02000000eb019f3700000000
96ff2b1b02000000eb019f3700000000
ff9676524000000077809ff800000000
96ff2b1b02000000eb019f3700000000
96ff2b1b02000000eb019f3700000000
ff9676524000000077809ff800000000
96ff2b1b02000000eb019f3700000000
ff9676524000000077809ff800000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>3,n=>7,a=>-113,m=>1,d=>-3,j=>5,l=>0,c=>1,k=>2,h=>6,b=>0,g=>5,f=>-2,o=>22,i=>0}
8fff4867050000004601020807160000
8fff4867050000004601020807160000
8fff4867050000004601020807160000
ff8f06bca0000000c2800204e0160000
8fff4867050000004601020807160000
8fff4867050000004601020807160000
ff8f06bca0000000c2800204e0160000
8fff4867050000004601020807160000
ff8f06bca0000000c2800204e0160000
-
{e=>6,n=>7,a=>-82,m=>-2,d=>-3,j=>7,l=>3,c=>-1,k=>-116,h=>6,b=>1,g=>5,f=>2,o=>227,i=>-2}
aeff792d05000000f6018c3307e30000
aeff792d05000000f6018c3307e30000
aeff792d05000000f6018c3307e30000
ffae3ee4a0000000db808c78e0e30000
aeff792d05000000f6018c3307e30000
aeff792d05000000f6018c3307e30000
ffae3ee4a0000000db808c78e0e30000
aeff792d05000000f6018c3307e30000
ffae3ee4a0000000db808c78e0e30000
-
{e=>1,n=>4,a=>-117,m=>-2,d=>-2,j=>2,l=>5,c=>1,k=>-17,h=>3,b=>6,g=>3,f=>-4,o=>238,i=>-2}
8bff8e4303000000b300ef3504ee0000
8bff8e4303000000b300ef3504ee0000
8bff8e4303000000b300ef3504ee0000
ff8bc718600000007900efb880ee0000
8bff8e4303000000b300ef3504ee0000
8bff8e4303000000b300ef3504ee0000
ff8bc718600000007900efb880ee0000
8bff8e4303000000b300ef3504ee0000
ff8bc718600000007900efb880ee0000
-
{e=>4,n=>6,a=>62,m=>-2,d=>3,j=>0,l=>4,c=>2,k=>119,h=>2,b=>7,g=>6,f=>0,o=>141,i=>-4}
3e00d7080600000022007734068d0000
3e00d7080600000022007734068d0000
3e00d7080600000022007734068d0000
003ee9c0c000000050007798c08d0000
3e00d7080600000022007734068d0000
3e00d7080600000022007734068d0000
003ee9c0c000000050007798c08d0000
3e00d7080600000022007734068d0000
003ee9c0c000000050007798c08d0000
-
{e=>0,n=>5,a=>59,m=>0,d=>1,j=>3,l=>5,c=>-2,k=>-64,h=>0,b=>7,g=>0,f=>-4,o=>130,i=>3}
3b00774000000000d800c00505820000
3b00774000000000d800c00505820000
3b00774000000000d800c00505820000
003bf888000000000d80c0a0a0820000
3b00774000000000d800c00505820000
3b00774000000000d800c00505820000
003bf888000000000d80c0a0a0820000
3b00774000000000d800c00505820000
003bf888000000000d80c0a0a0820000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
};
-
{a=>-25,b=>5}
e7ffffff05000000
e7ffffff05000000
e7ffffff05000000
ffffffe7a0000000
e7ffffff05000000
e7ffffff05000000
ffffffe7a0000000
e7ffffff05000000
ffffffe7a0000000
-
{a=>10,b=>1}
0a00000001000000
0a00000001000000
0a00000001000000
0000000a20000000
0a00000001000000
0a00000001000000
0000000a20000000
0a00000001000000
0000000a20000000
-
{a=>8,b=>7}
0800000007000000
0800000007000000
0800000007000000
00000008e0000000
0800000007000000
0800000007000000
00000008e0000000
0800000007000000
00000008e0000000
-
{a=>-93,b=>6}
a3ffffff06000000
a3ffffff06000000
a3ffffff06000000
ffffffa3c0000000
a3ffffff06000000
a3ffffff06000000
ffffffa3c0000000
a3ffffff06000000
ffffffa3c0000000
-
{a=>-67,b=>1}
bdffffff01000000
bdffffff01000000
bdffffff01000000
ffffffbd20000000
bdffffff01000000
bdffffff01000000
ffffffbd20000000
bdffffff01000000
ffffffbd20000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>0,a=>-12,b=>7}
f4ffffff07000000
f4ffffff07000000
f4ffffff07000000
fffffff4e0000000
f4ffffff07000000
f4ffffff07000000
fffffff4e0000000
f4ffffff07000000
fffffff4e0000000
-
{c=>-4,a=>99,b=>7}
6300000027000000
6300000027000000
6300000027000000
00000063f0000000
6300000027000000
6300000027000000
00000063f0000000
6300000027000000
00000063f0000000
-
{c=>1,a=>18,b=>7}
120000000f000000
120000000f000000
120000000f000000
00000012e4000000
120000000f000000
120000000f000000
00000012e4000000
120000000f000000
00000012e4000000
-
{c=>2,a=>43,b=>7}
2b00000017000000
2b00000017000000
2b00000017000000
0000002be8000000
2b00000017000000
2b00000017000000
0000002be8000000
2b00000017000000
0000002be8000000
-
{c=>-4,a=>34,b=>0}
2200000020000000
2200000020000000
2200000020000000
0000002210000000
2200000020000000
2200000020000000
0000002210000000
2200000020000000
0000002210000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>-2,a=>26,b=>4,d=>1}
1a00000074000000
1a00000074000000
1a00000074000000
0000001a98800000
1a00000074000000
1a00000074000000
0000001a98800000
1a00000074000000
0000001a98800000
-
{c=>-3,a=>42,b=>5,d=>0}
2a0000002d000000
2a0000002d000000
2a0000002d000000
0000002ab4000000
2a0000002d000000
2a0000002d000000
0000002ab4000000
2a0000002d000000
0000002ab4000000
-
{c=>3,a=>115,b=>3,d=>-4}
730000001b010000
730000001b010000
730000001b010000
000000736e000000
730000001b010000
730000001b010000
000000736e000000
730000001b010000
000000736e000000
-
{c=>1,a=>21,b=>4,d=>-2}
150000008c010000
150000008c010000
150000008c010000
0000001587000000
150000008c010000
150000008c010000
0000001587000000
150000008c010000
0000001587000000
-
{c=>1,a=>124,b=>0,d=>-2}
7c00000088010000
7c00000088010000
7c00000088010000
0000007c07000000
7c00000088010000
7c00000088010000
0000007c07000000
7c00000088010000
0000007c07000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>1,c=>-3,a=>-59,b=>7,d=>-3}
c5ffffff6f030000
c5ffffff6f030000
c5ffffff6f030000
ffffffc5f6900000
c5ffffff6f030000
c5ffffff6f030000
ffffffc5f6900000
c5ffffff6f030000
ffffffc5f6900000
-
{e=>5,c=>3,a=>96,b=>7,d=>1}
600000005f0a0000
600000005f0a0000
600000005f0a0000
00000060ecd00000
600000005f0a0000
600000005f0a0000
00000060ecd00000
600000005f0a0000
00000060ecd00000
-
{e=>6,c=>-3,a=>97,b=>1,d=>1}
61000000690c0000
61000000690c0000
61000000690c0000
0000006134e00000
61000000690c0000
61000000690c0000
0000006134e00000
61000000690c0000
0000006134e00000
-
{e=>0,c=>-3,a=>45,b=>5,d=>-2}
2d000000ad010000
2d000000ad010000
2d000000ad010000
0000002db7000000
2d000000ad010000
2d000000ad010000
0000002db7000000
2d000000ad010000
0000002db7000000
-
{e=>5,c=>-4,a=>-125,b=>0,d=>1}
83ffffff600a0000
83ffffff600a0000
83ffffff600a0000
ffffff8310d00000
83ffffff600a0000
83ffffff600a0000
ffffff8310d00000
83ffffff600a0000
ffffff8310d00000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
};
-
{e=>6,c=>3,a=>-75,b=>2,d=>-3,f=>0}
b5ffffff5a0d0000
b5ffffff5a0d0000
b5ffffff5a0d0000
ffffffb54ee00000
b5ffffff5a0d0000
b5ffffff5a0d0000
ffffffb54ee00000
b5ffffff5a0d0000
ffffffb54ee00000
-
{e=>5,c=>-4,a=>-82,b=>3,d=>3,f=>1}
aeffffffe31a0000
aeffffffe31a0000
aeffffffe31a0000
ffffffae71d20000
aeffffffe31a0000
aeffffffe31a0000
ffffffae71d20000
aeffffffe31a0000
ffffffae71d20000
-
{e=>7,c=>1,a=>53,b=>4,d=>-2,f=>0}
350000008c0f0000
350000008c0f0000
350000008c0f0000
0000003587700000
350000008c0f0000
350000008c0f0000
0000003587700000
350000008c0f0000
0000003587700000
-
{e=>1,c=>2,a=>126,b=>6,d=>-3,f=>0}
7e00000056030000
7e00000056030000
7e00000056030000
0000007eca900000
7e00000056030000
7e00000056030000
0000007eca900000
7e00000056030000
0000007eca900000
-
{e=>3,c=>0,a=>11,b=>4,d=>-1,f=>-1}
0b000000c4770000
0b000000c4770000
0b000000c4770000
0000000b83be0000
0b000000c4770000
0b000000c4770000
0000000b83be0000
0b000000c4770000
0000000b83be0000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
};
-
{e=>2,c=>-1,a=>-28,g=>6,b=>6,d=>1,f=>-2}
e4ffffff7e640300
e4ffffff7e640300
e4ffffff7e640300
ffffffe4dcad8000
e4ffffff7e640300
e4ffffff7e640300
ffffffe4dcad8000
e4ffffff7e640300
ffffffe4dcad8000
-
{e=>1,c=>2,a=>-122,g=>5,b=>3,d=>2,f=>-2}
86ffffff93e20200
86ffffff93e20200
86ffffff93e20200
ffffff86691d4000
86ffffff93e20200
86ffffff93e20200
ffffff86691d4000
86ffffff93e20200
ffffff86691d4000
-
{e=>7,c=>-2,a=>-4,g=>7,b=>7,d=>1,f=>3}
fcffffff77be0300
fcffffff77be0300
fcffffff77be0300
fffffffcf8f7c000
fcffffff77be0300
fcffffff77be0300
fffffffcf8f7c000
fcffffff77be0300
fffffffcf8f7c000
-
{e=>3,c=>-1,a=>-107,g=>6,b=>5,d=>-4,f=>-3}
95ffffff3d570300
95ffffff3d570300
95ffffff3d570300
ffffff95be3b8000
95ffffff3d570300
95ffffff3d570300
ffffff95be3b8000
95ffffff3d570300
ffffff95be3b8000
-
{e=>2,c=>1,a=>-115,g=>0,b=>7,d=>2,f=>0}
8dffffff8f040000
8dffffff8f040000
8dffffff8f040000
ffffff8de5200000
8dffffff8f040000
8dffffff8f040000
ffffff8de5200000
8dffffff8f040000
ffffff8de5200000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>4,c=>1,a=>-92,g=>6,b=>5,d=>-4,f=>-4}
a4ffffff0d490300
a4ffffff0d490300
a4ffffff0d490300
ffffffa4a6498000
a4ffffff0d490300
a4ffffff0d490300
ffffffa4a6498000
a4ffffff0d490300
ffffffa4a6498000
-
{e=>3,c=>3,a=>112,g=>1,b=>4,d=>0,f=>-3}
700000001cd60000
700000001cd60000
700000001cd60000
000000708c3a4000
700000001cd60000
700000001cd60000
000000708c3a4000
700000001cd60000
000000708c3a4000
-
{e=>2,c=>1,a=>-90,g=>7,b=>2,d=>1,f=>0}
a6ffffff4a840300
a6ffffff4a840300
a6ffffff4a840300
ffffffa644a1c000
a6ffffff4a840300
a6ffffff4a840300
ffffffa644a1c000
a6ffffff4a840300
ffffffa644a1c000
-
{e=>1,c=>3,a=>20,g=>3,b=>6,d=>-1,f=>-4}
14000000dec30100
14000000dec30100
14000000dec30100
00000014cf98c000
14000000dec30100
14000000dec30100
00000014cf98c000
14000000dec30100
00000014cf98c000
-
{e=>0,c=>1,a=>-18,g=>4,b=>0,d=>-2,f=>-2}
eeffffff88610200
eeffffff88610200
eeffffff88610200
ffffffee070d0000
eeffffff88610200
eeffffff88610200
ffffffee070d0000
eeffffff88610200
ffffffee070d0000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>6,a=>38,d=>-1,c=>-1,h=>0,b=>7,g=>7,f=>3}
26000000ffbd030000000000
26000000ffbd030000000000
26000000ffbd030000000000
00000026ffe7c00000000000
26000000ffbd030000000000
26000000ffbd030000000000
00000026ffe7c00000000000
26000000ffbd030000000000
00000026ffe7c00000000000
-
{e=>6,a=>31,d=>3,c=>2,h=>1,b=>2,g=>0,f=>3}
1f000000d23c000001000000
1f000000d23c000001000000
1f000000d23c000001000000
0000001f49e6000020000000
1f000000d23c000001000000
1f000000d23c000001000000
0000001f49e6000020000000
1f000000d23c000001000000
0000001f49e6000020000000
-
{e=>7,a=>-56,d=>-4,c=>0,h=>5,b=>1,g=>2,f=>-4}
c8ffffff014f010005000000
c8ffffff014f010005000000
c8ffffff014f010005000000
ffffffc822788000a0000000
c8ffffff014f010005000000
c8ffffff014f010005000000
ffffffc822788000a0000000
c8ffffff014f010005000000
ffffffc822788000a0000000
-
{e=>7,a=>119,d=>2,c=>-4,h=>5,b=>7,g=>0,f=>-3}
77000000a75e000005000000
77000000a75e000005000000
77000000a75e000005000000
00000077f17a0000a0000000
77000000a75e000005000000
77000000a75e000005000000
00000077f17a0000a0000000
77000000a75e000005000000
00000077f17a0000a0000000
-
{e=>7,a=>-122,d=>3,c=>3,h=>6,b=>2,g=>7,f=>2}
86ffffffdaae030006000000
86ffffffdaae030006000000
86ffffffdaae030006000000
ffffff864df5c000c0000000
86ffffffdaae030006000000
86ffffffdaae030006000000
ffffff864df5c000c0000000
86ffffffdaae030006000000
ffffff864df5c000c0000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>0,a=>66,d=>-4,c=>-4,h=>6,b=>2,g=>6,f=>3,i=>2}
420000002231030016000000
420000002231030016000000
420000002231030016000000
0000004252078000c8000000
420000002231030016000000
420000002231030016000000
0000004252078000c8000000
420000002231030016000000
0000004252078000c8000000
-
{e=>2,a=>19,d=>-2,c=>3,h=>4,b=>6,g=>5,f=>2,i=>3}
130000009ea502001c000000
130000009ea502001c000000
130000009ea502001c000000
00000013cf2540008c000000
130000009ea502001c000000
130000009ea502001c000000
00000013cf2540008c000000
130000009ea502001c000000
00000013cf2540008c000000
-
{e=>1,a=>-41,d=>-3,c=>-3,h=>6,b=>5,g=>0,f=>-3,i=>-2}
d7ffffff6d53000036000000
d7ffffff6d53000036000000
d7ffffff6d53000036000000
ffffffd7b69a0000d8000000
d7ffffff6d53000036000000
d7ffffff6d53000036000000
ffffffd7b69a0000d8000000
d7ffffff6d53000036000000
ffffffd7b69a0000d8000000
-
{e=>3,a=>-25,d=>1,c=>0,h=>2,b=>2,g=>6,f=>2,i=>-3}
e7ffffff422603002a000000
e7ffffff422603002a000000
e7ffffff422603002a000000
ffffffe740b5800054000000
e7ffffff422603002a000000
e7ffffff422603002a000000
ffffffe740b5800054000000
e7ffffff422603002a000000
ffffffe740b5800054000000
-
{e=>3,a=>77,d=>3,c=>-1,h=>3,b=>5,g=>6,f=>-1,i=>3}
4d000000fd7603001b000000
4d000000fd7603001b000000
4d000000fd7603001b000000
0000004dbdbf80006c000000
4d000000fd7603001b000000
4d000000fd7603001b000000
0000004dbdbf80006c000000
4d000000fd7603001b000000
0000004dbdbf80006c000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
};
-
{e=>7,a=>-49,d=>3,j=>4,c=>1,h=>6,b=>5,g=>7,f=>-3,i=>-2}
cfffffffcdde030036010000
cfffffffcdde030036010000
cfffffffcdde030036010000
ffffffcfa5fbc000da000000
cfffffffcdde030036010000
cfffffffcdde030036010000
ffffffcfa5fbc000da000000
cfffffffcdde030036010000
ffffffcfa5fbc000da000000
-
{e=>4,a=>-24,d=>-3,j=>3,c=>3,h=>3,b=>6,g=>6,f=>3,i=>1}
e8ffffff5e390300cb000000
e8ffffff5e390300cb000000
e8ffffff5e390300cb000000
ffffffe8cec7800065800000
e8ffffff5e390300cb000000
e8ffffff5e390300cb000000
ffffffe8cec7800065800000
e8ffffff5e390300cb000000
ffffffe8cec7800065800000
-
{e=>5,a=>-77,d=>1,j=>7,c=>-3,h=>0,b=>6,g=>1,f=>2,i=>1}
b3ffffff6eaa0000c8010000
b3ffffff6eaa0000c8010000
b3ffffff6eaa0000c8010000
ffffffb3d4d4400007800000
b3ffffff6eaa0000c8010000
b3ffffff6eaa0000c8010000
ffffffb3d4d4400007800000
b3ffffff6eaa0000c8010000
ffffffb3d4d4400007800000
-
{e=>5,a=>80,d=>3,j=>5,c=>-3,h=>1,b=>6,g=>7,f=>-4,i=>3}
50000000eeca030059010000
50000000eeca030059010000
50000000eeca030059010000
00000050d5d9c0002e800000
50000000eeca030059010000
50000000eeca030059010000
00000050d5d9c0002e800000
50000000eeca030059010000
00000050d5d9c0002e800000
-
{e=>3,a=>33,d=>-4,j=>4,c=>-1,h=>5,b=>4,g=>2,f=>3,i=>-2}
210000003c37010035010000
210000003c37010035010000
210000003c37010035010000
000000219e368000ba000000
210000003c37010035010000
210000003c37010035010000
000000219e368000ba000000
210000003c37010035010000
000000219e368000ba000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
};
-
{e=>1,a=>-125,d=>-4,j=>6,c=>-1,k=>-20,h=>4,b=>1,g=>5,f=>-1,i=>1}
83ffffff39f302008c01ec00
83ffffff39f302008c01ec00
83ffffff39f302008c01ec00
ffffff833e1f40008700ec00
83ffffff39f302008c01ec00
83ffffff39f302008c01ec00
ffffff833e1f40008700ec00
83ffffff39f302008c01ec00
ffffff833e1f40008700ec00
-
{e=>6,a=>123,d=>0,j=>3,c=>1,k=>-127,h=>6,b=>5,g=>2,f=>-2,i=>-2}
7b0000000d6c0100f6008100
7b0000000d6c0100f6008100
7b0000000d6c0100f6008100
0000007ba46c8000d9808100
7b0000000d6c0100f6008100
7b0000000d6c0100f6008100
0000007ba46c8000d9808100
7b0000000d6c0100f6008100
0000007ba46c8000d9808100
-
{e=>3,a=>80,d=>-3,j=>6,c=>3,k=>-21,h=>1,b=>7,g=>5,f=>-2,i=>-1}
500000005fe70200b901eb00
500000005fe70200b901eb00
500000005fe70200b901eb00
00000050eebd40003f00eb00
500000005fe70200b901eb00
500000005fe70200b901eb00
00000050eebd40003f00eb00
500000005fe70200b901eb00
00000050eebd40003f00eb00
-
{e=>6,a=>85,d=>-2,j=>5,c=>-3,k=>-38,h=>1,b=>5,g=>2,f=>-4,i=>-1}
55000000ad4d01007901da00
55000000ad4d01007901da00
55000000ad4d01007901da00
00000055b76880003e80da00
55000000ad4d01007901da00
55000000ad4d01007901da00
00000055b76880003e80da00
55000000ad4d01007901da00
00000055b76880003e80da00
-
{e=>6,a=>-9,d=>-1,j=>0,c=>1,k=>20,h=>1,b=>6,g=>3,f=>-3,i=>-1}
f7ffffffcedd010039001400
f7ffffffcedd010039001400
f7ffffffcedd010039001400
fffffff7c7eac0003c001400
f7ffffffcedd010039001400
f7ffffffcedd010039001400
fffffff7c7eac0003c001400
f7ffffffcedd010039001400
fffffff7c7eac0003c001400
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>5,a=>42,d=>2,j=>4,l=>7,c=>1,k=>-45,h=>5,b=>5,g=>3,f=>2,i=>1}
2a0000008daa01000d01d307
2a0000008daa01000d01d307
2a0000008daa01000d01d307
0000002aa554c000a600d3e0
2a0000008daa01000d01d307
2a0000008daa01000d01d307
0000002aa554c000a600d3e0
2a0000008daa01000d01d307
0000002aa554c000a600d3e0
-
{e=>7,a=>-123,d=>2,j=>5,l=>5,c=>3,k=>-51,h=>4,b=>7,g=>5,f=>-3,i=>0}
85ffffff9fde02004401cd05
85ffffff9fde02004401cd05
85ffffff9fde02004401cd05
ffffff85ed7b40008280cda0
85ffffff9fde02004401cd05
85ffffff9fde02004401cd05
ffffff85ed7b40008280cda0
85ffffff9fde02004401cd05
ffffff85ed7b40008280cda0
-
{e=>0,a=>0,d=>-3,j=>0,l=>2,c=>3,k=>-69,h=>4,b=>4,g=>6,f=>-1,i=>-4}
000000005c7103002400bb02
000000005c7103002400bb02
000000005c7103002400bb02
000000008e8f80009000bb40
000000005c7103002400bb02
000000005c7103002400bb02
000000008e8f80009000bb40
000000005c7103002400bb02
000000008e8f80009000bb40
-
{e=>0,a=>17,d=>-2,j=>3,l=>2,c=>-4,k=>-21,h=>0,b=>6,g=>7,f=>-1,i=>2}
11000000a6f10300d000eb02
11000000a6f10300d000eb02
11000000a6f10300d000eb02
00000011d30fc0000980eb40
11000000a6f10300d000eb02
11000000a6f10300d000eb02
00000011d30fc0000980eb40
11000000a6f10300d000eb02
00000011d30fc0000980eb40
-
{e=>2,a=>-122,d=>2,j=>5,l=>6,c=>0,k=>-75,h=>4,b=>7,g=>2,f=>-3,i=>0}
86ffffff875401004401b506
86ffffff875401004401b506
86ffffff875401004401b506
ffffff86e12a80008280b5c0
86ffffff875401004401b506
86ffffff875401004401b506
ffffff86e12a80008280b5c0
86ffffff875401004401b506
ffffff86e12a80008280b5c0
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>4,a=>-47,m=>-1,d=>-2,j=>0,l=>1,c=>2,k=>8,h=>1,b=>5,g=>4,f=>0,i=>-2}
d1ffffff9509020031000839
d1ffffff9509020031000839
d1ffffff9509020031000839
ffffffd1ab4100003800083c
d1ffffff9509020031000839
d1ffffff9509020031000839
ffffffd1ab4100003800083c
d1ffffff9509020031000839
ffffffd1ab4100003800083c
-
{e=>4,a=>96,m=>1,d=>-1,j=>2,l=>1,c=>-4,k=>62,h=>0,b=>1,g=>6,f=>0,i=>3}
60000000e109030098003e09
60000000e109030098003e09
60000000e109030098003e09
0000006033c180000d003e24
60000000e109030098003e09
60000000e109030098003e09
0000006033c180000d003e24
60000000e109030098003e09
0000006033c180000d003e24
-
{e=>7,a=>119,m=>-3,d=>1,j=>2,l=>5,c=>0,k=>22,h=>2,b=>6,g=>1,f=>-4,i=>2}
7700000046ce00009200162d
7700000046ce00009200162d
7700000046ce00009200162d
00000077c0f84000490016b4
7700000046ce00009200162d
7700000046ce00009200162d
00000077c0f84000490016b4
7700000046ce00009200162d
00000077c0f84000490016b4
-
{e=>5,a=>105,m=>-4,d=>-4,j=>6,l=>5,c=>-3,k=>5,h=>1,b=>4,g=>2,f=>1,i=>0}
690000002c1b010081010525
690000002c1b010081010525
690000002c1b010081010525
0000006996528000230005b0
690000002c1b010081010525
690000002c1b010081010525
0000006996528000230005b0
690000002c1b010081010525
0000006996528000230005b0
-
{e=>3,a=>23,m=>1,d=>-4,j=>1,l=>2,c=>1,k=>-75,h=>5,b=>4,g=>3,f=>0,i=>3}
170000000c8701005d00b50a
170000000c8701005d00b50a
170000000c8701005d00b50a
000000178630c000ac80b544
170000000c8701005d00b50a
170000000c8701005d00b50a
000000178630c000ac80b544
170000000c8701005d00b50a
000000178630c000ac80b544
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>5,n=>3,a=>-113,m=>0,d=>1,j=>4,l=>0,c=>-1,k=>-9,h=>4,b=>0,g=>0,f=>2,i=>-4}
8fffffff782a00002401f70003000000
8fffffff782a00002401f70003000000
8fffffff782a00002401f70003000000
ffffff8f1cd400009200f70060000000
8fffffff782a00002401f70003000000
8fffffff782a00002401f70003000000
ffffff8f1cd400009200f70060000000
8fffffff782a00002401f70003000000
ffffff8f1cd400009200f70060000000
-
{e=>0,n=>4,a=>64,m=>2,d=>-3,j=>4,l=>3,c=>-3,k=>-98,h=>5,b=>3,g=>6,f=>-3,i=>-4}
400000006b51030025019e1304000000
400000006b51030025019e1304000000
400000006b51030025019e1304000000
00000040768b8000b2009e6880000000
400000006b51030025019e1304000000
400000006b51030025019e1304000000
00000040768b8000b2009e6880000000
400000006b51030025019e1304000000
00000040768b8000b2009e6880000000
-
{e=>1,n=>7,a=>-94,m=>-4,d=>3,j=>1,l=>2,c=>2,k=>-115,h=>0,b=>0,g=>6,f=>2,i=>2}
a2ffffffd022030050008d2207000000
a2ffffffd022030050008d2207000000
a2ffffffd022030050008d2207000000
ffffffa20995800008808d50e0000000
a2ffffffd022030050008d2207000000
a2ffffffd022030050008d2207000000
ffffffa20995800008808d50e0000000
a2ffffffd022030050008d2207000000
ffffffa20995800008808d50e0000000
-
{e=>3,n=>0,a=>-84,m=>0,d=>-2,j=>4,l=>2,c=>-1,k=>-57,h=>4,b=>5,g=>4,f=>-1,i=>1}
acffffffbd7702000c01c70200000000
acffffffbd7702000c01c70200000000
acffffffbd7702000c01c70200000000
ffffffacbf3f00008600c74000000000
acffffffbd7702000c01c70200000000
acffffffbd7702000c01c70200000000
ffffffacbf3f00008600c74000000000
acffffffbd7702000c01c70200000000
ffffffacbf3f00008600c74000000000
-
{e=>6,n=>3,a=>-84,m=>0,d=>-2,j=>6,l=>5,c=>-4,k=>45,h=>4,b=>0,g=>3,f=>-1,i=>-3}
acffffffa0fd0100ac012d0503000000
acffffffa0fd0100ac012d0503000000
acffffffa0fd0100ac012d0503000000
ffffffac136ec00097002da060000000
acffffffa0fd0100ac012d0503000000
acffffffa0fd0100ac012d0503000000
ffffffac136ec00097002da060000000
acffffffa0fd0100ac012d0503000000
ffffffac136ec00097002da060000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>2,n=>1,a=>73,m=>-2,d=>1,j=>5,l=>1,c=>-4,k=>34,h=>0,b=>2,g=>0,f=>-2,o=>136,i=>0}
49000000626400004001223101880000
49000000626400004001223101880000
49000000626400004001223101880000
0000004950ac00000280223820880000
49000000626400004001223101880000
49000000626400004001223101880000
0000004950ac00000280223820880000
49000000626400004001223101880000
0000004950ac00000280223820880000
-
{e=>7,n=>0,a=>-14,m=>-2,d=>2,j=>2,l=>3,c=>-2,k=>-24,h=>3,b=>6,g=>5,f=>3,o=>72,i=>1}
f2ffffffb6be02008b00e83300480000
f2ffffffb6be02008b00e83300480000
f2ffffffb6be02008b00e83300480000
fffffff2d97740006500e87800480000
f2ffffffb6be02008b00e83300480000
f2ffffffb6be02008b00e83300480000
fffffff2d97740006500e87800480000
f2ffffffb6be02008b00e83300480000
fffffff2d97740006500e87800480000
-
{e=>7,n=>0,a=>-32,m=>0,d=>3,j=>6,l=>3,c=>-2,k=>-5,h=>3,b=>6,g=>6,f=>1,o=>139,i=>-2}
e0fffffff61e0300b301fb03008b0000
e0fffffff61e0300b301fb03008b0000
e0fffffff61e0300b301fb03008b0000
ffffffe0d9f380007b00fb60008b0000
e0fffffff61e0300b301fb03008b0000
e0fffffff61e0300b301fb03008b0000
ffffffe0d9f380007b00fb60008b0000
e0fffffff61e0300b301fb03008b0000
ffffffe0d9f380007b00fb60008b0000
-
{e=>7,n=>0,a=>-69,m=>2,d=>2,j=>2,l=>1,c=>0,k=>118,h=>3,b=>5,g=>4,f=>-4,o=>156,i=>2}
bbffffff854e020093007611009c0000
bbffffff854e020093007611009c0000
bbffffff854e020093007611009c0000
ffffffbba179000069007628009c0000
bbffffff854e020093007611009c0000
bbffffff854e020093007611009c0000
ffffffbba179000069007628009c0000
bbffffff854e020093007611009c0000
ffffffbba179000069007628009c0000
-
{e=>0,n=>4,a=>-23,m=>-1,d=>-2,j=>3,l=>7,c=>0,k=>44,h=>7,b=>0,g=>5,f=>0,o=>146,i=>1}
e9ffffff80810200cf002c3f04920000
e9ffffff80810200cf002c3f04920000
e9ffffff80810200cf002c3f04920000
ffffffe903014000e5802cfc80920000
e9ffffff80810200cf002c3f04920000
e9ffffff80810200cf002c3f04920000
ffffffe903014000e5802cfc80920000
e9ffffff80810200cf002c3f04920000
ffffffe903014000e5802cfc80920000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
};
-
{a=>116,b=>0}
7400000000000000
74000000000000000000000000000000
74000000000000000000000000000000
0000007400000000
7400000000000000
7400000000000000
00000000000000740000000000000000
7400000000000000
0000007400000000
-
{a=>-38,b=>2}
daffffff02000000
daffffffffffffff0200000000000000
daffffffffffffff0200000000000000
ffffffda40000000
daffffff02000000
daffffff02000000
ffffffffffffffda4000000000000000
daffffff02000000
ffffffda40000000
-
{a=>-116,b=>0}
8cffffff00000000
8cffffffffffffff0000000000000000
8cffffffffffffff0000000000000000
ffffff8c00000000
8cffffff00000000
8cffffff00000000
ffffffffffffff8c0000000000000000
8cffffff00000000
ffffff8c00000000
-
{a=>-9,b=>4}
f7ffffff04000000
f7ffffffffffffff0400000000000000
f7ffffffffffffff0400000000000000
fffffff780000000
f7ffffff04000000
f7ffffff04000000
fffffffffffffff78000000000000000
f7ffffff04000000
fffffff780000000
-
{a=>-84,b=>1}
acffffff01000000
acffffffffffffff0100000000000000
acffffffffffffff0100000000000000
ffffffac20000000
acffffff01000000
acffffff01000000
ffffffffffffffac2000000000000000
acffffff01000000
ffffffac20000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>2,a=>-53,b=>0}
cbffffff10000000
cbffffffffffffff1000000000000000
cbffffffffffffff1000000000000000
ffffffcb08000000
cbffffff10000000
cbffffff10000000
ffffffffffffffcb0800000000000000
cbffffff10000000
ffffffcb08000000
-
{c=>-2,a=>54,b=>3}
3600000033000000
36000000000000003300000000000000
36000000000000003300000000000000
0000003678000000
3600000033000000
3600000033000000
00000000000000367800000000000000
3600000033000000
0000003678000000
-
{c=>-2,a=>90,b=>7}
5a00000037000000
5a000000000000003700000000000000
5a000000000000003700000000000000
0000005af8000000
5a00000037000000
5a00000037000000
000000000000005af800000000000000
5a00000037000000
0000005af8000000
-
{c=>-1,a=>16,b=>0}
1000000038000000
10000000000000003800000000000000
10000000000000003800000000000000
000000101c000000
1000000038000000
1000000038000000
00000000000000101c00000000000000
1000000038000000
000000101c000000
-
{c=>2,a=>66,b=>6}
4200000016000000
42000000000000001600000000000000
42000000000000001600000000000000
00000042c8000000
4200000016000000
4200000016000000
0000000000000042c800000000000000
4200000016000000
00000042c8000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>1,a=>101,b=>3,d=>-4}
650000000b010000
65000000000000000b01000000000000
65000000000000000b01000000000000
0000006566000000
650000000b010000
650000000b010000
00000000000000656600000000000000
650000000b010000
0000006566000000
-
{c=>0,a=>-29,b=>2,d=>-4}
e3ffffff02010000
e3ffffffffffffff0201000000000000
e3ffffffffffffff0201000000000000
ffffffe342000000
e3ffffff02010000
e3ffffff02010000
ffffffffffffffe34200000000000000
e3ffffff02010000
ffffffe342000000
-
{c=>-2,a=>-116,b=>7,d=>2}
8cffffffb7000000
8cffffffffffffffb700000000000000
8cffffffffffffffb700000000000000
ffffff8cf9000000
8cffffffb7000000
8cffffffb7000000
ffffffffffffff8cf900000000000000
8cffffffb7000000
ffffff8cf9000000
-
{c=>-4,a=>-103,b=>1,d=>-2}
99ffffffa1010000
99ffffffffffffffa101000000000000
99ffffffffffffffa101000000000000
ffffff9933000000
99ffffffa1010000
99ffffffa1010000
ffffffffffffff993300000000000000
99ffffffa1010000
ffffff9933000000
-
{c=>-4,a=>90,b=>4,d=>0}
5a00000024000000
5a000000000000002400000000000000
5a000000000000002400000000000000
0000005a90000000
5a00000024000000
5a00000024000000
000000000000005a9000000000000000
5a00000024000000
0000005a90000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>6,c=>-3,a=>-61,b=>2,d=>-2}
c3ffffffaa0d0000
c3ffffffffffffffaa0d000000000000
c3ffffffffffffffaa0d000000000000
ffffffc357600000
c3ffffffaa0d0000
c3ffffffaa0d0000
ffffffffffffffc35760000000000000
c3ffffffaa0d0000
ffffffc357600000
-
{e=>4,c=>1,a=>111,b=>2,d=>3}
6f000000ca080000
6f00000000000000ca08000000000000
6f00000000000000ca08000000000000
0000006f45c00000
6f000000ca080000
6f000000ca080000
000000000000006f45c0000000000000
6f000000ca080000
0000006f45c00000
-
{e=>4,c=>0,a=>-27,b=>3,d=>-2}
e5ffffff83090000
e5ffffffffffffff8309000000000000
e5ffffffffffffff8309000000000000
ffffffe563400000
e5ffffff83090000
e5ffffff83090000
ffffffffffffffe56340000000000000
e5ffffff83090000
ffffffe563400000
-
{e=>0,c=>0,a=>123,b=>5,d=>-2}
7b00000085010000
7b000000000000008501000000000000
7b000000000000008501000000000000
0000007ba3000000
7b00000085010000
7b00000085010000
000000000000007ba300000000000000
7b00000085010000
0000007ba3000000
-
{e=>2,c=>0,a=>92,b=>7,d=>-4}
5c00000007050000
5c000000000000000705000000000000
5c000000000000000705000000000000
0000005ce2200000
5c00000007050000
5c00000007050000
000000000000005ce220000000000000
5c00000007050000
0000005ce2200000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
};
-
{e=>3,c=>0,a=>-105,b=>0,d=>2,f=>0}
97ffffff80060000
97ffffffffffffff8006000000000000
97ffffffffffffff8006000000000000
ffffff9701300000
97ffffff80060000
97ffffff80060000
ffffffffffffff970130000000000000
97ffffff80060000
ffffff9701300000
-
{e=>0,c=>1,a=>-22,b=>2,d=>-1,f=>-2}
eaffffffca610000
eaffffffffffffffca61000000000000
eaffffffffffffffca61000000000000
ffffffea478c0000
eaffffffca610000
eaffffffca610000
ffffffffffffffea478c000000000000
eaffffffca610000
ffffffea478c0000
-
{e=>1,c=>-3,a=>42,b=>2,d=>-1,f=>-1}
2a000000ea730000
2a00000000000000ea73000000000000
2a00000000000000ea73000000000000
0000002a579e0000
2a000000ea730000
2a000000ea730000
000000000000002a579e000000000000
2a000000ea730000
0000002a579e0000
-
{e=>6,c=>0,a=>-26,b=>6,d=>-1,f=>-3}
e6ffffffc65d0000
e6ffffffffffffffc65d000000000000
e6ffffffffffffffc65d000000000000
ffffffe6c3ea0000
e6ffffffc65d0000
e6ffffffc65d0000
ffffffffffffffe6c3ea000000000000
e6ffffffc65d0000
ffffffe6c3ea0000
-
{e=>2,c=>2,a=>65,b=>0,d=>0,f=>0}
4100000010040000
41000000000000001004000000000000
41000000000000001004000000000000
0000004108200000
4100000010040000
4100000010040000
00000000000000410820000000000000
4100000010040000
0000004108200000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
};
-
{e=>0,c=>-2,a=>40,g=>2,b=>5,d=>2,f=>-4}
28000000b5400100
2800000000000000b540010000000000
2800000000000000b540010000000000
00000028b9088000
28000000b5400100
28000000b5400100
0000000000000028b908800000000000
28000000b5400100
00000028b9088000
-
{e=>7,c=>3,a=>118,g=>5,b=>4,d=>-3,f=>-3}
760000005cdf0200
76000000000000005cdf020000000000
76000000000000005cdf020000000000
000000768efb4000
760000005cdf0200
760000005cdf0200
00000000000000768efb400000000000
760000005cdf0200
000000768efb4000
-
{e=>5,c=>-2,a=>-74,g=>3,b=>3,d=>-4,f=>2}
b6ffffff33ab0100
b6ffffffffffffff33ab010000000000
b6ffffffffffffff33ab010000000000
ffffffb67a54c000
b6ffffff33ab0100
b6ffffff33ab0100
ffffffffffffffb67a54c00000000000
b6ffffff33ab0100
ffffffb67a54c000
-
{e=>4,c=>-4,a=>-40,g=>1,b=>7,d=>-4,f=>-1}
d8ffffff27f90000
d8ffffffffffffff27f9000000000000
d8ffffffffffffff27f9000000000000
ffffffd8f24e4000
d8ffffff27f90000
d8ffffff27f90000
ffffffffffffffd8f24e400000000000
d8ffffff27f90000
ffffffd8f24e4000
-
{e=>0,c=>3,a=>18,g=>6,b=>0,d=>-4,f=>1}
1200000018110300
12000000000000001811030000000000
12000000000000001811030000000000
000000120e038000
1200000018110300
1200000018110300
00000000000000120e03800000000000
1200000018110300
000000120e038000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>0,c=>-2,a=>14,g=>3,b=>7,d=>3,f=>0}
0e000000f7800100
0e00000000000000f780010000000000
0e00000000000000f780010000000000
0000000ef980c000
0e000000f7800100
0e000000f7800100
000000000000000ef980c00000000000
0e000000f7800100
0000000ef980c000
-
{e=>1,c=>0,a=>-50,g=>4,b=>7,d=>3,f=>0}
ceffffffc7020200
ceffffffffffffffc702020000000000
ceffffffffffffffc702020000000000
ffffffcee1910000
ceffffffc7020200
ceffffffc7020200
ffffffffffffffcee191000000000000
ceffffffc7020200
ffffffcee1910000
-
{e=>6,c=>-3,a=>101,g=>4,b=>2,d=>-4,f=>0}
650000002a0d0200
65000000000000002a0d020000000000
65000000000000002a0d020000000000
0000006556610000
650000002a0d0200
650000002a0d0200
00000000000000655661000000000000
650000002a0d0200
0000006556610000
-
{e=>4,c=>-1,a=>87,g=>0,b=>1,d=>1,f=>1}
5700000079180000
57000000000000007918000000000000
57000000000000007918000000000000
000000573cc20000
5700000079180000
5700000079180000
00000000000000573cc2000000000000
5700000079180000
000000573cc20000
-
{e=>3,c=>-1,a=>45,g=>7,b=>0,d=>-2,f=>3}
2d000000b8b70300
2d00000000000000b8b7030000000000
2d00000000000000b8b7030000000000
0000002d1f37c000
2d000000b8b70300
2d000000b8b70300
000000000000002d1f37c00000000000
2d000000b8b70300
0000002d1f37c000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>6,a=>-39,d=>0,c=>-2,h=>1,b=>3,g=>7,f=>-3}
d9ffffff33dc030001000000
d9ffffffffffffff33dc030001000000
d9ffffffffffffff33dc030001000000
ffffffd9786bc00020000000
d9ffffff33dc030001000000
d9ffffff33dc030001000000
ffffffffffffffd9786bc00020000000
d9ffffff33dc030001000000
ffffffd9786bc00020000000
-
{e=>2,a=>-6,d=>-3,c=>1,h=>0,b=>1,g=>4,f=>-1}
faffffff4975020000000000
faffffffffffffff4975020000000000
faffffffffffffff4975020000000000
fffffffa26af000000000000
faffffff4975020000000000
faffffff4975020000000000
fffffffffffffffa26af000000000000
faffffff4975020000000000
fffffffa26af000000000000
-
{e=>4,a=>-114,d=>3,c=>-2,h=>2,b=>6,g=>2,f=>3}
8efffffff638010002000000
8efffffffffffffff638010002000000
8efffffffffffffff638010002000000
ffffff8ed9c6800040000000
8efffffff638010002000000
8efffffff638010002000000
ffffffffffffff8ed9c6800040000000
8efffffff638010002000000
ffffff8ed9c6800040000000
-
{e=>2,a=>-117,d=>0,c=>-2,h=>2,b=>3,g=>0,f=>0}
8bffffff3304000002000000
8bffffffffffffff3304000002000000
8bffffffffffffff3304000002000000
ffffff8b7820000040000000
8bffffff3304000002000000
8bffffff3304000002000000
ffffffffffffff8b7820000040000000
8bffffff3304000002000000
ffffff8b7820000040000000
-
{e=>6,a=>120,d=>2,c=>1,h=>5,b=>7,g=>4,f=>-3}
780000008f5c020005000000
78000000000000008f5c020005000000
78000000000000008f5c020005000000
00000078e56b0000a0000000
780000008f5c020005000000
780000008f5c020005000000
0000000000000078e56b0000a0000000
780000008f5c020005000000
00000078e56b0000a0000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>1,a=>52,d=>1,c=>3,h=>2,b=>3,g=>6,f=>2,i=>-3}
340000005b2203002a000000
34000000000000005b2203002a000000
34000000000000005b2203002a000000
000000346c95800054000000
340000005b2203002a000000
340000005b2203002a000000
00000000000000346c95800054000000
340000005b2203002a000000
000000346c95800054000000
-
{e=>3,a=>53,d=>0,c=>0,h=>1,b=>3,g=>6,f=>2,i=>1}
350000000326030009000000
35000000000000000326030009000000
35000000000000000326030009000000
000000356035800024000000
350000000326030009000000
350000000326030009000000
00000000000000356035800024000000
350000000326030009000000
000000356035800024000000
-
{e=>6,a=>16,d=>-4,c=>-1,h=>7,b=>1,g=>6,f=>1,i=>3}
10000000391d03001f000000
1000000000000000391d03001f000000
1000000000000000391d03001f000000
000000103e638000ec000000
10000000391d03001f000000
10000000391d03001f000000
00000000000000103e638000ec000000
10000000391d03001f000000
000000103e638000ec000000
-
{e=>5,a=>110,d=>-3,c=>-2,h=>1,b=>4,g=>6,f=>1,i=>-1}
6e000000741b030039000000
6e00000000000000741b030039000000
6e00000000000000741b030039000000
0000006e9ad380003c000000
6e000000741b030039000000
6e000000741b030039000000
000000000000006e9ad380003c000000
6e000000741b030039000000
0000006e9ad380003c000000
-
{e=>2,a=>-21,d=>1,c=>3,h=>1,b=>2,g=>0,f=>-4,i=>-3}
ebffffff5a44000029000000
ebffffffffffffff5a44000029000000
ebffffffffffffff5a44000029000000
ffffffeb4ca8000034000000
ebffffff5a44000029000000
ebffffff5a44000029000000
ffffffffffffffeb4ca8000034000000
ebffffff5a44000029000000
ffffffeb4ca8000034000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
};
-
{e=>3,a=>-50,d=>3,j=>1,c=>0,h=>3,b=>2,g=>2,f=>3,i=>-2}
ceffffffc236010073000000
ceffffffffffffffc236010073000000
ceffffffffffffffc236010073000000
ffffffce41b6800078800000
ceffffffc236010073000000
ceffffffc236010073000000
ffffffffffffffce41b6800078800000
ceffffffc236010073000000
ffffffce41b6800078800000
-
{e=>1,a=>-3,d=>0,j=>2,c=>-3,h=>2,b=>0,g=>1,f=>-2,i=>-4}
fdffffff28e20000a2000000
fdffffffffffffff28e20000a2000000
fdffffffffffffff28e20000a2000000
fffffffd141c400051000000
fdffffff28e20000a2000000
fdffffff28e20000a2000000
fffffffffffffffd141c400051000000
fdffffff28e20000a2000000
fffffffd141c400051000000
-
{e=>4,a=>52,d=>-2,j=>6,c=>-2,h=>1,b=>2,g=>0,f=>0,i=>-2}
34000000b2090000b1010000
3400000000000000b2090000b1010000
3400000000000000b2090000b1010000
000000345b4000003b000000
34000000b2090000b1010000
34000000b2090000b1010000
00000000000000345b4000003b000000
34000000b2090000b1010000
000000345b4000003b000000
-
{e=>1,a=>99,d=>1,j=>7,c=>3,h=>7,b=>6,g=>4,f=>0,i=>3}
630000005e020200df010000
63000000000000005e020200df010000
63000000000000005e020200df010000
00000063cc910000ef800000
630000005e020200df010000
630000005e020200df010000
0000000000000063cc910000ef800000
630000005e020200df010000
00000063cc910000ef800000
-
{e=>6,a=>127,d=>2,j=>0,c=>1,h=>5,b=>5,g=>5,f=>1,i=>-2}
7f0000008d9c020035000000
7f000000000000008d9c020035000000
7f000000000000008d9c020035000000
0000007fa5634000b8000000
7f0000008d9c020035000000
7f0000008d9c020035000000
000000000000007fa5634000b8000000
7f0000008d9c020035000000
0000007fa5634000b8000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
};
-
{e=>5,a=>53,d=>-2,j=>1,c=>0,k=>-7,h=>4,b=>1,g=>5,f=>1,i=>-1}
35000000819b02007c00f900
3500000000000000819b02007c00f900
3500000000000000819b02007c00f900
00000035235340009c80f900
35000000819b02007c00f900
35000000819b02007c00f900
0000000000000035235340009c80f900
35000000819b02007c00f900
00000035235340009c80f900
-
{e=>4,a=>-53,d=>-4,j=>2,c=>1,k=>34,h=>7,b=>1,g=>3,f=>0,i=>0}
cbffffff0989010087002200
cbffffffffffffff0989010087002200
cbffffffffffffff0989010087002200
ffffffcb2640c000e1002200
cbffffff0989010087002200
cbffffff0989010087002200
ffffffffffffffcb2640c000e1002200
cbffffff0989010087002200
ffffffcb2640c000e1002200
-
{e=>6,a=>-45,d=>3,j=>5,c=>1,k=>97,h=>4,b=>6,g=>0,f=>-3,i=>2}
d3ffffffce5c000054016100
d3ffffffffffffffce5c000054016100
d3ffffffffffffffce5c000054016100
ffffffd3c5ea00008a806100
d3ffffffce5c000054016100
d3ffffffce5c000054016100
ffffffffffffffd3c5ea00008a806100
d3ffffffce5c000054016100
ffffffd3c5ea00008a806100
-
{e=>1,a=>65,d=>1,j=>0,c=>0,k=>30,h=>0,b=>0,g=>2,f=>3,i=>-4}
410000004032010020001e00
41000000000000004032010020001e00
41000000000000004032010020001e00
000000410096800010001e00
410000004032010020001e00
410000004032010020001e00
00000000000000410096800010001e00
410000004032010020001e00
000000410096800010001e00
-
{e=>1,a=>-80,d=>-4,j=>5,c=>-3,k=>115,h=>3,b=>5,g=>3,f=>-4,i=>3}
b0ffffff2dc301005b017300
b0ffffffffffffff2dc301005b017300
b0ffffffffffffff2dc301005b017300
ffffffb0b618c0006e807300
b0ffffff2dc301005b017300
b0ffffff2dc301005b017300
ffffffffffffffb0b618c0006e807300
b0ffffff2dc301005b017300
ffffffb0b618c0006e807300
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>4,a=>122,d=>2,j=>4,l=>5,c=>-3,k=>111,h=>7,b=>3,g=>4,f=>2,i=>2}
7a000000ab28020017016f05
7a00000000000000ab28020017016f05
7a00000000000000ab28020017016f05
0000007a75450000ea006fa0
7a000000ab28020017016f05
7a000000ab28020017016f05
000000000000007a75450000ea006fa0
7a000000ab28020017016f05
0000007a75450000ea006fa0
-
{e=>4,a=>-118,d=>2,j=>0,l=>5,c=>-1,k=>9,h=>1,b=>4,g=>4,f=>1,i=>-3}
8affffffbc18020029000905
8affffffffffffffbc18020029000905
8affffffffffffffbc18020029000905
ffffff8a9d430000340009a0
8affffffbc18020029000905
8affffffbc18020029000905
ffffffffffffff8a9d430000340009a0
8affffffbc18020029000905
ffffff8a9d430000340009a0
-
{e=>7,a=>-99,d=>-3,j=>1,l=>6,c=>3,k=>-51,h=>4,b=>0,g=>0,f=>2,i=>-1}
9dffffff582f00007c00cd06
9dffffffffffffff582f00007c00cd06
9dffffffffffffff582f00007c00cd06
ffffff9d0ef400009c80cdc0
9dffffff582f00007c00cd06
9dffffff582f00007c00cd06
ffffffffffffff9d0ef400009c80cdc0
9dffffff582f00007c00cd06
ffffff9d0ef400009c80cdc0
-
{e=>5,a=>46,d=>-1,j=>7,l=>2,c=>-4,k=>-82,h=>4,b=>6,g=>6,f=>-4,i=>-1}
2e000000e64b0300fc01ae02
2e00000000000000e64b0300fc01ae02
2e00000000000000e64b0300fc01ae02
0000002ed3d980009f80ae40
2e000000e64b0300fc01ae02
2e000000e64b0300fc01ae02
000000000000002ed3d980009f80ae40
2e000000e64b0300fc01ae02
0000002ed3d980009f80ae40
-
{e=>5,a=>-15,d=>-4,j=>3,l=>1,c=>3,k=>-7,h=>3,b=>7,g=>2,f=>-3,i=>3}
f1ffffff1f5b0100db00f901
f1ffffffffffffff1f5b0100db00f901
f1ffffffffffffff1f5b0100db00f901
fffffff1ee5a80006d80f920
f1ffffff1f5b0100db00f901
f1ffffff1f5b0100db00f901
fffffffffffffff1ee5a80006d80f920
f1ffffff1f5b0100db00f901
fffffff1ee5a80006d80f920
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>3,a=>-125,m=>2,d=>0,j=>0,l=>5,c=>-2,k=>49,h=>6,b=>0,g=>6,f=>3,i=>-4}
83ffffff3036030026003115
83ffffffffffffff3036030026003115
83ffffffffffffff3036030026003115
ffffff8318378000d00031a8
83ffffff3036030026003115
83ffffff3036030026003115
ffffffffffffff8318378000d00031a8
83ffffff3036030026003115
ffffff8318378000d00031a8
-
{e=>5,a=>127,m=>1,d=>-3,j=>3,l=>3,c=>-4,k=>15,h=>1,b=>5,g=>6,f=>3,i=>1}
7f000000653b0300c9000f0b
7f00000000000000653b0300c9000f0b
7f00000000000000653b0300c9000f0b
0000007fb2d7800025800f64
7f000000653b0300c9000f0b
7f000000653b0300c9000f0b
000000000000007fb2d7800025800f64
7f000000653b0300c9000f0b
0000007fb2d7800025800f64
-
{e=>5,a=>-102,m=>2,d=>1,j=>7,l=>4,c=>-2,k=>76,h=>2,b=>5,g=>4,f=>2,i=>0}
9affffff752a0200c2014c14
9affffffffffffff752a0200c2014c14
9affffffffffffff752a0200c2014c14
ffffff9ab8d5000043804c88
9affffff752a0200c2014c14
9affffff752a0200c2014c14
ffffffffffffff9ab8d5000043804c88
9affffff752a0200c2014c14
ffffff9ab8d5000043804c88
-
{e=>3,a=>83,m=>-2,d=>-3,j=>6,l=>6,c=>-4,k=>56,h=>4,b=>0,g=>3,f=>1,i=>-1}
5300000060970100bc013836
530000000000000060970100bc013836
530000000000000060970100bc013836
0000005312b2c0009f0038d8
5300000060970100bc013836
5300000060970100bc013836
000000000000005312b2c0009f0038d8
5300000060970100bc013836
0000005312b2c0009f0038d8
-
{e=>1,a=>-24,m=>-4,d=>-3,j=>0,l=>0,c=>2,k=>-52,h=>5,b=>6,g=>3,f=>2,i=>-2}
e8ffffff56a301003500cc20
e8ffffffffffffff56a301003500cc20
e8ffffffffffffff56a301003500cc20
ffffffe8ca94c000b800cc10
e8ffffff56a301003500cc20
e8ffffff56a301003500cc20
ffffffffffffffe8ca94c000b800cc10
e8ffffff56a301003500cc20
ffffffe8ca94c000b800cc10
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>5,n=>0,a=>74,m=>-2,d=>1,j=>6,l=>3,c=>2,k=>113,h=>1,b=>0,g=>0,f=>0,i=>-4}
4a000000500a0000a101713300000000
4a00000000000000500a0000a10171330000000000000000
4a00000000000000500a0000a10171330000000000000000
0000004a08d000003300717800000000
4a000000500a0000a101713300000000
4a000000500a0000a101713300000000
000000000000004a08d00000330071780000000000000000
4a000000500a0000a101713300000000
0000004a08d000003300717800000000
-
{e=>5,n=>3,a=>-44,m=>1,d=>-3,j=>3,l=>6,c=>2,k=>-63,h=>7,b=>0,g=>4,f=>-1,i=>3}
d4ffffff507b0200df00c10e03000000
d4ffffffffffffff507b0200df00c10e0300000000000000
d4ffffffffffffff507b0200df00c10e0300000000000000
ffffffd40adf0000ed80c1c460000000
d4ffffff507b0200df00c10e03000000
d4ffffff507b0200df00c10e03000000
ffffffffffffffd40adf0000ed80c1c46000000000000000
d4ffffff507b0200df00c10e03000000
ffffffd40adf0000ed80c1c460000000
-
{e=>5,n=>1,a=>39,m=>1,d=>-3,j=>5,l=>0,c=>0,k=>1,h=>0,b=>1,g=>3,f=>2,i=>-1}
2700000041ab01007801010801000000
270000000000000041ab0100780101080100000000000000
270000000000000041ab0100780101080100000000000000
0000002722d4c0001e80010420000000
2700000041ab01007801010801000000
2700000041ab01007801010801000000
000000000000002722d4c0001e8001042000000000000000
2700000041ab01007801010801000000
0000002722d4c0001e80010420000000
-
{e=>4,n=>3,a=>97,m=>-3,d=>-3,j=>7,l=>4,c=>-3,k=>75,h=>5,b=>6,g=>5,f=>3,i=>3}
610000006eb90200dd014b2c03000000
61000000000000006eb90200dd014b2c0300000000000000
61000000000000006eb90200dd014b2c0300000000000000
00000061d6c74000af804b9460000000
610000006eb90200dd014b2c03000000
610000006eb90200dd014b2c03000000
0000000000000061d6c74000af804b946000000000000000
610000006eb90200dd014b2c03000000
00000061d6c74000af804b9460000000
-
{e=>1,n=>3,a=>77,m=>1,d=>-2,j=>3,l=>6,c=>-4,k=>50,h=>4,b=>0,g=>1,f=>-2,i=>-4}
4d000000a0e30000e400320e03000000
4d00000000000000a0e30000e400320e0300000000000000
4d00000000000000a0e30000e400320e0300000000000000
0000004d131c4000918032c460000000
4d000000a0e30000e400320e03000000
4d000000a0e30000e400320e03000000
000000000000004d131c4000918032c46000000000000000
4d000000a0e30000e400320e03000000
0000004d131c4000918032c460000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct mixed_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>2,n=>1,a=>104,m=>0,d=>3,j=>1,l=>6,c=>2,k=>-66,h=>7,b=>0,g=>4,f=>-1,o=>189,i=>-3}
68000000d07402006f00be0601bd0000
6800000000000000d07402006f00be0601bd000000000000
6800000000000000d07402006f00be0601bd000000000000
0000006809af0000f480bec020bd0000
68000000d07402006f00be0601bd0000
68000000d07402006f00be0601bd0000
000000000000006809af0000f480bec020bd000000000000
68000000d07402006f00be0601bd0000
0000006809af0000f480bec020bd0000
-
{e=>4,n=>1,a=>-82,m=>-1,d=>-2,j=>2,l=>6,c=>3,k=>81,h=>7,b=>1,g=>0,f=>-2,o=>27,i=>-3}
aeffffff99690000af00513e011b0000
aeffffffffffffff99690000af00513e011b000000000000
aeffffffffffffff99690000af00513e011b000000000000
ffffffae2f4c0000f50051dc201b0000
aeffffff99690000af00513e011b0000
aeffffff99690000af00513e011b0000
ffffffffffffffae2f4c0000f50051dc201b000000000000
aeffffff99690000af00513e011b0000
ffffffae2f4c0000f50051dc201b0000
-
{e=>0,n=>0,a=>110,m=>-3,d=>0,j=>2,l=>6,c=>-3,k=>27,h=>6,b=>6,g=>5,f=>0,o=>50,i=>3}
6e0000002e8002009e001b2e00320000
6e000000000000002e8002009e001b2e0032000000000000
6e000000000000002e8002009e001b2e0032000000000000
0000006ed4014000cd001bd400320000
6e0000002e8002009e001b2e00320000
6e0000002e8002009e001b2e00320000
000000000000006ed4014000cd001bd40032000000000000
6e0000002e8002009e001b2e00320000
0000006ed4014000cd001bd400320000
-
{e=>0,n=>5,a=>65,m=>-4,d=>1,j=>3,l=>2,c=>-1,k=>-88,h=>2,b=>4,g=>7,f=>0,o=>17,i=>1}
410000007c800300ca00a82205110000
41000000000000007c800300ca00a8220511000000000000
41000000000000007c800300ca00a8220511000000000000
000000419c81c0004580a850a0110000
410000007c800300ca00a82205110000
410000007c800300ca00a82205110000
00000000000000419c81c0004580a850a011000000000000
410000007c800300ca00a82205110000
000000419c81c0004580a850a0110000
-
{e=>2,n=>3,a=>51,m=>-2,d=>-3,j=>1,l=>1,c=>-1,k=>-125,h=>6,b=>2,g=>2,f=>-2,o=>98,i=>2}
330000007a6501005600833103620000
33000000000000007a650100560083310362000000000000
33000000000000007a650100560083310362000000000000
000000335eac8000c880833860620000
330000007a6501005600833103620000
330000007a6501005600833103620000
00000000000000335eac8000c88083386062000000000000
330000007a6501005600833103620000
000000335eac8000c880833860620000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
};
-
{a=>4}
04000000
04000000
04000000
80000000
04000000
04000000
80000000
04000000
80000000
-
{a=>3}
03000000
03000000
03000000
60000000
03000000
03000000
60000000
03000000
60000000
-
{a=>1}
01000000
01000000
01000000
20000000
01000000
01000000
20000000
01000000
20000000
-
{a=>5}
05000000
05000000
05000000
a0000000
05000000
05000000
a0000000
05000000
a0000000
-
{a=>3}
03000000
03000000
03000000
60000000
03000000
03000000
60000000
03000000
60000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
};
-
{a=>1,b=>-2}
31000000
31000000
31000000
38000000
31000000
31000000
38000000
31000000
38000000
-
{a=>2,b=>3}
1a000000
1a000000
1a000000
4c000000
1a000000
1a000000
4c000000
1a000000
4c000000
-
{a=>2,b=>2}
12000000
12000000
12000000
48000000
12000000
12000000
48000000
12000000
48000000
-
{a=>2,b=>-2}
32000000
32000000
32000000
58000000
32000000
32000000
58000000
32000000
58000000
-
{a=>5,b=>-4}
25000000
25000000
25000000
b0000000
25000000
25000000
b0000000
25000000
b0000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
};
-
{c=>0,a=>0,b=>3}
18000000
18000000
18000000
0c000000
18000000
18000000
0c000000
18000000
0c000000
-
{c=>-3,a=>0,b=>-3}
68010000
68010000
68010000
16800000
68010000
68010000
16800000
68010000
16800000
-
{c=>-3,a=>3,b=>-4}
63010000
63010000
63010000
72800000
63010000
63010000
72800000
63010000
72800000
-
{c=>-2,a=>6,b=>-2}
b6010000
b6010000
b6010000
db000000
b6010000
b6010000
db000000
b6010000
db000000
-
{c=>-1,a=>4,b=>-3}
ec010000
ec010000
ec010000
97800000
ec010000
ec010000
97800000
ec010000
97800000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
};
-
{c=>0,a=>5,b=>-1,d=>0}
3d000000
3d000000
3d000000
bc000000
3d000000
3d000000
bc000000
3d000000
bc000000
-
{c=>3,a=>4,b=>-2,d=>4}
f4080000
f4080000
f4080000
99c00000
f4080000
f4080000
99c00000
f4080000
99c00000
-
{c=>2,a=>0,b=>-1,d=>4}
b8080000
b8080000
b8080000
1d400000
b8080000
b8080000
1d400000
b8080000
1d400000
-
{c=>-3,a=>4,b=>2,d=>3}
54070000
54070000
54070000
8ab00000
54070000
54070000
8ab00000
54070000
8ab00000
-
{c=>-2,a=>0,b=>0,d=>7}
800f0000
800f0000
800f0000
03700000
800f0000
800f0000
03700000
800f0000
03700000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
};
-
{e=>1,c=>-1,a=>5,b=>1,d=>0}
cd110000
cd110000
cd110000
a7820000
cd110000
cd110000
a7820000
cd110000
a7820000
-
{e=>-3,c=>-4,a=>1,b=>2,d=>4}
11590000
11590000
11590000
2a4a0000
11590000
11590000
2a4a0000
11590000
2a4a0000
-
{e=>-1,c=>-1,a=>3,b=>0,d=>7}
c37f0000
c37f0000
c37f0000
63fe0000
c37f0000
c37f0000
63fe0000
c37f0000
63fe0000
-
{e=>0,c=>-3,a=>4,b=>-3,d=>0}
6c010000
6c010000
6c010000
96800000
6c010000
6c010000
96800000
6c010000
96800000
-
{e=>2,c=>0,a=>5,b=>1,d=>7}
0d2e0000
0d2e0000
0d2e0000
a4740000
0d2e0000
0d2e0000
a4740000
0d2e0000
a4740000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
};
-
{e=>-1,c=>3,a=>3,b=>-2,d=>2,f=>6}
f3740300
f3740300
f3740300
79af8000
f3740300
f3740300
79af8000
f3740300
79af8000
-
{e=>2,c=>-1,a=>1,b=>-4,d=>5,f=>2}
e12b0100
e12b0100
e12b0100
33d48000
e12b0100
e12b0100
33d48000
e12b0100
33d48000
-
{e=>1,c=>1,a=>3,b=>-4,d=>2,f=>6}
63140300
63140300
63140300
70a38000
63140300
63140300
70a38000
63140300
70a38000
-
{e=>1,c=>-2,a=>2,b=>-4,d=>2,f=>3}
a2950100
a2950100
a2950100
5322c000
a2950100
a2950100
5322c000
a2950100
5322c000
-
{e=>0,c=>0,a=>5,b=>-4,d=>4,f=>5}
25880200
25880200
25880200
b0414000
25880200
25880200
b0414000
25880200
b0414000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
};
-
{e=>-4,c=>-1,a=>5,b=>3,d=>2,f=>2}
dd450100
dd450100
dd450100
afa88000
dd450100
dd450100
afa88000
dd450100
afa88000
-
{e=>1,c=>-1,a=>3,b=>2,d=>7,f=>6}
d31f0300
d31f0300
d31f0300
6bf38000
d31f0300
d31f0300
6bf38000
d31f0300
6bf38000
-
{e=>-1,c=>3,a=>0,b=>1,d=>4,f=>5}
c8f80200
c8f80200
c8f80200
05cf4000
c8f80200
c8f80200
05cf4000
c8f80200
05cf4000
-
{e=>1,c=>-4,a=>2,b=>1,d=>1,f=>7}
0a930300
0a930300
0a930300
4613c000
0a930300
0a930300
4613c000
0a930300
4613c000
-
{e=>-4,c=>-3,a=>2,b=>-1,d=>4,f=>1}
7ac90000
7ac90000
7ac90000
5ec84000
7ac90000
7ac90000
5ec84000
7ac90000
5ec84000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
};
-
{e=>-3,c=>3,a=>4,g=>2,b=>-1,d=>7,f=>5}
fcde020002000000
fcde020002000000
fcde020002000000
9dfb400040000000
fcde020002000000
fcde020002000000
9dfb400040000000
fcde020002000000
9dfb400040000000
-
{e=>0,c=>-4,a=>2,g=>2,b=>-4,d=>5,f=>5}
228b020002000000
228b020002000000
228b020002000000
5251400040000000
228b020002000000
228b020002000000
5251400040000000
228b020002000000
5251400040000000
-
{e=>2,c=>1,a=>1,g=>6,b=>3,d=>3,f=>0}
5926000006000000
5926000006000000
5926000006000000
2cb40000c0000000
5926000006000000
5926000006000000
2cb40000c0000000
5926000006000000
2cb40000c0000000
-
{e=>1,c=>-3,a=>3,g=>6,b=>2,d=>7,f=>0}
531f000006000000
531f000006000000
531f000006000000
6af20000c0000000
531f000006000000
531f000006000000
6af20000c0000000
531f000006000000
6af20000c0000000
-
{e=>-4,c=>0,a=>5,g=>1,b=>-1,d=>3,f=>2}
3d46010001000000
3d46010001000000
3d46010001000000
bc38800020000000
3d46010001000000
3d46010001000000
bc38800020000000
3d46010001000000
bc38800020000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
};
-
{e=>-3,a=>2,d=>5,c=>-4,h=>0,b=>-1,g=>5,f=>7}
3adb030005000000
3adb030005000000
3adb030005000000
5e5bc000a0000000
3adb030005000000
3adb030005000000
5e5bc000a0000000
3adb030005000000
5e5bc000a0000000
-
{e=>-3,a=>4,d=>6,c=>2,h=>-4,b=>3,g=>6,f=>3}
9cdc010026000000
9cdc010026000000
9cdc010026000000
8d6ac000d0000000
9cdc010026000000
9cdc010026000000
8d6ac000d0000000
9cdc010026000000
8d6ac000d0000000
-
{e=>1,a=>4,d=>4,c=>3,h=>-1,b=>-2,g=>6,f=>3}
f49801003e000000
f49801003e000000
f49801003e000000
99c2c000dc000000
f49801003e000000
f49801003e000000
99c2c000dc000000
f49801003e000000
99c2c000dc000000
-
{e=>3,a=>5,d=>5,c=>1,h=>-2,b=>2,g=>6,f=>2}
553a010036000000
553a010036000000
553a010036000000
a8d68000d8000000
553a010036000000
553a010036000000
a8d68000d8000000
553a010036000000
a8d68000d8000000
-
{e=>1,a=>7,d=>6,c=>2,h=>0,b=>3,g=>0,f=>6}
9f1c030000000000
9f1c030000000000
9f1c030000000000
ed63800000000000
9f1c030000000000
9f1c030000000000
ed63800000000000
9f1c030000000000
ed63800000000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
};
-
{e=>2,a=>1,d=>3,c=>-3,h=>1,b=>-4,g=>1,f=>7,i=>5}
61a7030049010000
61a7030049010000
61a7030049010000
32b5c00026800000
61a7030049010000
61a7030049010000
32b5c00026800000
61a7030049010000
32b5c00026800000
-
{e=>-4,a=>1,d=>3,c=>-2,h=>2,b=>-3,g=>7,f=>4,i=>3}
a9470200d7000000
a9470200d7000000
a9470200d7000000
37390000e9800000
a9470200d7000000
a9470200d7000000
37390000e9800000
a9470200d7000000
37390000e9800000
-
{e=>0,a=>2,d=>7,c=>3,h=>2,b=>2,g=>5,f=>2,i=>1}
d20e010055000000
d20e010055000000
d20e010055000000
49f08000a8800000
d20e010055000000
d20e010055000000
49f08000a8800000
d20e010055000000
49f08000a8800000
-
{e=>1,a=>3,d=>2,c=>2,h=>2,b=>0,g=>7,f=>6,i=>0}
8314030017000000
8314030017000000
8314030017000000
61238000e8000000
8314030017000000
8314030017000000
61238000e8000000
8314030017000000
61238000e8000000
-
{e=>-4,a=>3,d=>2,c=>-1,h=>0,b=>-3,g=>4,f=>7,i=>4}
ebc5030004010000
ebc5030004010000
ebc5030004010000
77a9c00082000000
ebc5030004010000
ebc5030004010000
77a9c00082000000
ebc5030004010000
77a9c00082000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
};
-
{e=>0,a=>0,d=>0,j=>-15,c=>0,h=>-4,b=>-2,g=>1,f=>2,i=>3}
30000100e100f100
30000100e100f100
30000100e100f100
180080003180f100
30000100e100f100
30000100e100f100
180080003180f100
30000100e100f100
180080003180f100
-
{e=>-4,a=>2,d=>1,j=>101,c=>3,h=>1,b=>-2,g=>5,f=>1,i=>6}
f2c200008d016500
f2c200008d016500
f2c200008d016500
59984000a7006500
f2c200008d016500
f2c200008d016500
59984000a7006500
f2c200008d016500
59984000a7006500
-
{e=>-1,a=>0,d=>3,j=>90,c=>3,h=>3,b=>2,g=>6,f=>2,i=>1}
d07601005e005a00
d07601005e005a00
d07601005e005a00
09be8000cc805a00
d07601005e005a00
d07601005e005a00
09be8000cc805a00
d07601005e005a00
09be8000cc805a00
-
{e=>-4,a=>2,d=>2,j=>87,c=>3,h=>-1,b=>-1,g=>6,f=>4,i=>4}
fa4402003e015700
fa4402003e015700
fa4402003e015700
5da90000de005700
fa4402003e015700
fa4402003e015700
5da90000de005700
fa4402003e015700
5da90000de005700
-
{e=>1,a=>7,d=>3,j=>-72,c=>1,h=>0,b=>-1,g=>4,f=>1,i=>0}
7f9600000400b800
7f9600000400b800
7f9600000400b800
fcb240008000b800
7f9600000400b800
7f9600000400b800
fcb240008000b800
7f9600000400b800
fcb240008000b800
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
  unsigned char k:3;
};
-
{e=>-3,a=>3,d=>4,j=>77,c=>1,k=>1,h=>-3,b=>2,g=>3,f=>0,i=>2}
53580000ab004d01
53580000ab004d01
53580000ab004d01
68ca000075004d20
53580000ab004d01
53580000ab004d01
68ca000075004d20
53580000ab004d01
68ca000075004d20
-
{e=>1,a=>1,d=>1,j=>20,c=>2,k=>1,h=>1,b=>-3,g=>3,f=>3,i=>4}
a99201000b011401
a99201000b011401
a99201000b011401
3512c00066001420
a99201000b011401
a99201000b011401
3512c00066001420
a99201000b011401
3512c00066001420
-
{e=>2,a=>5,d=>2,j=>108,c=>1,k=>5,h=>2,b=>0,g=>2,f=>5,i=>2}
45a4020092006c05
45a4020092006c05
45a4020092006c05
a0a5400049006ca0
45a4020092006c05
45a4020092006c05
a0a5400049006ca0
45a4020092006c05
a0a5400049006ca0
-
{e=>3,a=>1,d=>1,j=>-2,c=>1,k=>7,h=>-1,b=>-3,g=>4,f=>4,i=>4}
693202003c01fe07
693202003c01fe07
693202003c01fe07
349700009e00fee0
693202003c01fe07
693202003c01fe07
349700009e00fee0
693202003c01fe07
349700009e00fee0
-
{e=>0,a=>4,d=>7,j=>-104,c=>-2,k=>3,h=>2,b=>-4,g=>2,f=>6,i=>3}
a40f0300d2009803
a40f0300d2009803
a40f0300d2009803
9371800049809860
a40f0300d2009803
a40f0300d2009803
9371800049809860
a40f0300d2009803
9371800049809860
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
};
-
{e=>1,a=>6,d=>7,j=>30,l=>2,c=>-1,k=>0,h=>-3,b=>-2,g=>6,f=>7,i=>5}
f69f03006e011e10
f69f03006e011e10
f69f03006e011e10
dbf3c000d6801e08
f69f03006e011e10
f69f03006e011e10
dbf3c000d6801e08
f69f03006e011e10
dbf3c000d6801e08
-
{e=>1,a=>1,d=>3,j=>-98,l=>0,c=>-1,k=>6,h=>-4,b=>-2,g=>1,f=>3,i=>1}
f197010061009e06
f197010061009e06
f197010061009e06
3bb2c00030809ec0
f197010061009e06
f197010061009e06
3bb2c00030809ec0
f197010061009e06
3bb2c00030809ec0
-
{e=>-2,a=>2,d=>1,j=>-45,l=>-2,c=>1,k=>7,h=>2,b=>-3,g=>0,f=>6,i=>6}
6a6203009001d337
6a6203009001d337
6a6203009001d337
549d80000b00d3f8
6a6203009001d337
6a6203009001d337
549d80000b00d3f8
6a6203009001d337
549d80000b00d3f8
-
{e=>-2,a=>4,d=>2,j=>-1,l=>0,c=>-4,k=>0,h=>-3,b=>0,g=>3,f=>0,i=>4}
046500002b01ff00
046500002b01ff00
046500002b01ff00
822c00007600ff00
046500002b01ff00
046500002b01ff00
822c00007600ff00
046500002b01ff00
822c00007600ff00
-
{e=>3,a=>4,d=>4,j=>110,l=>-1,c=>0,k=>1,h=>2,b=>-4,g=>0,f=>7,i=>6}
24b8030090016e39
24b8030090016e39
24b8030090016e39
9047c0000b006e3c
24b8030090016e39
24b8030090016e39
9047c0000b006e3c
24b8030090016e39
9047c0000b006e3c
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
  unsigned int  m:3;
};
-
{e=>-2,a=>6,m=>4,d=>0,j=>28,l=>-3,c=>-3,k=>2,h=>3,b=>-1,g=>3,f=>5,i=>6}
7ee102009b011c2a04000000
7ee102009b011c2a04000000
7ee102009b011c2a04000000
de8d40006f001c5480000000
7ee102009b011c2a04000000
7ee102009b011c2a04000000
de8d40006f001c5480000000
7ee102009b011c2a04000000
de8d40006f001c5480000000
-
{e=>-1,a=>7,m=>1,d=>6,j=>79,l=>2,c=>1,k=>3,h=>-4,b=>1,g=>1,f=>5,i=>2}
4ffc0200a1004f1301000000
4ffc0200a1004f1301000000
4ffc0200a1004f1301000000
e4ef400031004f6820000000
4ffc0200a1004f1301000000
4ffc0200a1004f1301000000
e4ef400031004f6820000000
4ffc0200a1004f1301000000
e4ef400031004f6820000000
-
{e=>-3,a=>5,m=>2,d=>3,j=>43,l=>-2,c=>-4,k=>3,h=>-4,b=>-3,g=>5,f=>6,i=>5}
2d57030065012b3302000000
2d57030065012b3302000000
2d57030065012b3302000000
b63b8000b2802b7840000000
2d57030065012b3302000000
2d57030065012b3302000000
b63b8000b2802b7840000000
2d57030065012b3302000000
b63b8000b2802b7840000000
-
{e=>-2,a=>6,m=>4,d=>2,j=>62,l=>-2,c=>-4,k=>4,h=>-2,b=>-1,g=>1,f=>5,i=>4}
3ee5020031013e3404000000
3ee5020031013e3404000000
3ee5020031013e3404000000
de2d40003a003e9880000000
3ee5020031013e3404000000
3ee5020031013e3404000000
de2d40003a003e9880000000
3ee5020031013e3404000000
de2d40003a003e9880000000
-
{e=>1,a=>1,m=>0,d=>4,j=>-74,l=>-3,c=>2,k=>1,h=>-2,b=>2,g=>2,f=>6,i=>4}
911803003201b62900000000
911803003201b62900000000
911803003201b62900000000
294380005a00b63400000000
911803003201b62900000000
911803003201b62900000000
294380005a00b63400000000
911803003201b62900000000
294380005a00b63400000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  signed   char e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  unsigned int  i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
  unsigned int  m:3;
  unsigned char n;
};
-
{e=>-4,n=>116,a=>1,m=>6,d=>4,j=>-19,l=>-1,c=>-2,k=>1,h=>0,b=>-1,g=>5,f=>3,i=>5}
b9c901004501ed3906740000
b9c901004501ed3906740000
b9c901004501ed3906740000
3f48c000a280ed3cc0740000
b9c901004501ed3906740000
b9c901004501ed3906740000
3f48c000a280ed3cc0740000
b9c901004501ed3906740000
3f48c000a280ed3cc0740000
-
{e=>2,n=>61,a=>4,m=>3,d=>0,j=>78,l=>-2,c=>3,k=>3,h=>-3,b=>-3,g=>2,f=>0,i=>2}
ec200000aa004e33033d0000
ec200000aa004e33033d0000
ec200000aa004e33033d0000
9584000055004e78603d0000
ec200000aa004e33033d0000
ec200000aa004e33033d0000
9584000055004e78603d0000
ec200000aa004e33033d0000
9584000055004e78603d0000
-
{e=>-1,n=>150,a=>3,m=>2,d=>3,j=>-89,l=>-4,c=>-3,k=>7,h=>-3,b=>-1,g=>3,f=>5,i=>1}
7bf702006b00a72702960000
7bf702006b00a72702960000
7bf702006b00a72702960000
7ebf40007480a7f040960000
7bf702006b00a72702960000
7bf702006b00a72702960000
7ebf40007480a7f040960000
7bf702006b00a72702960000
7ebf40007480a7f040960000
-
{e=>-1,n=>162,a=>3,m=>5,d=>1,j=>46,l=>-2,c=>-1,k=>2,h=>-1,b=>3,g=>4,f=>0,i=>2}
db730000bc002e3205a20000
db730000bc002e3205a20000
db730000bc002e3205a20000
6f9e00009d002e58a0a20000
db730000bc002e3205a20000
db730000bc002e3205a20000
6f9e00009d002e58a0a20000
db730000bc002e3205a20000
6f9e00009d002e58a0a20000
-
{e=>-4,n=>162,a=>2,m=>5,d=>7,j=>-26,l=>2,c=>3,k=>0,h=>3,b=>-2,g=>1,f=>3,i=>6}
f2ce01009901e61005a20000
f2ce01009901e61005a20000
f2ce01009901e61005a20000
59f8c0002f00e608a0a20000
f2ce01009901e61005a20000
f2ce01009901e61005a20000
59f8c0002f00e608a0a20000
f2ce01009901e61005a20000
59f8c0002f00e608a0a20000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
};
-
{a=>-94,b=>6}
a2060000
a2060000
a2060000
a2c00000
a2060000
a2060000
a2c00000
a2060000
a2c00000
-
{a=>-87,b=>1}
a9010000
a9010000
a9010000
a9200000
a9010000
a9010000
a9200000
a9010000
a9200000
-
{a=>-8,b=>2}
f8020000
f8020000
f8020000
f8400000
f8020000
f8020000
f8400000
f8020000
f8400000
-
{a=>-106,b=>2}
96020000
96020000
96020000
96400000
96020000
96020000
96400000
96020000
96400000
-
{a=>-98,b=>5}
9e050000
9e050000
9e050000
9ea00000
9e050000
9e050000
9ea00000
9e050000
9ea00000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>3,a=>-72,b=>5}
b81d0000
b81d0000
b81d0000
b8ac0000
b81d0000
b81d0000
b8ac0000
b81d0000
b8ac0000
-
{c=>0,a=>-13,b=>5}
f3050000
f3050000
f3050000
f3a00000
f3050000
f3050000
f3a00000
f3050000
f3a00000
-
{c=>3,a=>-92,b=>6}
a41e0000
a41e0000
a41e0000
a4cc0000
a41e0000
a41e0000
a4cc0000
a41e0000
a4cc0000
-
{c=>-1,a=>79,b=>3}
4f3b0000
4f3b0000
4f3b0000
4f7c0000
4f3b0000
4f3b0000
4f7c0000
4f3b0000
4f7c0000
-
{c=>-3,a=>-108,b=>7}
942f0000
942f0000
942f0000
94f40000
942f0000
942f0000
94f40000
942f0000
94f40000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>1,a=>49,b=>2,d=>-3}
314a0100
314a0100
314a0100
31468000
314a0100
314a0100
31468000
314a0100
31468000
-
{c=>0,a=>42,b=>7,d=>0}
2a070000
2a070000
2a070000
2ae00000
2a070000
2a070000
2ae00000
2a070000
2ae00000
-
{c=>-4,a=>41,b=>5,d=>-3}
29650100
29650100
29650100
29b28000
29650100
29650100
29b28000
29650100
29b28000
-
{c=>1,a=>-70,b=>4,d=>0}
ba0c0000
ba0c0000
ba0c0000
ba840000
ba0c0000
ba0c0000
ba840000
ba0c0000
ba840000
-
{c=>2,a=>-18,b=>5,d=>-1}
eed50100
eed50100
eed50100
eeab8000
eed50100
eed50100
eeab8000
eed50100
eeab8000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>1,c=>-3,a=>-42,b=>7,d=>-2}
d6af0300
d6af0300
d6af0300
d6f71000
d6af0300
d6af0300
d6f71000
d6af0300
d6f71000
-
{e=>5,c=>-4,a=>109,b=>4,d=>1}
6d640a00
6d640a00
6d640a00
6d90d000
6d640a00
6d640a00
6d90d000
6d640a00
6d90d000
-
{e=>7,c=>-2,a=>-119,b=>4,d=>0}
89340e00
89340e00
89340e00
89987000
89340e00
89340e00
89987000
89340e00
89987000
-
{e=>3,c=>-3,a=>-23,b=>6,d=>0}
e92e0600
e92e0600
e92e0600
e9d43000
e92e0600
e92e0600
e9d43000
e92e0600
e9d43000
-
{e=>1,c=>-4,a=>-38,b=>2,d=>3}
dae20200
dae20200
dae20200
da519000
dae20200
dae20200
da519000
dae20200
da519000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
};
-
{e=>5,c=>-3,a=>-8,b=>3,d=>-1,f=>0}
f8eb0b00
f8eb0b00
f8eb0b00
f877d000
f8eb0b00
f8eb0b00
f877d000
f8eb0b00
f877d000
-
{e=>4,c=>0,a=>3,b=>7,d=>2,f=>2}
03872800
03872800
03872800
03e14400
03872800
03872800
03e14400
03872800
03e14400
-
{e=>4,c=>2,a=>43,b=>3,d=>-4,f=>-3}
2b135900
2b135900
2b135900
2b6a4a00
2b135900
2b135900
2b6a4a00
2b135900
2b6a4a00
-
{e=>2,c=>-3,a=>-97,b=>6,d=>-4,f=>1}
9f2e1500
9f2e1500
9f2e1500
9fd62200
9f2e1500
9f2e1500
9fd62200
9f2e1500
9fd62200
-
{e=>6,c=>3,a=>87,b=>5,d=>2,f=>-1}
579d7c00
579d7c00
579d7c00
57ad6e00
579d7c00
579d7c00
57ad6e00
579d7c00
57ad6e00
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
};
-
{e=>7,c=>2,a=>-29,g=>2,b=>6,d=>-1,f=>-3}
e3d65f01
e3d65f01
e3d65f01
e3cbfa80
e3d65f01
e3d65f01
e3cbfa80
e3d65f01
e3cbfa80
-
{e=>5,c=>3,a=>-72,g=>6,b=>4,d=>-2,f=>0}
b89c0b03
b89c0b03
b89c0b03
b88f5180
b89c0b03
b89c0b03
b88f5180
b89c0b03
b88f5180
-
{e=>4,c=>0,a=>-24,g=>5,b=>4,d=>1,f=>2}
e844a802
e844a802
e844a802
e880c540
e844a802
e844a802
e880c540
e844a802
e880c540
-
{e=>1,c=>-1,a=>-37,g=>1,b=>4,d=>-3,f=>1}
db7c9300
db7c9300
db7c9300
db9e9240
db7c9300
db7c9300
db9e9240
db7c9300
db9e9240
-
{e=>7,c=>-2,a=>92,g=>0,b=>4,d=>-2,f=>-4}
5cb44f00
5cb44f00
5cb44f00
5c9b7800
5cb44f00
5cb44f00
5c9b7800
5cb44f00
5c9b7800
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>7,c=>2,a=>93,g=>4,b=>1,d=>-3,f=>3}
5d513f02
5d513f02
5d513f02
5d2af700
5d513f02
5d513f02
5d2af700
5d513f02
5d2af700
-
{e=>0,c=>-1,a=>-59,g=>5,b=>2,d=>-3,f=>-1}
c57af102
c57af102
c57af102
c55e8f40
c57af102
c57af102
c55e8f40
c57af102
c55e8f40
-
{e=>5,c=>-1,a=>8,g=>5,b=>2,d=>-2,f=>-1}
08bafb02
08bafb02
08bafb02
085f5f40
08bafb02
08bafb02
085f5f40
08bafb02
085f5f40
-
{e=>0,c=>3,a=>-103,g=>5,b=>5,d=>1,f=>0}
995d8002
995d8002
995d8002
99ac8140
995d8002
995d8002
99ac8140
995d8002
99ac8140
-
{e=>5,c=>-3,a=>114,g=>7,b=>1,d=>-4,f=>-1}
7229fb03
7229fb03
7229fb03
72365fc0
7229fb03
7229fb03
72365fc0
7229fb03
72365fc0
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>3,a=>2,d=>0,c=>2,h=>7,b=>5,g=>6,f=>-1}
0215760307000000
0215760307000000
0215760307000000
02a83f80e0000000
0215760307000000
0215760307000000
02a83f80e0000000
0215760307000000
02a83f80e0000000
-
{e=>3,a=>-24,d=>-1,c=>-1,h=>6,b=>3,g=>2,f=>2}
e8fb270106000000
e8fb270106000000
e8fb270106000000
e87fb480c0000000
e8fb270106000000
e8fb270106000000
e87fb480c0000000
e8fb270106000000
e87fb480c0000000
-
{e=>6,a=>66,d=>0,c=>-3,h=>1,b=>3,g=>1,f=>-1}
422bfc0001000000
422bfc0001000000
422bfc0001000000
42746e4020000000
422bfc0001000000
422bfc0001000000
42746e4020000000
422bfc0001000000
42746e4020000000
-
{e=>7,a=>83,d=>3,c=>0,h=>1,b=>1,g=>3,f=>3}
53c1be0101000000
53c1be0101000000
53c1be0101000000
5321f6c020000000
53c1be0101000000
53c1be0101000000
5321f6c020000000
53c1be0101000000
5321f6c020000000
-
{e=>2,a=>47,d=>-1,c=>-1,h=>7,b=>0,g=>5,f=>3}
2ff8b50207000000
2ff8b50207000000
2ff8b50207000000
2f1fa740e0000000
2ff8b50207000000
2ff8b50207000000
2f1fa740e0000000
2ff8b50207000000
2f1fa740e0000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>7,a=>60,d=>-2,c=>0,h=>6,b=>2,g=>2,f=>-2,i=>-2}
3c826f0136000000
3c826f0136000000
3c826f0136000000
3c437c80d8000000
3c826f0136000000
3c826f0136000000
3c437c80d8000000
3c826f0136000000
3c437c80d8000000
-
{e=>6,a=>-97,d=>0,c=>0,h=>0,b=>3,g=>4,f=>0,i=>3}
9f030c0218000000
9f030c0218000000
9f030c0218000000
9f6061000c000000
9f030c0218000000
9f030c0218000000
9f6061000c000000
9f030c0218000000
9f6061000c000000
-
{e=>3,a=>88,d=>-3,c=>-4,h=>7,b=>5,g=>1,f=>-4,i=>-2}
5865c70037000000
5865c70037000000
5865c70037000000
58b2b840f8000000
5865c70037000000
5865c70037000000
58b2b840f8000000
5865c70037000000
58b2b840f8000000
-
{e=>6,a=>86,d=>2,c=>0,h=>5,b=>0,g=>1,f=>3,i=>-2}
5680bc0035000000
5680bc0035000000
5680bc0035000000
56016640b8000000
5680bc0035000000
5680bc0035000000
56016640b8000000
5680bc0035000000
56016640b8000000
-
{e=>0,a=>52,d=>-3,c=>-4,h=>5,b=>5,g=>0,f=>3,i=>3}
346531001d000000
346531001d000000
346531001d000000
34b28600ac000000
346531001d000000
346531001d000000
34b28600ac000000
346531001d000000
34b28600ac000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
};
-
{e=>3,a=>80,d=>-2,j=>7,c=>0,h=>3,b=>2,g=>4,f=>1,i=>3}
50821702db010000
50821702db010000
50821702db010000
504333006f800000
50821702db010000
50821702db010000
504333006f800000
50821702db010000
504333006f800000
-
{e=>7,a=>-43,d=>-3,j=>6,c=>1,h=>2,b=>0,g=>4,f=>0,i=>3}
d5480f029a010000
d5480f029a010000
d5480f029a010000
d506f1004f000000
d5480f029a010000
d5480f029a010000
d506f1004f000000
d5480f029a010000
d506f1004f000000
-
{e=>7,a=>87,d=>0,j=>3,c=>2,h=>7,b=>0,g=>7,f=>-3,i=>2}
5710de03d7000000
5710de03d7000000
5710de03d7000000
57087bc0e9800000
5710de03d7000000
5710de03d7000000
57087bc0e9800000
5710de03d7000000
57087bc0e9800000
-
{e=>1,a=>57,d=>-4,j=>7,c=>-3,h=>2,b=>7,g=>4,f=>2,i=>2}
392f2302d2010000
392f2302d2010000
392f2302d2010000
39f615004b800000
392f2302d2010000
392f2302d2010000
39f615004b800000
392f2302d2010000
39f615004b800000
-
{e=>1,a=>61,d=>0,j=>0,c=>-2,h=>3,b=>3,g=>7,f=>0,i=>1}
3d3382030b000000
3d3382030b000000
3d3382030b000000
3d7811c064000000
3d3382030b000000
3d3382030b000000
3d7811c064000000
3d3382030b000000
3d7811c064000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
};
-
{e=>2,a=>-111,d=>2,j=>6,c=>0,k=>2,h=>7,b=>5,g=>5,f=>-2,i=>1}
9185e4028f010200
9185e4028f010200
9185e4028f010200
91a12d40e7000200
9185e4028f010200
9185e4028f010200
91a12d40e7000200
9185e4028f010200
91a12d40e7000200
-
{e=>3,a=>125,d=>-3,j=>7,c=>2,k=>102,h=>6,b=>4,g=>2,f=>-3,i=>3}
7d545701de016600
7d545701de016600
7d545701de016600
7d8aba80cf806600
7d545701de016600
7d545701de016600
7d8aba80cf806600
7d545701de016600
7d8aba80cf806600
-
{e=>5,a=>-3,d=>-3,j=>4,c=>0,k=>42,h=>5,b=>0,g=>6,f=>-1,i=>-4}
fd407b0325012a00
fd407b0325012a00
fd407b0325012a00
fd02df80b2002a00
fd407b0325012a00
fd407b0325012a00
fd02df80b2002a00
fd407b0325012a00
fd02df80b2002a00
-
{e=>2,a=>-127,d=>0,j=>1,c=>-1,k=>70,h=>5,b=>0,g=>0,f=>1,i=>-2}
8138140075004600
8138140075004600
8138140075004600
811c2200b8804600
8138140075004600
8138140075004600
811c2200b8804600
8138140075004600
811c2200b8804600
-
{e=>0,a=>43,d=>3,j=>3,c=>2,k=>93,h=>4,b=>2,g=>6,f=>1,i=>1}
2bd21003cc005d00
2bd21003cc005d00
2bd21003cc005d00
2b49838085805d00
2bd21003cc005d00
2bd21003cc005d00
2b49838085805d00
2bd21003cc005d00
2b49838085805d00
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>0,a=>-82,d=>1,j=>3,l=>2,c=>-1,k=>124,h=>4,b=>3,g=>7,f=>3,i=>-4}
ae7bb003e4007c02
ae7bb003e4007c02
ae7bb003e4007c02
ae7c87c091807c40
ae7bb003e4007c02
ae7bb003e4007c02
ae7c87c091807c40
ae7bb003e4007c02
ae7c87c091807c40
-
{e=>7,a=>125,d=>-3,j=>6,l=>7,c=>-3,k=>33,h=>0,b=>5,g=>7,f=>2,i=>-3}
7d6daf03a8012107
7d6daf03a8012107
7d6daf03a8012107
7db6f5c0170021e0
7d6daf03a8012107
7d6daf03a8012107
7db6f5c0170021e0
7d6daf03a8012107
7db6f5c0170021e0
-
{e=>0,a=>-27,d=>-1,j=>3,l=>5,c=>-1,k=>41,h=>0,b=>7,g=>6,f=>-2,i=>-2}
e5ff6103f0002905
e5ff6103f0002905
e5ff6103f0002905
e5ff8d80198029a0
e5ff6103f0002905
e5ff6103f0002905
e5ff8d80198029a0
e5ff6103f0002905
e5ff8d80198029a0
-
{e=>6,a=>-76,d=>-3,j=>7,l=>0,c=>0,k=>-16,h=>5,b=>7,g=>4,f=>-1,i=>2}
b4477d02d501f000
b4477d02d501f000
b4477d02d501f000
b4e2ef00ab80f000
b4477d02d501f000
b4477d02d501f000
b4e2ef00ab80f000
b4477d02d501f000
b4e2ef00ab80f000
-
{e=>4,a=>-66,d=>3,j=>1,l=>5,c=>2,k=>-26,h=>1,b=>6,g=>6,f=>0,i=>-1}
bed608037900e605
bed608037900e605
bed608037900e605
bec9c1803c80e6a0
bed608037900e605
bed608037900e605
bec9c1803c80e6a0
bed608037900e605
bec9c1803c80e6a0
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>7,a=>-113,m=>3,d=>-2,j=>5,l=>3,c=>2,k=>-9,h=>0,b=>7,g=>1,f=>0,i=>1}
8f978f004801f71b
8f978f004801f71b
8f978f004801f71b
8feb70400680f76c
8f978f004801f71b
8f978f004801f71b
8feb70400680f76c
8f978f004801f71b
8feb70400680f76c
-
{e=>5,a=>14,m=>3,d=>-4,j=>7,l=>1,c=>-1,k=>41,h=>6,b=>4,g=>0,f=>-2,i=>-4}
0e3c6b00e6012919
0e3c6b00e6012919
0e3c6b00e6012919
0e9e5c00d380292c
0e3c6b00e6012919
0e3c6b00e6012919
0e9e5c00d380292c
0e3c6b00e6012919
0e9e5c00d380292c
-
{e=>1,a=>50,m=>2,d=>3,j=>7,l=>3,c=>-4,k=>-106,h=>4,b=>3,g=>0,f=>-1,i=>-4}
32e37200e4019613
32e37200e4019613
32e37200e4019613
32719e0093809668
32e37200e4019613
32e37200e4019613
32719e0093809668
32e37200e4019613
32719e0093809668
-
{e=>3,a=>122,m=>2,d=>1,j=>5,l=>6,c=>-3,k=>83,h=>4,b=>0,g=>0,f=>-2,i=>2}
7a68660054015316
7a68660054015316
7a68660054015316
7a14bc008a8053c8
7a68660054015316
7a68660054015316
7a14bc008a8053c8
7a68660054015316
7a14bc008a8053c8
-
{e=>4,a=>25,m=>-4,d=>1,j=>5,l=>0,c=>1,k=>115,h=>2,b=>1,g=>6,f=>1,i=>0}
1949180342017320
1949180342017320
1949180342017320
1924c38042807310
1949180342017320
1949180342017320
1924c38042807310
1949180342017320
1924c38042807310
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>3,n=>7,a=>-13,m=>2,d=>-3,j=>4,l=>5,c=>-3,k=>-63,h=>6,b=>1,g=>7,f=>3,i=>3}
f369b7031e01c11507000000
f369b7031e01c11507000000
f369b7031e01c11507000000
f336b7c0ce00c1a8e0000000
f369b7031e01c11507000000
f369b7031e01c11507000000
f336b7c0ce00c1a8e0000000
f369b7031e01c11507000000
f336b7c0ce00c1a8e0000000
-
{e=>2,n=>2,a=>10,m=>2,d=>3,j=>4,l=>0,c=>2,k=>-15,h=>1,b=>3,g=>3,f=>-3,i=>-2}
0ad3d4013101f11002000000
0ad3d4013101f11002000000
0ad3d4013101f11002000000
0a69aac03a00f10840000000
0ad3d4013101f11002000000
0ad3d4013101f11002000000
0a69aac03a00f10840000000
0ad3d4013101f11002000000
0a69aac03a00f10840000000
-
{e=>2,n=>5,a=>53,m=>-2,d=>2,j=>5,l=>1,c=>2,k=>-31,h=>5,b=>7,g=>4,f=>-3,i=>1}
359754024d01e13105000000
359754024d01e13105000000
359754024d01e13105000000
35e92b00a680e138a0000000
359754024d01e13105000000
359754024d01e13105000000
35e92b00a680e138a0000000
359754024d01e13105000000
35e92b00a680e138a0000000
-
{e=>2,n=>3,a=>92,m=>3,d=>3,j=>6,l=>6,c=>-2,k=>99,h=>7,b=>3,g=>4,f=>-4,i=>-2}
5cf34402b701631e03000000
5cf34402b701631e03000000
5cf34402b701631e03000000
5c79a900fb0063cc60000000
5cf34402b701631e03000000
5cf34402b701631e03000000
5c79a900fb0063cc60000000
5cf34402b701631e03000000
5c79a900fb0063cc60000000
-
{e=>2,n=>6,a=>-14,m=>1,d=>0,j=>0,l=>2,c=>-4,k=>1,h=>7,b=>7,g=>4,f=>1,i=>-3}
f22714022f00010a06000000
f22714022f00010a06000000
f22714022f00010a06000000
f2f02300f4000144c0000000
f22714022f00010a06000000
f22714022f00010a06000000
f2f02300f4000144c0000000
f22714022f00010a06000000
f2f02300f4000144c0000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>0,n=>5,a=>61,m=>-2,d=>-4,j=>1,l=>6,c=>1,k=>-87,h=>5,b=>7,g=>7,f=>-1,o=>42,i=>1}
3d0ff1034d00a936052a0000
3d0ff1034d00a936052a0000
3d0ff1034d00a936052a0000
3de60fc0a480a9d8a02a0000
3d0ff1034d00a936052a0000
3d0ff1034d00a936052a0000
3de60fc0a480a9d8a02a0000
3d0ff1034d00a936052a0000
3de60fc0a480a9d8a02a0000
-
{e=>1,n=>4,a=>116,m=>-1,d=>-4,j=>0,l=>7,c=>3,k=>-107,h=>2,b=>6,g=>5,f=>0,o=>162,i=>3}
741e83021a00953f04a20000
741e83021a00953f04a20000
741e83021a00953f04a20000
74ce11404c0095fc80a20000
741e83021a00953f04a20000
741e83021a00953f04a20000
74ce11404c0095fc80a20000
741e83021a00953f04a20000
74ce11404c0095fc80a20000
-
{e=>4,n=>5,a=>114,m=>-3,d=>-2,j=>4,l=>5,c=>-2,k=>68,h=>3,b=>7,g=>3,f=>-2,o=>112,i=>-2}
72b7e9013301442d05700000
72b7e9013301442d05700000
72b7e9013301442d05700000
72fb4cc07a0044b4a0700000
72b7e9013301442d05700000
72b7e9013301442d05700000
72fb4cc07a0044b4a0700000
72b7e9013301442d05700000
72fb4cc07a0044b4a0700000
-
{e=>2,n=>7,a=>-31,m=>-2,d=>-2,j=>7,l=>7,c=>-4,k=>20,h=>2,b=>1,g=>3,f=>-3,o=>162,i=>-2}
e1a1d501f201143707a20000
e1a1d501f201143707a20000
e1a1d501f201143707a20000
e1332ac05b8014f8e0a20000
e1a1d501f201143707a20000
e1a1d501f201143707a20000
e1332ac05b8014f8e0a20000
e1a1d501f201143707a20000
e1332ac05b8014f8e0a20000
-
{e=>2,n=>1,a=>-39,m=>-4,d=>-1,j=>4,l=>3,c=>1,k=>-123,h=>7,b=>7,g=>5,f=>1,o=>105,i=>-2}
d9cf95023701852301690000
d9cf95023701852301690000
d9cf95023701852301690000
d9e7a340fa00857020690000
d9cf95023701852301690000
d9cf95023701852301690000
d9e7a340fa00857020690000
d9cf95023701852301690000
d9e7a340fa00857020690000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
};
-
{a=>103,b=>3}
67000300
67000300
67000300
00676000
67000300
67000300
00676000
67000300
00676000
-
{a=>38,b=>4}
26000400
26000400
26000400
00268000
26000400
26000400
00268000
26000400
00268000
-
{a=>52,b=>0}
34000000
34000000
34000000
00340000
34000000
34000000
00340000
34000000
00340000
-
{a=>-12,b=>3}
f4ff0300
f4ff0300
f4ff0300
fff46000
f4ff0300
f4ff0300
fff46000
f4ff0300
fff46000
-
{a=>5,b=>6}
05000600
05000600
05000600
0005c000
05000600
05000600
0005c000
05000600
0005c000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>0,a=>-92,b=>5}
a4ff0500
a4ff0500
a4ff0500
ffa4a000
a4ff0500
a4ff0500
ffa4a000
a4ff0500
ffa4a000
-
{c=>-2,a=>-97,b=>2}
9fff3200
9fff3200
9fff3200
ff9f5800
9fff3200
9fff3200
ff9f5800
9fff3200
ff9f5800
-
{c=>3,a=>-63,b=>1}
c1ff1900
c1ff1900
c1ff1900
ffc12c00
c1ff1900
c1ff1900
ffc12c00
c1ff1900
ffc12c00
-
{c=>2,a=>93,b=>2}
5d001200
5d001200
5d001200
005d4800
5d001200
5d001200
005d4800
5d001200
005d4800
-
{c=>2,a=>1,b=>3}
01001300
01001300
01001300
00016800
01001300
01001300
00016800
01001300
00016800
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>-2,a=>65,b=>6,d=>-1}
4100f601
4100f601
4100f601
0041db80
4100f601
4100f601
0041db80
4100f601
0041db80
-
{c=>-2,a=>107,b=>0,d=>3}
6b00f000
6b00f000
6b00f000
006b1980
6b00f000
6b00f000
006b1980
6b00f000
006b1980
-
{c=>-2,a=>-7,b=>3,d=>1}
f9ff7300
f9ff7300
f9ff7300
fff97880
f9ff7300
f9ff7300
fff97880
f9ff7300
fff97880
-
{c=>-1,a=>-11,b=>3,d=>0}
f5ff3b00
f5ff3b00
f5ff3b00
fff57c00
f5ff3b00
f5ff3b00
fff57c00
f5ff3b00
fff57c00
-
{c=>-3,a=>-10,b=>7,d=>-3}
f6ff6f01
f6ff6f01
f6ff6f01
fff6f680
f6ff6f01
f6ff6f01
fff6f680
f6ff6f01
fff6f680
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>7,c=>-3,a=>69,b=>7,d=>-2}
4500af0f
4500af0f
4500af0f
0045f770
4500af0f
4500af0f
0045f770
4500af0f
0045f770
-
{e=>1,c=>1,a=>92,b=>7,d=>3}
5c00cf02
5c00cf02
5c00cf02
005ce590
5c00cf02
5c00cf02
005ce590
5c00cf02
005ce590
-
{e=>5,c=>-3,a=>104,b=>7,d=>1}
68006f0a
68006f0a
68006f0a
0068f4d0
68006f0a
68006f0a
0068f4d0
68006f0a
0068f4d0
-
{e=>6,c=>-3,a=>50,b=>7,d=>1}
32006f0c
32006f0c
32006f0c
0032f4e0
32006f0c
32006f0c
0032f4e0
32006f0c
0032f4e0
-
{e=>6,c=>-3,a=>52,b=>5,d=>2}
3400ad0c
3400ad0c
3400ad0c
0034b560
3400ad0c
3400ad0c
0034b560
3400ad0c
0034b560
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
};
-
{e=>2,c=>1,a=>-16,b=>7,d=>-4,f=>2}
f0ff0f25
f0ff0f25
f0ff0f25
fff0e624
f0ff0f25
f0ff0f25
fff0e624
f0ff0f25
fff0e624
-
{e=>3,c=>1,a=>-81,b=>2,d=>-3,f=>-2}
afff4a67
afff4a67
afff4a67
ffaf46bc
afff4a67
afff4a67
ffaf46bc
afff4a67
ffaf46bc
-
{e=>0,c=>-2,a=>-7,b=>6,d=>2,f=>2}
f9ffb620
f9ffb620
f9ffb620
fff9d904
f9ffb620
f9ffb620
fff9d904
f9ffb620
fff9d904
-
{e=>5,c=>3,a=>46,b=>4,d=>1,f=>3}
2e005c3a
2e005c3a
2e005c3a
002e8cd6
2e005c3a
2e005c3a
002e8cd6
2e005c3a
002e8cd6
-
{e=>2,c=>-4,a=>110,b=>3,d=>2,f=>-3}
6e00a354
6e00a354
6e00a354
006e712a
6e00a354
6e00a354
006e712a
6e00a354
006e712a
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
};
-
{e=>1,c=>2,a=>-118,g=>2,b=>2,d=>1,f=>1}
8aff521202000000
8aff521202000000
8aff521202000000
ff8a489240000000
8aff521202000000
8aff521202000000
ff8a489240000000
8aff521202000000
ff8a489240000000
-
{e=>7,c=>-3,a=>73,g=>6,b=>3,d=>-4,f=>3}
49002b3f06000000
49002b3f06000000
49002b3f06000000
00497676c0000000
49002b3f06000000
49002b3f06000000
00497676c0000000
49002b3f06000000
00497676c0000000
-
{e=>0,c=>-4,a=>51,g=>5,b=>3,d=>-1,f=>-1}
3300e37105000000
3300e37105000000
3300e37105000000
0033738ea0000000
3300e37105000000
3300e37105000000
0033738ea0000000
3300e37105000000
0033738ea0000000
-
{e=>6,c=>0,a=>-60,g=>3,b=>4,d=>-3,f=>1}
c4ff441d03000000
c4ff441d03000000
c4ff441d03000000
ffc482e260000000
c4ff441d03000000
c4ff441d03000000
ffc482e260000000
c4ff441d03000000
ffc482e260000000
-
{e=>3,c=>-4,a=>-59,g=>0,b=>1,d=>-3,f=>3}
c5ff613700000000
c5ff613700000000
c5ff613700000000
ffc532b600000000
c5ff613700000000
c5ff613700000000
ffc532b600000000
c5ff613700000000
ffc532b600000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>5,c=>-3,a=>-108,g=>3,b=>6,d=>-1,f=>-4}
94ffee4b03000000
94ffee4b03000000
94ffee4b03000000
ff94d7d860000000
94ffee4b03000000
94ffee4b03000000
ff94d7d860000000
94ffee4b03000000
ff94d7d860000000
-
{e=>0,c=>1,a=>1,g=>6,b=>4,d=>-3,f=>-3}
01004c5106000000
01004c5106000000
01004c5106000000
0001868ac0000000
01004c5106000000
01004c5106000000
0001868ac0000000
01004c5106000000
0001868ac0000000
-
{e=>7,c=>-3,a=>-122,g=>3,b=>2,d=>-4,f=>1}
86ff2a1f03000000
86ff2a1f03000000
86ff2a1f03000000
ff86567260000000
86ff2a1f03000000
86ff2a1f03000000
ff86567260000000
86ff2a1f03000000
ff86567260000000
-
{e=>4,c=>-2,a=>112,g=>2,b=>6,d=>-4,f=>1}
7000361902000000
7000361902000000
7000361902000000
0070da4240000000
7000361902000000
7000361902000000
0070da4240000000
7000361902000000
0070da4240000000
-
{e=>0,c=>-1,a=>-72,g=>6,b=>5,d=>3,f=>-4}
b8fffd4006000000
b8fffd4006000000
b8fffd4006000000
ffb8bd88c0000000
b8fffd4006000000
b8fffd4006000000
ffb8bd88c0000000
b8fffd4006000000
ffb8bd88c0000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>7,a=>108,d=>2,c=>0,h=>5,b=>7,g=>0,f=>3}
6c00873e0000000005000000
6c00873e0000000005000000
6c00873e0000000005000000
006ce17600000000a0000000
6c00873e0000000005000000
6c00873e0000000005000000
006ce17600000000a0000000
6c00873e0000000005000000
006ce17600000000a0000000
-
{e=>3,a=>126,d=>-1,c=>3,h=>6,b=>3,g=>6,f=>-2}
7e00db670600000006000000
7e00db670600000006000000
7e00db670600000006000000
007e6fbcc0000000c0000000
7e00db670600000006000000
7e00db670600000006000000
007e6fbcc0000000c0000000
7e00db670600000006000000
007e6fbcc0000000c0000000
-
{e=>0,a=>-62,d=>-2,c=>-4,h=>1,b=>5,g=>7,f=>-1}
c2ffa5710700000001000000
c2ffa5710700000001000000
c2ffa5710700000001000000
ffc2b30ee000000020000000
c2ffa5710700000001000000
c2ffa5710700000001000000
ffc2b30ee000000020000000
c2ffa5710700000001000000
ffc2b30ee000000020000000
-
{e=>4,a=>102,d=>2,c=>2,h=>7,b=>1,g=>3,f=>-1}
660091780300000007000000
660091780300000007000000
660091780300000007000000
0066294e60000000e0000000
660091780300000007000000
660091780300000007000000
0066294e60000000e0000000
660091780300000007000000
0066294e60000000e0000000
-
{e=>5,a=>-66,d=>2,c=>-4,h=>7,b=>7,g=>7,f=>-2}
beffa76a0700000007000000
beffa76a0700000007000000
beffa76a0700000007000000
ffbef15ce0000000e0000000
beffa76a0700000007000000
beffa76a0700000007000000
ffbef15ce0000000e0000000
beffa76a0700000007000000
ffbef15ce0000000e0000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>7,a=>114,d=>1,c=>-2,h=>7,b=>7,g=>2,f=>-1,i=>-2}
7200777e0200000037000000
7200777e0200000037000000
7200777e0200000037000000
0072f8fe40000000f8000000
7200777e0200000037000000
7200777e0200000037000000
0072f8fe40000000f8000000
7200777e0200000037000000
0072f8fe40000000f8000000
-
{e=>1,a=>-112,d=>-3,c=>2,h=>5,b=>5,g=>1,f=>-2,i=>-2}
90ff55630100000035000000
90ff55630100000035000000
90ff55630100000035000000
ff90aa9c20000000b8000000
90ff55630100000035000000
90ff55630100000035000000
ff90aa9c20000000b8000000
90ff55630100000035000000
ff90aa9c20000000b8000000
-
{e=>5,a=>88,d=>0,c=>1,h=>4,b=>4,g=>6,f=>-2,i=>2}
58000c6a0600000014000000
58000c6a0600000014000000
58000c6a0600000014000000
0058845cc000000088000000
58000c6a0600000014000000
58000c6a0600000014000000
0058845cc000000088000000
58000c6a0600000014000000
0058845cc000000088000000
-
{e=>2,a=>-8,d=>-2,c=>-1,h=>5,b=>0,g=>4,f=>-4,i=>0}
f8ffb8450400000005000000
f8ffb8450400000005000000
f8ffb8450400000005000000
fff81f2880000000a0000000
f8ffb8450400000005000000
f8ffb8450400000005000000
fff81f2880000000a0000000
f8ffb8450400000005000000
fff81f2880000000a0000000
-
{e=>7,a=>-35,d=>3,c=>3,h=>0,b=>4,g=>0,f=>-2,i=>-4}
ddffdc6e0000000020000000
ddffdc6e0000000020000000
ddffdc6e0000000020000000
ffdd8dfc0000000010000000
ddffdc6e0000000020000000
ddffdc6e0000000020000000
ffdd8dfc0000000010000000
ddffdc6e0000000020000000
ffdd8dfc0000000010000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
};
-
{e=>0,a=>-31,d=>-2,j=>5,c=>-3,h=>0,b=>0,g=>5,f=>-3,i=>3}
e1ffa8510500000058010000
e1ffa8510500000058010000
e1ffa8510500000058010000
ffe1170aa00000000e800000
e1ffa8510500000058010000
e1ffa8510500000058010000
ffe1170aa00000000e800000
e1ffa8510500000058010000
ffe1170aa00000000e800000
-
{e=>3,a=>0,d=>-1,j=>1,c=>-1,h=>0,b=>2,g=>1,f=>-2,i=>2}
0000fa670100000050000000
0000fa670100000050000000
0000fa670100000050000000
00005fbc2000000008800000
0000fa670100000050000000
0000fa670100000050000000
00005fbc2000000008800000
0000fa670100000050000000
00005fbc2000000008800000
-
{e=>0,a=>72,d=>-1,j=>5,c=>2,h=>6,b=>5,g=>1,f=>-4,i=>-4}
4800d5410100000066010000
4800d5410100000066010000
4800d5410100000066010000
0048ab8820000000d2800000
4800d5410100000066010000
4800d5410100000066010000
0048ab8820000000d2800000
4800d5410100000066010000
0048ab8820000000d2800000
-
{e=>5,a=>84,d=>1,j=>1,c=>1,h=>3,b=>5,g=>2,f=>-3,i=>2}
54004d5a0200000053000000
54004d5a0200000053000000
54004d5a0200000053000000
0054a4da4000000068800000
54004d5a0200000053000000
54004d5a0200000053000000
0054a4da4000000068800000
54004d5a0200000053000000
0054a4da4000000068800000
-
{e=>2,a=>75,d=>1,j=>3,c=>1,h=>2,b=>7,g=>5,f=>-2,i=>0}
4b004f6405000000c2000000
4b004f6405000000c2000000
4b004f6405000000c2000000
004be4aca000000041800000
4b004f6405000000c2000000
4b004f6405000000c2000000
004be4aca000000041800000
4b004f6405000000c2000000
004be4aca000000041800000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
};
-
{e=>7,a=>-23,d=>-3,j=>1,c=>-3,k=>-79,h=>4,b=>0,g=>6,f=>0,i=>1}
e9ff680f060000004c00b100
e9ff680f060000004c00b100
e9ff680f060000004c00b100
ffe916f0c00000008480b100
e9ff680f060000004c00b100
e9ff680f060000004c00b100
ffe916f0c00000008480b100
e9ff680f060000004c00b100
ffe916f0c00000008480b100
-
{e=>2,a=>-89,d=>0,j=>5,c=>1,k=>-14,h=>6,b=>6,g=>6,f=>3,i=>-3}
a7ff0e34060000006e01f200
a7ff0e34060000006e01f200
a7ff0e34060000006e01f200
ffa7c426c0000000d680f200
a7ff0e34060000006e01f200
a7ff0e34060000006e01f200
ffa7c426c0000000d680f200
a7ff0e34060000006e01f200
ffa7c426c0000000d680f200
-
{e=>1,a=>-23,d=>0,j=>2,c=>1,k=>-2,h=>1,b=>1,g=>5,f=>2,i=>-2}
e9ff092205000000b100fe00
e9ff092205000000b100fe00
e9ff092205000000b100fe00
ffe92414a00000003900fe00
e9ff092205000000b100fe00
e9ff092205000000b100fe00
ffe92414a00000003900fe00
e9ff092205000000b100fe00
ffe92414a00000003900fe00
-
{e=>7,a=>-84,d=>-2,j=>3,c=>-4,k=>1,h=>6,b=>3,g=>4,f=>-2,i=>-4}
acffa36f04000000e6000100
acffa36f04000000e6000100
acffa36f04000000e6000100
ffac737c80000000d1800100
acffa36f04000000e6000100
acffa36f04000000e6000100
ffac737c80000000d1800100
acffa36f04000000e6000100
ffac737c80000000d1800100
-
{e=>4,a=>-2,d=>-1,j=>3,c=>3,k=>-56,h=>3,b=>2,g=>6,f=>0,i=>-2}
feffda0906000000f300c800
feffda0906000000f300c800
feffda0906000000f300c800
fffe4fc0c00000007980c800
feffda0906000000f300c800
feffda0906000000f300c800
fffe4fc0c00000007980c800
feffda0906000000f300c800
fffe4fc0c00000007980c800
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>1,a=>43,d=>-2,j=>3,l=>3,c=>0,k=>-20,h=>3,b=>4,g=>1,f=>1,i=>-2}
2b00841301000000f300ec03
2b00841301000000f300ec03
2b00841301000000f300ec03
002b8312200000007980ec60
2b00841301000000f300ec03
2b00841301000000f300ec03
002b8312200000007980ec60
2b00841301000000f300ec03
002b8312200000007980ec60
-
{e=>1,a=>-33,d=>1,j=>3,l=>2,c=>-3,k=>77,h=>2,b=>4,g=>0,f=>2,i=>2}
dfff6c2200000000d2004d02
dfff6c2200000000d2004d02
dfff6c2200000000d2004d02
ffdf94940000000049804d40
dfff6c2200000000d2004d02
dfff6c2200000000d2004d02
ffdf94940000000049804d40
dfff6c2200000000d2004d02
ffdf94940000000049804d40
-
{e=>7,a=>122,d=>0,j=>5,l=>3,c=>-3,k=>-62,h=>7,b=>5,g=>3,f=>3,i=>0}
7a002d3e030000004701c203
7a002d3e030000004701c203
7a002d3e030000004701c203
007ab47660000000e280c260
7a002d3e030000004701c203
7a002d3e030000004701c203
007ab47660000000e280c260
7a002d3e030000004701c203
007ab47660000000e280c260
-
{e=>4,a=>36,d=>3,j=>2,l=>1,c=>0,k=>-1,h=>6,b=>7,g=>1,f=>-3,i=>-3}
2400c75801000000ae00ff01
2400c75801000000ae00ff01
2400c75801000000ae00ff01
0024e1ca20000000d500ff20
2400c75801000000ae00ff01
2400c75801000000ae00ff01
0024e1ca20000000d500ff20
2400c75801000000ae00ff01
0024e1ca20000000d500ff20
-
{e=>2,a=>126,d=>-4,j=>2,l=>3,c=>0,k=>-47,h=>2,b=>6,g=>7,f=>0,i=>-4}
7e00060507000000a200d103
7e00060507000000a200d103
7e00060507000000a200d103
007ec220e00000005100d160
7e00060507000000a200d103
7e00060507000000a200d103
007ec220e00000005100d160
7e00060507000000a200d103
007ec220e00000005100d160
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>0,a=>-59,m=>-4,d=>1,j=>2,l=>7,c=>0,k=>-30,h=>2,b=>7,g=>7,f=>-1,i=>0}
c5ff4770070000008200e227
c5ff4770070000008200e227
c5ff4770070000008200e227
ffc5e08ee00000004100e2f0
c5ff4770070000008200e227
c5ff4770070000008200e227
ffc5e08ee00000004100e2f0
c5ff4770070000008200e227
ffc5e08ee00000004100e2f0
-
{e=>5,a=>-106,m=>-1,d=>3,j=>2,l=>5,c=>3,k=>84,h=>4,b=>3,g=>3,f=>-3,i=>-1}
96ffdb5a03000000bc00543d
96ffdb5a03000000bc00543d
96ffdb5a03000000bc00543d
ff966dda600000009d0054bc
96ffdb5a03000000bc00543d
96ffdb5a03000000bc00543d
ff966dda600000009d0054bc
96ffdb5a03000000bc00543d
ff966dda600000009d0054bc
-
{e=>1,a=>41,m=>1,d=>1,j=>7,l=>5,c=>2,k=>33,h=>5,b=>7,g=>4,f=>-1,i=>-1}
2900577204000000fd01210d
2900577204000000fd01210d
2900577204000000fd01210d
0029e89e80000000bf8021a4
2900577204000000fd01210d
2900577204000000fd01210d
0029e89e80000000bf8021a4
2900577204000000fd01210d
0029e89e80000000bf8021a4
-
{e=>7,a=>53,m=>0,d=>2,j=>5,l=>6,c=>0,k=>-74,h=>1,b=>1,g=>6,f=>-1,i=>-4}
3500817e060000006101b606
3500817e060000006101b606
3500817e060000006101b606
0035217ec00000003280b6c0
3500817e060000006101b606
3500817e060000006101b606
0035217ec00000003280b6c0
3500817e060000006101b606
0035217ec00000003280b6c0
-
{e=>0,a=>-26,m=>0,d=>-3,j=>0,l=>6,c=>1,k=>94,h=>3,b=>2,g=>5,f=>3,i=>-2}
e6ff4a310500000033005e06
e6ff4a310500000033005e06
e6ff4a310500000033005e06
ffe64686a000000078005ec0
e6ff4a310500000033005e06
e6ff4a310500000033005e06
ffe64686a000000078005ec0
e6ff4a310500000033005e06
ffe64686a000000078005ec0
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>3,n=>3,a=>116,m=>1,d=>-1,j=>4,l=>5,c=>-4,k=>-99,h=>6,b=>1,g=>1,f=>-1,i=>-4}
7400e1770100000026019d0d03000000
7400e1770100000026019d0d03000000
7400e1770100000026019d0d03000000
007433be20000000d2009da460000000
7400e1770100000026019d0d03000000
7400e1770100000026019d0d03000000
007433be20000000d2009da460000000
7400e1770100000026019d0d03000000
007433be20000000d2009da460000000
-
{e=>5,n=>6,a=>-60,m=>-4,d=>-1,j=>1,l=>5,c=>0,k=>-90,h=>3,b=>3,g=>2,f=>-2,i=>-3}
c4ffc36b020000006b00a62506000000
c4ffc36b020000006b00a62506000000
c4ffc36b020000006b00a62506000000
ffc463dc400000007480a6b0c0000000
c4ffc36b020000006b00a62506000000
c4ffc36b020000006b00a62506000000
ffc463dc400000007480a6b0c0000000
c4ffc36b020000006b00a62506000000
ffc463dc400000007480a6b0c0000000
-
{e=>1,n=>3,a=>101,m=>1,d=>1,j=>5,l=>4,c=>-1,k=>0,h=>0,b=>0,g=>3,f=>3,i=>2}
65007832030000005001000c03000000
65007832030000005001000c03000000
65007832030000005001000c03000000
00651c96600000000a80008460000000
65007832030000005001000c03000000
65007832030000005001000c03000000
00651c96600000000a80008460000000
65007832030000005001000c03000000
00651c96600000000a80008460000000
-
{e=>1,n=>5,a=>-81,m=>-2,d=>1,j=>4,l=>7,c=>-3,k=>24,h=>2,b=>7,g=>4,f=>2,i=>1}
afff6f22040000000a01183705000000
afff6f22040000000a01183705000000
afff6f22040000000a01183705000000
ffaff49480000000460018f8a0000000
afff6f22040000000a01183705000000
afff6f22040000000a01183705000000
ffaff49480000000460018f8a0000000
afff6f22040000000a01183705000000
ffaff49480000000460018f8a0000000
-
{e=>5,n=>7,a=>69,m=>-1,d=>-4,j=>4,l=>5,c=>-3,k=>-48,h=>3,b=>1,g=>1,f=>-3,i=>1}
4500295b010000000b01d03d07000000
4500295b010000000b01d03d07000000
4500295b010000000b01d03d07000000
0045365a200000006600d0bce0000000
4500295b010000000b01d03d07000000
4500295b010000000b01d03d07000000
0045365a200000006600d0bce0000000
4500295b010000000b01d03d07000000
0045365a200000006600d0bce0000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>6,n=>1,a=>-4,m=>-3,d=>1,j=>6,l=>4,c=>1,k=>-26,h=>3,b=>6,g=>0,f=>3,o=>238,i=>2}
fcff4e3c000000009301e62c01ee0000
fcff4e3c000000009301e62c01ee0000
fcff4e3c000000009301e62c01ee0000
fffcc4e6000000006b00e69420ee0000
fcff4e3c000000009301e62c01ee0000
fcff4e3c000000009301e62c01ee0000
fffcc4e6000000006b00e69420ee0000
fcff4e3c000000009301e62c01ee0000
fffcc4e6000000006b00e69420ee0000
-
{e=>0,n=>1,a=>-68,m=>-2,d=>1,j=>5,l=>3,c=>-2,k=>121,h=>3,b=>2,g=>1,f=>-2,o=>129,i=>2}
bcff7260010000005301793301810000
bcff7260010000005301793301810000
bcff7260010000005301793301810000
ffbc588c200000006a80797820810000
bcff7260010000005301793301810000
bcff7260010000005301793301810000
ffbc588c200000006a80797820810000
bcff7260010000005301793301810000
ffbc588c200000006a80797820810000
-
{e=>0,n=>3,a=>-111,m=>-4,d=>2,j=>1,l=>5,c=>-4,k=>58,h=>7,b=>2,g=>1,f=>-4,o=>239,i=>-2}
91ffa2400100000077003a2503ef0000
91ffa2400100000077003a2503ef0000
91ffa2400100000077003a2503ef0000
ff91510820000000f8803ab060ef0000
91ffa2400100000077003a2503ef0000
91ffa2400100000077003a2503ef0000
ff91510820000000f8803ab060ef0000
91ffa2400100000077003a2503ef0000
ff91510820000000f8803ab060ef0000
-
{e=>0,n=>5,a=>-114,m=>-2,d=>-4,j=>1,l=>2,c=>2,k=>-17,h=>7,b=>3,g=>3,f=>-3,o=>107,i=>-1}
8eff1351030000007f00ef32056b0000
8eff1351030000007f00ef32056b0000
8eff1351030000007f00ef32056b0000
ff8e6a0a60000000fc80ef58a06b0000
8eff1351030000007f00ef32056b0000
8eff1351030000007f00ef32056b0000
ff8e6a0a60000000fc80ef58a06b0000
8eff1351030000007f00ef32056b0000
ff8e6a0a60000000fc80ef58a06b0000
-
{e=>1,n=>6,a=>-2,m=>1,d=>0,j=>0,l=>6,c=>1,k=>68,h=>6,b=>2,g=>4,f=>-3,o=>139,i=>1}
feff0a52040000000e00440e068b0000
feff0a52040000000e00440e068b0000
feff0a52040000000e00440e068b0000
fffe441a80000000c40044c4c08b0000
feff0a52040000000e00440e068b0000
feff0a52040000000e00440e068b0000
fffe441a80000000c40044c4c08b0000
feff0a52040000000e00440e068b0000
fffe441a80000000c40044c4c08b0000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
};
-
{a=>109,b=>7}
6d00000007000000
6d00000007000000
6d00000007000000
0000006de0000000
6d00000007000000
6d00000007000000
0000006de0000000
6d00000007000000
0000006de0000000
-
{a=>-103,b=>4}
99ffffff04000000
99ffffff04000000
99ffffff04000000
ffffff9980000000
99ffffff04000000
99ffffff04000000
ffffff9980000000
99ffffff04000000
ffffff9980000000
-
{a=>111,b=>4}
6f00000004000000
6f00000004000000
6f00000004000000
0000006f80000000
6f00000004000000
6f00000004000000
0000006f80000000
6f00000004000000
0000006f80000000
-
{a=>-58,b=>4}
c6ffffff04000000
c6ffffff04000000
c6ffffff04000000
ffffffc680000000
c6ffffff04000000
c6ffffff04000000
ffffffc680000000
c6ffffff04000000
ffffffc680000000
-
{a=>117,b=>4}
7500000004000000
7500000004000000
7500000004000000
0000007580000000
7500000004000000
7500000004000000
0000007580000000
7500000004000000
0000007580000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>-4,a=>54,b=>7}
3600000027000000
3600000027000000
3600000027000000
00000036f0000000
3600000027000000
3600000027000000
00000036f0000000
3600000027000000
00000036f0000000
-
{c=>-4,a=>-26,b=>7}
e6ffffff27000000
e6ffffff27000000
e6ffffff27000000
ffffffe6f0000000
e6ffffff27000000
e6ffffff27000000
ffffffe6f0000000
e6ffffff27000000
ffffffe6f0000000
-
{c=>1,a=>35,b=>7}
230000000f000000
230000000f000000
230000000f000000
00000023e4000000
230000000f000000
230000000f000000
00000023e4000000
230000000f000000
00000023e4000000
-
{c=>-3,a=>59,b=>0}
3b00000028000000
3b00000028000000
3b00000028000000
0000003b14000000
3b00000028000000
3b00000028000000
0000003b14000000
3b00000028000000
0000003b14000000
-
{c=>-3,a=>70,b=>2}
460000002a000000
460000002a000000
460000002a000000
0000004654000000
460000002a000000
460000002a000000
0000004654000000
460000002a000000
0000004654000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>-4,a=>-61,b=>4,d=>2}
c3ffffffa4000000
c3ffffffa4000000
c3ffffffa4000000
ffffffc391000000
c3ffffffa4000000
c3ffffffa4000000
ffffffc391000000
c3ffffffa4000000
ffffffc391000000
-
{c=>-3,a=>79,b=>5,d=>3}
4f000000ed000000
4f000000ed000000
4f000000ed000000
0000004fb5800000
4f000000ed000000
4f000000ed000000
0000004fb5800000
4f000000ed000000
0000004fb5800000
-
{c=>-3,a=>-113,b=>0,d=>-3}
8fffffff68010000
8fffffff68010000
8fffffff68010000
ffffff8f16800000
8fffffff68010000
8fffffff68010000
ffffff8f16800000
8fffffff68010000
ffffff8f16800000
-
{c=>-3,a=>-20,b=>5,d=>3}
ecffffffed000000
ecffffffed000000
ecffffffed000000
ffffffecb5800000
ecffffffed000000
ecffffffed000000
ffffffecb5800000
ecffffffed000000
ffffffecb5800000
-
{c=>-1,a=>84,b=>7,d=>-3}
540000007f010000
540000007f010000
540000007f010000
00000054fe800000
540000007f010000
540000007f010000
00000054fe800000
540000007f010000
00000054fe800000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>4,c=>0,a=>-47,b=>6,d=>-1}
d1ffffffc6090000
d1ffffffc6090000
d1ffffffc6090000
ffffffd1c3c00000
d1ffffffc6090000
d1ffffffc6090000
ffffffd1c3c00000
d1ffffffc6090000
ffffffd1c3c00000
-
{e=>3,c=>1,a=>-93,b=>5,d=>-3}
a3ffffff4d070000
a3ffffff4d070000
a3ffffff4d070000
ffffffa3a6b00000
a3ffffff4d070000
a3ffffff4d070000
ffffffa3a6b00000
a3ffffff4d070000
ffffffa3a6b00000
-
{e=>1,c=>3,a=>123,b=>0,d=>-1}
7b000000d8030000
7b000000d8030000
7b000000d8030000
0000007b0f900000
7b000000d8030000
7b000000d8030000
0000007b0f900000
7b000000d8030000
0000007b0f900000
-
{e=>1,c=>-1,a=>-36,b=>7,d=>3}
dcffffffff020000
dcffffffff020000
dcffffffff020000
ffffffdcfd900000
dcffffffff020000
dcffffffff020000
ffffffdcfd900000
dcffffffff020000
ffffffdcfd900000
-
{e=>2,c=>0,a=>-51,b=>2,d=>1}
cdffffff42040000
cdffffff42040000
cdffffff42040000
ffffffcd40a00000
cdffffff42040000
cdffffff42040000
ffffffcd40a00000
cdffffff42040000
ffffffcd40a00000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
};
-
{e=>6,c=>-3,a=>54,b=>4,d=>-3,f=>1}
360000006c1d0000
360000006c1d0000
360000006c1d0000
0000003696e20000
360000006c1d0000
360000006c1d0000
0000003696e20000
360000006c1d0000
0000003696e20000
-
{e=>4,c=>2,a=>53,b=>2,d=>-4,f=>0}
3500000012090000
3500000012090000
3500000012090000
000000354a400000
3500000012090000
3500000012090000
000000354a400000
3500000012090000
000000354a400000
-
{e=>3,c=>1,a=>-32,b=>6,d=>2,f=>1}
e0ffffff8e160000
e0ffffff8e160000
e0ffffff8e160000
ffffffe0c5320000
e0ffffff8e160000
e0ffffff8e160000
ffffffe0c5320000
e0ffffff8e160000
ffffffe0c5320000
-
{e=>4,c=>-4,a=>57,b=>1,d=>-1,f=>-4}
39000000e1490000
39000000e1490000
39000000e1490000
0000003933c80000
39000000e1490000
39000000e1490000
0000003933c80000
39000000e1490000
0000003933c80000
-
{e=>2,c=>-2,a=>-128,b=>2,d=>0,f=>-2}
80ffffff32640000
80ffffff32640000
80ffffff32640000
ffffff80582c0000
80ffffff32640000
80ffffff32640000
ffffff80582c0000
80ffffff32640000
ffffff80582c0000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
};
-
{e=>7,c=>-2,a=>-88,g=>0,b=>2,d=>3,f=>-4}
a8fffffff24e0000
a8fffffff24e0000
a8fffffff24e0000
ffffffa859f80000
a8fffffff24e0000
a8fffffff24e0000
ffffffa859f80000
a8fffffff24e0000
ffffffa859f80000
-
{e=>5,c=>-3,a=>90,g=>6,b=>2,d=>-1,f=>1}
5a000000ea1b0300
5a000000ea1b0300
5a000000ea1b0300
0000005a57d38000
5a000000ea1b0300
5a000000ea1b0300
0000005a57d38000
5a000000ea1b0300
0000005a57d38000
-
{e=>4,c=>3,a=>68,g=>6,b=>2,d=>-1,f=>-3}
44000000da590300
44000000da590300
44000000da590300
000000444fcb8000
44000000da590300
44000000da590300
000000444fcb8000
44000000da590300
000000444fcb8000
-
{e=>0,c=>3,a=>54,g=>6,b=>1,d=>-2,f=>2}
3600000099210300
3600000099210300
3600000099210300
000000362f058000
3600000099210300
3600000099210300
000000362f058000
3600000099210300
000000362f058000
-
{e=>2,c=>2,a=>45,g=>3,b=>1,d=>2,f=>-4}
2d00000091c40100
2d00000091c40100
2d00000091c40100
0000002d2928c000
2d00000091c40100
2d00000091c40100
0000002d2928c000
2d00000091c40100
0000002d2928c000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>3,c=>2,a=>-87,g=>6,b=>4,d=>0,f=>-1}
a9ffffff14760300
a9ffffff14760300
a9ffffff14760300
ffffffa9883f8000
a9ffffff14760300
a9ffffff14760300
ffffffa9883f8000
a9ffffff14760300
ffffffa9883f8000
-
{e=>7,c=>-3,a=>103,g=>6,b=>0,d=>2,f=>-4}
67000000a84e0300
67000000a84e0300
67000000a84e0300
0000006715798000
67000000a84e0300
67000000a84e0300
0000006715798000
67000000a84e0300
0000006715798000
-
{e=>2,c=>2,a=>-32,g=>2,b=>6,d=>2,f=>-2}
e0ffffff96640100
e0ffffff96640100
e0ffffff96640100
ffffffe0c92c8000
e0ffffff96640100
e0ffffff96640100
ffffffe0c92c8000
e0ffffff96640100
ffffffe0c92c8000
-
{e=>5,c=>0,a=>122,g=>7,b=>4,d=>-4,f=>1}
7a000000049b0300
7a000000049b0300
7a000000049b0300
0000007a8253c000
7a000000049b0300
7a000000049b0300
0000007a8253c000
7a000000049b0300
0000007a8253c000
-
{e=>4,c=>-2,a=>-85,g=>0,b=>0,d=>-3,f=>-3}
abffffff70590000
abffffff70590000
abffffff70590000
ffffffab1aca0000
abffffff70590000
abffffff70590000
ffffffab1aca0000
abffffff70590000
ffffffab1aca0000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>2,a=>-79,d=>-4,c=>2,h=>5,b=>0,g=>4,f=>-4}
b1ffffff1045020005000000
b1ffffff1045020005000000
b1ffffff1045020005000000
ffffffb10a290000a0000000
b1ffffff1045020005000000
b1ffffff1045020005000000
ffffffb10a290000a0000000
b1ffffff1045020005000000
ffffffb10a290000a0000000
-
{e=>1,a=>61,d=>1,c=>-2,h=>7,b=>2,g=>4,f=>-3}
3d0000007252020007000000
3d0000007252020007000000
3d0000007252020007000000
0000003d589b0000e0000000
3d0000007252020007000000
3d0000007252020007000000
0000003d589b0000e0000000
3d0000007252020007000000
0000003d589b0000e0000000
-
{e=>7,a=>-36,d=>3,c=>-2,h=>0,b=>2,g=>0,f=>-1}
dcfffffff27e000000000000
dcfffffff27e000000000000
dcfffffff27e000000000000
ffffffdc59fe000000000000
dcfffffff27e000000000000
dcfffffff27e000000000000
ffffffdc59fe000000000000
dcfffffff27e000000000000
ffffffdc59fe000000000000
-
{e=>3,a=>-11,d=>-2,c=>-4,h=>2,b=>6,g=>5,f=>3}
f5ffffffa6b7020002000000
f5ffffffa6b7020002000000
f5ffffffa6b7020002000000
fffffff5d337400040000000
f5ffffffa6b7020002000000
f5ffffffa6b7020002000000
fffffff5d337400040000000
f5ffffffa6b7020002000000
fffffff5d337400040000000
-
{e=>7,a=>-10,d=>1,c=>-3,h=>4,b=>7,g=>0,f=>3}
f6ffffff6f3e000004000000
f6ffffff6f3e000004000000
f6ffffff6f3e000004000000
fffffff6f4f6000080000000
f6ffffff6f3e000004000000
f6ffffff6f3e000004000000
fffffff6f4f6000080000000
f6ffffff6f3e000004000000
fffffff6f4f6000080000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>6,a=>32,d=>-2,c=>1,h=>7,b=>7,g=>0,f=>1,i=>3}
200000008f1d00001f000000
200000008f1d00001f000000
200000008f1d00001f000000
00000020e7620000ec000000
200000008f1d00001f000000
200000008f1d00001f000000
00000020e7620000ec000000
200000008f1d00001f000000
00000020e7620000ec000000
-
{e=>7,a=>-98,d=>-3,c=>3,h=>1,b=>1,g=>1,f=>-1,i=>1}
9effffff59ff000009000000
9effffff59ff000009000000
9effffff59ff000009000000
ffffff9e2efe400024000000
9effffff59ff000009000000
9effffff59ff000009000000
ffffff9e2efe400024000000
9effffff59ff000009000000
ffffff9e2efe400024000000
-
{e=>0,a=>-83,d=>-2,c=>-4,h=>7,b=>5,g=>5,f=>-4,i=>1}
adffffffa5c102000f000000
adffffffa5c102000f000000
adffffffa5c102000f000000
ffffffadb3094000e4000000
adffffffa5c102000f000000
adffffffa5c102000f000000
ffffffadb3094000e4000000
adffffffa5c102000f000000
ffffffadb3094000e4000000
-
{e=>6,a=>-52,d=>-4,c=>-4,h=>5,b=>5,g=>0,f=>-1,i=>-2}
ccffffff257d000035000000
ccffffff257d000035000000
ccffffff257d000035000000
ffffffccb26e0000b8000000
ccffffff257d000035000000
ccffffff257d000035000000
ffffffccb26e0000b8000000
ccffffff257d000035000000
ffffffccb26e0000b8000000
-
{e=>4,a=>123,d=>2,c=>0,h=>6,b=>7,g=>2,f=>-1,i=>0}
7b0000008778010006000000
7b0000008778010006000000
7b0000008778010006000000
0000007be14e8000c0000000
7b0000008778010006000000
7b0000008778010006000000
0000007be14e8000c0000000
7b0000008778010006000000
0000007be14e8000c0000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
};
-
{e=>3,a=>62,d=>-1,j=>3,c=>-2,h=>0,b=>7,g=>2,f=>1,i=>-3}
3e000000f7170100e8000000
3e000000f7170100e8000000
3e000000f7170100e8000000
0000003efbb2800015800000
3e000000f7170100e8000000
3e000000f7170100e8000000
0000003efbb2800015800000
3e000000f7170100e8000000
0000003efbb2800015800000
-
{e=>6,a=>-59,d=>2,j=>5,c=>1,h=>5,b=>5,g=>7,f=>3,i=>0}
c5ffffff8dbc030045010000
c5ffffff8dbc030045010000
c5ffffff8dbc030045010000
ffffffc5a567c000a2800000
c5ffffff8dbc030045010000
c5ffffff8dbc030045010000
ffffffc5a567c000a2800000
c5ffffff8dbc030045010000
ffffffc5a567c000a2800000
-
{e=>6,a=>76,d=>0,j=>7,c=>2,h=>1,b=>4,g=>2,f=>1,i=>-1}
4c000000141c0100f9010000
4c000000141c0100f9010000
4c000000141c0100f9010000
0000004c886280003f800000
4c000000141c0100f9010000
4c000000141c0100f9010000
0000004c886280003f800000
4c000000141c0100f9010000
0000004c886280003f800000
-
{e=>6,a=>-74,d=>0,j=>1,c=>1,h=>5,b=>6,g=>7,f=>3,i=>-1}
b6ffffff0ebc03007d000000
b6ffffff0ebc03007d000000
b6ffffff0ebc03007d000000
ffffffb6c467c000bc800000
b6ffffff0ebc03007d000000
b6ffffff0ebc03007d000000
ffffffb6c467c000bc800000
b6ffffff0ebc03007d000000
ffffffb6c467c000bc800000
-
{e=>0,a=>-90,d=>-4,j=>4,c=>3,h=>5,b=>5,g=>2,f=>-2,i=>0}
a6ffffff1d61010005010000
a6ffffff1d61010005010000
a6ffffff1d61010005010000
ffffffa6ae0c8000a2000000
a6ffffff1d61010005010000
a6ffffff1d61010005010000
ffffffa6ae0c8000a2000000
a6ffffff1d61010005010000
ffffffa6ae0c8000a2000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
};
-
{e=>6,a=>-103,d=>-1,j=>0,c=>1,k=>-31,h=>7,b=>0,g=>1,f=>1,i=>-3}
99ffffffc89d00002f00e100
99ffffffc89d00002f00e100
99ffffffc89d00002f00e100
ffffff9907e24000f400e100
99ffffffc89d00002f00e100
99ffffffc89d00002f00e100
ffffff9907e24000f400e100
99ffffffc89d00002f00e100
ffffff9907e24000f400e100
-
{e=>5,a=>-2,d=>-1,j=>6,c=>0,k=>78,h=>6,b=>1,g=>4,f=>3,i=>3}
feffffffc13b02009e014e00
feffffffc13b02009e014e00
feffffffc13b02009e014e00
fffffffe23d70000cf004e00
feffffffc13b02009e014e00
feffffffc13b02009e014e00
fffffffe23d70000cf004e00
feffffffc13b02009e014e00
fffffffe23d70000cf004e00
-
{e=>3,a=>-110,d=>-1,j=>1,c=>2,k=>-117,h=>6,b=>1,g=>6,f=>1,i=>2}
92ffffffd117030056008b00
92ffffffd117030056008b00
92ffffffd117030056008b00
ffffff922bb38000c8808b00
92ffffffd117030056008b00
92ffffffd117030056008b00
ffffff922bb38000c8808b00
92ffffffd117030056008b00
ffffff922bb38000c8808b00
-
{e=>3,a=>-42,d=>-2,j=>0,c=>-2,k=>-72,h=>4,b=>5,g=>4,f=>-4,i=>1}
d6ffffffb54702000c00b800
d6ffffffb54702000c00b800
d6ffffffb54702000c00b800
ffffffd6bb3900008400b800
d6ffffffb54702000c00b800
d6ffffffb54702000c00b800
ffffffd6bb3900008400b800
d6ffffffb54702000c00b800
ffffffd6bb3900008400b800
-
{e=>1,a=>117,d=>-4,j=>1,c=>-3,k=>97,h=>4,b=>0,g=>1,f=>2,i=>-3}
7500000028a300006c006100
7500000028a300006c006100
7500000028a300006c006100
000000751614400094806100
7500000028a300006c006100
7500000028a300006c006100
000000751614400094806100
7500000028a300006c006100
000000751614400094806100
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>3,a=>-57,d=>2,j=>6,l=>1,c=>0,k=>73,h=>5,b=>5,g=>3,f=>1,i=>-3}
c7ffffff85960100ad014901
c7ffffff85960100ad014901
c7ffffff85960100ad014901
ffffffc7a132c000b7004920
c7ffffff85960100ad014901
c7ffffff85960100ad014901
ffffffc7a132c000b7004920
c7ffffff85960100ad014901
ffffffc7a132c000b7004920
-
{e=>6,a=>-107,d=>1,j=>5,l=>4,c=>-2,k=>25,h=>2,b=>1,g=>3,f=>3,i=>3}
95ffffff71bc01005a011904
95ffffff71bc01005a011904
95ffffff71bc01005a011904
ffffff9538e6c0004e801980
95ffffff71bc01005a011904
95ffffff71bc01005a011904
ffffff9538e6c0004e801980
95ffffff71bc01005a011904
ffffff9538e6c0004e801980
-
{e=>2,a=>108,d=>-3,j=>1,l=>5,c=>-3,k=>74,h=>4,b=>7,g=>4,f=>0,i=>-3}
6c0000006f0502006c004a05
6c0000006f0502006c004a05
6c0000006f0502006c004a05
0000006cf6a1000094804aa0
6c0000006f0502006c004a05
6c0000006f0502006c004a05
0000006cf6a1000094804aa0
6c0000006f0502006c004a05
0000006cf6a1000094804aa0
-
{e=>7,a=>-5,d=>3,j=>2,l=>7,c=>-3,k=>54,h=>0,b=>1,g=>0,f=>-2,i=>-1}
fbffffffe96e0000b8003607
fbffffffe96e0000b8003607
fbffffffe96e0000b8003607
fffffffb35fc00001d0036e0
fbffffffe96e0000b8003607
fbffffffe96e0000b8003607
fffffffb35fc00001d0036e0
fbffffffe96e0000b8003607
fffffffb35fc00001d0036e0
-
{e=>0,a=>-52,d=>2,j=>2,l=>0,c=>0,k=>118,h=>7,b=>0,g=>4,f=>1,i=>3}
ccffffff801002009f007600
ccffffff801002009f007600
ccffffff801002009f007600
ffffffcc01030000ed007600
ccffffff801002009f007600
ccffffff801002009f007600
ffffffcc01030000ed007600
ccffffff801002009f007600
ffffffcc01030000ed007600
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>3,a=>-84,m=>1,d=>0,j=>1,l=>3,c=>-2,k=>78,h=>2,b=>4,g=>7,f=>2,i=>-3}
acffffff34a603006a004e0b
acffffff34a603006a004e0b
acffffff34a603006a004e0b
ffffffac9835c00054804e64
acffffff34a603006a004e0b
acffffff34a603006a004e0b
ffffffac9835c00054804e64
acffffff34a603006a004e0b
ffffffac9835c00054804e64
-
{e=>7,a=>80,m=>-4,d=>0,j=>6,l=>1,c=>3,k=>-88,h=>3,b=>1,g=>7,f=>-3,i=>1}
5000000019de03008b01a821
5000000019de03008b01a821
5000000019de03008b01a821
000000502c7bc0006700a830
5000000019de03008b01a821
5000000019de03008b01a821
000000502c7bc0006700a830
5000000019de03008b01a821
000000502c7bc0006700a830
-
{e=>6,a=>112,m=>-2,d=>1,j=>3,l=>1,c=>3,k=>69,h=>2,b=>1,g=>4,f=>-1,i=>2}
70000000597c0200d2004531
70000000597c0200d2004531
70000000597c0200d2004531
000000702cef000049804538
70000000597c0200d2004531
70000000597c0200d2004531
000000702cef000049804538
70000000597c0200d2004531
000000702cef000049804538
-
{e=>1,a=>110,m=>-1,d=>0,j=>1,l=>3,c=>0,k=>-21,h=>1,b=>4,g=>0,f=>2,i=>1}
6e000000042200004900eb3b
6e000000042200004900eb3b
6e000000042200004900eb3b
0000006e801400002480eb7c
6e000000042200004900eb3b
6e000000042200004900eb3b
0000006e801400002480eb7c
6e000000042200004900eb3b
0000006e801400002480eb7c
-
{e=>7,a=>35,m=>-2,d=>0,j=>1,l=>1,c=>3,k=>36,h=>3,b=>4,g=>4,f=>-4,i=>-3}
230000001c4e02006b002431
230000001c4e02006b002431
230000001c4e02006b002431
000000238c79000074802438
230000001c4e02006b002431
230000001c4e02006b002431
000000238c79000074802438
230000001c4e02006b002431
000000238c79000074802438
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>2,n=>0,a=>-6,m=>3,d=>0,j=>7,l=>2,c=>-4,k=>-55,h=>7,b=>3,g=>5,f=>2,i=>-2}
faffffff23a40200f701c91a00000000
faffffff23a40200f701c91a00000000
faffffff23a40200f701c91a00000000
fffffffa70254000fb80c94c00000000
faffffff23a40200f701c91a00000000
faffffff23a40200f701c91a00000000
fffffffa70254000fb80c94c00000000
faffffff23a40200f701c91a00000000
fffffffa70254000fb80c94c00000000
-
{e=>1,n=>7,a=>-87,m=>0,d=>0,j=>6,l=>4,c=>-2,k=>24,h=>7,b=>2,g=>1,f=>-3,i=>-3}
a9ffffff32d20000af01180407000000
a9ffffff32d20000af01180407000000
a9ffffff32d20000af01180407000000
ffffffa9581a4000f7001880e0000000
a9ffffff32d20000af01180407000000
a9ffffff32d20000af01180407000000
ffffffa9581a4000f7001880e0000000
a9ffffff32d20000af01180407000000
ffffffa9581a4000f7001880e0000000
-
{e=>4,n=>4,a=>-107,m=>-1,d=>-2,j=>6,l=>0,c=>1,k=>-90,h=>5,b=>5,g=>2,f=>-4,i=>-2}
95ffffff8d490100b501a63804000000
95ffffff8d490100b501a63804000000
95ffffff8d490100b501a63804000000
ffffff95a7488000bb00a61c80000000
95ffffff8d490100b501a63804000000
95ffffff8d490100b501a63804000000
ffffff95a7488000bb00a61c80000000
95ffffff8d490100b501a63804000000
ffffff95a7488000bb00a61c80000000
-
{e=>1,n=>5,a=>-24,m=>-2,d=>-4,j=>6,l=>7,c=>1,k=>-102,h=>1,b=>5,g=>0,f=>-2,i=>0}
e8ffffff0d63000081019a3705000000
e8ffffff0d63000081019a3705000000
e8ffffff0d63000081019a3705000000
ffffffe8a61c000023009af8a0000000
e8ffffff0d63000081019a3705000000
e8ffffff0d63000081019a3705000000
ffffffe8a61c000023009af8a0000000
e8ffffff0d63000081019a3705000000
ffffffe8a61c000023009af8a0000000
-
{e=>0,n=>4,a=>127,m=>-2,d=>-1,j=>7,l=>4,c=>-4,k=>68,h=>0,b=>1,g=>4,f=>-4,i=>-3}
7f000000e1410200e801443404000000
7f000000e1410200e801443404000000
7f000000e1410200e801443404000000
0000007f338900001780449880000000
7f000000e1410200e801443404000000
7f000000e1410200e801443404000000
0000007f338900001780449880000000
7f000000e1410200e801443404000000
0000007f338900001780449880000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>2,n=>4,a=>47,m=>3,d=>0,j=>7,l=>0,c=>3,k=>-117,h=>2,b=>3,g=>0,f=>-4,o=>238,i=>-3}
2f0000001b440000ea018b1804ee0000
2f0000001b440000ea018b1804ee0000
2f0000001b440000ea018b1804ee0000
0000002f6c28000057808b0c80ee0000
2f0000001b440000ea018b1804ee0000
2f0000001b440000ea018b1804ee0000
0000002f6c28000057808b0c80ee0000
2f0000001b440000ea018b1804ee0000
0000002f6c28000057808b0c80ee0000
-
{e=>1,n=>4,a=>-56,m=>-3,d=>0,j=>0,l=>3,c=>-3,k=>-65,h=>0,b=>6,g=>7,f=>-2,o=>157,i=>3}
c8ffffff2ee203001800bf2b049d0000
c8ffffff2ee203001800bf2b049d0000
c8ffffff2ee203001800bf2b049d0000
ffffffc8d41dc0000c00bf74809d0000
c8ffffff2ee203001800bf2b049d0000
c8ffffff2ee203001800bf2b049d0000
ffffffc8d41dc0000c00bf74809d0000
c8ffffff2ee203001800bf2b049d0000
ffffffc8d41dc0000c00bf74809d0000
-
{e=>6,n=>5,a=>44,m=>1,d=>1,j=>3,l=>1,c=>1,k=>57,h=>1,b=>7,g=>4,f=>2,o=>68,i=>2}
2c0000004f2c0200d100390905440000
2c0000004f2c0200d100390905440000
2c0000004f2c0200d100390905440000
0000002ce4e5000029803924a0440000
2c0000004f2c0200d100390905440000
2c0000004f2c0200d100390905440000
0000002ce4e5000029803924a0440000
2c0000004f2c0200d100390905440000
0000002ce4e5000029803924a0440000
-
{e=>2,n=>6,a=>-122,m=>0,d=>0,j=>6,l=>6,c=>3,k=>87,h=>1,b=>2,g=>7,f=>2,o=>182,i=>3}
86ffffff1aa403009901570606b60000
86ffffff1aa403009901570606b60000
86ffffff1aa403009901570606b60000
ffffff864c25c0002f0057c0c0b60000
86ffffff1aa403009901570606b60000
86ffffff1aa403009901570606b60000
ffffff864c25c0002f0057c0c0b60000
86ffffff1aa403009901570606b60000
ffffff864c25c0002f0057c0c0b60000
-
{e=>6,n=>4,a=>-93,m=>0,d=>-3,j=>5,l=>2,c=>2,k=>104,h=>6,b=>0,g=>1,f=>-3,o=>134,i=>-1}
a3ffffff50dd00007e01680204860000
a3ffffff50dd00007e01680204860000
a3ffffff50dd00007e01680204860000
ffffffa30aea4000de80684080860000
a3ffffff50dd00007e01680204860000
a3ffffff50dd00007e01680204860000
ffffffa30aea4000de80684080860000
a3ffffff50dd00007e01680204860000
ffffffa30aea4000de80684080860000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
};
-
{a=>92,b=>7}
5c00000007000000
5c000000000000000700000000000000
5c000000000000000700000000000000
0000005ce0000000
5c00000007000000
5c00000007000000
000000000000005ce000000000000000
5c00000007000000
0000005ce0000000
-
{a=>73,b=>2}
4900000002000000
49000000000000000200000000000000
49000000000000000200000000000000
0000004940000000
4900000002000000
4900000002000000
00000000000000494000000000000000
4900000002000000
0000004940000000
-
{a=>-17,b=>2}
efffffff02000000
efffffffffffffff0200000000000000
efffffffffffffff0200000000000000
ffffffef40000000
efffffff02000000
efffffff02000000
ffffffffffffffef4000000000000000
efffffff02000000
ffffffef40000000
-
{a=>6,b=>0}
0600000000000000
06000000000000000000000000000000
06000000000000000000000000000000
0000000600000000
0600000000000000
0600000000000000
00000000000000060000000000000000
0600000000000000
0000000600000000
-
{a=>-12,b=>7}
f4ffffff07000000
f4ffffffffffffff0700000000000000
f4ffffffffffffff0700000000000000
fffffff4e0000000
f4ffffff07000000
f4ffffff07000000
fffffffffffffff4e000000000000000
f4ffffff07000000
fffffff4e0000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>0,a=>5,b=>1}
0500000001000000
05000000000000000100000000000000
05000000000000000100000000000000
0000000520000000
0500000001000000
0500000001000000
00000000000000052000000000000000
0500000001000000
0000000520000000
-
{c=>3,a=>54,b=>3}
360000001b000000
36000000000000001b00000000000000
36000000000000001b00000000000000
000000366c000000
360000001b000000
360000001b000000
00000000000000366c00000000000000
360000001b000000
000000366c000000
-
{c=>3,a=>58,b=>0}
3a00000018000000
3a000000000000001800000000000000
3a000000000000001800000000000000
0000003a0c000000
3a00000018000000
3a00000018000000
000000000000003a0c00000000000000
3a00000018000000
0000003a0c000000
-
{c=>2,a=>-6,b=>6}
faffffff16000000
faffffffffffffff1600000000000000
faffffffffffffff1600000000000000
fffffffac8000000
faffffff16000000
faffffff16000000
fffffffffffffffac800000000000000
faffffff16000000
fffffffac8000000
-
{c=>1,a=>-30,b=>2}
e2ffffff0a000000
e2ffffffffffffff0a00000000000000
e2ffffffffffffff0a00000000000000
ffffffe244000000
e2ffffff0a000000
e2ffffff0a000000
ffffffffffffffe24400000000000000
e2ffffff0a000000
ffffffe244000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>3,a=>18,b=>6,d=>1}
120000005e000000
12000000000000005e00000000000000
12000000000000005e00000000000000
00000012cc800000
120000005e000000
120000005e000000
0000000000000012cc80000000000000
120000005e000000
00000012cc800000
-
{c=>-1,a=>-92,b=>2,d=>-2}
a4ffffffba010000
a4ffffffffffffffba01000000000000
a4ffffffffffffffba01000000000000
ffffffa45f000000
a4ffffffba010000
a4ffffffba010000
ffffffffffffffa45f00000000000000
a4ffffffba010000
ffffffa45f000000
-
{c=>-1,a=>-128,b=>5,d=>3}
80fffffffd000000
80fffffffffffffffd00000000000000
80fffffffffffffffd00000000000000
ffffff80bd800000
80fffffffd000000
80fffffffd000000
ffffffffffffff80bd80000000000000
80fffffffd000000
ffffff80bd800000
-
{c=>-4,a=>-90,b=>0,d=>0}
a6ffffff20000000
a6ffffffffffffff2000000000000000
a6ffffffffffffff2000000000000000
ffffffa610000000
a6ffffff20000000
a6ffffff20000000
ffffffffffffffa61000000000000000
a6ffffff20000000
ffffffa610000000
-
{c=>2,a=>-12,b=>2,d=>2}
f4ffffff92000000
f4ffffffffffffff9200000000000000
f4ffffffffffffff9200000000000000
fffffff449000000
f4ffffff92000000
f4ffffff92000000
fffffffffffffff44900000000000000
f4ffffff92000000
fffffff449000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>4,c=>-2,a=>-52,b=>1,d=>-2}
ccffffffb1090000
ccffffffffffffffb109000000000000
ccffffffffffffffb109000000000000
ffffffcc3b400000
ccffffffb1090000
ccffffffb1090000
ffffffffffffffcc3b40000000000000
ccffffffb1090000
ffffffcc3b400000
-
{e=>3,c=>2,a=>-5,b=>6,d=>0}
fbffffff16060000
fbffffffffffffff1606000000000000
fbffffffffffffff1606000000000000
fffffffbc8300000
fbffffff16060000
fbffffff16060000
fffffffffffffffbc830000000000000
fbffffff16060000
fffffffbc8300000
-
{e=>5,c=>-4,a=>51,b=>1,d=>-2}
33000000a10b0000
3300000000000000a10b000000000000
3300000000000000a10b000000000000
0000003333500000
33000000a10b0000
33000000a10b0000
00000000000000333350000000000000
33000000a10b0000
0000003333500000
-
{e=>2,c=>2,a=>-120,b=>6,d=>-4}
88ffffff16050000
88ffffffffffffff1605000000000000
88ffffffffffffff1605000000000000
ffffff88ca200000
88ffffff16050000
88ffffff16050000
ffffffffffffff88ca20000000000000
88ffffff16050000
ffffff88ca200000
-
{e=>5,c=>1,a=>-11,b=>3,d=>2}
f5ffffff8b0a0000
f5ffffffffffffff8b0a000000000000
f5ffffffffffffff8b0a000000000000
fffffff565500000
f5ffffff8b0a0000
f5ffffff8b0a0000
fffffffffffffff56550000000000000
f5ffffff8b0a0000
fffffff565500000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
};
-
{e=>6,c=>-4,a=>-32,b=>4,d=>0,f=>-1}
e0ffffff247c0000
e0ffffffffffffff247c000000000000
e0ffffffffffffff247c000000000000
ffffffe0906e0000
e0ffffff247c0000
e0ffffff247c0000
ffffffffffffffe0906e000000000000
e0ffffff247c0000
ffffffe0906e0000
-
{e=>5,c=>2,a=>50,b=>1,d=>2,f=>1}
32000000911a0000
3200000000000000911a000000000000
3200000000000000911a000000000000
0000003229520000
32000000911a0000
32000000911a0000
00000000000000322952000000000000
32000000911a0000
0000003229520000
-
{e=>7,c=>-2,a=>106,b=>5,d=>-4,f=>1}
6a000000351f0000
6a00000000000000351f000000000000
6a00000000000000351f000000000000
0000006aba720000
6a000000351f0000
6a000000351f0000
000000000000006aba72000000000000
6a000000351f0000
0000006aba720000
-
{e=>4,c=>-4,a=>-26,b=>5,d=>-3,f=>-4}
e6ffffff65490000
e6ffffffffffffff6549000000000000
e6ffffffffffffff6549000000000000
ffffffe6b2c80000
e6ffffff65490000
e6ffffff65490000
ffffffffffffffe6b2c8000000000000
e6ffffff65490000
ffffffe6b2c80000
-
{e=>6,c=>1,a=>30,b=>1,d=>-3,f=>1}
1e000000491d0000
1e00000000000000491d000000000000
1e00000000000000491d000000000000
0000001e26e20000
1e000000491d0000
1e000000491d0000
000000000000001e26e2000000000000
1e000000491d0000
0000001e26e20000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
};
-
{e=>2,c=>-3,a=>34,g=>7,b=>0,d=>0,f=>-2}
2200000028e40300
220000000000000028e4030000000000
220000000000000028e4030000000000
00000022142dc000
2200000028e40300
2200000028e40300
0000000000000022142dc00000000000
2200000028e40300
00000022142dc000
-
{e=>7,c=>1,a=>-121,g=>0,b=>5,d=>0,f=>-2}
87ffffff0d6e0000
87ffffffffffffff0d6e000000000000
87ffffffffffffff0d6e000000000000
ffffff87a47c0000
87ffffff0d6e0000
87ffffff0d6e0000
ffffffffffffff87a47c000000000000
87ffffff0d6e0000
ffffff87a47c0000
-
{e=>3,c=>-3,a=>0,g=>1,b=>0,d=>2,f=>-1}
00000000a8f60000
0000000000000000a8f6000000000000
0000000000000000a8f6000000000000
00000000153e4000
00000000a8f60000
00000000a8f60000
0000000000000000153e400000000000
00000000a8f60000
00000000153e4000
-
{e=>5,c=>-3,a=>-126,g=>5,b=>5,d=>-3,f=>3}
82ffffff6dbb0200
82ffffffffffffff6dbb020000000000
82ffffffffffffff6dbb020000000000
ffffff82b6d74000
82ffffff6dbb0200
82ffffff6dbb0200
ffffffffffffff82b6d7400000000000
82ffffff6dbb0200
ffffff82b6d74000
-
{e=>0,c=>2,a=>-72,g=>7,b=>0,d=>3,f=>3}
b8ffffffd0b00300
b8ffffffffffffffd0b0030000000000
b8ffffffffffffffd0b0030000000000
ffffffb80987c000
b8ffffffd0b00300
b8ffffffd0b00300
ffffffffffffffb80987c00000000000
b8ffffffd0b00300
ffffffb80987c000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>1,c=>-1,a=>16,g=>1,b=>3,d=>-4,f=>-4}
100000003bc30000
10000000000000003bc3000000000000
10000000000000003bc3000000000000
000000107e184000
100000003bc30000
100000003bc30000
00000000000000107e18400000000000
100000003bc30000
000000107e184000
-
{e=>5,c=>-2,a=>-124,g=>2,b=>1,d=>3,f=>3}
84fffffff13a0100
84fffffffffffffff13a010000000000
84fffffffffffffff13a010000000000
ffffff8439d68000
84fffffff13a0100
84fffffff13a0100
ffffffffffffff8439d6800000000000
84fffffff13a0100
ffffff8439d68000
-
{e=>3,c=>-4,a=>-30,g=>6,b=>6,d=>0,f=>-3}
e2ffffff26560300
e2ffffffffffffff2656030000000000
e2ffffffffffffff2656030000000000
ffffffe2d03b8000
e2ffffff26560300
e2ffffff26560300
ffffffffffffffe2d03b800000000000
e2ffffff26560300
ffffffe2d03b8000
-
{e=>5,c=>-4,a=>101,g=>4,b=>2,d=>2,f=>2}
65000000a22a0200
6500000000000000a22a020000000000
6500000000000000a22a020000000000
0000006551550000
65000000a22a0200
65000000a22a0200
00000000000000655155000000000000
65000000a22a0200
0000006551550000
-
{e=>0,c=>1,a=>-30,g=>0,b=>0,d=>-1,f=>-1}
e2ffffffc8710000
e2ffffffffffffffc871000000000000
e2ffffffffffffffc871000000000000
ffffffe2078e0000
e2ffffffc8710000
e2ffffffc8710000
ffffffffffffffe2078e000000000000
e2ffffffc8710000
ffffffe2078e0000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>3,a=>-63,d=>-4,c=>-3,h=>4,b=>0,g=>7,f=>-1}
c1ffffff28f7030004000000
c1ffffffffffffff28f7030004000000
c1ffffffffffffff28f7030004000000
ffffffc1163fc00080000000
c1ffffff28f7030004000000
c1ffffff28f7030004000000
ffffffffffffffc1163fc00080000000
c1ffffff28f7030004000000
ffffffc1163fc00080000000
-
{e=>1,a=>-112,d=>3,c=>0,h=>7,b=>3,g=>1,f=>2}
90ffffffc3a2000007000000
90ffffffffffffffc3a2000007000000
90ffffffffffffffc3a2000007000000
ffffff9061944000e0000000
90ffffffc3a2000007000000
90ffffffc3a2000007000000
ffffffffffffff9061944000e0000000
90ffffffc3a2000007000000
ffffff9061944000e0000000
-
{e=>5,a=>-65,d=>-1,c=>2,h=>5,b=>6,g=>4,f=>-2}
bfffffffd66b020005000000
bfffffffffffffffd66b020005000000
bfffffffffffffffd66b020005000000
ffffffbfcbdd0000a0000000
bfffffffd66b020005000000
bfffffffd66b020005000000
ffffffffffffffbfcbdd0000a0000000
bfffffffd66b020005000000
ffffffbfcbdd0000a0000000
-
{e=>7,a=>63,d=>0,c=>-4,h=>3,b=>5,g=>4,f=>1}
3f000000251e020003000000
3f00000000000000251e020003000000
3f00000000000000251e020003000000
0000003fb073000060000000
3f000000251e020003000000
3f000000251e020003000000
000000000000003fb073000060000000
3f000000251e020003000000
0000003fb073000060000000
-
{e=>3,a=>-66,d=>-3,c=>3,h=>4,b=>0,g=>2,f=>-3}
beffffff5857010004000000
beffffffffffffff5857010004000000
beffffffffffffff5857010004000000
ffffffbe0eba800080000000
beffffff5857010004000000
beffffff5857010004000000
ffffffffffffffbe0eba800080000000
beffffff5857010004000000
ffffffbe0eba800080000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>0,a=>-44,d=>-1,c=>-2,h=>7,b=>4,g=>5,f=>-3,i=>1}
d4fffffff4d102000f000000
d4fffffffffffffff4d102000f000000
d4fffffffffffffff4d102000f000000
ffffffd49b8b4000e4000000
d4fffffff4d102000f000000
d4fffffff4d102000f000000
ffffffffffffffd49b8b4000e4000000
d4fffffff4d102000f000000
ffffffd49b8b4000e4000000
-
{e=>2,a=>-106,d=>-4,c=>2,h=>0,b=>5,g=>5,f=>-3,i=>-2}
96ffffff15d5020030000000
96ffffffffffffff15d5020030000000
96ffffffffffffff15d5020030000000
ffffff96aa2b400018000000
96ffffff15d5020030000000
96ffffff15d5020030000000
ffffffffffffff96aa2b400018000000
96ffffff15d5020030000000
ffffff96aa2b400018000000
-
{e=>0,a=>127,d=>-4,c=>2,h=>5,b=>2,g=>1,f=>-2,i=>-4}
7f00000012e1000025000000
7f0000000000000012e1000025000000
7f0000000000000012e1000025000000
0000007f4a0c4000b0000000
7f00000012e1000025000000
7f00000012e1000025000000
000000000000007f4a0c4000b0000000
7f00000012e1000025000000
0000007f4a0c4000b0000000
-
{e=>2,a=>-89,d=>1,c=>-2,h=>5,b=>4,g=>0,f=>-2,i=>3}
a7ffffff746400001d000000
a7ffffffffffffff746400001d000000
a7ffffffffffffff746400001d000000
ffffffa798ac0000ac000000
a7ffffff746400001d000000
a7ffffff746400001d000000
ffffffffffffffa798ac0000ac000000
a7ffffff746400001d000000
ffffffa798ac0000ac000000
-
{e=>3,a=>86,d=>2,c=>1,h=>6,b=>4,g=>7,f=>3,i=>-4}
560000008cb6030026000000
56000000000000008cb6030026000000
56000000000000008cb6030026000000
000000568537c000d0000000
560000008cb6030026000000
560000008cb6030026000000
00000000000000568537c000d0000000
560000008cb6030026000000
000000568537c000d0000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
};
-
{e=>2,a=>68,d=>-3,j=>7,c=>-1,h=>6,b=>2,g=>2,f=>-2,i=>-1}
440000007a650100fe010000
44000000000000007a650100fe010000
44000000000000007a650100fe010000
000000445eac8000df800000
440000007a650100fe010000
440000007a650100fe010000
00000000000000445eac8000df800000
440000007a650100fe010000
000000445eac8000df800000
-
{e=>5,a=>125,d=>2,j=>0,c=>2,h=>0,b=>0,g=>1,f=>2,i=>3}
7d00000090aa000018000000
7d0000000000000090aa000018000000
7d0000000000000090aa000018000000
0000007d095440000c000000
7d00000090aa000018000000
7d00000090aa000018000000
000000000000007d095440000c000000
7d00000090aa000018000000
0000007d095440000c000000
-
{e=>7,a=>-98,d=>-3,j=>3,c=>1,h=>0,b=>2,g=>0,f=>3,i=>2}
9effffff4a3f0000d0000000
9effffffffffffff4a3f0000d0000000
9effffffffffffff4a3f0000d0000000
ffffff9e46f6000009800000
9effffff4a3f0000d0000000
9effffff4a3f0000d0000000
ffffffffffffff9e46f6000009800000
9effffff4a3f0000d0000000
ffffff9e46f6000009800000
-
{e=>6,a=>65,d=>-4,j=>2,c=>2,h=>4,b=>4,g=>6,f=>0,i=>-1}
41000000140d0300bc000000
4100000000000000140d0300bc000000
4100000000000000140d0300bc000000
000000418a6180009d000000
41000000140d0300bc000000
41000000140d0300bc000000
00000000000000418a6180009d000000
41000000140d0300bc000000
000000418a6180009d000000
-
{e=>4,a=>-43,d=>-4,j=>1,c=>0,h=>7,b=>1,g=>0,f=>1,i=>2}
d5ffffff0119000057000000
d5ffffffffffffff0119000057000000
d5ffffffffffffff0119000057000000
ffffffd522420000e8800000
d5ffffff0119000057000000
d5ffffff0119000057000000
ffffffffffffffd522420000e8800000
d5ffffff0119000057000000
ffffffd522420000e8800000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
};
-
{e=>7,a=>86,d=>3,j=>2,c=>0,k=>-13,h=>7,b=>3,g=>7,f=>3,i=>-4}
56000000c3be0300a700f300
5600000000000000c3be0300a700f300
5600000000000000c3be0300a700f300
0000005661f7c000f100f300
56000000c3be0300a700f300
56000000c3be0300a700f300
000000000000005661f7c000f100f300
56000000c3be0300a700f300
0000005661f7c000f100f300
-
{e=>5,a=>-12,d=>-3,j=>6,c=>-3,k=>-95,h=>0,b=>6,g=>0,f=>-2,i=>-3}
f4ffffff6e6b0000a801a100
f4ffffffffffffff6e6b0000a801a100
f4ffffffffffffff6e6b0000a801a100
fffffff4d6dc00001700a100
f4ffffff6e6b0000a801a100
f4ffffff6e6b0000a801a100
fffffffffffffff4d6dc00001700a100
f4ffffff6e6b0000a801a100
fffffff4d6dc00001700a100
-
{e=>6,a=>-124,d=>3,j=>3,c=>-3,k=>50,h=>6,b=>7,g=>2,f=>-1,i=>-1}
84ffffffef7c0100fe003200
84ffffffffffffffef7c0100fe003200
84ffffffffffffffef7c0100fe003200
ffffff84f5ee8000dd803200
84ffffffef7c0100fe003200
84ffffffef7c0100fe003200
ffffffffffffff84f5ee8000dd803200
84ffffffef7c0100fe003200
ffffff84f5ee8000dd803200
-
{e=>2,a=>47,d=>0,j=>0,c=>-4,k=>102,h=>3,b=>7,g=>6,f=>-4,i=>2}
2f0000002744030013006600
2f000000000000002744030013006600
2f000000000000002744030013006600
0000002ff029800068006600
2f0000002744030013006600
2f0000002744030013006600
000000000000002ff029800068006600
2f0000002744030013006600
0000002ff029800068006600
-
{e=>5,a=>95,d=>0,j=>6,c=>0,k=>66,h=>6,b=>6,g=>6,f=>-4,i=>-4}
5f000000064a0300a6014200
5f00000000000000064a0300a6014200
5f00000000000000064a0300a6014200
0000005fc0598000d3004200
5f000000064a0300a6014200
5f000000064a0300a6014200
000000000000005fc0598000d3004200
5f000000064a0300a6014200
0000005fc0598000d3004200
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>7,a=>101,d=>-2,j=>1,l=>0,c=>-3,k=>83,h=>7,b=>0,g=>3,f=>-4,i=>2}
65000000a8cf010057005300
6500000000000000a8cf010057005300
6500000000000000a8cf010057005300
000000651778c000e8805300
65000000a8cf010057005300
65000000a8cf010057005300
00000000000000651778c000e8805300
65000000a8cf010057005300
000000651778c000e8805300
-
{e=>7,a=>-82,d=>2,j=>3,l=>2,c=>1,k=>50,h=>0,b=>2,g=>7,f=>-2,i=>-2}
aeffffff8aee0300f0003202
aeffffffffffffff8aee0300f0003202
aeffffffffffffff8aee0300f0003202
ffffffae457dc00019803240
aeffffff8aee0300f0003202
aeffffff8aee0300f0003202
ffffffffffffffae457dc00019803240
aeffffff8aee0300f0003202
ffffffae457dc00019803240
-
{e=>5,a=>49,d=>-3,j=>1,l=>7,c=>-2,k=>-9,h=>7,b=>5,g=>5,f=>-1,i=>2}
3100000075fb02005700f707
310000000000000075fb02005700f707
310000000000000075fb02005700f707
00000031badf4000e880f7e0
3100000075fb02005700f707
3100000075fb02005700f707
0000000000000031badf4000e880f7e0
3100000075fb02005700f707
00000031badf4000e880f7e0
-
{e=>0,a=>-76,d=>3,j=>0,l=>0,c=>-1,k=>-27,h=>7,b=>6,g=>6,f=>-1,i=>-4}
b4fffffffe7003002700e500
b4fffffffffffffffe7003002700e500
b4fffffffffffffffe7003002700e500
ffffffb4dd8f8000f000e500
b4fffffffe7003002700e500
b4fffffffe7003002700e500
ffffffffffffffb4dd8f8000f000e500
b4fffffffe7003002700e500
ffffffb4dd8f8000f000e500
-
{e=>5,a=>62,d=>2,j=>1,l=>2,c=>-1,k=>-59,h=>5,b=>1,g=>5,f=>-2,i=>-2}
3e000000b9ea02007500c502
3e00000000000000b9ea02007500c502
3e00000000000000b9ea02007500c502
0000003e3d5d4000b880c540
3e000000b9ea02007500c502
3e000000b9ea02007500c502
000000000000003e3d5d4000b880c540
3e000000b9ea02007500c502
0000003e3d5d4000b880c540
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>7,a=>61,m=>-3,d=>-2,j=>7,l=>1,c=>3,k=>-49,h=>5,b=>0,g=>1,f=>-3,i=>0}
3d00000098df0000c501cf29
3d0000000000000098df0000c501cf29
3d0000000000000098df0000c501cf29
0000003d0f7a4000a380cf34
3d00000098df0000c501cf29
3d00000098df0000c501cf29
000000000000003d0f7a4000a380cf34
3d00000098df0000c501cf29
0000003d0f7a4000a380cf34
-
{e=>6,a=>115,m=>-1,d=>0,j=>4,l=>2,c=>-2,k=>32,h=>7,b=>4,g=>3,f=>-2,i=>-2}
7300000034ec01003701203a
730000000000000034ec01003701203a
730000000000000034ec01003701203a
00000073986cc000fa00205c
7300000034ec01003701203a
7300000034ec01003701203a
0000000000000073986cc000fa00205c
7300000034ec01003701203a
00000073986cc000fa00205c
-
{e=>7,a=>74,m=>3,d=>-1,j=>6,l=>5,c=>-1,k=>34,h=>3,b=>4,g=>4,f=>2,i=>2}
4a000000fc2f02009301221d
4a00000000000000fc2f02009301221d
4a00000000000000fc2f02009301221d
0000004a9ff500006b0022ac
4a000000fc2f02009301221d
4a000000fc2f02009301221d
000000000000004a9ff500006b0022ac
4a000000fc2f02009301221d
0000004a9ff500006b0022ac
-
{e=>3,a=>91,m=>-3,d=>0,j=>2,l=>7,c=>-1,k=>-86,h=>5,b=>0,g=>1,f=>-1,i=>-4}
5b00000038f60000a500aa2f
5b0000000000000038f60000a500aa2f
5b0000000000000038f60000a500aa2f
0000005b1c3e4000b100aaf4
5b00000038f60000a500aa2f
5b00000038f60000a500aa2f
000000000000005b1c3e4000b100aaf4
5b00000038f60000a500aa2f
0000005b1c3e4000b100aaf4
-
{e=>4,a=>-16,m=>0,d=>2,j=>2,l=>3,c=>-2,k=>-46,h=>7,b=>2,g=>0,f=>-1,i=>-3}
f0ffffffb2780000af00d203
f0ffffffffffffffb2780000af00d203
f0ffffffffffffffb2780000af00d203
fffffff0594e0000f500d260
f0ffffffb2780000af00d203
f0ffffffb2780000af00d203
fffffffffffffff0594e0000f500d260
f0ffffffb2780000af00d203
fffffff0594e0000f500d260
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>1,n=>1,a=>-128,m=>-2,d=>2,j=>3,l=>2,c=>3,k=>-47,h=>3,b=>1,g=>0,f=>1,i=>0}
80ffffff99120000c300d13201000000
80ffffffffffffff99120000c300d1320100000000000000
80ffffffffffffff99120000c300d1320100000000000000
ffffff802d1200006180d15820000000
80ffffff99120000c300d13201000000
80ffffff99120000c300d13201000000
ffffffffffffff802d1200006180d1582000000000000000
80ffffff99120000c300d13201000000
ffffff802d1200006180d15820000000
-
{e=>0,n=>3,a=>39,m=>2,d=>2,j=>2,l=>2,c=>-2,k=>-60,h=>2,b=>2,g=>1,f=>-4,i=>-1}
27000000b2c00000ba00c41203000000
2700000000000000b2c00000ba00c4120300000000000000
2700000000000000b2c00000ba00c4120300000000000000
00000027590840005d00c44860000000
27000000b2c00000ba00c41203000000
27000000b2c00000ba00c41203000000
0000000000000027590840005d00c4486000000000000000
27000000b2c00000ba00c41203000000
00000027590840005d00c44860000000
-
{e=>0,n=>7,a=>86,m=>-3,d=>-2,j=>4,l=>4,c=>-1,k=>24,h=>1,b=>4,g=>3,f=>-2,i=>3}
56000000bce101001901182c07000000
5600000000000000bce101001901182c0700000000000000
5600000000000000bce101001901182c0700000000000000
000000569f0cc0002e001894e0000000
56000000bce101001901182c07000000
56000000bce101001901182c07000000
00000000000000569f0cc0002e001894e000000000000000
56000000bce101001901182c07000000
000000569f0cc0002e001894e0000000
-
{e=>3,n=>4,a=>-28,m=>2,d=>3,j=>2,l=>5,c=>0,k=>-23,h=>7,b=>2,g=>7,f=>1,i=>1}
e4ffffffc29603008f00e91504000000
e4ffffffffffffffc29603008f00e9150400000000000000
e4ffffffffffffffc29603008f00e9150400000000000000
ffffffe441b3c000e500e9a880000000
e4ffffffc29603008f00e91504000000
e4ffffffc29603008f00e91504000000
ffffffffffffffe441b3c000e500e9a88000000000000000
e4ffffffc29603008f00e91504000000
ffffffe441b3c000e500e9a880000000
-
{e=>3,n=>3,a=>-127,m=>-4,d=>-2,j=>6,l=>7,c=>0,k=>51,h=>2,b=>0,g=>5,f=>-3,i=>-2}
81ffffff80d70200b201332703000000
81ffffffffffffff80d70200b20133270300000000000000
81ffffffffffffff80d70200b20133270300000000000000
ffffff81033b40005b0033f060000000
81ffffff80d70200b201332703000000
81ffffff80d70200b201332703000000
ffffffffffffff81033b40005b0033f06000000000000000
81ffffff80d70200b201332703000000
ffffff81033b40005b0033f060000000
=
typedef int foo;

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct mixed_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  signed   char f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  unsigned int  j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>2,n=>5,a=>-107,m=>2,d=>3,j=>1,l=>1,c=>-1,k=>88,h=>1,b=>3,g=>2,f=>3,o=>104,i=>2}
95fffffffb3401005100581105680000
95fffffffffffffffb340100510058110568000000000000
95fffffffffffffffb340100510058110568000000000000
ffffff957da6800028805828a0680000
95fffffffb3401005100581105680000
95fffffffb3401005100581105680000
ffffffffffffff957da6800028805828a068000000000000
95fffffffb3401005100581105680000
ffffff957da6800028805828a0680000
-
{e=>1,n=>6,a=>84,m=>-1,d=>-2,j=>3,l=>7,c=>1,k=>29,h=>2,b=>3,g=>3,f=>-2,o=>30,i=>-3}
540000008be30100ea001d3f061e0000
54000000000000008be30100ea001d3f061e000000000000
54000000000000008be30100ea001d3f061e000000000000
00000054671cc00055801dfcc01e0000
540000008be30100ea001d3f061e0000
540000008be30100ea001d3f061e0000
0000000000000054671cc00055801dfcc01e000000000000
540000008be30100ea001d3f061e0000
00000054671cc00055801dfcc01e0000
-
{e=>3,n=>0,a=>79,m=>3,d=>-3,j=>2,l=>6,c=>1,k=>125,h=>1,b=>2,g=>3,f=>3,o=>59,i=>-1}
4f0000004ab70100b9007d1e003b0000
4f000000000000004ab70100b9007d1e003b000000000000
4f000000000000004ab70100b9007d1e003b000000000000
0000004f46b6c0003d007dcc003b0000
4f0000004ab70100b9007d1e003b0000
4f0000004ab70100b9007d1e003b0000
000000000000004f46b6c0003d007dcc003b000000000000
4f0000004ab70100b9007d1e003b0000
0000004f46b6c0003d007dcc003b0000
-
{e=>7,n=>7,a=>112,m=>-1,d=>3,j=>4,l=>0,c=>1,k=>-29,h=>5,b=>4,g=>4,f=>-2,o=>130,i=>2}
70000000cc6e02001501e33807820000
7000000000000000cc6e02001501e3380782000000000000
7000000000000000cc6e02001501e3380782000000000000
0000007085fd0000aa00e31ce0820000
70000000cc6e02001501e33807820000
70000000cc6e02001501e33807820000
000000000000007085fd0000aa00e31ce082000000000000
70000000cc6e02001501e33807820000
0000007085fd0000aa00e31ce0820000
-
{e=>7,n=>0,a=>27,m=>-1,d=>2,j=>1,l=>6,c=>-2,k=>40,h=>4,b=>0,g=>5,f=>1,o=>182,i=>-4}
1b000000b09e02006400283e00b60000
1b00000000000000b09e02006400283e00b6000000000000
1b00000000000000b09e02006400283e00b6000000000000
0000001b19734000908028dc00b60000
1b000000b09e02006400283e00b60000
1b000000b09e02006400283e00b60000
000000000000001b19734000908028dc00b6000000000000
1b000000b09e02006400283e00b60000
0000001b19734000908028dc00b60000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
};
-
{a=>3}
03000000
03000000
03000000
60000000
03000000
03000000
60000000
03000000
60000000
-
{a=>1}
01000000
01000000
01000000
20000000
01000000
01000000
20000000
01000000
20000000
-
{a=>1}
01000000
01000000
01000000
20000000
01000000
01000000
20000000
01000000
20000000
-
{a=>6}
06000000
06000000
06000000
c0000000
06000000
06000000
c0000000
06000000
c0000000
-
{a=>5}
05000000
05000000
05000000
a0000000
05000000
05000000
a0000000
05000000
a0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
};
-
{a=>4,b=>-3}
2c000000
2c000000
2c000000
94000000
2c000000
2c000000
94000000
2c000000
94000000
-
{a=>7,b=>-4}
27000000
27000000
27000000
f0000000
27000000
27000000
f0000000
27000000
f0000000
-
{a=>3,b=>-3}
2b000000
2b000000
2b000000
74000000
2b000000
2b000000
74000000
2b000000
74000000
-
{a=>3,b=>-3}
2b000000
2b000000
2b000000
74000000
2b000000
2b000000
74000000
2b000000
74000000
-
{a=>6,b=>-3}
2e000000
2e000000
2e000000
d4000000
2e000000
2e000000
d4000000
2e000000
d4000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
};
-
{c=>3,a=>7,b=>-3}
ef000000
ef000000
ef000000
f5800000
ef000000
ef000000
f5800000
ef000000
f5800000
-
{c=>-3,a=>7,b=>-3}
6f010000
6f010000
6f010000
f6800000
6f010000
6f010000
f6800000
6f010000
f6800000
-
{c=>-4,a=>0,b=>2}
10010000
10010000
10010000
0a000000
10010000
10010000
0a000000
10010000
0a000000
-
{c=>1,a=>0,b=>3}
58000000
58000000
58000000
0c800000
58000000
58000000
0c800000
58000000
0c800000
-
{c=>-1,a=>5,b=>-2}
f5010000
f5010000
f5010000
bb800000
f5010000
f5010000
bb800000
f5010000
bb800000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
};
-
{c=>1,a=>5,b=>-2,d=>7}
750e0000
750e0000
750e0000
b8f00000
750e0000
750e0000
b8f00000
750e0000
b8f00000
-
{c=>-3,a=>0,b=>-4,d=>1}
60030000
60030000
60030000
12900000
60030000
60030000
12900000
60030000
12900000
-
{c=>-4,a=>4,b=>-2,d=>0}
34010000
34010000
34010000
9a000000
34010000
34010000
9a000000
34010000
9a000000
-
{c=>0,a=>3,b=>3,d=>5}
1b0a0000
1b0a0000
1b0a0000
6c500000
1b0a0000
1b0a0000
6c500000
1b0a0000
6c500000
-
{c=>-4,a=>6,b=>2,d=>3}
16070000
16070000
16070000
ca300000
16070000
16070000
ca300000
16070000
ca300000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
};
-
{e=>'UE6',c=>2,a=>1,b=>-1,d=>1}
b9620000
b9620000
b9620000
3d1c0000
b9620000
b9620000
3d1c0000
b9620000
3d1c0000
-
{e=>'UE7',c=>-2,a=>1,b=>1,d=>0}
89710000
89710000
89710000
270e0000
89710000
89710000
270e0000
89710000
270e0000
-
{e=>'UE7',c=>-4,a=>0,b=>-1,d=>4}
38790000
38790000
38790000
1e4e0000
38790000
38790000
1e4e0000
38790000
1e4e0000
-
{e=>'UE0',c=>-3,a=>4,b=>-4,d=>0}
64010000
64010000
64010000
92800000
64010000
64010000
92800000
64010000
92800000
-
{e=>'UE5',c=>-3,a=>5,b=>-3,d=>0}
6d510000
6d510000
6d510000
b68a0000
6d510000
6d510000
b68a0000
6d510000
b68a0000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
};
-
{e=>'UE2',c=>-2,a=>7,b=>1,d=>7,f=>1}
8faf0000
8faf0000
8faf0000
e7744000
8faf0000
8faf0000
e7744000
8faf0000
e7744000
-
{e=>'UE3',c=>0,a=>4,b=>2,d=>4,f=>2}
14380100
14380100
14380100
88468000
14380100
14380100
88468000
14380100
88468000
-
{e=>'UE2',c=>3,a=>4,b=>0,d=>0,f=>0}
c4200000
c4200000
c4200000
81840000
c4200000
c4200000
81840000
c4200000
81840000
-
{e=>'UE1',c=>0,a=>3,b=>1,d=>0,f=>6}
0b100300
0b100300
0b100300
64038000
0b100300
0b100300
64038000
0b100300
64038000
-
{e=>'UE2',c=>3,a=>1,b=>2,d=>3,f=>5}
d1a60200
d1a60200
d1a60200
29b54000
d1a60200
d1a60200
29b54000
d1a60200
29b54000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
};
-
{e=>'UE1',c=>3,a=>2,b=>-3,d=>0,f=>0}
ea100000
ea100000
ea100000
55820000
ea100000
ea100000
55820000
ea100000
55820000
-
{e=>'UE6',c=>-2,a=>7,b=>-2,d=>7,f=>1}
b7ef0000
b7ef0000
b7ef0000
fb7c4000
b7ef0000
b7ef0000
fb7c4000
b7ef0000
fb7c4000
-
{e=>'UE2',c=>-2,a=>5,b=>2,d=>6,f=>5}
95ad0200
95ad0200
95ad0200
ab654000
95ad0200
95ad0200
ab654000
95ad0200
ab654000
-
{e=>'UE1',c=>2,a=>1,b=>-1,d=>4,f=>6}
b9180300
b9180300
b9180300
3d438000
b9180300
b9180300
3d438000
b9180300
3d438000
-
{e=>'UE1',c=>3,a=>1,b=>-3,d=>3,f=>4}
e9160200
e9160200
e9160200
35b30000
e9160200
e9160200
35b30000
e9160200
35b30000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
};
-
{e=>'UE6',c=>-2,a=>0,g=>0,b=>3,d=>6,f=>4}
986d020000000000
986d020000000000
986d020000000000
0f6d000000000000
986d020000000000
986d020000000000
0f6d000000000000
986d020000000000
0f6d000000000000
-
{e=>'UE4',c=>2,a=>2,g=>2,b=>-4,d=>7,f=>3}
a2ce010002000000
a2ce010002000000
a2ce010002000000
5178c00040000000
a2ce010002000000
a2ce010002000000
5178c00040000000
a2ce010002000000
5178c00040000000
-
{e=>'UE2',c=>-3,a=>4,g=>6,b=>3,d=>6,f=>7}
5cad030006000000
5cad030006000000
5cad030006000000
8ee5c000c0000000
5cad030006000000
5cad030006000000
8ee5c000c0000000
5cad030006000000
8ee5c000c0000000
-
{e=>'UE6',c=>-1,a=>7,g=>6,b=>2,d=>7,f=>6}
d76f030006000000
d76f030006000000
d76f030006000000
ebfd8000c0000000
d76f030006000000
d76f030006000000
ebfd8000c0000000
d76f030006000000
ebfd8000c0000000
-
{e=>'UE3',c=>-2,a=>7,g=>2,b=>-3,d=>4,f=>7}
afb9030002000000
afb9030002000000
afb9030002000000
f747c00040000000
afb9030002000000
afb9030002000000
f747c00040000000
afb9030002000000
f747c00040000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
};
-
{e=>'UE2',a=>3,d=>3,c=>1,h=>2,b=>-1,g=>0,f=>2}
7b26010010000000
7b26010010000000
7b26010010000000
7cb4800008000000
7b26010010000000
7b26010010000000
7cb4800008000000
7b26010010000000
7cb4800008000000
-
{e=>'UE5',a=>4,d=>6,c=>1,h=>-4,b=>-1,g=>5,f=>4}
7c5c020025000000
7c5c020025000000
7c5c020025000000
9ceb0000b0000000
7c5c020025000000
7c5c020025000000
9ceb0000b0000000
7c5c020025000000
9ceb0000b0000000
-
{e=>'UE0',a=>7,d=>2,c=>3,h=>1,b=>-3,g=>2,f=>1}
ef8400000a000000
ef8400000a000000
ef8400000a000000
f5a0400044000000
ef8400000a000000
ef8400000a000000
f5a0400044000000
ef8400000a000000
f5a0400044000000
-
{e=>'UE0',a=>1,d=>7,c=>-3,h=>-1,b=>1,g=>3,f=>4}
490f02003b000000
490f02003b000000
490f02003b000000
26f100007c000000
490f02003b000000
490f02003b000000
26f100007c000000
490f02003b000000
26f100007c000000
-
{e=>'UE1',a=>5,d=>3,c=>3,h=>2,b=>-4,g=>2,f=>5}
e596020012000000
e596020012000000
e596020012000000
b1b3400048000000
e596020012000000
e596020012000000
b1b3400048000000
e596020012000000
b1b3400048000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  enum en_s     i:3;
};
-
{e=>'UE2',a=>0,d=>0,c=>-4,h=>1,b=>1,g=>0,f=>7,i=>'SEM2'}
08a1030088010000
08a1030088010000
08a1030088010000
0605c00007000000
08a1030088010000
08a1030088010000
0605c00007000000
08a1030088010000
0605c00007000000
-
{e=>'UE1',a=>1,d=>7,c=>-1,h=>3,b=>2,g=>2,f=>5,i=>'SEM1'}
d19f0200da010000
d19f0200da010000
d19f0200da010000
2bf340004f800000
d19f0200da010000
d19f0200da010000
2bf340004f800000
d19f0200da010000
2bf340004f800000
-
{e=>'UE7',a=>7,d=>3,c=>-4,h=>3,b=>-3,g=>0,f=>5,i=>'SE0'}
2ff7020018000000
2ff7020018000000
2ff7020018000000
f63f40000c000000
2ff7020018000000
2ff7020018000000
f63f40000c000000
2ff7020018000000
f63f40000c000000
-
{e=>'UE6',a=>6,d=>1,c=>3,h=>0,b=>1,g=>5,f=>5,i=>'SEM2'}
cee2020085010000
cee2020085010000
cee2020085010000
c59d4000a3000000
cee2020085010000
cee2020085010000
c59d4000a3000000
cee2020085010000
c59d4000a3000000
-
{e=>'UE6',a=>5,d=>4,c=>3,h=>1,b=>3,g=>2,f=>4,i=>'SE1'}
dd6802004a000000
dd6802004a000000
dd6802004a000000
adcd000044800000
dd6802004a000000
dd6802004a000000
adcd000044800000
dd6802004a000000
adcd000044800000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  enum en_s     i:3;
  char          j;
};
-
{e=>'UE4',a=>6,d=>2,j=>117,c=>2,h=>-4,b=>2,g=>0,f=>5,i=>'SE2'}
96c40200a0007500
96c40200a0007500
96c40200a0007500
c929400011007500
96c40200a0007500
96c40200a0007500
c929400011007500
96c40200a0007500
c929400011007500
-
{e=>'UE1',a=>3,d=>4,j=>126,c=>3,h=>0,b=>-4,g=>2,f=>5,i=>'SEM3'}
e398020042017e00
e398020042017e00
e398020042017e00
71c3400042807e00
e398020042017e00
e398020042017e00
71c3400042807e00
e398020042017e00
71c3400042807e00
-
{e=>'UE4',a=>4,d=>7,j=>-36,c=>1,h=>-4,b=>-3,g=>7,f=>2,i=>'SEM2'}
6c4e0100a701dc00
6c4e0100a701dc00
6c4e0100a701dc00
94f88000f300dc00
6c4e0100a701dc00
6c4e0100a701dc00
94f88000f300dc00
6c4e0100a701dc00
94f88000f300dc00
-
{e=>'UE5',a=>1,d=>1,j=>61,c=>-3,h=>-3,b=>-4,g=>4,f=>6,i=>'SEM1'}
61530300ec013d00
61530300ec013d00
61530300ec013d00
329b800097803d00
61530300ec013d00
61530300ec013d00
329b800097803d00
61530300ec013d00
329b800097803d00
-
{e=>'UE6',a=>3,d=>1,j=>-91,c=>1,h=>-1,b=>-1,g=>6,f=>1,i=>'SEM4'}
7be200003e01a500
7be200003e01a500
7be200003e01a500
7c9c4000de00a500
7be200003e01a500
7be200003e01a500
7c9c4000de00a500
7be200003e01a500
7c9c4000de00a500
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  enum en_s     i:3;
  char          j;
  unsigned char k:3;
};
-
{e=>'UE4',a=>1,d=>0,j=>-29,c=>-3,k=>3,h=>3,b=>-1,g=>1,f=>7,i=>'SE2'}
79c103009900e303
79c103009900e303
79c103009900e303
3e89c0002d00e360
79c103009900e303
79c103009900e303
3e89c0002d00e360
79c103009900e303
3e89c0002d00e360
-
{e=>'UE7',a=>0,d=>6,j=>9,c=>1,k=>7,h=>2,b=>-4,g=>3,f=>4,i=>'SEM4'}
607c020013010907
607c020013010907
607c020013010907
10ef00006a0009e0
607c020013010907
607c020013010907
10ef00006a0009e0
607c020013010907
10ef00006a0009e0
-
{e=>'UE2',a=>0,d=>2,j=>101,c=>2,k=>1,h=>-4,b=>1,g=>7,f=>1,i=>'SEM2'}
88a40000a7016501
88a40000a7016501
88a40000a7016501
05244000f3006520
88a40000a7016501
88a40000a7016501
05244000f3006520
88a40000a7016501
05244000f3006520
-
{e=>'UE3',a=>0,d=>6,j=>74,c=>1,k=>1,h=>-1,b=>1,g=>4,f=>2,i=>'SE0'}
483c01003c004a01
483c01003c004a01
483c01003c004a01
04e680009c004a20
483c01003c004a01
483c01003c004a01
04e680009c004a20
483c01003c004a01
04e680009c004a20
-
{e=>'UE1',a=>4,d=>7,j=>-119,c=>-3,k=>4,h=>1,b=>2,g=>7,f=>4,i=>'SEM4'}
541f02000f018904
541f02000f018904
541f02000f018904
8af30000e6008980
541f02000f018904
541f02000f018904
8af30000e6008980
541f02000f018904
8af30000e6008980
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  enum en_s     i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
};
-
{e=>'UE0',a=>5,d=>7,j=>-122,l=>-3,c=>-4,k=>2,h=>1,b=>-1,g=>4,f=>3,i=>'SEM3'}
3d8f01004c01862a
3d8f01004c01862a
3d8f01004c01862a
be70c00086808654
3d8f01004c01862a
3d8f01004c01862a
be70c00086808654
3d8f01004c01862a
be70c00086808654
-
{e=>'UE0',a=>1,d=>3,j=>-34,l=>-4,c=>-3,k=>6,h=>-3,b=>-2,g=>1,f=>7,i=>'SEM1'}
71870300e901de26
71870300e901de26
71870300e901de26
3ab1c0003780ded0
71870300e901de26
71870300e901de26
3ab1c0003780ded0
71870300e901de26
3ab1c0003780ded0
-
{e=>'UE1',a=>1,d=>0,j=>86,l=>-4,c=>-3,k=>3,h=>2,b=>1,g=>0,f=>0,i=>'SEM3'}
4911000050015623
4911000050015623
4911000050015623
268200000a805670
4911000050015623
4911000050015623
268200000a805670
4911000050015623
268200000a805670
-
{e=>'UE1',a=>2,d=>1,j=>-57,l=>-1,c=>3,k=>5,h=>1,b=>-2,g=>7,f=>0,i=>'SE3'}
f2120000cf00c73d
f2120000cf00c73d
f2120000cf00c73d
59920000e580c7bc
f2120000cf00c73d
f2120000cf00c73d
59920000e580c7bc
f2120000cf00c73d
59920000e580c7bc
-
{e=>'UE7',a=>3,d=>1,j=>111,l=>-4,c=>-4,k=>6,h=>-3,b=>-2,g=>4,f=>3,i=>'SEM2'}
33f30100ac016f26
33f30100ac016f26
33f30100ac016f26
7a1ec00097006fd0
33f30100ac016f26
33f30100ac016f26
7a1ec00097006fd0
33f30100ac016f26
7a1ec00097006fd0
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  enum en_s     i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
  unsigned int  m:3;
};
-
{e=>'UE3',a=>5,m=>4,d=>5,j=>-36,l=>2,c=>0,k=>4,h=>0,b=>-3,g=>5,f=>0,i=>'SEM1'}
2d3a0000c501dc1404000000
2d3a0000c501dc1404000000
2d3a0000c501dc1404000000
b4560000a380dc8880000000
2d3a0000c501dc1404000000
2d3a0000c501dc1404000000
b4560000a380dc8880000000
2d3a0000c501dc1404000000
b4560000a380dc8880000000
-
{e=>'UE7',a=>5,m=>0,d=>6,j=>-48,l=>3,c=>1,k=>3,h=>2,b=>-3,g=>2,f=>0,i=>'SE1'}
6d7c00005200d01b00000000
6d7c00005200d01b00000000
6d7c00005200d01b00000000
b4ee00004880d06c00000000
6d7c00005200d01b00000000
6d7c00005200d01b00000000
b4ee00004880d06c00000000
6d7c00005200d01b00000000
b4ee00004880d06c00000000
-
{e=>'UE5',a=>6,m=>5,d=>5,j=>-112,l=>1,c=>-4,k=>5,h=>0,b=>2,g=>1,f=>3,i=>'SEM2'}
16db01008101900d05000000
16db01008101900d05000000
16db01008101900d05000000
ca5ac000230090a4a0000000
16db01008101900d05000000
16db01008101900d05000000
ca5ac000230090a4a0000000
16db01008101900d05000000
ca5ac000230090a4a0000000
-
{e=>'UE3',a=>5,m=>5,d=>5,j=>-44,l=>-2,c=>-3,k=>0,h=>1,b=>-1,g=>4,f=>3,i=>'SE0'}
7dbb01000c00d43005000000
7dbb01000c00d43005000000
7dbb01000c00d43005000000
bed6c0008400d418a0000000
7dbb01000c00d43005000000
7dbb01000c00d43005000000
bed6c0008400d418a0000000
7dbb01000c00d43005000000
bed6c0008400d418a0000000
-
{e=>'UE1',a=>5,m=>1,d=>7,j=>-106,l=>0,c=>-2,k=>7,h=>-4,b=>2,g=>0,f=>0,i=>'SE2'}
951f0000a000960701000000
951f0000a000960701000000
951f0000a000960701000000
ab720000110096e020000000
951f0000a000960701000000
951f0000a000960701000000
ab720000110096e020000000
951f0000a000960701000000
ab720000110096e020000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  enum en_s     i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
  unsigned int  m:3;
  unsigned char n;
};
-
{e=>'UE2',n=>245,a=>6,m=>3,d=>5,j=>21,l=>-3,c=>3,k=>3,h=>-2,b=>1,g=>3,f=>4,i=>'SE2'}
ce2a0200b300152b03f50000
ce2a0200b300152b03f50000
ce2a0200b300152b03f50000
c5d500007900157460f50000
ce2a0200b300152b03f50000
ce2a0200b300152b03f50000
c5d500007900157460f50000
ce2a0200b300152b03f50000
c5d500007900157460f50000
-
{e=>'UE4',n=>39,a=>4,m=>1,d=>1,j=>-106,l=>0,c=>-3,k=>5,h=>2,b=>1,g=>6,f=>2,i=>'SEM1'}
4c430100d601960501270000
4c430100d601960501270000
4c430100d601960501270000
86988000cb8096a020270000
4c430100d601960501270000
4c430100d601960501270000
86988000cb8096a020270000
4c430100d601960501270000
86988000cb8096a020270000
-
{e=>'UE2',n=>222,a=>0,m=>0,d=>4,j=>23,l=>0,c=>-2,k=>3,h=>3,b=>-1,g=>2,f=>1,i=>'SE1'}
b8a900005a00170300de0000
b8a900005a00170300de0000
b8a900005a00170300de0000
1f4440004c80176000de0000
b8a900005a00170300de0000
b8a900005a00170300de0000
1f4440004c80176000de0000
b8a900005a00170300de0000
1f4440004c80176000de0000
-
{e=>'UE1',n=>14,a=>6,m=>6,d=>0,j=>-82,l=>3,c=>-4,k=>6,h=>-2,b=>-4,g=>4,f=>7,i=>'SEM4'}
269103003401ae1e060e0000
269103003401ae1e060e0000
269103003401ae1e060e0000
d203c0009a00aeccc00e0000
269103003401ae1e060e0000
269103003401ae1e060e0000
d203c0009a00aeccc00e0000
269103003401ae1e060e0000
d203c0009a00aeccc00e0000
-
{e=>'UE5',n=>1,a=>2,m=>5,d=>2,j=>-12,l=>1,c=>-3,k=>4,h=>-3,b=>1,g=>0,f=>7,i=>'SEM3'}
4ad503006801f40c05010000
4ad503006801f40c05010000
4ad503006801f40c05010000
46abc0001680f484a0010000
4ad503006801f40c05010000
4ad503006801f40c05010000
46abc0001680f484a0010000
4ad503006801f40c05010000
46abc0001680f484a0010000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
};
-
{a=>13,b=>3}
0d030000
0d030000
0d030000
0d600000
0d030000
0d030000
0d600000
0d030000
0d600000
-
{a=>-11,b=>1}
f5010000
f5010000
f5010000
f5200000
f5010000
f5010000
f5200000
f5010000
f5200000
-
{a=>5,b=>2}
05020000
05020000
05020000
05400000
05020000
05020000
05400000
05020000
05400000
-
{a=>-65,b=>1}
bf010000
bf010000
bf010000
bf200000
bf010000
bf010000
bf200000
bf010000
bf200000
-
{a=>51,b=>3}
33030000
33030000
33030000
33600000
33030000
33030000
33600000
33030000
33600000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>3,a=>-27,b=>4}
e51c0000
e51c0000
e51c0000
e58c0000
e51c0000
e51c0000
e58c0000
e51c0000
e58c0000
-
{c=>-2,a=>123,b=>4}
7b340000
7b340000
7b340000
7b980000
7b340000
7b340000
7b980000
7b340000
7b980000
-
{c=>-4,a=>-38,b=>5}
da250000
da250000
da250000
dab00000
da250000
da250000
dab00000
da250000
dab00000
-
{c=>-3,a=>4,b=>0}
04280000
04280000
04280000
04140000
04280000
04280000
04140000
04280000
04140000
-
{c=>0,a=>-104,b=>5}
98050000
98050000
98050000
98a00000
98050000
98050000
98a00000
98050000
98a00000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>-2,a=>-116,b=>0,d=>-2}
8cb00100
8cb00100
8cb00100
8c1b0000
8cb00100
8cb00100
8c1b0000
8cb00100
8c1b0000
-
{c=>-3,a=>-33,b=>2,d=>-3}
df6a0100
df6a0100
df6a0100
df568000
df6a0100
df6a0100
df568000
df6a0100
df568000
-
{c=>-2,a=>-99,b=>7,d=>2}
9db70000
9db70000
9db70000
9df90000
9db70000
9db70000
9df90000
9db70000
9df90000
-
{c=>-4,a=>103,b=>5,d=>-3}
67650100
67650100
67650100
67b28000
67650100
67650100
67b28000
67650100
67b28000
-
{c=>1,a=>111,b=>5,d=>0}
6f0d0000
6f0d0000
6f0d0000
6fa40000
6f0d0000
6f0d0000
6fa40000
6f0d0000
6fa40000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>1,c=>0,a=>17,b=>1,d=>-4}
11010300
11010300
11010300
11221000
11010300
11010300
11221000
11010300
11221000
-
{e=>4,c=>-2,a=>-99,b=>6,d=>-1}
9df60900
9df60900
9df60900
9ddbc000
9df60900
9df60900
9ddbc000
9df60900
9ddbc000
-
{e=>3,c=>-1,a=>-98,b=>4,d=>-1}
9efc0700
9efc0700
9efc0700
9e9fb000
9efc0700
9efc0700
9e9fb000
9efc0700
9e9fb000
-
{e=>1,c=>-2,a=>-9,b=>2,d=>3}
f7f20200
f7f20200
f7f20200
f7599000
f7f20200
f7f20200
f7599000
f7f20200
f7599000
-
{e=>5,c=>0,a=>-8,b=>0,d=>0}
f8000a00
f8000a00
f8000a00
f8005000
f8000a00
f8000a00
f8005000
f8000a00
f8005000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
};
-
{e=>5,c=>-1,a=>-128,b=>0,d=>2,f=>'UE2'}
80b82a00
80b82a00
80b82a00
801d5400
80b82a00
80b82a00
801d5400
80b82a00
801d5400
-
{e=>1,c=>-1,a=>19,b=>6,d=>3,f=>'UE0'}
13fe0200
13fe0200
13fe0200
13dd9000
13fe0200
13fe0200
13dd9000
13fe0200
13dd9000
-
{e=>3,c=>1,a=>-34,b=>1,d=>-3,f=>'UE2'}
de492700
de492700
de492700
de26b400
de492700
de492700
de26b400
de492700
de26b400
-
{e=>3,c=>3,a=>-85,b=>7,d=>1,f=>'UE4'}
ab5f4600
ab5f4600
ab5f4600
abecb800
ab5f4600
ab5f4600
abecb800
ab5f4600
abecb800
-
{e=>3,c=>-3,a=>14,b=>3,d=>1,f=>'UE7'}
0e6b7600
0e6b7600
0e6b7600
0e74be00
0e6b7600
0e6b7600
0e74be00
0e6b7600
0e74be00
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
};
-
{e=>3,c=>-2,a=>-81,g=>5,b=>0,d=>3,f=>'UE1'}
aff09602
aff09602
aff09602
af19b340
aff09602
aff09602
af19b340
aff09602
af19b340
-
{e=>5,c=>3,a=>-48,g=>4,b=>5,d=>-3,f=>'UE0'}
d05d0b02
d05d0b02
d05d0b02
d0aed100
d05d0b02
d05d0b02
d0aed100
d05d0b02
d0aed100
-
{e=>6,c=>1,a=>72,g=>3,b=>3,d=>-3,f=>'UE4'}
484bcd01
484bcd01
484bcd01
4866e8c0
484bcd01
484bcd01
4866e8c0
484bcd01
4866e8c0
-
{e=>5,c=>-4,a=>-73,g=>6,b=>4,d=>-1,f=>'UE3'}
b7e43b03
b7e43b03
b7e43b03
b793d780
b7e43b03
b7e43b03
b793d780
b7e43b03
b793d780
-
{e=>4,c=>-4,a=>33,g=>5,b=>5,d=>-3,f=>'UE6'}
2165e902
2165e902
2165e902
21b2cd40
2165e902
2165e902
21b2cd40
2165e902
21b2cd40
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>4,c=>2,a=>15,g=>5,b=>7,d=>1,f=>'UE1'}
0f579802
0f579802
0f579802
0fe8c340
0f579802
0f579802
0fe8c340
0f579802
0fe8c340
-
{e=>6,c=>-2,a=>117,g=>0,b=>0,d=>-2,f=>'UE3'}
75b03d00
75b03d00
75b03d00
751b6600
75b03d00
75b03d00
751b6600
75b03d00
751b6600
-
{e=>3,c=>2,a=>70,g=>7,b=>0,d=>2,f=>'UE0'}
46908603
46908603
46908603
460931c0
46908603
46908603
460931c0
46908603
460931c0
-
{e=>7,c=>-3,a=>95,g=>4,b=>2,d=>-2,f=>'UE7'}
5faa7f02
5faa7f02
5faa7f02
5f577f00
5faa7f02
5faa7f02
5f577f00
5faa7f02
5f577f00
-
{e=>3,c=>0,a=>42,g=>4,b=>7,d=>2,f=>'UE4'}
2a874602
2a874602
2a874602
2ae13900
2a874602
2a874602
2ae13900
2a874602
2ae13900
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>5,a=>-95,d=>0,c=>-2,h=>7,b=>4,g=>4,f=>'UE1'}
a1341a0207000000
a1341a0207000000
a1341a0207000000
a1985300e0000000
a1341a0207000000
a1341a0207000000
a1985300e0000000
a1341a0207000000
a1985300e0000000
-
{e=>0,a=>79,d=>3,c=>3,h=>4,b=>2,g=>0,f=>'UE4'}
4fda400004000000
4fda400004000000
4fda400004000000
4f4d880080000000
4fda400004000000
4fda400004000000
4f4d880080000000
4fda400004000000
4f4d880080000000
-
{e=>4,a=>23,d=>0,c=>3,h=>5,b=>5,g=>0,f=>'UE4'}
171d480005000000
171d480005000000
171d480005000000
17ac4800a0000000
171d480005000000
171d480005000000
17ac4800a0000000
171d480005000000
17ac4800a0000000
-
{e=>5,a=>-48,d=>2,c=>1,h=>4,b=>4,g=>4,f=>'UE1'}
d08c1a0204000000
d08c1a0204000000
d08c1a0204000000
d085530080000000
d08c1a0204000000
d08c1a0204000000
d085530080000000
d08c1a0204000000
d085530080000000
-
{e=>1,a=>-57,d=>3,c=>1,h=>5,b=>0,g=>0,f=>'UE3'}
c7c8320005000000
c7c8320005000000
c7c8320005000000
c7059600a0000000
c7c8320005000000
c7c8320005000000
c7059600a0000000
c7c8320005000000
c7059600a0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>5,a=>-24,d=>-4,c=>3,h=>2,b=>2,g=>3,f=>'UE2',i=>-2}
e81aab0132000000
e81aab0132000000
e81aab0132000000
e84e54c058000000
e81aab0132000000
e81aab0132000000
e84e54c058000000
e81aab0132000000
e84e54c058000000
-
{e=>7,a=>25,d=>0,c=>3,h=>3,b=>2,g=>3,f=>'UE0',i=>0}
191a8e0103000000
191a8e0103000000
191a8e0103000000
194c70c060000000
191a8e0103000000
191a8e0103000000
194c70c060000000
191a8e0103000000
194c70c060000000
-
{e=>3,a=>31,d=>2,c=>-1,h=>1,b=>1,g=>4,f=>'UE5',i=>1}
1fb9560209000000
1fb9560209000000
1fb9560209000000
1f3d3b0024000000
1fb9560209000000
1fb9560209000000
1f3d3b0024000000
1fb9560209000000
1f3d3b0024000000
-
{e=>4,a=>21,d=>-2,c=>1,h=>4,b=>6,g=>6,f=>'UE4',i=>-2}
158e490334000000
158e490334000000
158e490334000000
15c7498098000000
158e490334000000
158e490334000000
15c7498098000000
158e490334000000
15c7498098000000
-
{e=>6,a=>106,d=>-1,c=>1,h=>0,b=>0,g=>4,f=>'UE5',i=>-2}
6ac85d0230000000
6ac85d0230000000
6ac85d0230000000
6a07eb0018000000
6ac85d0230000000
6ac85d0230000000
6a07eb0018000000
6ac85d0230000000
6a07eb0018000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
};
-
{e=>5,a=>-92,d=>-4,j=>'SEM4',c=>1,h=>0,b=>7,g=>4,f=>'UE4',i=>0}
a40f4b0200010000
a40f4b0200010000
a40f4b0200010000
a4e6590002000000
a40f4b0200010000
a40f4b0200010000
a4e6590002000000
a40f4b0200010000
a4e6590002000000
-
{e=>6,a=>89,d=>1,j=>'SEM4',c=>0,h=>5,b=>5,g=>1,f=>'UE7',i=>2}
5945fc0015010000
5945fc0015010000
5945fc0015010000
59a0ee40aa000000
5945fc0015010000
5945fc0015010000
59a0ee40aa000000
5945fc0015010000
59a0ee40aa000000
-
{e=>2,a=>15,d=>0,j=>'SEM2',c=>1,h=>1,b=>4,g=>3,f=>'UE7',i=>0}
0f0cf40181010000
0f0cf40181010000
0f0cf40181010000
0f842ec023000000
0f0cf40181010000
0f0cf40181010000
0f842ec023000000
0f0cf40181010000
0f842ec023000000
-
{e=>3,a=>-2,d=>3,j=>'SEM2',c=>1,h=>1,b=>3,g=>4,f=>'UE7',i=>1}
fecb760289010000
fecb760289010000
fecb760289010000
fe65bf0027000000
fecb760289010000
fecb760289010000
fe65bf0027000000
fecb760289010000
fe65bf0027000000
-
{e=>5,a=>113,d=>0,j=>'SE2',c=>3,h=>5,b=>4,g=>5,f=>'UE2',i=>3}
711caa029d000000
711caa029d000000
711caa029d000000
718c5540ad000000
711caa029d000000
711caa029d000000
718c5540ad000000
711caa029d000000
718c5540ad000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
};
-
{e=>4,a=>-108,d=>-2,j=>'SE0',c=>3,k=>33,h=>1,b=>5,g=>1,f=>'UE4',i=>-2}
949dc90031002100
949dc90031002100
949dc90031002100
94af484038002100
949dc90031002100
949dc90031002100
94af484038002100
949dc90031002100
94af484038002100
-
{e=>5,a=>-119,d=>-4,j=>'SE1',c=>-2,k=>-4,h=>2,b=>0,g=>3,f=>'UE2',i=>-4}
8930ab016200fc00
8930ab016200fc00
8930ab016200fc00
891a54c05080fc00
8930ab016200fc00
8930ab016200fc00
891a54c05080fc00
8930ab016200fc00
891a54c05080fc00
-
{e=>7,a=>-38,d=>-4,j=>'SEM1',c=>1,k=>-5,h=>1,b=>7,g=>7,f=>'UE2',i=>1}
da0faf03c901fb00
da0faf03c901fb00
da0faf03c901fb00
dae675c02780fb00
da0faf03c901fb00
da0faf03c901fb00
dae675c02780fb00
da0faf03c901fb00
dae675c02780fb00
-
{e=>4,a=>-11,d=>0,j=>'SEM3',c=>3,k=>-84,h=>3,b=>6,g=>3,f=>'UE3',i=>2}
f51eb8015301ac00
f51eb8015301ac00
f51eb8015301ac00
f5cc46c06a80ac00
f51eb8015301ac00
f51eb8015301ac00
f5cc46c06a80ac00
f51eb8015301ac00
f5cc46c06a80ac00
-
{e=>0,a=>27,d=>2,j=>'SE2',c=>1,k=>-54,h=>0,b=>4,g=>1,f=>'UE4',i=>3}
1b8cc0009800ca00
1b8cc0009800ca00
1b8cc0009800ca00
1b8508400d00ca00
1b8cc0009800ca00
1b8cc0009800ca00
1b8508400d00ca00
1b8cc0009800ca00
1b8508400d00ca00
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>4,a=>-97,d=>3,j=>'SEM4',l=>0,c=>-2,k=>122,h=>3,b=>1,g=>1,f=>'UE3',i=>1}
9ff1b8000b017a00
9ff1b8000b017a00
9ff1b8000b017a00
9f39c64066007a00
9ff1b8000b017a00
9ff1b8000b017a00
9f39c64066007a00
9ff1b8000b017a00
9f39c64066007a00
-
{e=>4,a=>-122,d=>3,j=>'SEM2',l=>1,c=>3,k=>50,h=>0,b=>4,g=>5,f=>'UE0',i=>-3}
86dc8802a8013201
86dc8802a8013201
86dc8802a8013201
868dc14017003220
86dc8802a8013201
86dc8802a8013201
868dc14017003220
86dc8802a8013201
868dc14017003220
-
{e=>1,a=>-106,d=>0,j=>'SEM1',l=>1,c=>3,k=>-92,h=>5,b=>3,g=>7,f=>'UE1',i=>1}
961b9203cd01a401
961b9203cd01a401
961b9203cd01a401
966c13c0a780a420
961b9203cd01a401
961b9203cd01a401
966c13c0a780a420
961b9203cd01a401
966c13c0a780a420
-
{e=>5,a=>-50,d=>0,j=>'SE1',l=>0,c=>-2,k=>62,h=>7,b=>3,g=>6,f=>'UE5',i=>0}
ce335a0347003e00
ce335a0347003e00
ce335a0347003e00
ce785b80e0803e00
ce335a0347003e00
ce335a0347003e00
ce785b80e0803e00
ce335a0347003e00
ce785b80e0803e00
-
{e=>5,a=>100,d=>0,j=>'SE3',l=>3,c=>-4,k=>67,h=>1,b=>1,g=>7,f=>'UE3',i=>1}
6421ba03c9004303
6421ba03c9004303
6421ba03c9004303
643057c025804360
6421ba03c9004303
6421ba03c9004303
643057c025804360
6421ba03c9004303
643057c025804360
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>3,a=>18,m=>-4,d=>-2,j=>'SE0',l=>1,c=>-3,k=>-93,h=>5,b=>2,g=>6,f=>'UE1',i=>3}
12aa17031d00a321
12aa17031d00a321
12aa17031d00a321
12573380ac00a330
12aa17031d00a321
12aa17031d00a321
12573380ac00a330
12aa17031d00a321
12573380ac00a330
-
{e=>3,a=>-79,m=>-4,d=>0,j=>'SEM1',l=>5,c=>3,k=>20,h=>2,b=>5,g=>5,f=>'UE2',i=>-3}
b11da602ea011425
b11da602ea011425
b11da602ea011425
b1ac3540578014b0
b11da602ea011425
b11da602ea011425
b1ac3540578014b0
b11da602ea011425
b1ac3540578014b0
-
{e=>1,a=>16,m=>-1,d=>2,j=>'SEM3',l=>5,c=>1,k=>116,h=>3,b=>7,g=>5,f=>'UE1',i=>-3}
108f92026b01743d
108f92026b01743d
108f92026b01743d
10e51340768074bc
108f92026b01743d
108f92026b01743d
10e51340768074bc
108f92026b01743d
10e51340768074bc
-
{e=>3,a=>33,m=>-2,d=>0,j=>'SE0',l=>4,c=>3,k=>98,h=>3,b=>1,g=>6,f=>'UE6',i=>0}
2119660303006234
2119660303006234
2119660303006234
212c3d8060006298
2119660303006234
2119660303006234
212c3d8060006298
2119660303006234
212c3d8060006298
-
{e=>7,a=>-14,m=>-4,d=>-2,j=>'SE2',l=>7,c=>1,k=>-62,h=>0,b=>2,g=>0,f=>'UE2',i=>-1}
f28a2f00b800c227
f28a2f00b800c227
f28a2f00b800c227
f24774001d00c2f0
f28a2f00b800c227
f28a2f00b800c227
f24774001d00c2f0
f28a2f00b800c227
f24774001d00c2f0
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>2,n=>0,a=>-27,m=>-4,d=>-3,j=>'SEM3',l=>3,c=>3,k=>23,h=>3,b=>6,g=>7,f=>'UE4',i=>-3}
e55ec5036b01172300000000
e55ec5036b01172300000000
e55ec5036b01172300000000
e5cea9c07680177000000000
e55ec5036b01172300000000
e55ec5036b01172300000000
e5cea9c07680177000000000
e55ec5036b01172300000000
e5cea9c07680177000000000
-
{e=>4,n=>7,a=>-105,m=>-4,d=>-4,j=>'SE0',l=>6,c=>2,k=>99,h=>3,b=>1,g=>6,f=>'UE0',i=>2}
971109031300632607000000
971109031300632607000000
971109031300632607000000
972a4180680063d0e0000000
971109031300632607000000
971109031300632607000000
972a4180680063d0e0000000
971109031300632607000000
972a4180680063d0e0000000
-
{e=>4,n=>4,a=>96,m=>-3,d=>-3,j=>'SEM2',l=>4,c=>-1,k=>7,h=>7,b=>3,g=>5,f=>'UE3',i=>1}
607bb9028f01072c04000000
607bb9028f01072c04000000
607bb9028f01072c04000000
607ec740e700079480000000
607bb9028f01072c04000000
607bb9028f01072c04000000
607ec740e700079480000000
607bb9028f01072c04000000
607ec740e700079480000000
-
{e=>0,n=>4,a=>-116,m=>-1,d=>-4,j=>'SE1',l=>1,c=>0,k=>-79,h=>4,b=>7,g=>6,f=>'UE4',i=>-2}
8c0741037400b13904000000
8c0741037400b13904000000
8c0741037400b13904000000
8ce209809880b13c80000000
8c0741037400b13904000000
8c0741037400b13904000000
8ce209809880b13c80000000
8c0741037400b13904000000
8ce209809880b13c80000000
-
{e=>3,n=>0,a=>75,m=>0,d=>1,j=>'SEM4',l=>3,c=>-1,k=>-22,h=>4,b=>7,g=>7,f=>'UE1',i=>-2}
4b7f96033401ea0300000000
4b7f96033401ea0300000000
4b7f96033401ea0300000000
4bfcb3c09a00ea6000000000
4b7f96033401ea0300000000
4b7f96033401ea0300000000
4bfcb3c09a00ea6000000000
4b7f96033401ea0300000000
4bfcb3c09a00ea6000000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>7,n=>0,a=>-125,m=>1,d=>-1,j=>'SE1',l=>4,c=>3,k=>75,h=>2,b=>4,g=>2,f=>'UE4',o=>207,i=>1}
83dc4f014a004b0c00cf0000
83dc4f014a004b0c00cf0000
83dc4f014a004b0c00cf0000
838ff88044804b8400cf0000
83dc4f014a004b0c00cf0000
83dc4f014a004b0c00cf0000
838ff88044804b8400cf0000
83dc4f014a004b0c00cf0000
838ff88044804b8400cf0000
-
{e=>5,n=>5,a=>123,m=>2,d=>2,j=>'SEM4',l=>0,c=>-1,k=>-99,h=>5,b=>0,g=>6,f=>'UE2',o=>139,i=>0}
7bb82a0305019d10058b0000
7bb82a0305019d10058b0000
7bb82a0305019d10058b0000
7b1d5580a2009d08a08b0000
7bb82a0305019d10058b0000
7bb82a0305019d10058b0000
7b1d5580a2009d08a08b0000
7bb82a0305019d10058b0000
7b1d5580a2009d08a08b0000
-
{e=>4,n=>3,a=>11,m=>-1,d=>-1,j=>'SE1',l=>7,c=>-1,k=>-112,h=>3,b=>4,g=>6,f=>'UE7',o=>200,i=>-2}
0bfc79037300903f03c80000
0bfc79037300903f03c80000
0bfc79037300903f03c80000
0b9fcf80788090fc60c80000
0bfc79037300903f03c80000
0bfc79037300903f03c80000
0b9fcf80788090fc60c80000
0bfc79037300903f03c80000
0b9fcf80788090fc60c80000
-
{e=>3,n=>1,a=>-24,m=>1,d=>1,j=>'SE3',l=>4,c=>1,k=>14,h=>1,b=>5,g=>4,f=>'UE3',o=>226,i=>1}
e84d3602c9000e0c01e20000
e84d3602c9000e0c01e20000
e84d3602c9000e0c01e20000
e8a4b70025800e8420e20000
e84d3602c9000e0c01e20000
e84d3602c9000e0c01e20000
e8a4b70025800e8420e20000
e84d3602c9000e0c01e20000
e8a4b70025800e8420e20000
-
{e=>1,n=>3,a=>-40,m=>-4,d=>3,j=>'SE0',l=>2,c=>3,k=>-119,h=>2,b=>6,g=>1,f=>'UE3',o=>233,i=>0}
d8deb2000200892203e90000
d8deb2000200892203e90000
d8deb2000200892203e90000
d8cd96404000895060e90000
d8deb2000200892203e90000
d8deb2000200892203e90000
d8cd96404000895060e90000
d8deb2000200892203e90000
d8cd96404000895060e90000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
};
-
{a=>66,b=>2}
42000200
42000200
42000200
00424000
42000200
42000200
00424000
42000200
00424000
-
{a=>47,b=>3}
2f000300
2f000300
2f000300
002f6000
2f000300
2f000300
002f6000
2f000300
002f6000
-
{a=>34,b=>7}
22000700
22000700
22000700
0022e000
22000700
22000700
0022e000
22000700
0022e000
-
{a=>-104,b=>2}
98ff0200
98ff0200
98ff0200
ff984000
98ff0200
98ff0200
ff984000
98ff0200
ff984000
-
{a=>43,b=>2}
2b000200
2b000200
2b000200
002b4000
2b000200
2b000200
002b4000
2b000200
002b4000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>1,a=>3,b=>3}
03000b00
03000b00
03000b00
00036400
03000b00
03000b00
00036400
03000b00
00036400
-
{c=>-2,a=>65,b=>7}
41003700
41003700
41003700
0041f800
41003700
41003700
0041f800
41003700
0041f800
-
{c=>-2,a=>41,b=>1}
29003100
29003100
29003100
00293800
29003100
29003100
00293800
29003100
00293800
-
{c=>2,a=>111,b=>5}
6f001500
6f001500
6f001500
006fa800
6f001500
6f001500
006fa800
6f001500
006fa800
-
{c=>-2,a=>11,b=>1}
0b003100
0b003100
0b003100
000b3800
0b003100
0b003100
000b3800
0b003100
000b3800
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>1,a=>121,b=>6,d=>-2}
79008e01
79008e01
79008e01
0079c700
79008e01
79008e01
0079c700
79008e01
0079c700
-
{c=>2,a=>-66,b=>7,d=>-3}
beff5701
beff5701
beff5701
ffbeea80
beff5701
beff5701
ffbeea80
beff5701
ffbeea80
-
{c=>3,a=>-37,b=>3,d=>1}
dbff5b00
dbff5b00
dbff5b00
ffdb6c80
dbff5b00
dbff5b00
ffdb6c80
dbff5b00
ffdb6c80
-
{c=>-1,a=>-22,b=>6,d=>-3}
eaff7e01
eaff7e01
eaff7e01
ffeade80
eaff7e01
eaff7e01
ffeade80
eaff7e01
ffeade80
-
{c=>-1,a=>-107,b=>1,d=>-2}
95ffb901
95ffb901
95ffb901
ff953f00
95ffb901
95ffb901
ff953f00
95ffb901
ff953f00
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>2,c=>3,a=>113,b=>7,d=>2}
71009f04
71009f04
71009f04
0071ed20
71009f04
71009f04
0071ed20
71009f04
0071ed20
-
{e=>3,c=>2,a=>104,b=>0,d=>-2}
68009007
68009007
68009007
00680b30
68009007
68009007
00680b30
68009007
00680b30
-
{e=>4,c=>-4,a=>91,b=>2,d=>-1}
5b00e209
5b00e209
5b00e209
005b53c0
5b00e209
5b00e209
005b53c0
5b00e209
005b53c0
-
{e=>1,c=>0,a=>-67,b=>3,d=>0}
bdff0302
bdff0302
bdff0302
ffbd6010
bdff0302
bdff0302
ffbd6010
bdff0302
ffbd6010
-
{e=>6,c=>-2,a=>-125,b=>5,d=>-2}
83ffb50d
83ffb50d
83ffb50d
ff83bb60
83ffb50d
83ffb50d
ff83bb60
83ffb50d
ff83bb60
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
};
-
{e=>4,c=>-4,a=>63,b=>1,d=>-3,f=>'UE7'}
3f006179
3f006179
3f006179
003f32ce
3f006179
3f006179
003f32ce
3f006179
003f32ce
-
{e=>2,c=>2,a=>20,b=>1,d=>-4,f=>'UE1'}
14001115
14001115
14001115
00142a22
14001115
14001115
00142a22
14001115
00142a22
-
{e=>6,c=>-3,a=>-51,b=>5,d=>1,f=>'UE1'}
cdff6d1c
cdff6d1c
cdff6d1c
ffcdb4e2
cdff6d1c
cdff6d1c
ffcdb4e2
cdff6d1c
ffcdb4e2
-
{e=>6,c=>0,a=>82,b=>2,d=>0,f=>'UE0'}
5200020c
5200020c
5200020c
00524060
5200020c
5200020c
00524060
5200020c
00524060
-
{e=>5,c=>-4,a=>32,b=>4,d=>0,f=>'UE6'}
2000246a
2000246a
2000246a
0020905c
2000246a
2000246a
0020905c
2000246a
0020905c
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
};
-
{e=>0,c=>-4,a=>-51,g=>5,b=>5,d=>1,f=>'UE0'}
cdff650005000000
cdff650005000000
cdff650005000000
ffcdb080a0000000
cdff650005000000
cdff650005000000
ffcdb080a0000000
cdff650005000000
ffcdb080a0000000
-
{e=>3,c=>-3,a=>51,g=>5,b=>3,d=>1,f=>'UE7'}
33006b7605000000
33006b7605000000
33006b7605000000
003374bea0000000
33006b7605000000
33006b7605000000
003374bea0000000
33006b7605000000
003374bea0000000
-
{e=>2,c=>-3,a=>-58,g=>5,b=>3,d=>3,f=>'UE3'}
c6ffeb3405000000
c6ffeb3405000000
c6ffeb3405000000
ffc675a6a0000000
c6ffeb3405000000
c6ffeb3405000000
ffc675a6a0000000
c6ffeb3405000000
ffc675a6a0000000
-
{e=>5,c=>1,a=>-74,g=>7,b=>3,d=>-2,f=>'UE3'}
b6ff8b3b07000000
b6ff8b3b07000000
b6ff8b3b07000000
ffb66756e0000000
b6ff8b3b07000000
b6ff8b3b07000000
ffb66756e0000000
b6ff8b3b07000000
ffb66756e0000000
-
{e=>3,c=>1,a=>90,g=>5,b=>1,d=>3,f=>'UE6'}
5a00c96605000000
5a00c96605000000
5a00c96605000000
005a25bca0000000
5a00c96605000000
5a00c96605000000
005a25bca0000000
5a00c96605000000
005a25bca0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>7,c=>-4,a=>20,g=>5,b=>1,d=>2,f=>'UE0'}
1400a10e05000000
1400a10e05000000
1400a10e05000000
00143170a0000000
1400a10e05000000
1400a10e05000000
00143170a0000000
1400a10e05000000
00143170a0000000
-
{e=>3,c=>-3,a=>78,g=>5,b=>4,d=>2,f=>'UE5'}
4e00ac5605000000
4e00ac5605000000
4e00ac5605000000
004e953aa0000000
4e00ac5605000000
4e00ac5605000000
004e953aa0000000
4e00ac5605000000
004e953aa0000000
-
{e=>6,c=>3,a=>-109,g=>0,b=>6,d=>2,f=>'UE4'}
93ff9e4c00000000
93ff9e4c00000000
93ff9e4c00000000
ff93cd6800000000
93ff9e4c00000000
93ff9e4c00000000
ff93cd6800000000
93ff9e4c00000000
ff93cd6800000000
-
{e=>5,c=>0,a=>92,g=>2,b=>4,d=>1,f=>'UE1'}
5c00441a02000000
5c00441a02000000
5c00441a02000000
005c80d240000000
5c00441a02000000
5c00441a02000000
005c80d240000000
5c00441a02000000
005c80d240000000
-
{e=>6,c=>2,a=>-108,g=>4,b=>7,d=>-1,f=>'UE4'}
94ffd74d04000000
94ffd74d04000000
94ffd74d04000000
ff94ebe880000000
94ffd74d04000000
94ffd74d04000000
ff94ebe880000000
94ffd74d04000000
ff94ebe880000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>3,a=>8,d=>-1,c=>-4,h=>6,b=>1,g=>5,f=>'UE6'}
0800e1670500000006000000
0800e1670500000006000000
0800e1670500000006000000
000833bca0000000c0000000
0800e1670500000006000000
0800e1670500000006000000
000833bca0000000c0000000
0800e1670500000006000000
000833bca0000000c0000000
-
{e=>4,a=>118,d=>1,c=>0,h=>2,b=>3,g=>1,f=>'UE6'}
760043680100000002000000
760043680100000002000000
760043680100000002000000
007660cc2000000040000000
760043680100000002000000
760043680100000002000000
007660cc2000000040000000
760043680100000002000000
007660cc2000000040000000
-
{e=>7,a=>27,d=>-4,c=>2,h=>1,b=>4,g=>3,f=>'UE2'}
1b00142f0300000001000000
1b00142f0300000001000000
1b00142f0300000001000000
001b8a746000000020000000
1b00142f0300000001000000
1b00142f0300000001000000
001b8a746000000020000000
1b00142f0300000001000000
001b8a746000000020000000
-
{e=>0,a=>91,d=>-2,c=>3,h=>3,b=>5,g=>1,f=>'UE6'}
5b009d610100000003000000
5b009d610100000003000000
5b009d610100000003000000
005baf0c2000000060000000
5b009d610100000003000000
5b009d610100000003000000
005baf0c2000000060000000
5b009d610100000003000000
005baf0c2000000060000000
-
{e=>2,a=>70,d=>-3,c=>1,h=>6,b=>6,g=>5,f=>'UE4'}
46004e450500000006000000
46004e450500000006000000
46004e450500000006000000
0046c6a8a0000000c0000000
46004e450500000006000000
46004e450500000006000000
0046c6a8a0000000c0000000
46004e450500000006000000
0046c6a8a0000000c0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>2,a=>-26,d=>1,c=>-1,h=>0,b=>3,g=>0,f=>'UE4',i=>-4}
e6ff7b440000000020000000
e6ff7b440000000020000000
e6ff7b440000000020000000
ffe67ca80000000010000000
e6ff7b440000000020000000
e6ff7b440000000020000000
ffe67ca80000000010000000
e6ff7b440000000020000000
ffe67ca80000000010000000
-
{e=>0,a=>70,d=>3,c=>0,h=>3,b=>0,g=>5,f=>'UE0',i=>1}
4600c000050000000b000000
4600c000050000000b000000
4600c000050000000b000000
00460180a000000064000000
4600c000050000000b000000
4600c000050000000b000000
00460180a000000064000000
4600c000050000000b000000
00460180a000000064000000
-
{e=>1,a=>17,d=>3,c=>-4,h=>3,b=>1,g=>1,f=>'UE4',i=>-1}
1100e142010000003b000000
1100e142010000003b000000
1100e142010000003b000000
00113198200000007c000000
1100e142010000003b000000
1100e142010000003b000000
00113198200000007c000000
1100e142010000003b000000
00113198200000007c000000
-
{e=>2,a=>39,d=>1,c=>1,h=>0,b=>1,g=>0,f=>'UE1',i=>0}
270049140000000000000000
270049140000000000000000
270049140000000000000000
002724a20000000000000000
270049140000000000000000
270049140000000000000000
002724a20000000000000000
270049140000000000000000
002724a20000000000000000
-
{e=>6,a=>-65,d=>-2,c=>-1,h=>2,b=>6,g=>7,f=>'UE1',i=>-4}
bfffbe1d0700000022000000
bfffbe1d0700000022000000
bfffbe1d0700000022000000
ffbfdf62e000000050000000
bfffbe1d0700000022000000
bfffbe1d0700000022000000
ffbfdf62e000000050000000
bfffbe1d0700000022000000
ffbfdf62e000000050000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
};
-
{e=>7,a=>118,d=>1,j=>'SE2',c=>1,h=>6,b=>3,g=>5,f=>'UE4',i=>2}
76004b4e0500000096000000
76004b4e0500000096000000
76004b4e0500000096000000
007664f8a0000000c9000000
76004b4e0500000096000000
76004b4e0500000096000000
007664f8a0000000c9000000
76004b4e0500000096000000
007664f8a0000000c9000000
-
{e=>0,a=>32,d=>2,j=>'SE3',c=>2,h=>5,b=>3,g=>7,f=>'UE1',i=>-4}
2000931007000000e5000000
2000931007000000e5000000
2000931007000000e5000000
00206902e0000000b1800000
2000931007000000e5000000
2000931007000000e5000000
00206902e0000000b1800000
2000931007000000e5000000
00206902e0000000b1800000
-
{e=>2,a=>88,d=>0,j=>'SEM3',c=>1,h=>5,b=>2,g=>2,f=>'UE0',i=>1}
58000a04020000004d010000
58000a04020000004d010000
58000a04020000004d010000
0058442040000000a6800000
58000a04020000004d010000
58000a04020000004d010000
0058442040000000a6800000
58000a04020000004d010000
0058442040000000a6800000
-
{e=>7,a=>105,d=>-3,j=>'SE3',c=>0,h=>0,b=>3,g=>2,f=>'UE0',i=>-2}
6900430f02000000f0000000
6900430f02000000f0000000
6900430f02000000f0000000
006962f04000000019800000
6900430f02000000f0000000
6900430f02000000f0000000
006962f04000000019800000
6900430f02000000f0000000
006962f04000000019800000
-
{e=>4,a=>-56,d=>-2,j=>'SE0',c=>-3,h=>4,b=>1,g=>4,f=>'UE4',i=>2}
c8ffa9490400000014000000
c8ffa9490400000014000000
c8ffa9490400000014000000
ffc837488000000088000000
c8ffa9490400000014000000
c8ffa9490400000014000000
ffc837488000000088000000
c8ffa9490400000014000000
ffc837488000000088000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
};
-
{e=>0,a=>-104,d=>-4,j=>'SE0',c=>-2,k=>8,h=>1,b=>4,g=>6,f=>'UE1',i=>1}
98ff34110600000009000800
98ff34110600000009000800
98ff34110600000009000800
ff989a02c000000024000800
98ff34110600000009000800
98ff34110600000009000800
ff989a02c000000024000800
98ff34110600000009000800
ff989a02c000000024000800
-
{e=>2,a=>-127,d=>-1,j=>'SE0',c=>0,k=>-15,h=>5,b=>7,g=>0,f=>'UE1',i=>-1}
81ffc715000000003d00f100
81ffc715000000003d00f100
81ffc715000000003d00f100
ff81e3a200000000bc00f100
81ffc715000000003d00f100
81ffc715000000003d00f100
ff81e3a200000000bc00f100
81ffc715000000003d00f100
ff81e3a200000000bc00f100
-
{e=>0,a=>47,d=>2,j=>'SEM2',c=>-4,k=>-44,h=>0,b=>7,g=>0,f=>'UE3',i=>-3}
2f00a73000000000a801d400
2f00a73000000000a801d400
2f00a73000000000a801d400
002ff106000000001700d400
2f00a73000000000a801d400
2f00a73000000000a801d400
002ff106000000001700d400
2f00a73000000000a801d400
002ff106000000001700d400
-
{e=>7,a=>116,d=>-1,j=>'SEM3',c=>-3,k=>-14,h=>3,b=>5,g=>1,f=>'UE7',i=>2}
7400ed7f010000005301f200
7400ed7f010000005301f200
7400ed7f010000005301f200
0074b7fe200000006a80f200
7400ed7f010000005301f200
7400ed7f010000005301f200
0074b7fe200000006a80f200
7400ed7f010000005301f200
0074b7fe200000006a80f200
-
{e=>7,a=>45,d=>-1,j=>'SE3',c=>-4,k=>65,h=>3,b=>2,g=>6,f=>'UE0',i=>1}
2d00e20f06000000cb004100
2d00e20f06000000cb004100
2d00e20f06000000cb004100
002d53f0c000000065804100
2d00e20f06000000cb004100
2d00e20f06000000cb004100
002d53f0c000000065804100
2d00e20f06000000cb004100
002d53f0c000000065804100
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>1,a=>-38,d=>0,j=>'SEM4',l=>1,c=>3,k=>122,h=>0,b=>3,g=>6,f=>'UE0',i=>-4}
daff1b020600000020017a01
daff1b020600000020017a01
daff1b020600000020017a01
ffda6c10c000000012007a20
daff1b020600000020017a01
daff1b020600000020017a01
ffda6c10c000000012007a20
daff1b020600000020017a01
ffda6c10c000000012007a20
-
{e=>6,a=>-120,d=>-2,j=>'SE0',l=>0,c=>2,k=>-45,h=>4,b=>5,g=>6,f=>'UE7',i=>-1}
88ff957d060000003c00d300
88ff957d060000003c00d300
88ff957d060000003c00d300
ff88ab6ec00000009c00d300
88ff957d060000003c00d300
88ff957d060000003c00d300
ff88ab6ec00000009c00d300
88ff957d060000003c00d300
ff88ab6ec00000009c00d300
-
{e=>2,a=>115,d=>3,j=>'SEM4',l=>2,c=>-1,k=>-24,h=>4,b=>3,g=>1,f=>'UE2',i=>-3}
7300fb24010000002c01e802
7300fb24010000002c01e802
7300fb24010000002c01e802
00737da4200000009600e840
7300fb24010000002c01e802
7300fb24010000002c01e802
00737da4200000009600e840
7300fb24010000002c01e802
00737da4200000009600e840
-
{e=>2,a=>-120,d=>2,j=>'SEM3',l=>5,c=>-3,k=>-38,h=>3,b=>5,g=>5,f=>'UE0',i=>0}
88ffad04050000004301da05
88ffad04050000004301da05
88ffad04050000004301da05
ff88b520a00000006280daa0
88ffad04050000004301da05
88ffad04050000004301da05
ff88b520a00000006280daa0
88ffad04050000004301da05
ff88b520a00000006280daa0
-
{e=>1,a=>-3,d=>3,j=>'SEM4',l=>6,c=>3,k=>-72,h=>4,b=>1,g=>3,f=>'UE4',i=>-3}
fdffd942030000002c01b806
fdffd942030000002c01b806
fdffd942030000002c01b806
fffd2d98600000009600b8c0
fdffd942030000002c01b806
fdffd942030000002c01b806
fffd2d98600000009600b8c0
fdffd942030000002c01b806
fffd2d98600000009600b8c0
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>0,a=>-115,m=>-1,d=>1,j=>'SE1',l=>5,c=>3,k=>34,h=>4,b=>3,g=>5,f=>'UE3',i=>-1}
8dff5b30050000007c00223d
8dff5b30050000007c00223d
8dff5b30050000007c00223d
ff8d6c86a00000009c8022bc
8dff5b30050000007c00223d
8dff5b30050000007c00223d
ff8d6c86a00000009c8022bc
8dff5b30050000007c00223d
ff8d6c86a00000009c8022bc
-
{e=>7,a=>101,m=>-3,d=>2,j=>'SE2',l=>7,c=>2,k=>33,h=>5,b=>4,g=>7,f=>'UE5',i=>1}
6500945e070000008d00212f
6500945e070000008d00212f
6500945e070000008d00212f
0065897ae0000000a50021f4
6500945e070000008d00212f
6500945e070000008d00212f
0065897ae0000000a50021f4
6500945e070000008d00212f
0065897ae0000000a50021f4
-
{e=>4,a=>75,m=>-2,d=>-1,j=>'SE0',l=>6,c=>-4,k=>-42,h=>0,b=>5,g=>5,f=>'UE2',i=>-1}
4b00e529050000003800d636
4b00e529050000003800d636
4b00e529050000003800d636
004bb3c4a00000001c00d6d8
4b00e529050000003800d636
4b00e529050000003800d636
004bb3c4a00000001c00d6d8
4b00e529050000003800d636
004bb3c4a00000001c00d6d8
-
{e=>4,a=>124,m=>-2,d=>1,j=>'SE0',l=>2,c=>2,k=>-11,h=>2,b=>2,g=>2,f=>'UE5',i=>-1}
7c005258020000003a00f532
7c005258020000003a00f532
7c005258020000003a00f532
007c48ca400000005c00f558
7c005258020000003a00f532
7c005258020000003a00f532
007c48ca400000005c00f558
7c005258020000003a00f532
007c48ca400000005c00f558
-
{e=>1,a=>39,m=>-2,d=>2,j=>'SE1',l=>5,c=>0,k=>86,h=>1,b=>1,g=>0,f=>'UE6',i=>-4}
270081620000000061005635
270081620000000061005635
270081620000000061005635
0027211c00000000308056b8
270081620000000061005635
270081620000000061005635
0027211c00000000308056b8
270081620000000061005635
0027211c00000000308056b8
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>5,n=>6,a=>-69,m=>-2,d=>1,j=>'SE2',l=>5,c=>3,k=>-27,h=>7,b=>0,g=>7,f=>'UE6',i=>-2}
bbff586a07000000b700e53506000000
bbff586a07000000b700e53506000000
bbff586a07000000b700e53506000000
ffbb0cdce0000000f900e5b8c0000000
bbff586a07000000b700e53506000000
bbff586a07000000b700e53506000000
ffbb0cdce0000000f900e5b8c0000000
bbff586a07000000b700e53506000000
ffbb0cdce0000000f900e5b8c0000000
-
{e=>5,n=>2,a=>107,m=>-3,d=>0,j=>'SE1',l=>1,c=>-4,k=>111,h=>1,b=>0,g=>4,f=>'UE6',i=>-2}
6b00206a0400000071006f2902000000
6b00206a0400000071006f2902000000
6b00206a0400000071006f2902000000
006b105c8000000038806f3440000000
6b00206a0400000071006f2902000000
6b00206a0400000071006f2902000000
006b105c8000000038806f3440000000
6b00206a0400000071006f2902000000
006b105c8000000038806f3440000000
-
{e=>4,n=>7,a=>-128,m=>-2,d=>-1,j=>'SEM2',l=>7,c=>-4,k=>-5,h=>5,b=>5,g=>1,f=>'UE7',i=>-4}
80ffe57901000000a501fb3707000000
80ffe57901000000a501fb3707000000
80ffe57901000000a501fb3707000000
ff80b3ce20000000b300fbf8e0000000
80ffe57901000000a501fb3707000000
80ffe57901000000a501fb3707000000
ff80b3ce20000000b300fbf8e0000000
80ffe57901000000a501fb3707000000
ff80b3ce20000000b300fbf8e0000000
-
{e=>4,n=>4,a=>-44,m=>0,d=>3,j=>'SEM3',l=>3,c=>1,k=>-62,h=>4,b=>0,g=>2,f=>'UE5',i=>-1}
d4ffc858020000007c01c20304000000
d4ffc858020000007c01c20304000000
d4ffc858020000007c01c20304000000
ffd405ca400000009e80c26080000000
d4ffc858020000007c01c20304000000
d4ffc858020000007c01c20304000000
ffd405ca400000009e80c26080000000
d4ffc858020000007c01c20304000000
ffd405ca400000009e80c26080000000
-
{e=>1,n=>3,a=>20,m=>0,d=>-3,j=>'SE0',l=>7,c=>3,k=>86,h=>1,b=>3,g=>2,f=>'UE2',i=>3}
14005b23020000001900560703000000
14005b23020000001900560703000000
14005b23020000001900560703000000
00146e94400000002c0056e060000000
14005b23020000001900560703000000
14005b23020000001900560703000000
00146e94400000002c0056e060000000
14005b23020000001900560703000000
00146e94400000002c0056e060000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>0,n=>7,a=>-36,m=>-2,d=>-4,j=>'SEM1',l=>5,c=>-4,k=>-30,h=>6,b=>2,g=>7,f=>'UE1',o=>11,i=>-1}
dcff221107000000fe01e235070b0000
dcff221107000000fe01e235070b0000
dcff221107000000fe01e235070b0000
ffdc5202e0000000df80e2b8e00b0000
dcff221107000000fe01e235070b0000
dcff221107000000fe01e235070b0000
ffdc5202e0000000df80e2b8e00b0000
dcff221107000000fe01e235070b0000
ffdc5202e0000000df80e2b8e00b0000
-
{e=>1,n=>0,a=>47,m=>2,d=>-1,j=>'SE1',l=>6,c=>2,k=>19,h=>7,b=>5,g=>3,f=>'UE5',o=>117,i=>-1}
2f00d553030000007f00131600750000
2f00d553030000007f00131600750000
2f00d553030000007f00131600750000
002fab9a60000000fc8013c800750000
2f00d553030000007f00131600750000
2f00d553030000007f00131600750000
002fab9a60000000fc8013c800750000
2f00d553030000007f00131600750000
002fab9a60000000fc8013c800750000
-
{e=>3,n=>4,a=>60,m=>-4,d=>0,j=>'SE0',l=>6,c=>-2,k=>48,h=>1,b=>2,g=>6,f=>'UE7',o=>42,i=>1}
3c0032760600000009003026042a0000
3c0032760600000009003026042a0000
3c0032760600000009003026042a0000
003c583ec0000000240030d0802a0000
3c0032760600000009003026042a0000
3c0032760600000009003026042a0000
003c583ec0000000240030d0802a0000
3c0032760600000009003026042a0000
003c583ec0000000240030d0802a0000
-
{e=>1,n=>2,a=>116,m=>1,d=>-4,j=>'SEM2',l=>7,c=>3,k=>100,h=>0,b=>7,g=>2,f=>'UE3',o=>77,i=>-1}
74001f3302000000b801640f024d0000
74001f3302000000b801640f024d0000
74001f3302000000b801640f024d0000
0074ee16400000001f0064e4404d0000
74001f3302000000b801640f024d0000
74001f3302000000b801640f024d0000
0074ee16400000001f0064e4404d0000
74001f3302000000b801640f024d0000
0074ee16400000001f0064e4404d0000
-
{e=>1,n=>7,a=>-98,m=>-3,d=>2,j=>'SEM4',l=>5,c=>0,k=>27,h=>7,b=>1,g=>1,f=>'UE2',o=>35,i=>-2}
9eff81220100000037011b2d07230000
9eff81220100000037011b2d07230000
9eff81220100000037011b2d07230000
ff9e211420000000fa001bb4e0230000
9eff81220100000037011b2d07230000
9eff81220100000037011b2d07230000
ff9e211420000000fa001bb4e0230000
9eff81220100000037011b2d07230000
ff9e211420000000fa001bb4e0230000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
};
-
{a=>54,b=>7}
3600000007000000
3600000007000000
3600000007000000
00000036e0000000
3600000007000000
3600000007000000
00000036e0000000
3600000007000000
00000036e0000000
-
{a=>-14,b=>1}
f2ffffff01000000
f2ffffff01000000
f2ffffff01000000
fffffff220000000
f2ffffff01000000
f2ffffff01000000
fffffff220000000
f2ffffff01000000
fffffff220000000
-
{a=>8,b=>5}
0800000005000000
0800000005000000
0800000005000000
00000008a0000000
0800000005000000
0800000005000000
00000008a0000000
0800000005000000
00000008a0000000
-
{a=>-128,b=>2}
80ffffff02000000
80ffffff02000000
80ffffff02000000
ffffff8040000000
80ffffff02000000
80ffffff02000000
ffffff8040000000
80ffffff02000000
ffffff8040000000
-
{a=>89,b=>7}
5900000007000000
5900000007000000
5900000007000000
00000059e0000000
5900000007000000
5900000007000000
00000059e0000000
5900000007000000
00000059e0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>-4,a=>71,b=>4}
4700000024000000
4700000024000000
4700000024000000
0000004790000000
4700000024000000
4700000024000000
0000004790000000
4700000024000000
0000004790000000
-
{c=>-1,a=>22,b=>7}
160000003f000000
160000003f000000
160000003f000000
00000016fc000000
160000003f000000
160000003f000000
00000016fc000000
160000003f000000
00000016fc000000
-
{c=>3,a=>6,b=>4}
060000001c000000
060000001c000000
060000001c000000
000000068c000000
060000001c000000
060000001c000000
000000068c000000
060000001c000000
000000068c000000
-
{c=>0,a=>5,b=>7}
0500000007000000
0500000007000000
0500000007000000
00000005e0000000
0500000007000000
0500000007000000
00000005e0000000
0500000007000000
00000005e0000000
-
{c=>-1,a=>71,b=>5}
470000003d000000
470000003d000000
470000003d000000
00000047bc000000
470000003d000000
470000003d000000
00000047bc000000
470000003d000000
00000047bc000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>-3,a=>-39,b=>5,d=>-4}
d9ffffff2d010000
d9ffffff2d010000
d9ffffff2d010000
ffffffd9b6000000
d9ffffff2d010000
d9ffffff2d010000
ffffffd9b6000000
d9ffffff2d010000
ffffffd9b6000000
-
{c=>1,a=>-63,b=>0,d=>-1}
c1ffffffc8010000
c1ffffffc8010000
c1ffffffc8010000
ffffffc107800000
c1ffffffc8010000
c1ffffffc8010000
ffffffc107800000
c1ffffffc8010000
ffffffc107800000
-
{c=>3,a=>-125,b=>4,d=>1}
83ffffff5c000000
83ffffff5c000000
83ffffff5c000000
ffffff838c800000
83ffffff5c000000
83ffffff5c000000
ffffff838c800000
83ffffff5c000000
ffffff838c800000
-
{c=>-4,a=>-67,b=>6,d=>-1}
bdffffffe6010000
bdffffffe6010000
bdffffffe6010000
ffffffbdd3800000
bdffffffe6010000
bdffffffe6010000
ffffffbdd3800000
bdffffffe6010000
ffffffbdd3800000
-
{c=>3,a=>-19,b=>7,d=>-4}
edffffff1f010000
edffffff1f010000
edffffff1f010000
ffffffedee000000
edffffff1f010000
edffffff1f010000
ffffffedee000000
edffffff1f010000
ffffffedee000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>2,c=>-1,a=>96,b=>4,d=>1}
600000007c040000
600000007c040000
600000007c040000
000000609ca00000
600000007c040000
600000007c040000
000000609ca00000
600000007c040000
000000609ca00000
-
{e=>0,c=>1,a=>-33,b=>2,d=>0}
dfffffff0a000000
dfffffff0a000000
dfffffff0a000000
ffffffdf44000000
dfffffff0a000000
dfffffff0a000000
ffffffdf44000000
dfffffff0a000000
ffffffdf44000000
-
{e=>1,c=>-3,a=>-123,b=>4,d=>-2}
85ffffffac030000
85ffffffac030000
85ffffffac030000
ffffff8597100000
85ffffffac030000
85ffffffac030000
ffffff8597100000
85ffffffac030000
ffffff8597100000
-
{e=>2,c=>0,a=>-85,b=>3,d=>2}
abffffff83040000
abffffff83040000
abffffff83040000
ffffffab61200000
abffffff83040000
abffffff83040000
ffffffab61200000
abffffff83040000
ffffffab61200000
-
{e=>5,c=>2,a=>93,b=>6,d=>-3}
5d000000560b0000
5d000000560b0000
5d000000560b0000
0000005dcad00000
5d000000560b0000
5d000000560b0000
0000005dcad00000
5d000000560b0000
0000005dcad00000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
};
-
{e=>4,c=>-2,a=>-117,b=>4,d=>2,f=>'UE6'}
8bffffffb4680000
8bffffffb4680000
8bffffffb4680000
ffffff8b994c0000
8bffffffb4680000
8bffffffb4680000
ffffff8b994c0000
8bffffffb4680000
ffffff8b994c0000
-
{e=>2,c=>-4,a=>78,b=>0,d=>-2,f=>'UE4'}
4e000000a0450000
4e000000a0450000
4e000000a0450000
0000004e13280000
4e000000a0450000
4e000000a0450000
0000004e13280000
4e000000a0450000
0000004e13280000
-
{e=>3,c=>3,a=>-102,b=>0,d=>-3,f=>'UE2'}
9affffff58270000
9affffff58270000
9affffff58270000
ffffff9a0eb40000
9affffff58270000
9affffff58270000
ffffff9a0eb40000
9affffff58270000
ffffff9a0eb40000
-
{e=>3,c=>-4,a=>10,b=>2,d=>0,f=>'UE1'}
0a00000022160000
0a00000022160000
0a00000022160000
0000000a50320000
0a00000022160000
0a00000022160000
0000000a50320000
0a00000022160000
0000000a50320000
-
{e=>5,c=>3,a=>112,b=>7,d=>-2,f=>'UE1'}
700000009f1b0000
700000009f1b0000
700000009f1b0000
00000070ef520000
700000009f1b0000
700000009f1b0000
00000070ef520000
700000009f1b0000
00000070ef520000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
};
-
{e=>4,c=>3,a=>77,g=>5,b=>3,d=>2,f=>'UE5'}
4d0000009bd80200
4d0000009bd80200
4d0000009bd80200
0000004d6d4b4000
4d0000009bd80200
4d0000009bd80200
0000004d6d4b4000
4d0000009bd80200
0000004d6d4b4000
-
{e=>7,c=>3,a=>5,g=>6,b=>2,d=>0,f=>'UE5'}
050000001a5e0300
050000001a5e0300
050000001a5e0300
000000054c7b8000
050000001a5e0300
050000001a5e0300
000000054c7b8000
050000001a5e0300
000000054c7b8000
-
{e=>7,c=>-2,a=>-24,g=>2,b=>0,d=>3,f=>'UE1'}
e8fffffff01e0100
e8fffffff01e0100
e8fffffff01e0100
ffffffe819f28000
e8fffffff01e0100
e8fffffff01e0100
ffffffe819f28000
e8fffffff01e0100
ffffffe819f28000
-
{e=>7,c=>3,a=>-1,g=>3,b=>6,d=>-2,f=>'UE6'}
ffffffff9eef0100
ffffffff9eef0100
ffffffff9eef0100
ffffffffcf7cc000
ffffffff9eef0100
ffffffff9eef0100
ffffffffcf7cc000
ffffffff9eef0100
ffffffffcf7cc000
-
{e=>1,c=>-1,a=>-111,g=>1,b=>4,d=>1,f=>'UE5'}
91ffffff7cd20000
91ffffff7cd20000
91ffffff7cd20000
ffffff919c9a4000
91ffffff7cd20000
91ffffff7cd20000
ffffff919c9a4000
91ffffff7cd20000
ffffff919c9a4000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>3,c=>-3,a=>50,g=>6,b=>2,d=>-3,f=>'UE2'}
320000006a270300
320000006a270300
320000006a270300
0000003256b58000
320000006a270300
320000006a270300
0000003256b58000
320000006a270300
0000003256b58000
-
{e=>2,c=>-3,a=>47,g=>0,b=>3,d=>-3,f=>'UE1'}
2f0000006b150000
2f0000006b150000
2f0000006b150000
0000002f76a20000
2f0000006b150000
2f0000006b150000
0000002f76a20000
2f0000006b150000
0000002f76a20000
-
{e=>0,c=>0,a=>-123,g=>6,b=>6,d=>-3,f=>'UE4'}
85ffffff46410300
85ffffff46410300
85ffffff46410300
ffffff85c2898000
85ffffff46410300
85ffffff46410300
ffffff85c2898000
85ffffff46410300
ffffff85c2898000
-
{e=>1,c=>-2,a=>-46,g=>4,b=>5,d=>0,f=>'UE6'}
d2ffffff35620200
d2ffffff35620200
d2ffffff35620200
ffffffd2b81d0000
d2ffffff35620200
d2ffffff35620200
ffffffd2b81d0000
d2ffffff35620200
ffffffd2b81d0000
-
{e=>4,c=>-4,a=>41,g=>7,b=>7,d=>-2,f=>'UE3'}
29000000a7b90300
29000000a7b90300
29000000a7b90300
00000029f347c000
29000000a7b90300
29000000a7b90300
00000029f347c000
29000000a7b90300
00000029f347c000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>4,a=>-86,d=>3,c=>3,h=>2,b=>7,g=>7,f=>'UE7'}
aaffffffdff8030002000000
aaffffffdff8030002000000
aaffffffdff8030002000000
ffffffaaedcfc00040000000
aaffffffdff8030002000000
aaffffffdff8030002000000
ffffffaaedcfc00040000000
aaffffffdff8030002000000
ffffffaaedcfc00040000000
-
{e=>4,a=>64,d=>2,c=>1,h=>5,b=>5,g=>4,f=>'UE0'}
400000008d08020005000000
400000008d08020005000000
400000008d08020005000000
00000040a5410000a0000000
400000008d08020005000000
400000008d08020005000000
00000040a5410000a0000000
400000008d08020005000000
00000040a5410000a0000000
-
{e=>4,a=>-56,d=>2,c=>-4,h=>6,b=>5,g=>1,f=>'UE6'}
c8ffffffa5e8000006000000
c8ffffffa5e8000006000000
c8ffffffa5e8000006000000
ffffffc8b14c4000c0000000
c8ffffffa5e8000006000000
c8ffffffa5e8000006000000
ffffffc8b14c4000c0000000
c8ffffffa5e8000006000000
ffffffc8b14c4000c0000000
-
{e=>6,a=>78,d=>3,c=>-1,h=>3,b=>0,g=>6,f=>'UE4'}
4e000000f84c030003000000
4e000000f84c030003000000
4e000000f84c030003000000
0000004e1de9800060000000
4e000000f84c030003000000
4e000000f84c030003000000
0000004e1de9800060000000
4e000000f84c030003000000
0000004e1de9800060000000
-
{e=>7,a=>-101,d=>0,c=>-2,h=>6,b=>1,g=>4,f=>'UE1'}
9bffffff311e020006000000
9bffffff311e020006000000
9bffffff311e020006000000
ffffff9b38730000c0000000
9bffffff311e020006000000
9bffffff311e020006000000
ffffff9b38730000c0000000
9bffffff311e020006000000
ffffff9b38730000c0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>4,a=>98,d=>1,c=>0,h=>3,b=>1,g=>0,f=>'UE5',i=>-4}
620000004158000023000000
620000004158000023000000
620000004158000023000000
0000006220ca000070000000
620000004158000023000000
620000004158000023000000
0000006220ca000070000000
620000004158000023000000
0000006220ca000070000000
-
{e=>6,a=>-56,d=>-2,c=>-4,h=>6,b=>4,g=>7,f=>'UE5',i=>2}
c8ffffffa4dd030016000000
c8ffffffa4dd030016000000
c8ffffffa4dd030016000000
ffffffc8936bc000c8000000
c8ffffffa4dd030016000000
c8ffffffa4dd030016000000
ffffffc8936bc000c8000000
c8ffffffa4dd030016000000
ffffffc8936bc000c8000000
-
{e=>3,a=>-48,d=>0,c=>1,h=>5,b=>7,g=>5,f=>'UE1',i=>3}
d0ffffff0f9602001d000000
d0ffffff0f9602001d000000
d0ffffff0f9602001d000000
ffffffd0e4334000ac000000
d0ffffff0f9602001d000000
d0ffffff0f9602001d000000
ffffffd0e4334000ac000000
d0ffffff0f9602001d000000
ffffffd0e4334000ac000000
-
{e=>0,a=>-14,d=>-1,c=>-4,h=>1,b=>1,g=>4,f=>'UE1',i=>1}
f2ffffffe111020009000000
f2ffffffe111020009000000
f2ffffffe111020009000000
fffffff23383000024000000
f2ffffffe111020009000000
f2ffffffe111020009000000
fffffff23383000024000000
f2ffffffe111020009000000
fffffff23383000024000000
-
{e=>4,a=>-3,d=>3,c=>2,h=>1,b=>6,g=>6,f=>'UE4',i=>-2}
fdffffffd648030031000000
fdffffffd648030031000000
fdffffffd648030031000000
fffffffdc9c9800038000000
fdffffffd648030031000000
fdffffffd648030031000000
fffffffdc9c9800038000000
fdffffffd648030031000000
fffffffdc9c9800038000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
};
-
{e=>7,a=>-125,d=>-1,j=>'SE0',c=>-3,h=>0,b=>3,g=>0,f=>'UE0',i=>0}
83ffffffeb0f000000000000
83ffffffeb0f000000000000
83ffffffeb0f000000000000
ffffff8377f0000000000000
83ffffffeb0f000000000000
83ffffffeb0f000000000000
ffffff8377f0000000000000
83ffffffeb0f000000000000
ffffff8377f0000000000000
-
{e=>4,a=>-83,d=>1,j=>'SEM1',c=>-2,h=>0,b=>5,g=>2,f=>'UE1',i=>3}
adffffff75180100d8010000
adffffff75180100d8010000
adffffff75180100d8010000
ffffffadb8c280000f800000
adffffff75180100d8010000
adffffff75180100d8010000
ffffffadb8c280000f800000
adffffff75180100d8010000
ffffffadb8c280000f800000
-
{e=>1,a=>118,d=>-1,j=>'SE0',c=>1,h=>6,b=>1,g=>5,f=>'UE7',i=>0}
76000000c9f3020006000000
76000000c9f3020006000000
76000000c9f3020006000000
00000076279f4000c0000000
76000000c9f3020006000000
76000000c9f3020006000000
00000076279f4000c0000000
76000000c9f3020006000000
00000076279f4000c0000000
-
{e=>1,a=>-5,d=>-4,j=>'SE0',c=>0,h=>0,b=>6,g=>3,f=>'UE3',i=>2}
fbffffff06b3010010000000
fbffffff06b3010010000000
fbffffff06b3010010000000
fffffffbc216c00008000000
fbffffff06b3010010000000
fbffffff06b3010010000000
fffffffbc216c00008000000
fbffffff06b3010010000000
fffffffbc216c00008000000
-
{e=>0,a=>70,d=>-3,j=>'SEM1',c=>0,h=>3,b=>5,g=>3,f=>'UE5',i=>2}
4600000045d10100d3010000
4600000045d10100d3010000
4600000045d10100d3010000
00000046a28ac0006b800000
4600000045d10100d3010000
4600000045d10100d3010000
00000046a28ac0006b800000
4600000045d10100d3010000
00000046a28ac0006b800000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
};
-
{e=>0,a=>2,d=>0,j=>'SE2',c=>2,k=>37,h=>4,b=>1,g=>0,f=>'UE2',i=>0}
020000001120000084002500
020000001120000084002500
020000001120000084002500
000000022804000081002500
020000001120000084002500
020000001120000084002500
000000022804000081002500
020000001120000084002500
000000022804000081002500
-
{e=>1,a=>68,d=>-2,j=>'SEM2',c=>-4,k=>-109,h=>0,b=>4,g=>2,f=>'UE5',i=>0}
44000000a453010080019300
44000000a453010080019300
44000000a453010080019300
00000044931a800003009300
44000000a453010080019300
44000000a453010080019300
00000044931a800003009300
44000000a453010080019300
00000044931a800003009300
-
{e=>4,a=>117,d=>-4,j=>'SEM4',c=>2,k=>-10,h=>7,b=>3,g=>1,f=>'UE3',i=>-2}
7500000013b900003701f600
7500000013b900003701f600
7500000013b900003701f600
000000756a464000fa00f600
7500000013b900003701f600
7500000013b900003701f600
000000756a464000fa00f600
7500000013b900003701f600
000000756a464000fa00f600
-
{e=>7,a=>-56,d=>-3,j=>'SE2',c=>3,k=>30,h=>7,b=>6,g=>5,f=>'UE5',i=>-1}
c8ffffff5edf0200bf001e00
c8ffffff5edf0200bf001e00
c8ffffff5edf0200bf001e00
ffffffc8cefb4000fd001e00
c8ffffff5edf0200bf001e00
c8ffffff5edf0200bf001e00
ffffffc8cefb4000fd001e00
c8ffffff5edf0200bf001e00
ffffffc8cefb4000fd001e00
-
{e=>1,a=>-1,d=>-2,j=>'SEM1',c=>-3,k=>-71,h=>6,b=>6,g=>3,f=>'UE2',i=>-3}
ffffffffaea30100ee01b900
ffffffffaea30100ee01b900
ffffffffaea30100ee01b900
ffffffffd714c000d780b900
ffffffffaea30100ee01b900
ffffffffaea30100ee01b900
ffffffffd714c000d780b900
ffffffffaea30100ee01b900
ffffffffd714c000d780b900
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>1,a=>26,d=>2,j=>'SEM1',l=>2,c=>-2,k=>-113,h=>2,b=>0,g=>0,f=>'UE7',i=>-3}
1a000000b0720000ea018f02
1a000000b0720000ea018f02
1a000000b0720000ea018f02
0000001a191e000057808f40
1a000000b0720000ea018f02
1a000000b0720000ea018f02
0000001a191e000057808f40
1a000000b0720000ea018f02
0000001a191e000057808f40
-
{e=>2,a=>117,d=>-4,j=>'SE1',l=>6,c=>3,k=>-95,h=>1,b=>6,g=>4,f=>'UE0',i=>1}
750000001e0502004900a106
750000001e0502004900a106
750000001e0502004900a106
00000075ce2100002480a1c0
750000001e0502004900a106
750000001e0502004900a106
00000075ce2100002480a1c0
750000001e0502004900a106
00000075ce2100002480a1c0
-
{e=>4,a=>69,d=>3,j=>'SE1',l=>7,c=>-3,k=>-103,h=>5,b=>4,g=>7,f=>'UE2',i=>-4}
45000000eca8030065009907
45000000eca8030065009907
45000000eca8030065009907
0000004595c5c000b08099e0
45000000eca8030065009907
45000000eca8030065009907
0000004595c5c000b08099e0
45000000eca8030065009907
0000004595c5c000b08099e0
-
{e=>0,a=>66,d=>0,j=>'SEM1',l=>4,c=>-2,k=>-115,h=>0,b=>6,g=>2,f=>'UE6',i=>-1}
4200000036600100f8018d04
4200000036600100f8018d04
4200000036600100f8018d04
00000042d80c80001f808d80
4200000036600100f8018d04
4200000036600100f8018d04
00000042d80c80001f808d80
4200000036600100f8018d04
00000042d80c80001f808d80
-
{e=>0,a=>115,d=>3,j=>'SE3',l=>6,c=>-3,k=>-110,h=>4,b=>7,g=>6,f=>'UE3',i=>1}
73000000ef300300cc009206
73000000ef300300cc009206
73000000ef300300cc009206
00000073f5878000858092c0
73000000ef300300cc009206
73000000ef300300cc009206
00000073f5878000858092c0
73000000ef300300cc009206
00000073f5878000858092c0
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>1,a=>20,m=>-3,d=>1,j=>'SE3',l=>5,c=>-3,k=>47,h=>7,b=>3,g=>2,f=>'UE7',i=>-4}
140000006b720100e7002f2d
140000006b720100e7002f2d
140000006b720100e7002f2d
00000014749e8000f1802fb4
140000006b720100e7002f2d
140000006b720100e7002f2d
00000014749e8000f1802fb4
140000006b720100e7002f2d
00000014749e8000f1802fb4
-
{e=>5,a=>113,m=>0,d=>-2,j=>'SE3',l=>3,c=>-4,k=>63,h=>2,b=>7,g=>2,f=>'UE2',i=>2}
71000000a72b0100d2003f03
71000000a72b0100d2003f03
71000000a72b0100d2003f03
00000071f354800049803f60
71000000a72b0100d2003f03
71000000a72b0100d2003f03
00000071f354800049803f60
71000000a72b0100d2003f03
00000071f354800049803f60
-
{e=>1,a=>58,m=>-1,d=>-1,j=>'SEM2',l=>1,c=>1,k=>4,h=>1,b=>2,g=>7,f=>'UE5',i=>-2}
3a000000cad30300b1010439
3a000000cad30300b1010439
3a000000cad30300b1010439
0000003a479bc0003b00043c
3a000000cad30300b1010439
3a000000cad30300b1010439
0000003a479bc0003b00043c
3a000000cad30300b1010439
0000003a479bc0003b00043c
-
{e=>5,a=>101,m=>0,d=>3,j=>'SEM4',l=>6,c=>-2,k=>124,h=>5,b=>7,g=>0,f=>'UE0',i=>-1}
65000000f70a00003d017c06
65000000f70a00003d017c06
65000000f70a00003d017c06
00000065f9d00000be007cc0
65000000f70a00003d017c06
65000000f70a00003d017c06
00000065f9d00000be007cc0
65000000f70a00003d017c06
00000065f9d00000be007cc0
-
{e=>1,a=>73,m=>-4,d=>-1,j=>'SEM1',l=>2,c=>1,k=>-19,h=>4,b=>0,g=>5,f=>'UE3',i=>-4}
49000000c8b30200e401ed22
49000000c8b30200e401ed22
49000000c8b30200e401ed22
00000049079740009380ed50
49000000c8b30200e401ed22
49000000c8b30200e401ed22
00000049079740009380ed50
49000000c8b30200e401ed22
00000049079740009380ed50
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>1,n=>1,a=>-71,m=>-2,d=>0,j=>'SE1',l=>0,c=>-2,k=>60,h=>6,b=>4,g=>5,f=>'UE5',i=>-1}
b9ffffff34d202007e003c3001000000
b9ffffff34d202007e003c3001000000
b9ffffff34d202007e003c3001000000
ffffffb9981b4000dc803c1820000000
b9ffffff34d202007e003c3001000000
b9ffffff34d202007e003c3001000000
ffffffb9981b4000dc803c1820000000
b9ffffff34d202007e003c3001000000
ffffffb9981b4000dc803c1820000000
-
{e=>7,n=>5,a=>-15,m=>-1,d=>0,j=>'SEM1',l=>5,c=>-2,k=>4,h=>2,b=>3,g=>3,f=>'UE0',i=>-3}
f1ffffff338e0100ea01043d05000000
f1ffffff338e0100ea01043d05000000
f1ffffff338e0100ea01043d05000000
fffffff17870c000578004bca0000000
f1ffffff338e0100ea01043d05000000
f1ffffff338e0100ea01043d05000000
fffffff17870c000578004bca0000000
f1ffffff338e0100ea01043d05000000
fffffff17870c000578004bca0000000
-
{e=>6,n=>3,a=>12,m=>1,d=>3,j=>'SE3',l=>4,c=>-4,k=>116,h=>6,b=>1,g=>4,f=>'UE2',i=>-2}
0c000000e12c0200f600740c03000000
0c000000e12c0200f600740c03000000
0c000000e12c0200f600740c03000000
0000000c31e50000d980748460000000
0c000000e12c0200f600740c03000000
0c000000e12c0200f600740c03000000
0000000c31e50000d980748460000000
0c000000e12c0200f600740c03000000
0000000c31e50000d980748460000000
-
{e=>5,n=>3,a=>42,m=>1,d=>-3,j=>'SE3',l=>4,c=>1,k=>-90,h=>4,b=>3,g=>6,f=>'UE3',i=>-1}
2a0000004b3b0300fc00a60c03000000
2a0000004b3b0300fc00a60c03000000
2a0000004b3b0300fc00a60c03000000
0000002a66d780009d80a68460000000
2a0000004b3b0300fc00a60c03000000
2a0000004b3b0300fc00a60c03000000
0000002a66d780009d80a68460000000
2a0000004b3b0300fc00a60c03000000
0000002a66d780009d80a68460000000
-
{e=>7,n=>3,a=>55,m=>-2,d=>0,j=>'SE2',l=>0,c=>2,k=>-125,h=>4,b=>5,g=>7,f=>'UE7',i=>-4}
3700000015fe0300a400833003000000
3700000015fe0300a400833003000000
3700000015fe0300a400833003000000
00000037a87fc0009100831860000000
3700000015fe0300a400833003000000
3700000015fe0300a400833003000000
00000037a87fc0009100831860000000
3700000015fe0300a400833003000000
00000037a87fc0009100831860000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>7,n=>5,a=>111,m=>-1,d=>3,j=>'SE1',l=>5,c=>-1,k=>85,h=>5,b=>0,g=>4,f=>'UE7',o=>100,i=>2}
6f000000f87e02005500553d05640000
6f000000f87e02005500553d05640000
6f000000f87e02005500553d05640000
0000006f1dff0000a88055bca0640000
6f000000f87e02005500553d05640000
6f000000f87e02005500553d05640000
0000006f1dff0000a88055bca0640000
6f000000f87e02005500553d05640000
0000006f1dff0000a88055bca0640000
-
{e=>3,n=>3,a=>68,m=>3,d=>-2,j=>'SE0',l=>2,c=>3,k=>30,h=>0,b=>6,g=>3,f=>'UE0',o=>140,i=>-1}
440000009e87010038001e1a038c0000
440000009e87010038001e1a038c0000
440000009e87010038001e1a038c0000
00000044cf30c0001c001e4c608c0000
440000009e87010038001e1a038c0000
440000009e87010038001e1a038c0000
00000044cf30c0001c001e4c608c0000
440000009e87010038001e1a038c0000
00000044cf30c0001c001e4c608c0000
-
{e=>1,n=>2,a=>-1,m=>2,d=>1,j=>'SE0',l=>1,c=>3,k=>-56,h=>3,b=>0,g=>3,f=>'UE1',o=>96,i=>2}
ffffffff589201001300c81102600000
ffffffff589201001300c81102600000
ffffffff589201001300c81102600000
ffffffff0c92c0006800c82840600000
ffffffff589201001300c81102600000
ffffffff589201001300c81102600000
ffffffff0c92c0006800c82840600000
ffffffff589201001300c81102600000
ffffffff0c92c0006800c82840600000
-
{e=>7,n=>5,a=>26,m=>3,d=>1,j=>'SEM3',l=>5,c=>-1,k=>-127,h=>0,b=>4,g=>2,f=>'UE1',o=>99,i=>-3}
1a0000007c1e01006801811d05630000
1a0000007c1e01006801811d05630000
1a0000007c1e01006801811d05630000
0000001a9cf28000168081aca0630000
1a0000007c1e01006801811d05630000
1a0000007c1e01006801811d05630000
0000001a9cf28000168081aca0630000
1a0000007c1e01006801811d05630000
0000001a9cf28000168081aca0630000
-
{e=>1,n=>3,a=>-55,m=>0,d=>0,j=>'SEM1',l=>2,c=>1,k=>-1,h=>1,b=>3,g=>3,f=>'UE2',o=>164,i=>-4}
c9ffffff0ba20100e101ff0203a40000
c9ffffff0ba20100e101ff0203a40000
c9ffffff0ba20100e101ff0203a40000
ffffffc96414c0003380ff4060a40000
c9ffffff0ba20100e101ff0203a40000
c9ffffff0ba20100e101ff0203a40000
ffffffc96414c0003380ff4060a40000
c9ffffff0ba20100e101ff0203a40000
ffffffc96414c0003380ff4060a40000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
};
-
{a=>30,b=>3}
1e00000003000000
1e000000000000000300000000000000
1e000000000000000300000000000000
0000001e60000000
1e00000003000000
1e00000003000000
000000000000001e6000000000000000
1e00000003000000
0000001e60000000
-
{a=>-14,b=>4}
f2ffffff04000000
f2ffffffffffffff0400000000000000
f2ffffffffffffff0400000000000000
fffffff280000000
f2ffffff04000000
f2ffffff04000000
fffffffffffffff28000000000000000
f2ffffff04000000
fffffff280000000
-
{a=>3,b=>2}
0300000002000000
03000000000000000200000000000000
03000000000000000200000000000000
0000000340000000
0300000002000000
0300000002000000
00000000000000034000000000000000
0300000002000000
0000000340000000
-
{a=>98,b=>5}
6200000005000000
62000000000000000500000000000000
62000000000000000500000000000000
00000062a0000000
6200000005000000
6200000005000000
0000000000000062a000000000000000
6200000005000000
00000062a0000000
-
{a=>85,b=>3}
5500000003000000
55000000000000000300000000000000
55000000000000000300000000000000
0000005560000000
5500000003000000
5500000003000000
00000000000000556000000000000000
5500000003000000
0000005560000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>-1,a=>-46,b=>6}
d2ffffff3e000000
d2ffffffffffffff3e00000000000000
d2ffffffffffffff3e00000000000000
ffffffd2dc000000
d2ffffff3e000000
d2ffffff3e000000
ffffffffffffffd2dc00000000000000
d2ffffff3e000000
ffffffd2dc000000
-
{c=>2,a=>-36,b=>5}
dcffffff15000000
dcffffffffffffff1500000000000000
dcffffffffffffff1500000000000000
ffffffdca8000000
dcffffff15000000
dcffffff15000000
ffffffffffffffdca800000000000000
dcffffff15000000
ffffffdca8000000
-
{c=>-4,a=>78,b=>7}
4e00000027000000
4e000000000000002700000000000000
4e000000000000002700000000000000
0000004ef0000000
4e00000027000000
4e00000027000000
000000000000004ef000000000000000
4e00000027000000
0000004ef0000000
-
{c=>-4,a=>65,b=>5}
4100000025000000
41000000000000002500000000000000
41000000000000002500000000000000
00000041b0000000
4100000025000000
4100000025000000
0000000000000041b000000000000000
4100000025000000
00000041b0000000
-
{c=>-1,a=>124,b=>3}
7c0000003b000000
7c000000000000003b00000000000000
7c000000000000003b00000000000000
0000007c7c000000
7c0000003b000000
7c0000003b000000
000000000000007c7c00000000000000
7c0000003b000000
0000007c7c000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>0,a=>45,b=>2,d=>1}
2d00000042000000
2d000000000000004200000000000000
2d000000000000004200000000000000
0000002d40800000
2d00000042000000
2d00000042000000
000000000000002d4080000000000000
2d00000042000000
0000002d40800000
-
{c=>0,a=>-85,b=>5,d=>0}
abffffff05000000
abffffffffffffff0500000000000000
abffffffffffffff0500000000000000
ffffffaba0000000
abffffff05000000
abffffff05000000
ffffffffffffffaba000000000000000
abffffff05000000
ffffffaba0000000
-
{c=>-3,a=>62,b=>0,d=>0}
3e00000028000000
3e000000000000002800000000000000
3e000000000000002800000000000000
0000003e14000000
3e00000028000000
3e00000028000000
000000000000003e1400000000000000
3e00000028000000
0000003e14000000
-
{c=>3,a=>52,b=>1,d=>1}
3400000059000000
34000000000000005900000000000000
34000000000000005900000000000000
000000342c800000
3400000059000000
3400000059000000
00000000000000342c80000000000000
3400000059000000
000000342c800000
-
{c=>-2,a=>17,b=>6,d=>-4}
1100000036010000
11000000000000003601000000000000
11000000000000003601000000000000
00000011da000000
1100000036010000
1100000036010000
0000000000000011da00000000000000
1100000036010000
00000011da000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>4,c=>-1,a=>-49,b=>1,d=>-4}
cfffffff39090000
cfffffffffffffff3909000000000000
cfffffffffffffff3909000000000000
ffffffcf3e400000
cfffffff39090000
cfffffff39090000
ffffffffffffffcf3e40000000000000
cfffffff39090000
ffffffcf3e400000
-
{e=>5,c=>0,a=>127,b=>4,d=>0}
7f000000040a0000
7f00000000000000040a000000000000
7f00000000000000040a000000000000
0000007f80500000
7f000000040a0000
7f000000040a0000
000000000000007f8050000000000000
7f000000040a0000
0000007f80500000
-
{e=>3,c=>0,a=>28,b=>0,d=>3}
1c000000c0060000
1c00000000000000c006000000000000
1c00000000000000c006000000000000
0000001c01b00000
1c000000c0060000
1c000000c0060000
000000000000001c01b0000000000000
1c000000c0060000
0000001c01b00000
-
{e=>3,c=>2,a=>42,b=>3,d=>-4}
2a00000013070000
2a000000000000001307000000000000
2a000000000000001307000000000000
0000002a6a300000
2a00000013070000
2a00000013070000
000000000000002a6a30000000000000
2a00000013070000
0000002a6a300000
-
{e=>1,c=>3,a=>-60,b=>0,d=>-2}
c4ffffff98030000
c4ffffffffffffff9803000000000000
c4ffffffffffffff9803000000000000
ffffffc40f100000
c4ffffff98030000
c4ffffff98030000
ffffffffffffffc40f10000000000000
c4ffffff98030000
ffffffc40f100000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
};
-
{e=>7,c=>3,a=>-108,b=>1,d=>-1,f=>'UE1'}
94ffffffd91f0000
94ffffffffffffffd91f000000000000
94ffffffffffffffd91f000000000000
ffffff942ff20000
94ffffffd91f0000
94ffffffd91f0000
ffffffffffffff942ff2000000000000
94ffffffd91f0000
ffffff942ff20000
-
{e=>6,c=>-2,a=>4,b=>1,d=>-4,f=>'UE2'}
04000000312d0000
0400000000000000312d000000000000
0400000000000000312d000000000000
000000043a640000
04000000312d0000
04000000312d0000
00000000000000043a64000000000000
04000000312d0000
000000043a640000
-
{e=>3,c=>-3,a=>79,b=>0,d=>-4,f=>'UE0'}
4f00000028070000
4f000000000000002807000000000000
4f000000000000002807000000000000
0000004f16300000
4f00000028070000
4f00000028070000
000000000000004f1630000000000000
4f00000028070000
0000004f16300000
-
{e=>2,c=>-2,a=>45,b=>0,d=>3,f=>'UE5'}
2d000000f0540000
2d00000000000000f054000000000000
2d00000000000000f054000000000000
0000002d19aa0000
2d000000f0540000
2d000000f0540000
000000000000002d19aa000000000000
2d000000f0540000
0000002d19aa0000
-
{e=>4,c=>-1,a=>18,b=>7,d=>-1,f=>'UE2'}
12000000ff290000
1200000000000000ff29000000000000
1200000000000000ff29000000000000
00000012ffc40000
12000000ff290000
12000000ff290000
0000000000000012ffc4000000000000
12000000ff290000
00000012ffc40000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
};
-
{e=>5,c=>-1,a=>107,g=>7,b=>1,d=>-2,f=>'UE5'}
6b000000b9db0300
6b00000000000000b9db030000000000
6b00000000000000b9db030000000000
0000006b3f5bc000
6b000000b9db0300
6b000000b9db0300
000000000000006b3f5bc00000000000
6b000000b9db0300
0000006b3f5bc000
-
{e=>0,c=>-1,a=>-57,g=>6,b=>7,d=>-4,f=>'UE2'}
c7ffffff3f210300
c7ffffffffffffff3f21030000000000
c7ffffffffffffff3f21030000000000
ffffffc7fe058000
c7ffffff3f210300
c7ffffff3f210300
ffffffffffffffc7fe05800000000000
c7ffffff3f210300
ffffffc7fe058000
-
{e=>1,c=>2,a=>9,g=>5,b=>7,d=>2,f=>'UE7'}
0900000097f20200
090000000000000097f2020000000000
090000000000000097f2020000000000
00000009e91f4000
0900000097f20200
0900000097f20200
0000000000000009e91f400000000000
0900000097f20200
00000009e91f4000
-
{e=>3,c=>3,a=>-7,g=>4,b=>4,d=>2,f=>'UE5'}
f9ffffff9c560200
f9ffffffffffffff9c56020000000000
f9ffffffffffffff9c56020000000000
fffffff98d3b0000
f9ffffff9c560200
f9ffffff9c560200
fffffffffffffff98d3b000000000000
f9ffffff9c560200
fffffff98d3b0000
-
{e=>7,c=>1,a=>-15,g=>6,b=>2,d=>2,f=>'UE0'}
f1ffffff8a0e0300
f1ffffffffffffff8a0e030000000000
f1ffffffffffffff8a0e030000000000
fffffff145718000
f1ffffff8a0e0300
f1ffffff8a0e0300
fffffffffffffff14571800000000000
f1ffffff8a0e0300
fffffff145718000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>1,c=>-1,a=>-17,g=>2,b=>3,d=>-2,f=>'UE0'}
efffffffbb030100
efffffffffffffffbb03010000000000
efffffffffffffffbb03010000000000
ffffffef7f108000
efffffffbb030100
efffffffbb030100
ffffffffffffffef7f10800000000000
efffffffbb030100
ffffffef7f108000
-
{e=>7,c=>-2,a=>6,g=>1,b=>0,d=>-3,f=>'UE6'}
0600000070ef0000
060000000000000070ef000000000000
060000000000000070ef000000000000
000000061afc4000
0600000070ef0000
0600000070ef0000
00000000000000061afc400000000000
0600000070ef0000
000000061afc4000
-
{e=>2,c=>3,a=>64,g=>4,b=>2,d=>2,f=>'UE1'}
400000009a140200
40000000000000009a14020000000000
40000000000000009a14020000000000
000000404d230000
400000009a140200
400000009a140200
00000000000000404d23000000000000
400000009a140200
000000404d230000
-
{e=>2,c=>1,a=>58,g=>6,b=>1,d=>1,f=>'UE5'}
3a00000049540300
3a000000000000004954030000000000
3a000000000000004954030000000000
0000003a24ab8000
3a00000049540300
3a00000049540300
000000000000003a24ab800000000000
3a00000049540300
0000003a24ab8000
-
{e=>0,c=>1,a=>-124,g=>4,b=>2,d=>-1,f=>'UE4'}
84ffffffca410200
84ffffffffffffffca41020000000000
84ffffffffffffffca41020000000000
ffffff8447890000
84ffffffca410200
84ffffffca410200
ffffffffffffff844789000000000000
84ffffffca410200
ffffff8447890000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>5,a=>5,d=>1,c=>-3,h=>0,b=>1,g=>2,f=>'UE1'}
05000000691a010000000000
0500000000000000691a010000000000
0500000000000000691a010000000000
0000000534d2800000000000
05000000691a010000000000
05000000691a010000000000
000000000000000534d2800000000000
05000000691a010000000000
0000000534d2800000000000
-
{e=>2,a=>-102,d=>-2,c=>-2,h=>5,b=>0,g=>1,f=>'UE6'}
9affffffb0e5000005000000
9affffffffffffffb0e5000005000000
9affffffffffffffb0e5000005000000
ffffff9a1b2c4000a0000000
9affffffb0e5000005000000
9affffffb0e5000005000000
ffffffffffffff9a1b2c4000a0000000
9affffffb0e5000005000000
ffffff9a1b2c4000a0000000
-
{e=>5,a=>65,d=>-4,c=>0,h=>7,b=>3,g=>2,f=>'UE7'}
41000000037b010007000000
4100000000000000037b010007000000
4100000000000000037b010007000000
00000041625e8000e0000000
41000000037b010007000000
41000000037b010007000000
0000000000000041625e8000e0000000
41000000037b010007000000
00000041625e8000e0000000
-
{e=>2,a=>-87,d=>3,c=>-1,h=>1,b=>7,g=>2,f=>'UE6'}
a9ffffffff64010001000000
a9ffffffffffffffff64010001000000
a9ffffffffffffffff64010001000000
ffffffa9fdac800020000000
a9ffffffff64010001000000
a9ffffffff64010001000000
ffffffffffffffa9fdac800020000000
a9ffffffff64010001000000
ffffffa9fdac800020000000
-
{e=>5,a=>-29,d=>2,c=>-4,h=>3,b=>6,g=>7,f=>'UE3'}
e3ffffffa6ba030003000000
e3ffffffffffffffa6ba030003000000
e3ffffffffffffffa6ba030003000000
ffffffe3d157c00060000000
e3ffffffa6ba030003000000
e3ffffffa6ba030003000000
ffffffffffffffe3d157c00060000000
e3ffffffa6ba030003000000
ffffffe3d157c00060000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>1,a=>-52,d=>-3,c=>2,h=>1,b=>4,g=>2,f=>'UE6',i=>3}
ccffffff5463010019000000
ccffffffffffffff5463010019000000
ccffffffffffffff5463010019000000
ffffffcc8a9c80002c000000
ccffffff5463010019000000
ccffffff5463010019000000
ffffffffffffffcc8a9c80002c000000
ccffffff5463010019000000
ffffffcc8a9c80002c000000
-
{e=>6,a=>-55,d=>-2,c=>2,h=>7,b=>1,g=>4,f=>'UE2',i=>-2}
c9ffffff912d020037000000
c9ffffffffffffff912d020037000000
c9ffffffffffffff912d020037000000
ffffffc92b650000f8000000
c9ffffff912d020037000000
c9ffffff912d020037000000
ffffffffffffffc92b650000f8000000
c9ffffff912d020037000000
ffffffc92b650000f8000000
-
{e=>3,a=>1,d=>-4,c=>3,h=>2,b=>6,g=>2,f=>'UE1',i=>0}
010000001e17010002000000
01000000000000001e17010002000000
01000000000000001e17010002000000
00000001ce32800040000000
010000001e17010002000000
010000001e17010002000000
0000000000000001ce32800040000000
010000001e17010002000000
00000001ce32800040000000
-
{e=>7,a=>92,d=>1,c=>0,h=>3,b=>6,g=>4,f=>'UE3',i=>3}
5c000000463e02001b000000
5c00000000000000463e02001b000000
5c00000000000000463e02001b000000
0000005cc0f700006c000000
5c000000463e02001b000000
5c000000463e02001b000000
000000000000005cc0f700006c000000
5c000000463e02001b000000
0000005cc0f700006c000000
-
{e=>4,a=>83,d=>-3,c=>-2,h=>6,b=>1,g=>6,f=>'UE5',i=>-3}
53000000715903002e000000
5300000000000000715903002e000000
5300000000000000715903002e000000
000000533acb8000d4000000
53000000715903002e000000
53000000715903002e000000
00000000000000533acb8000d4000000
53000000715903002e000000
000000533acb8000d4000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
};
-
{e=>2,a=>104,d=>1,j=>'SEM2',c=>-3,h=>4,b=>3,g=>5,f=>'UE4',i=>3}
680000006bc402009c010000
68000000000000006bc402009c010000
68000000000000006bc402009c010000
0000006874a940008f000000
680000006bc402009c010000
680000006bc402009c010000
000000000000006874a940008f000000
680000006bc402009c010000
0000006874a940008f000000
-
{e=>5,a=>72,d=>-3,j=>'SE0',c=>2,h=>6,b=>2,g=>5,f=>'UE0',i=>0}
48000000528b020006000000
4800000000000000528b020006000000
4800000000000000528b020006000000
000000484ad14000c0000000
48000000528b020006000000
48000000528b020006000000
00000000000000484ad14000c0000000
48000000528b020006000000
000000484ad14000c0000000
-
{e=>4,a=>-114,d=>2,j=>'SE0',c=>-4,h=>4,b=>5,g=>7,f=>'UE7',i=>3}
8effffffa5f803001c000000
8effffffffffffffa5f803001c000000
8effffffffffffffa5f803001c000000
ffffff8eb14fc0008c000000
8effffffa5f803001c000000
8effffffa5f803001c000000
ffffffffffffff8eb14fc0008c000000
8effffffa5f803001c000000
ffffff8eb14fc0008c000000
-
{e=>5,a=>-114,d=>3,j=>'SE1',c=>2,h=>2,b=>5,g=>2,f=>'UE1',i=>-2}
8effffffd51a010072000000
8effffffffffffffd51a010072000000
8effffffffffffffd51a010072000000
ffffff8ea9d2800058800000
8effffffd51a010072000000
8effffffd51a010072000000
ffffffffffffff8ea9d2800058800000
8effffffd51a010072000000
ffffff8ea9d2800058800000
-
{e=>7,a=>-75,d=>1,j=>'SEM3',c=>-3,h=>1,b=>7,g=>1,f=>'UE2',i=>0}
b5ffffff6fae000041010000
b5ffffffffffffff6fae000041010000
b5ffffffffffffff6fae000041010000
ffffffb5f4f4400022800000
b5ffffff6fae000041010000
b5ffffff6fae000041010000
ffffffffffffffb5f4f4400022800000
b5ffffff6fae000041010000
ffffffb5f4f4400022800000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
};
-
{e=>2,a=>48,d=>-2,j=>'SE3',c=>3,k=>43,h=>4,b=>2,g=>2,f=>'UE5',i=>0}
300000009a550100c4002b00
30000000000000009a550100c4002b00
30000000000000009a550100c4002b00
000000304f2a800081802b00
300000009a550100c4002b00
300000009a550100c4002b00
00000000000000304f2a800081802b00
300000009a550100c4002b00
000000304f2a800081802b00
-
{e=>6,a=>-50,d=>0,j=>'SE0',c=>-1,k=>78,h=>6,b=>5,g=>5,f=>'UE6',i=>-3}
ceffffff3dec02002e004e00
ceffffffffffffff3dec02002e004e00
ceffffffffffffff3dec02002e004e00
ffffffcebc6d4000d4004e00
ceffffff3dec02002e004e00
ceffffff3dec02002e004e00
ffffffffffffffcebc6d4000d4004e00
ceffffff3dec02002e004e00
ffffffcebc6d4000d4004e00
-
{e=>4,a=>67,d=>0,j=>'SEM2',c=>3,k=>-96,h=>7,b=>3,g=>1,f=>'UE3',i=>2}
430000001bb800009701a000
43000000000000001bb800009701a000
43000000000000001bb800009701a000
000000436c464000eb00a000
430000001bb800009701a000
430000001bb800009701a000
00000000000000436c464000eb00a000
430000001bb800009701a000
000000436c464000eb00a000
-
{e=>5,a=>-6,d=>1,j=>'SE2',c=>0,k=>69,h=>4,b=>5,g=>0,f=>'UE0',i=>-4}
faffffff450a0000a4004500
faffffffffffffff450a0000a4004500
faffffffffffffff450a0000a4004500
fffffffaa0d0000091004500
faffffff450a0000a4004500
faffffff450a0000a4004500
fffffffffffffffaa0d0000091004500
faffffff450a0000a4004500
fffffffaa0d0000091004500
-
{e=>7,a=>-120,d=>1,j=>'SE0',c=>-1,k=>92,h=>1,b=>5,g=>5,f=>'UE3',i=>2}
88ffffff7dbe020011005c00
88ffffffffffffff7dbe020011005c00
88ffffffffffffff7dbe020011005c00
ffffff88bcf7400028005c00
88ffffff7dbe020011005c00
88ffffff7dbe020011005c00
ffffffffffffff88bcf7400028005c00
88ffffff7dbe020011005c00
ffffff88bcf7400028005c00
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>3,a=>-102,d=>-2,j=>'SEM4',l=>7,c=>-3,k=>-44,h=>3,b=>3,g=>7,f=>'UE6',i=>0}
9affffffabe703000301d407
9affffffffffffffabe703000301d407
9affffffffffffffabe703000301d407
ffffff9a773dc0006200d4e0
9affffffabe703000301d407
9affffffabe703000301d407
ffffffffffffff9a773dc0006200d4e0
9affffffabe703000301d407
ffffff9a773dc0006200d4e0
-
{e=>6,a=>15,d=>1,j=>'SE1',l=>1,c=>2,k=>-19,h=>5,b=>7,g=>1,f=>'UE6',i=>-2}
0f00000057ec00007500ed01
0f0000000000000057ec00007500ed01
0f0000000000000057ec00007500ed01
0000000fe8ec4000b880ed20
0f00000057ec00007500ed01
0f00000057ec00007500ed01
000000000000000fe8ec4000b880ed20
0f00000057ec00007500ed01
0000000fe8ec4000b880ed20
-
{e=>2,a=>-49,d=>-1,j=>'SEM3',l=>3,c=>-2,k=>75,h=>0,b=>4,g=>7,f=>'UE3',i=>-3}
cffffffff4b5030068014b03
cffffffffffffffff4b5030068014b03
cffffffffffffffff4b5030068014b03
ffffffcf9ba7c00016804b60
cffffffff4b5030068014b03
cffffffff4b5030068014b03
ffffffffffffffcf9ba7c00016804b60
cffffffff4b5030068014b03
ffffffcf9ba7c00016804b60
-
{e=>6,a=>-49,d=>1,j=>'SEM2',l=>3,c=>3,k=>-128,h=>7,b=>5,g=>0,f=>'UE1',i=>2}
cfffffff5d1c000097018003
cfffffffffffffff5d1c000097018003
cfffffffffffffff5d1c000097018003
ffffffcface20000eb008060
cfffffff5d1c000097018003
cfffffff5d1c000097018003
ffffffffffffffcface20000eb008060
cfffffff5d1c000097018003
ffffffcface20000eb008060
-
{e=>3,a=>-61,d=>0,j=>'SEM1',l=>1,c=>1,k=>6,h=>0,b=>1,g=>3,f=>'UE0',i=>-2}
c3ffffff09860100f0010601
c3ffffffffffffff09860100f0010601
c3ffffffffffffff09860100f0010601
ffffffc32430c0001b800620
c3ffffff09860100f0010601
c3ffffff09860100f0010601
ffffffffffffffc32430c0001b800620
c3ffffff09860100f0010601
ffffffc32430c0001b800620
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>1,a=>101,m=>1,d=>3,j=>'SEM4',l=>0,c=>3,k=>115,h=>2,b=>1,g=>3,f=>'UE0',i=>-3}
65000000d98201002a017308
6500000000000000d98201002a017308
6500000000000000d98201002a017308
000000652d90c00056007304
65000000d98201002a017308
65000000d98201002a017308
00000000000000652d90c00056007304
65000000d98201002a017308
000000652d90c00056007304
-
{e=>4,a=>-15,m=>1,d=>-3,j=>'SE2',l=>6,c=>-3,k=>-105,h=>6,b=>3,g=>5,f=>'UE5',i=>1}
f1ffffff6bd902008e00970e
f1ffffffffffffff6bd902008e00970e
f1ffffffffffffff6bd902008e00970e
fffffff176cb4000c50097c4
f1ffffff6bd902008e00970e
f1ffffff6bd902008e00970e
fffffffffffffff176cb4000c50097c4
f1ffffff6bd902008e00970e
fffffff176cb4000c50097c4
-
{e=>3,a=>111,m=>-1,d=>1,j=>'SE0',l=>6,c=>-1,k=>-84,h=>3,b=>4,g=>0,f=>'UE4',i=>-1}
6f0000007c4600003b00ac3e
6f000000000000007c4600003b00ac3e
6f000000000000007c4600003b00ac3e
0000006f9cb800007c00acdc
6f0000007c4600003b00ac3e
6f0000007c4600003b00ac3e
000000000000006f9cb800007c00acdc
6f0000007c4600003b00ac3e
0000006f9cb800007c00acdc
-
{e=>7,a=>-11,m=>3,d=>-4,j=>'SEM1',l=>3,c=>0,k=>-99,h=>0,b=>4,g=>4,f=>'UE4',i=>-3}
f5ffffff044f0200e8019d1b
f5ffffffffffffff044f0200e8019d1b
f5ffffffffffffff044f0200e8019d1b
fffffff58279000017809d6c
f5ffffff044f0200e8019d1b
f5ffffff044f0200e8019d1b
fffffffffffffff58279000017809d6c
f5ffffff044f0200e8019d1b
fffffff58279000017809d6c
-
{e=>4,a=>-69,m=>-3,d=>-2,j=>'SEM3',l=>2,c=>0,k=>94,h=>2,b=>4,g=>3,f=>'UE3',i=>2}
bbffffff84b9010052015e2a
bbffffffffffffff84b9010052015e2a
bbffffffffffffff84b9010052015e2a
ffffffbb8346c0004a805e54
bbffffff84b9010052015e2a
bbffffff84b9010052015e2a
ffffffffffffffbb8346c0004a805e54
bbffffff84b9010052015e2a
ffffffbb8346c0004a805e54
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>5,n=>4,a=>-5,m=>-1,d=>-3,j=>'SE0',l=>4,c=>-3,k=>70,h=>7,b=>6,g=>4,f=>'UE5',i=>-3}
fbffffff6e5b02002f00463c04000000
fbffffffffffffff6e5b02002f00463c0400000000000000
fbffffffffffffff6e5b02002f00463c0400000000000000
fffffffbd6db0000f400469c80000000
fbffffff6e5b02002f00463c04000000
fbffffff6e5b02002f00463c04000000
fffffffffffffffbd6db0000f400469c8000000000000000
fbffffff6e5b02002f00463c04000000
fffffffbd6db0000f400469c80000000
-
{e=>7,n=>6,a=>108,m=>-3,d=>1,j=>'SEM3',l=>5,c=>-3,k=>-4,h=>3,b=>0,g=>6,f=>'UE6',i=>-2}
6c000000686e03007301fc2d06000000
6c00000000000000686e03007301fc2d0600000000000000
6c00000000000000686e03007301fc2d0600000000000000
0000006c14fd80007a80fcb4c0000000
6c000000686e03007301fc2d06000000
6c000000686e03007301fc2d06000000
000000000000006c14fd80007a80fcb4c000000000000000
6c000000686e03007301fc2d06000000
0000006c14fd80007a80fcb4c0000000
-
{e=>3,n=>7,a=>-39,m=>-2,d=>3,j=>'SEM2',l=>2,c=>-4,k=>59,h=>1,b=>0,g=>7,f=>'UE5',i=>-4}
d9ffffffe0d60300a1013b3207000000
d9ffffffffffffffe0d60300a1013b320700000000000000
d9ffffffffffffffe0d60300a1013b320700000000000000
ffffffd911bbc00033003b58e0000000
d9ffffffe0d60300a1013b3207000000
d9ffffffe0d60300a1013b3207000000
ffffffffffffffd911bbc00033003b58e000000000000000
d9ffffffe0d60300a1013b3207000000
ffffffd911bbc00033003b58e0000000
-
{e=>2,n=>0,a=>-64,m=>1,d=>1,j=>'SE1',l=>0,c=>2,k=>123,h=>0,b=>7,g=>7,f=>'UE7',i=>1}
c0ffffff57f4030048007b0800000000
c0ffffffffffffff57f4030048007b080000000000000000
c0ffffffffffffff57f4030048007b080000000000000000
ffffffc0e8afc00004807b0400000000
c0ffffff57f4030048007b0800000000
c0ffffff57f4030048007b0800000000
ffffffffffffffc0e8afc00004807b040000000000000000
c0ffffff57f4030048007b0800000000
ffffffc0e8afc00004807b0400000000
-
{e=>5,n=>7,a=>-49,m=>-2,d=>-3,j=>'SE2',l=>0,c=>0,k=>95,h=>1,b=>5,g=>6,f=>'UE1',i=>-1}
cfffffff451b0300b9005f3007000000
cfffffffffffffff451b0300b9005f300700000000000000
cfffffffffffffff451b0300b9005f300700000000000000
ffffffcfa2d380003d005f18e0000000
cfffffff451b0300b9005f3007000000
cfffffff451b0300b9005f3007000000
ffffffffffffffcfa2d380003d005f18e000000000000000
cfffffff451b0300b9005f3007000000
ffffffcfa2d380003d005f18e0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct enum_pack_1 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>6,n=>7,a=>-65,m=>-2,d=>-3,j=>'SEM3',l=>0,c=>0,k=>67,h=>5,b=>3,g=>6,f=>'UE7',o=>184,i=>3}
bfffffff437d03005d01433007b80000
bfffffffffffffff437d03005d01433007b8000000000000
bfffffffffffffff437d03005d01433007b8000000000000
ffffffbf62ef8000ae804318e0b80000
bfffffff437d03005d01433007b80000
bfffffff437d03005d01433007b80000
ffffffffffffffbf62ef8000ae804318e0b8000000000000
bfffffff437d03005d01433007b80000
ffffffbf62ef8000ae804318e0b80000
-
{e=>5,n=>0,a=>80,m=>-2,d=>0,j=>'SEM2',l=>4,c=>-3,k=>18,h=>7,b=>4,g=>5,f=>'UE5',o=>3,i=>1}
500000002cda02008f01123400030000
50000000000000002cda02008f0112340003000000000000
50000000000000002cda02008f0112340003000000000000
00000050945b4000e700129800030000
500000002cda02008f01123400030000
500000002cda02008f01123400030000
0000000000000050945b4000e70012980003000000000000
500000002cda02008f01123400030000
00000050945b4000e700129800030000
-
{e=>5,n=>0,a=>89,m=>-1,d=>-4,j=>'SEM4',l=>6,c=>2,k=>-48,h=>0,b=>2,g=>2,f=>'UE7',o=>146,i=>2}
59000000127b01001001d03e00920000
5900000000000000127b01001001d03e0092000000000000
5900000000000000127b01001001d03e0092000000000000
000000594a5e80000a00d0dc00920000
59000000127b01001001d03e00920000
59000000127b01001001d03e00920000
00000000000000594a5e80000a00d0dc0092000000000000
59000000127b01001001d03e00920000
000000594a5e80000a00d0dc00920000
-
{e=>5,n=>6,a=>-3,m=>-1,d=>0,j=>'SE1',l=>1,c=>0,k=>72,h=>1,b=>3,g=>4,f=>'UE2',o=>92,i=>2}
fdffffff032a020051004839065c0000
fdffffffffffffff032a020051004839065c000000000000
fdffffffffffffff032a020051004839065c000000000000
fffffffd605500002880483cc05c0000
fdffffff032a020051004839065c0000
fdffffff032a020051004839065c0000
fffffffffffffffd605500002880483cc05c000000000000
fdffffff032a020051004839065c0000
fffffffd605500002880483cc05c0000
-
{e=>3,n=>5,a=>-96,m=>-4,d=>3,j=>'SE1',l=>5,c=>-4,k=>-39,h=>0,b=>3,g=>3,f=>'UE4',o=>240,i=>-2}
a0ffffffe3c601007000d92505f00000
a0ffffffffffffffe3c601007000d92505f0000000000000
a0ffffffffffffffe3c601007000d92505f0000000000000
ffffffa071b8c0001880d9b0a0f00000
a0ffffffe3c601007000d92505f00000
a0ffffffe3c601007000d92505f00000
ffffffffffffffa071b8c0001880d9b0a0f0000000000000
a0ffffffe3c601007000d92505f00000
ffffffa071b8c0001880d9b0a0f00000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
};
-
{a=>3}
03000000
03000000
03000000
60000000
03000000
03000000
60000000
03000000
60000000
-
{a=>4}
04000000
04000000
04000000
80000000
04000000
04000000
80000000
04000000
80000000
-
{a=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
-
{a=>2}
02000000
02000000
02000000
40000000
02000000
02000000
40000000
02000000
40000000
-
{a=>0}
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
00000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
};
-
{a=>5,b=>2}
15000000
15000000
15000000
a8000000
15000000
15000000
a8000000
15000000
a8000000
-
{a=>6,b=>-2}
36000000
36000000
36000000
d8000000
36000000
36000000
d8000000
36000000
d8000000
-
{a=>6,b=>3}
1e000000
1e000000
1e000000
cc000000
1e000000
1e000000
cc000000
1e000000
cc000000
-
{a=>7,b=>3}
1f000000
1f000000
1f000000
ec000000
1f000000
1f000000
ec000000
1f000000
ec000000
-
{a=>1,b=>0}
01000000
01000000
01000000
20000000
01000000
01000000
20000000
01000000
20000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
};
-
{c=>-4,a=>2,b=>-1}
3a010000
3a010000
3a010000
5e000000
3a010000
3a010000
5e000000
3a010000
5e000000
-
{c=>2,a=>0,b=>2}
90000000
90000000
90000000
09000000
90000000
90000000
09000000
90000000
09000000
-
{c=>-3,a=>7,b=>-4}
67010000
67010000
67010000
f2800000
67010000
67010000
f2800000
67010000
f2800000
-
{c=>2,a=>3,b=>1}
8b000000
8b000000
8b000000
65000000
8b000000
8b000000
65000000
8b000000
65000000
-
{c=>-4,a=>0,b=>-3}
28010000
28010000
28010000
16000000
28010000
28010000
16000000
28010000
16000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
};
-
{c=>2,a=>4,b=>0,d=>3}
84060000
84060000
84060000
81300000
84060000
84060000
81300000
84060000
81300000
-
{c=>-4,a=>2,b=>2,d=>5}
120b0000
120b0000
120b0000
4a500000
120b0000
120b0000
4a500000
120b0000
4a500000
-
{c=>-3,a=>2,b=>-3,d=>7}
6a0f0000
6a0f0000
6a0f0000
56f00000
6a0f0000
6a0f0000
56f00000
6a0f0000
56f00000
-
{c=>1,a=>7,b=>-4,d=>1}
67020000
67020000
67020000
f0900000
67020000
67020000
f0900000
67020000
f0900000
-
{c=>-2,a=>2,b=>3,d=>3}
9a070000
9a070000
9a070000
4f300000
9a070000
9a070000
4f300000
9a070000
4f300000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
};
-
{e=>'UE6',c=>-4,a=>5,b=>-3,d=>1}
2d630000
2d630000
2d630000
b61c0000
2d630000
2d630000
b61c0000
2d630000
b61c0000
-
{e=>'UE5',c=>1,a=>6,b=>2,d=>4}
56580000
56580000
56580000
c8ca0000
56580000
56580000
c8ca0000
56580000
c8ca0000
-
{e=>'UE6',c=>-1,a=>0,b=>-4,d=>7}
e06f0000
e06f0000
e06f0000
13fc0000
e06f0000
e06f0000
13fc0000
e06f0000
13fc0000
-
{e=>'UE1',c=>-4,a=>4,b=>-3,d=>4}
2c190000
2c190000
2c190000
96420000
2c190000
2c190000
96420000
2c190000
96420000
-
{e=>'UE1',c=>-2,a=>2,b=>2,d=>4}
92190000
92190000
92190000
4b420000
92190000
92190000
4b420000
92190000
4b420000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
};
-
{e=>'UE1',c=>-4,a=>4,b=>-1,d=>3,f=>3}
3c970100
3c970100
3c970100
9e32c000
3c970100
3c970100
9e32c000
3c970100
9e32c000
-
{e=>'UE3',c=>-4,a=>2,b=>-3,d=>0,f=>0}
2a310000
2a310000
2a310000
56060000
2a310000
2a310000
56060000
2a310000
56060000
-
{e=>'UE0',c=>0,a=>3,b=>-3,d=>5,f=>0}
2b0a0000
2b0a0000
2b0a0000
74500000
2b0a0000
2b0a0000
74500000
2b0a0000
74500000
-
{e=>'UE7',c=>1,a=>3,b=>-3,d=>3,f=>4}
6b760200
6b760200
6b760200
74bf0000
6b760200
6b760200
74bf0000
6b760200
74bf0000
-
{e=>'UE7',c=>-2,a=>2,b=>3,d=>6,f=>5}
9afd0200
9afd0200
9afd0200
4f6f4000
9afd0200
9afd0200
4f6f4000
9afd0200
4f6f4000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
};
-
{e=>'UE4',c=>2,a=>1,b=>-4,d=>1,f=>3}
a1c20100
a1c20100
a1c20100
3118c000
a1c20100
a1c20100
3118c000
a1c20100
3118c000
-
{e=>'UE7',c=>0,a=>6,b=>-4,d=>2,f=>7}
26f40300
26f40300
26f40300
d02fc000
26f40300
26f40300
d02fc000
26f40300
d02fc000
-
{e=>'UE6',c=>3,a=>4,b=>-2,d=>5,f=>2}
f46a0100
f46a0100
f46a0100
99dc8000
f46a0100
f46a0100
99dc8000
f46a0100
99dc8000
-
{e=>'UE0',c=>-3,a=>5,b=>-2,d=>5,f=>3}
758b0100
758b0100
758b0100
bad0c000
758b0100
758b0100
bad0c000
758b0100
bad0c000
-
{e=>'UE1',c=>0,a=>6,b=>0,d=>3,f=>4}
06160200
06160200
06160200
c0330000
06160200
06160200
c0330000
06160200
c0330000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
};
-
{e=>'UE4',c=>-2,a=>3,g=>3,b=>-4,d=>7,f=>5}
a3cf020003000000
a3cf020003000000
a3cf020003000000
7379400060000000
a3cf020003000000
a3cf020003000000
7379400060000000
a3cf020003000000
7379400060000000
-
{e=>'UE2',c=>0,a=>1,g=>7,b=>0,d=>6,f=>2}
012c010007000000
012c010007000000
012c010007000000
20648000e0000000
012c010007000000
012c010007000000
20648000e0000000
012c010007000000
20648000e0000000
-
{e=>'UE2',c=>-1,a=>3,g=>7,b=>3,d=>4,f=>2}
db29010007000000
db29010007000000
db29010007000000
6fc48000e0000000
db29010007000000
db29010007000000
6fc48000e0000000
db29010007000000
6fc48000e0000000
-
{e=>'UE0',c=>-1,a=>4,g=>1,b=>2,d=>0,f=>0}
d401000001000000
d401000001000000
d401000001000000
8b80000020000000
d401000001000000
d401000001000000
8b80000020000000
d401000001000000
8b80000020000000
-
{e=>'UE1',c=>-2,a=>7,g=>4,b=>-2,d=>3,f=>6}
b717030004000000
b717030004000000
b717030004000000
fb33800080000000
b717030004000000
b717030004000000
fb33800080000000
b717030004000000
fb33800080000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
};
-
{e=>'UE4',a=>1,d=>4,c=>-4,h=>-1,b=>2,g=>3,f=>1}
11c900003b000000
11c900003b000000
11c900003b000000
2a4840007c000000
11c900003b000000
11c900003b000000
2a4840007c000000
11c900003b000000
2a4840007c000000
-
{e=>'UE3',a=>3,d=>3,c=>2,h=>1,b=>-3,g=>5,f=>2}
ab3601000d000000
ab3601000d000000
ab3601000d000000
75368000a4000000
ab3601000d000000
ab3601000d000000
75368000a4000000
ab3601000d000000
75368000a4000000
-
{e=>'UE2',a=>0,d=>4,c=>-3,h=>2,b=>1,g=>2,f=>7}
48a9030012000000
48a9030012000000
48a9030012000000
06c5c00048000000
48a9030012000000
48a9030012000000
06c5c00048000000
48a9030012000000
06c5c00048000000
-
{e=>'UE4',a=>2,d=>3,c=>0,h=>-1,b=>-1,g=>2,f=>4}
3a4602003a000000
3a4602003a000000
3a4602003a000000
5c3900005c000000
3a4602003a000000
3a4602003a000000
5c3900005c000000
3a4602003a000000
5c3900005c000000
-
{e=>'UE5',a=>5,d=>7,c=>0,h=>-1,b=>3,g=>1,f=>1}
1dde000039000000
1dde000039000000
1dde000039000000
ac7a40003c000000
1dde000039000000
1dde000039000000
ac7a40003c000000
1dde000039000000
ac7a40003c000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  enum en_s     i:3;
};
-
{e=>'UE4',a=>1,d=>7,c=>-3,h=>0,b=>-4,g=>4,f=>3,i=>'SEM2'}
61cf010084010000
61cf010084010000
61cf010084010000
32f8c00083000000
61cf010084010000
61cf010084010000
32f8c00083000000
61cf010084010000
32f8c00083000000
-
{e=>'UE0',a=>0,d=>3,c=>1,h=>0,b=>-3,g=>6,f=>6,i=>'SE3'}
68060300c6000000
68060300c6000000
68060300c6000000
14b18000c1800000
68060300c6000000
68060300c6000000
14b18000c1800000
68060300c6000000
14b18000c1800000
-
{e=>'UE5',a=>0,d=>1,c=>-2,h=>2,b=>0,g=>6,f=>0,i=>'SE3'}
80530000d6000000
80530000d6000000
80530000d6000000
031a0000c9800000
80530000d6000000
80530000d6000000
031a0000c9800000
80530000d6000000
031a0000c9800000
-
{e=>'UE7',a=>5,d=>4,c=>-3,h=>-1,b=>2,g=>5,f=>6,i=>'SE2'}
55790300bd000000
55790300bd000000
55790300bd000000
aacf8000bd000000
55790300bd000000
55790300bd000000
aacf8000bd000000
55790300bd000000
aacf8000bd000000
-
{e=>'UE4',a=>6,d=>1,c=>-1,h=>2,b=>-3,g=>5,f=>1,i=>'SEM4'}
eec3000015010000
eec3000015010000
eec3000015010000
d7984000aa000000
eec3000015010000
eec3000015010000
d7984000aa000000
eec3000015010000
d7984000aa000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  enum en_s     i:3;
  char          j;
};
-
{e=>'UE2',a=>3,d=>3,j=>79,c=>-1,h=>-3,b=>2,g=>4,f=>1,i=>'SE3'}
d3a70000ec004f00
d3a70000ec004f00
d3a70000ec004f00
6bb4400095804f00
d3a70000ec004f00
d3a70000ec004f00
6bb4400095804f00
d3a70000ec004f00
6bb4400095804f00
-
{e=>'UE3',a=>4,d=>5,j=>33,c=>-2,h=>-4,b=>-1,g=>7,f=>7,i=>'SEM3'}
bcbb030067012100
bcbb030067012100
bcbb030067012100
9f57c000f2802100
bcbb030067012100
bcbb030067012100
9f57c000f2802100
bcbb030067012100
9f57c000f2802100
-
{e=>'UE3',a=>2,d=>6,j=>127,c=>-1,h=>1,b=>0,g=>1,f=>5,i=>'SEM1'}
c2bd0200c9017f00
c2bd0200c9017f00
c2bd0200c9017f00
43e7400027807f00
c2bd0200c9017f00
c2bd0200c9017f00
43e7400027807f00
c2bd0200c9017f00
43e7400027807f00
-
{e=>'UE7',a=>4,d=>1,j=>84,c=>2,h=>-3,b=>3,g=>7,f=>0,i=>'SEM1'}
9c720000ef015400
9c720000ef015400
9c720000ef015400
8d1e0000f7805400
9c720000ef015400
9c720000ef015400
8d1e0000f7805400
9c720000ef015400
8d1e0000f7805400
-
{e=>'UE6',a=>1,d=>7,j=>37,c=>2,h=>-2,b=>0,g=>3,f=>5,i=>'SE3'}
81ee0200f3002500
81ee0200f3002500
81ee0200f3002500
217d400079802500
81ee0200f3002500
81ee0200f3002500
217d400079802500
81ee0200f3002500
217d400079802500
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  enum en_s     i:3;
  char          j;
  unsigned char k:3;
};
-
{e=>'UE0',a=>7,d=>4,j=>-44,c=>0,k=>0,h=>0,b=>2,g=>5,f=>1,i=>'SEM4'}
178800000501d400
178800000501d400
178800000501d400
e8404000a200d400
178800000501d400
178800000501d400
e8404000a200d400
178800000501d400
e8404000a200d400
-
{e=>'UE6',a=>0,d=>4,j=>-58,c=>2,k=>1,h=>1,b=>-2,g=>2,f=>3,i=>'SEM3'}
b0e801004a01c601
b0e801004a01c601
b0e801004a01c601
194cc0004680c620
b0e801004a01c601
b0e801004a01c601
194cc0004680c620
b0e801004a01c601
194cc0004680c620
-
{e=>'UE7',a=>0,d=>4,j=>-25,c=>-4,k=>2,h=>-4,b=>1,g=>6,f=>3,i=>'SEM1'}
08f90100e601e702
08f90100e601e702
08f90100e601e702
064ec000d380e740
08f90100e601e702
08f90100e601e702
064ec000d380e740
08f90100e601e702
064ec000d380e740
-
{e=>'UE0',a=>0,d=>5,j=>87,c=>2,k=>4,h=>1,b=>2,g=>5,f=>4,i=>'SEM2'}
900a02008d015704
900a02008d015704
900a02008d015704
09510000a7005780
900a02008d015704
900a02008d015704
09510000a7005780
900a02008d015704
09510000a7005780
-
{e=>'UE3',a=>6,d=>5,j=>-127,c=>0,k=>4,h=>2,b=>-3,g=>7,f=>6,i=>'SE0'}
2e3a030017008104
2e3a030017008104
2e3a030017008104
d4578000e8008180
2e3a030017008104
2e3a030017008104
d4578000e8008180
2e3a030017008104
d4578000e8008180
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  enum en_s     i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
};
-
{e=>'UE1',a=>5,d=>7,j=>116,l=>-1,c=>2,k=>3,h=>-4,b=>0,g=>0,f=>1,i=>'SE3'}
859e0000e000743b
859e0000e000743b
859e0000e000743b
a17240001180747c
859e0000e000743b
859e0000e000743b
a17240001180747c
859e0000e000743b
a17240001180747c
-
{e=>'UE0',a=>3,d=>5,j=>-63,l=>3,c=>-4,k=>7,h=>2,b=>0,g=>1,f=>1,i=>'SEM2'}
038b00009101c11f
038b00009101c11f
038b00009101c11f
625040002b00c1ec
038b00009101c11f
038b00009101c11f
625040002b00c1ec
038b00009101c11f
625040002b00c1ec
-
{e=>'UE1',a=>6,d=>3,j=>-79,l=>1,c=>2,k=>1,h=>-2,b=>-4,g=>5,f=>0,i=>'SE0'}
a61600003500b109
a61600003500b109
a61600003500b109
d1320000b800b124
a61600003500b109
a61600003500b109
d1320000b800b124
a61600003500b109
d1320000b800b124
-
{e=>'UE1',a=>4,d=>5,j=>7,l=>2,c=>-2,k=>4,h=>-4,b=>-2,g=>3,f=>7,i=>'SE1'}
b49b030063000714
b49b030063000714
b49b030063000714
9b53c00070800788
b49b030063000714
b49b030063000714
9b53c00070800788
b49b030063000714
9b53c00070800788
-
{e=>'UE2',a=>5,d=>0,j=>41,l=>-2,c=>-4,k=>4,h=>-1,b=>3,g=>5,f=>4,i=>'SEM2'}
1d210200bd012934
1d210200bd012934
1d210200bd012934
ae050000bf002998
1d210200bd012934
1d210200bd012934
ae050000bf002998
1d210200bd012934
ae050000bf002998
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  enum en_s     i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
  unsigned int  m:3;
};
-
{e=>'UE1',a=>1,m=>3,d=>5,j=>80,l=>-4,c=>-4,k=>7,h=>-2,b=>1,g=>5,f=>1,i=>'SEM4'}
099b00003501502703000000
099b00003501502703000000
099b00003501502703000000
26524000ba0050f060000000
099b00003501502703000000
099b00003501502703000000
26524000ba0050f060000000
099b00003501502703000000
26524000ba0050f060000000
-
{e=>'UE0',a=>3,m=>1,d=>7,j=>-49,l=>-4,c=>-3,k=>5,h=>0,b=>-1,g=>3,f=>5,i=>'SEM4'}
7b8f02000301cf2501000000
7b8f02000301cf2501000000
7b8f02000301cf2501000000
7ef140006200cfb020000000
7b8f02000301cf2501000000
7b8f02000301cf2501000000
7ef140006200cfb020000000
7b8f02000301cf2501000000
7ef140006200cfb020000000
-
{e=>'UE5',a=>3,m=>7,d=>7,j=>100,l=>-4,c=>1,k=>4,h=>0,b=>-3,g=>1,f=>7,i=>'SE3'}
6bde0300c100642407000000
6bde0300c100642407000000
6bde0300c100642407000000
74fbc00021806490e0000000
6bde0300c100642407000000
6bde0300c100642407000000
74fbc00021806490e0000000
6bde0300c100642407000000
74fbc00021806490e0000000
-
{e=>'UE5',a=>7,m=>2,d=>0,j=>-111,l=>1,c=>2,k=>6,h=>0,b=>0,g=>4,f=>7,i=>'SEM3'}
87d003004401910e02000000
87d003004401910e02000000
87d003004401910e02000000
e10bc000828091c440000000
87d003004401910e02000000
87d003004401910e02000000
e10bc000828091c440000000
87d003004401910e02000000
e10bc000828091c440000000
-
{e=>'UE1',a=>6,m=>1,d=>3,j=>78,l=>-2,c=>-2,k=>1,h=>-3,b=>3,g=>4,f=>5,i=>'SE0'}
9e9702002c004e3101000000
9e9702002c004e3101000000
9e9702002c004e3101000000
cf33400094004e3820000000
9e9702002c004e3101000000
9e9702002c004e3101000000
cf33400094004e3820000000
9e9702002c004e3101000000
cf33400094004e3820000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  unsigned int  a:3;
  signed   int  b:3;
  foo           c:3;
  unsigned char d:3;
  enum en_u     e:3;
  unsigned int  f:3;
  int            :0;
  unsigned char g:3;
  signed   char h:3;
  enum en_s     i:3;
  char          j;
  unsigned char k:3;
  signed   char l:3;
  unsigned int  m:3;
  unsigned char n;
};
-
{e=>'UE0',n=>164,a=>0,m=>3,d=>1,j=>-21,l=>-4,c=>2,k=>3,h=>-4,b=>1,g=>0,f=>5,i=>'SE2'}
88820200a000eb2303a40000
88820200a000eb2303a40000
88820200a000eb2303a40000
051140001100eb7060a40000
88820200a000eb2303a40000
88820200a000eb2303a40000
051140001100eb7060a40000
88820200a000eb2303a40000
051140001100eb7060a40000
-
{e=>'UE6',n=>235,a=>5,m=>3,d=>0,j=>122,l=>0,c=>-2,k=>5,h=>3,b=>-2,g=>6,f=>1,i=>'SEM3'}
b5e100005e017a0503eb0000
b5e100005e017a0503eb0000
b5e100005e017a0503eb0000
bb0c4000ce807aa060eb0000
b5e100005e017a0503eb0000
b5e100005e017a0503eb0000
bb0c4000ce807aa060eb0000
b5e100005e017a0503eb0000
bb0c4000ce807aa060eb0000
-
{e=>'UE2',n=>226,a=>5,m=>6,d=>1,j=>0,l=>0,c=>-4,k=>4,h=>3,b=>-2,g=>1,f=>5,i=>'SEM3'}
35a302005901000406e20000
35a302005901000406e20000
35a302005901000406e20000
ba1540002e800080c0e20000
35a302005901000406e20000
35a302005901000406e20000
ba1540002e800080c0e20000
35a302005901000406e20000
ba1540002e800080c0e20000
-
{e=>'UE4',n=>153,a=>0,m=>7,d=>6,j=>106,l=>-2,c=>1,k=>6,h=>2,b=>2,g=>2,f=>2,i=>'SE3'}
504c0100d2006a3607990000
504c0100d2006a3607990000
504c0100d2006a3607990000
08e8800049806ad8e0990000
504c0100d2006a3607990000
504c0100d2006a3607990000
08e8800049806ad8e0990000
504c0100d2006a3607990000
08e8800049806ad8e0990000
-
{e=>'UE5',n=>143,a=>3,m=>3,d=>4,j=>112,l=>3,c=>1,k=>5,h=>-4,b=>-1,g=>3,f=>7,i=>'SEM4'}
7bd803002301701d038f0000
7bd803002301701d038f0000
7bd803002301701d038f0000
7ccbc000720070ac608f0000
7bd803002301701d038f0000
7bd803002301701d038f0000
7ccbc000720070ac608f0000
7bd803002301701d038f0000
7ccbc000720070ac608f0000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
};
-
{a=>35,b=>4}
23040000
23040000
23040000
23800000
23040000
23040000
23800000
23040000
23800000
-
{a=>-103,b=>7}
99070000
99070000
99070000
99e00000
99070000
99070000
99e00000
99070000
99e00000
-
{a=>-90,b=>6}
a6060000
a6060000
a6060000
a6c00000
a6060000
a6060000
a6c00000
a6060000
a6c00000
-
{a=>-77,b=>1}
b3010000
b3010000
b3010000
b3200000
b3010000
b3010000
b3200000
b3010000
b3200000
-
{a=>73,b=>6}
49060000
49060000
49060000
49c00000
49060000
49060000
49c00000
49060000
49c00000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>-4,a=>8,b=>7}
08270000
08270000
08270000
08f00000
08270000
08270000
08f00000
08270000
08f00000
-
{c=>-4,a=>110,b=>2}
6e220000
6e220000
6e220000
6e500000
6e220000
6e220000
6e500000
6e220000
6e500000
-
{c=>0,a=>-68,b=>0}
bc000000
bc000000
bc000000
bc000000
bc000000
bc000000
bc000000
bc000000
bc000000
-
{c=>0,a=>7,b=>7}
07070000
07070000
07070000
07e00000
07070000
07070000
07e00000
07070000
07e00000
-
{c=>1,a=>-91,b=>5}
a50d0000
a50d0000
a50d0000
a5a40000
a50d0000
a50d0000
a5a40000
a50d0000
a5a40000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>-2,a=>-105,b=>7,d=>1}
97770000
97770000
97770000
97f88000
97770000
97770000
97f88000
97770000
97f88000
-
{c=>0,a=>68,b=>2,d=>-1}
44c20100
44c20100
44c20100
44438000
44c20100
44c20100
44438000
44c20100
44438000
-
{c=>3,a=>66,b=>2,d=>-4}
421a0100
421a0100
421a0100
424e0000
421a0100
421a0100
424e0000
421a0100
424e0000
-
{c=>-2,a=>-3,b=>5,d=>2}
fdb50000
fdb50000
fdb50000
fdb90000
fdb50000
fdb50000
fdb90000
fdb50000
fdb90000
-
{c=>2,a=>-69,b=>0,d=>2}
bb900000
bb900000
bb900000
bb090000
bb900000
bb900000
bb090000
bb900000
bb090000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>5,c=>-4,a=>-27,b=>0,d=>2}
e5a00a00
e5a00a00
e5a00a00
e5115000
e5a00a00
e5a00a00
e5115000
e5a00a00
e5115000
-
{e=>6,c=>-1,a=>67,b=>7,d=>-4}
433f0d00
433f0d00
433f0d00
43fe6000
433f0d00
433f0d00
43fe6000
433f0d00
43fe6000
-
{e=>5,c=>-3,a=>-14,b=>5,d=>0}
f22d0a00
f22d0a00
f22d0a00
f2b45000
f22d0a00
f22d0a00
f2b45000
f22d0a00
f2b45000
-
{e=>7,c=>-3,a=>-84,b=>6,d=>0}
ac2e0e00
ac2e0e00
ac2e0e00
acd47000
ac2e0e00
ac2e0e00
acd47000
ac2e0e00
acd47000
-
{e=>4,c=>-1,a=>49,b=>2,d=>-1}
31fa0900
31fa0900
31fa0900
315fc000
31fa0900
31fa0900
315fc000
31fa0900
315fc000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
};
-
{e=>1,c=>2,a=>83,b=>0,d=>1,f=>'UE5'}
53505200
53505200
53505200
53089a00
53505200
53505200
53089a00
53505200
53089a00
-
{e=>2,c=>-2,a=>-120,b=>2,d=>-3,f=>'UE1'}
88721500
88721500
88721500
885aa200
88721500
88721500
885aa200
88721500
885aa200
-
{e=>7,c=>2,a=>-63,b=>6,d=>-1,f=>'UE4'}
c1d64f00
c1d64f00
c1d64f00
c1cbf800
c1d64f00
c1d64f00
c1cbf800
c1d64f00
c1cbf800
-
{e=>3,c=>2,a=>-5,b=>1,d=>-1,f=>'UE3'}
fbd13700
fbd13700
fbd13700
fb2bb600
fbd13700
fbd13700
fb2bb600
fbd13700
fb2bb600
-
{e=>3,c=>-1,a=>107,b=>5,d=>-1,f=>'UE2'}
6bfd2700
6bfd2700
6bfd2700
6bbfb400
6bfd2700
6bfd2700
6bbfb400
6bfd2700
6bbfb400
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
};
-
{e=>3,c=>-2,a=>0,g=>4,b=>0,d=>2,f=>'UE6'}
00b06602
00b06602
00b06602
00193d00
00b06602
00b06602
00193d00
00b06602
00193d00
-
{e=>1,c=>1,a=>30,g=>6,b=>2,d=>-2,f=>'UE4'}
1e8a4303
1e8a4303
1e8a4303
1e471980
1e8a4303
1e8a4303
1e471980
1e8a4303
1e471980
-
{e=>6,c=>3,a=>4,g=>1,b=>4,d=>0,f=>'UE7'}
041cfc00
041cfc00
041cfc00
048c6e40
041cfc00
041cfc00
048c6e40
041cfc00
048c6e40
-
{e=>7,c=>-1,a=>-95,g=>6,b=>5,d=>1,f=>'UE6'}
a17d6e03
a17d6e03
a17d6e03
a1bcfd80
a17d6e03
a17d6e03
a1bcfd80
a17d6e03
a1bcfd80
-
{e=>7,c=>2,a=>-102,g=>2,b=>3,d=>2,f=>'UE3'}
9a933e01
9a933e01
9a933e01
9a697680
9a933e01
9a933e01
9a697680
9a933e01
9a697680
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>2,c=>-3,a=>17,g=>0,b=>7,d=>-4,f=>'UE0'}
112f0500
112f0500
112f0500
11f62000
112f0500
112f0500
11f62000
112f0500
11f62000
-
{e=>5,c=>1,a=>-35,g=>5,b=>3,d=>0,f=>'UE7'}
dd0bfa02
dd0bfa02
dd0bfa02
dd645f40
dd0bfa02
dd0bfa02
dd645f40
dd0bfa02
dd645f40
-
{e=>3,c=>1,a=>-16,g=>3,b=>3,d=>-4,f=>'UE1'}
f00b9701
f00b9701
f00b9701
f06632c0
f00b9701
f00b9701
f06632c0
f00b9701
f06632c0
-
{e=>6,c=>3,a=>-120,g=>6,b=>3,d=>-2,f=>'UE6'}
889b6d03
889b6d03
889b6d03
886f6d80
889b6d03
889b6d03
886f6d80
889b6d03
886f6d80
-
{e=>6,c=>1,a=>-121,g=>1,b=>7,d=>-4,f=>'UE3'}
870fbd00
870fbd00
870fbd00
87e66640
870fbd00
870fbd00
87e66640
870fbd00
87e66640
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>5,a=>72,d=>-1,c=>-3,h=>1,b=>0,g=>2,f=>'UE5'}
48e85b0101000000
48e85b0101000000
48e85b0101000000
4817da8020000000
48e85b0101000000
48e85b0101000000
4817da8020000000
48e85b0101000000
4817da8020000000
-
{e=>3,a=>-54,d=>1,c=>-4,h=>3,b=>0,g=>2,f=>'UE3'}
ca60360103000000
ca60360103000000
ca60360103000000
ca10b68060000000
ca60360103000000
ca60360103000000
ca10b68060000000
ca60360103000000
ca10b68060000000
-
{e=>0,a=>-29,d=>3,c=>1,h=>1,b=>2,g=>7,f=>'UE1'}
e3ca900301000000
e3ca900301000000
e3ca900301000000
e34583c020000000
e3ca900301000000
e3ca900301000000
e34583c020000000
e3ca900301000000
e34583c020000000
-
{e=>5,a=>60,d=>-4,c=>3,h=>1,b=>5,g=>1,f=>'UE4'}
3c1dcb0001000000
3c1dcb0001000000
3c1dcb0001000000
3cae584020000000
3c1dcb0001000000
3c1dcb0001000000
3cae584020000000
3c1dcb0001000000
3cae584020000000
-
{e=>3,a=>21,d=>1,c=>0,h=>7,b=>2,g=>2,f=>'UE7'}
1542760107000000
1542760107000000
1542760107000000
1540be80e0000000
1542760107000000
1542760107000000
1540be80e0000000
1542760107000000
1540be80e0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>3,a=>31,d=>-2,c=>0,h=>4,b=>1,g=>4,f=>'UE7',i=>-3}
1f8177022c000000
1f8177022c000000
1f8177022c000000
1f233f0094000000
1f8177022c000000
1f8177022c000000
1f233f0094000000
1f8177022c000000
1f233f0094000000
-
{e=>7,a=>-56,d=>-4,c=>0,h=>3,b=>0,g=>6,f=>'UE0',i=>1}
c8000f030b000000
c8000f030b000000
c8000f030b000000
c802718064000000
c8000f030b000000
c8000f030b000000
c802718064000000
c8000f030b000000
c802718064000000
-
{e=>4,a=>-92,d=>3,c=>3,h=>0,b=>7,g=>7,f=>'UE0',i=>-2}
a4df880330000000
a4df880330000000
a4df880330000000
a4edc1c018000000
a4df880330000000
a4df880330000000
a4edc1c018000000
a4df880330000000
a4edc1c018000000
-
{e=>7,a=>27,d=>1,c=>-4,h=>7,b=>6,g=>4,f=>'UE1',i=>1}
1b661e020f000000
1b661e020f000000
1b661e020f000000
1bd0f300e4000000
1b661e020f000000
1b661e020f000000
1bd0f300e4000000
1b661e020f000000
1bd0f300e4000000
-
{e=>0,a=>-28,d=>1,c=>1,h=>1,b=>2,g=>5,f=>'UE1',i=>2}
e44a900211000000
e44a900211000000
e44a900211000000
e444834028000000
e44a900211000000
e44a900211000000
e444834028000000
e44a900211000000
e444834028000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
};
-
{e=>5,a=>43,d=>-4,j=>'SEM1',c=>-2,h=>5,b=>1,g=>0,f=>'UE6',i=>0}
2b316b00c5010000
2b316b00c5010000
2b316b00c5010000
2b3a5c00a3800000
2b316b00c5010000
2b316b00c5010000
2b3a5c00a3800000
2b316b00c5010000
2b3a5c00a3800000
-
{e=>1,a=>-116,d=>-3,j=>'SE2',c=>-3,h=>4,b=>4,g=>3,f=>'UE6',i=>1}
8c6ce3018c000000
8c6ce3018c000000
8c6ce3018c000000
8c969cc085000000
8c6ce3018c000000
8c6ce3018c000000
8c969cc085000000
8c6ce3018c000000
8c969cc085000000
-
{e=>5,a=>-97,d=>-4,j=>'SE2',c=>0,h=>6,b=>6,g=>2,f=>'UE0',i=>2}
9f060b0196000000
9f060b0196000000
9f060b0196000000
9fc25080c9000000
9f060b0196000000
9f060b0196000000
9fc25080c9000000
9f060b0196000000
9fc25080c9000000
-
{e=>3,a=>-10,d=>0,j=>'SE1',c=>-4,h=>1,b=>4,g=>4,f=>'UE7',i=>-3}
f624760269000000
f624760269000000
f624760269000000
f6903f0034800000
f624760269000000
f624760269000000
f6903f0034800000
f624760269000000
f6903f0034800000
-
{e=>0,a=>-83,d=>3,j=>'SEM4',c=>-1,h=>3,b=>7,g=>0,f=>'UE0',i=>2}
adff000013010000
adff000013010000
adff000013010000
adfd80006a000000
adff000013010000
adff000013010000
adfd80006a000000
adff000013010000
adfd80006a000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
};
-
{e=>4,a=>-72,d=>1,j=>'SEM4',c=>-2,k=>-69,h=>2,b=>2,g=>4,f=>'UE6',i=>-3}
b87268022a01bb00
b87268022a01bb00
b87268022a01bb00
b858cd005600bb00
b87268022a01bb00
b87268022a01bb00
b858cd005600bb00
b87268022a01bb00
b858cd005600bb00
-
{e=>3,a=>-74,d=>3,j=>'SE1',c=>1,k=>-22,h=>7,b=>7,g=>1,f=>'UE4',i=>1}
b6cfc6004f00ea00
b6cfc6004f00ea00
b6cfc6004f00ea00
b6e5b840e480ea00
b6cfc6004f00ea00
b6cfc6004f00ea00
b6e5b840e480ea00
b6cfc6004f00ea00
b6e5b840e480ea00
-
{e=>2,a=>-35,d=>3,j=>'SE0',c=>-3,k=>-17,h=>4,b=>5,g=>0,f=>'UE7',i=>-1}
dded74003c00ef00
dded74003c00ef00
dded74003c00ef00
ddb5ae009c00ef00
dded74003c00ef00
dded74003c00ef00
ddb5ae009c00ef00
dded74003c00ef00
ddb5ae009c00ef00
-
{e=>6,a=>36,d=>-4,j=>'SEM2',c=>-4,k=>-49,h=>0,b=>3,g=>4,f=>'UE3',i=>-2}
24233d02b001cf00
24233d02b001cf00
24233d02b001cf00
247267001b00cf00
24233d02b001cf00
24233d02b001cf00
247267001b00cf00
24233d02b001cf00
247267001b00cf00
-
{e=>0,a=>34,d=>-3,j=>'SEM2',c=>0,k=>9,h=>2,b=>6,g=>4,f=>'UE3',i=>-1}
22463102ba010900
22463102ba010900
22463102ba010900
22c287005f000900
22463102ba010900
22463102ba010900
22c287005f000900
22463102ba010900
22c287005f000900
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>7,a=>-52,d=>0,j=>'SE0',l=>6,c=>0,k=>67,h=>4,b=>1,g=>4,f=>'UE1',i=>3}
cc011e021c004306
cc011e021c004306
cc011e021c004306
cc2073008c0043c0
cc011e021c004306
cc011e021c004306
cc2073008c0043c0
cc011e021c004306
cc2073008c0043c0
-
{e=>0,a=>104,d=>-4,j=>'SE3',l=>4,c=>1,k=>-98,h=>7,b=>1,g=>2,f=>'UE1',i=>-1}
68091101ff009e04
68091101ff009e04
68091101ff009e04
68260280fd809e80
68091101ff009e04
68091101ff009e04
68260280fd809e80
68091101ff009e04
68260280fd809e80
-
{e=>1,a=>88,d=>-1,j=>'SE2',l=>4,c=>-2,k=>51,h=>4,b=>2,g=>4,f=>'UE2',i=>-2}
58f22302b4003304
58f22302b4003304
58f22302b4003304
585b950099003380
58f22302b4003304
58f22302b4003304
585b950099003380
58f22302b4003304
585b950099003380
-
{e=>2,a=>-81,d=>2,j=>'SE0',l=>2,c=>0,k=>87,h=>1,b=>1,g=>6,f=>'UE4',i=>0}
af81440301005702
af81440301005702
af81440301005702
af21298020005740
af81440301005702
af81440301005702
af21298020005740
af81440301005702
af21298020005740
-
{e=>5,a=>-126,d=>2,j=>'SE3',l=>6,c=>-3,k=>79,h=>0,b=>3,g=>4,f=>'UE4',i=>1}
82ab4a02c8004f06
82ab4a02c8004f06
82ab4a02c8004f06
8275590005804fc0
82ab4a02c8004f06
82ab4a02c8004f06
8275590005804fc0
82ab4a02c8004f06
8275590005804fc0
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>4,a=>-69,m=>2,d=>2,j=>'SE1',l=>1,c=>2,k=>35,h=>6,b=>4,g=>4,f=>'UE5',i=>3}
bb9458025e002311
bb9458025e002311
bb9458025e002311
bb894b00cc802328
bb9458025e002311
bb9458025e002311
bb894b00cc802328
bb9458025e002311
bb894b00cc802328
-
{e=>7,a=>87,m=>-2,d=>-4,j=>'SEM4',l=>1,c=>-1,k=>1,h=>7,b=>6,g=>4,f=>'UE4',i=>2}
573e4f0217010131
573e4f0217010131
573e4f0217010131
57de7900ea000138
573e4f0217010131
573e4f0217010131
57de7900ea000138
573e4f0217010131
57de7900ea000138
-
{e=>6,a=>-102,m=>1,d=>3,j=>'SEM4',l=>2,c=>-4,k=>78,h=>5,b=>7,g=>6,f=>'UE3',i=>-3}
9ae73c032d014e0a
9ae73c032d014e0a
9ae73c032d014e0a
9af1e780b6004e44
9ae73c032d014e0a
9ae73c032d014e0a
9af1e780b6004e44
9ae73c032d014e0a
9af1e780b6004e44
-
{e=>0,a=>122,m=>2,d=>-1,j=>'SEM2',l=>4,c=>-1,k=>-59,h=>6,b=>4,g=>0,f=>'UE1',i=>-3}
7afc1100ae01c514
7afc1100ae01c514
7afc1100ae01c514
7a9f8200d700c588
7afc1100ae01c514
7afc1100ae01c514
7a9f8200d700c588
7afc1100ae01c514
7a9f8200d700c588
-
{e=>2,a=>91,m=>2,d=>2,j=>'SEM4',l=>2,c=>0,k=>-51,h=>2,b=>4,g=>3,f=>'UE2',i=>3}
5b84a4011a01cd12
5b84a4011a01cd12
5b84a4011a01cd12
5b8124c04e00cd48
5b84a4011a01cd12
5b84a4011a01cd12
5b8124c04e00cd48
5b84a4011a01cd12
5b8124c04e00cd48
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>6,n=>0,a=>40,m=>0,d=>-2,j=>'SEM1',l=>4,c=>-3,k=>69,h=>7,b=>4,g=>3,f=>'UE0',i=>-1}
28ac8d01ff01450400000000
28ac8d01ff01450400000000
28ac8d01ff01450400000000
289760c0ff80458000000000
28ac8d01ff01450400000000
28ac8d01ff01450400000000
289760c0ff80458000000000
28ac8d01ff01450400000000
289760c0ff80458000000000
-
{e=>4,n=>6,a=>30,m=>1,d=>3,j=>'SEM1',l=>0,c=>-2,k=>-11,h=>4,b=>6,g=>7,f=>'UE3',i=>-1}
1ef6b803fc01f50806000000
1ef6b803fc01f50806000000
1ef6b803fc01f50806000000
1ed9c7c09f80f504c0000000
1ef6b803fc01f50806000000
1ef6b803fc01f50806000000
1ed9c7c09f80f504c0000000
1ef6b803fc01f50806000000
1ed9c7c09f80f504c0000000
-
{e=>7,n=>3,a=>-38,m=>3,d=>2,j=>'SEM4',l=>2,c=>-2,k=>-84,h=>7,b=>7,g=>3,f=>'UE2',i=>3}
dab7ae011f01ac1a03000000
dab7ae011f01ac1a03000000
dab7ae011f01ac1a03000000
daf974c0ee00ac4c60000000
dab7ae011f01ac1a03000000
dab7ae011f01ac1a03000000
daf974c0ee00ac4c60000000
dab7ae011f01ac1a03000000
daf974c0ee00ac4c60000000
-
{e=>0,n=>3,a=>39,m=>0,d=>1,j=>'SEM3',l=>7,c=>3,k=>-120,h=>5,b=>2,g=>6,f=>'UE2',i=>3}
275a20035d01880703000000
275a20035d01880703000000
275a20035d01880703000000
274c8580ae8088e060000000
275a20035d01880703000000
275a20035d01880703000000
274c8580ae8088e060000000
275a20035d01880703000000
274c8580ae8088e060000000
-
{e=>5,n=>5,a=>-10,m=>-4,d=>-1,j=>'SEM3',l=>5,c=>0,k=>23,h=>7,b=>0,g=>7,f=>'UE7',i=>0}
f6c0fb034701172505000000
f6c0fb034701172505000000
f6c0fb034701172505000000
f603dfc0e28017b0a0000000
f6c0fb034701172505000000
f6c0fb034701172505000000
f603dfc0e28017b0a0000000
f6c0fb034701172505000000
f603dfc0e28017b0a0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  char a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>2,n=>4,a=>-49,m=>-4,d=>-2,j=>'SE3',l=>1,c=>0,k=>-90,h=>0,b=>3,g=>1,f=>'UE1',o=>232,i=>1}
cf839500c800a62104e80000
cf839500c800a62104e80000
cf839500c800a62104e80000
cf6322400580a63080e80000
cf839500c800a62104e80000
cf839500c800a62104e80000
cf6322400580a63080e80000
cf839500c800a62104e80000
cf6322400580a63080e80000
-
{e=>6,n=>2,a=>4,m=>1,d=>3,j=>'SEM2',l=>1,c=>1,k=>-19,h=>7,b=>4,g=>3,f=>'UE0',o=>88,i=>1}
04cc8c018f01ed0902580000
04cc8c018f01ed0902580000
04cc8c018f01ed0902580000
0485e0c0e700ed2440580000
04cc8c018f01ed0902580000
04cc8c018f01ed0902580000
0485e0c0e700ed2440580000
04cc8c018f01ed0902580000
0485e0c0e700ed2440580000
-
{e=>4,n=>7,a=>61,m=>0,d=>2,j=>'SE1',l=>6,c=>-1,k=>113,h=>2,b=>6,g=>5,f=>'UE6',o=>234,i=>2}
3dbee8025200710607ea0000
3dbee8025200710607ea0000
3dbee8025200710607ea0000
3ddd4d40488071c0e0ea0000
3dbee8025200710607ea0000
3dbee8025200710607ea0000
3ddd4d40488071c0e0ea0000
3dbee8025200710607ea0000
3ddd4d40488071c0e0ea0000
-
{e=>1,n=>0,a=>-69,m=>-2,d=>2,j=>'SE0',l=>0,c=>0,k=>38,h=>4,b=>5,g=>1,f=>'UE6',o=>145,i=>-2}
bb85e2003400263000910000
bb85e2003400263000910000
bb85e2003400263000910000
bba11c409800261800910000
bb85e2003400263000910000
bb85e2003400263000910000
bba11c409800261800910000
bb85e2003400263000910000
bba11c409800261800910000
-
{e=>3,n=>2,a=>-1,m=>-1,d=>2,j=>'SEM3',l=>1,c=>1,k=>-52,h=>3,b=>1,g=>2,f=>'UE1',o=>195,i=>-3}
ff8916016b01cc3902c30000
ff8916016b01cc3902c30000
ff8916016b01cc3902c30000
ff2532807680cc3c40c30000
ff8916016b01cc3902c30000
ff8916016b01cc3902c30000
ff2532807680cc3c40c30000
ff8916016b01cc3902c30000
ff2532807680cc3c40c30000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
};
-
{a=>-117,b=>5}
8bff0500
8bff0500
8bff0500
ff8ba000
8bff0500
8bff0500
ff8ba000
8bff0500
ff8ba000
-
{a=>72,b=>7}
48000700
48000700
48000700
0048e000
48000700
48000700
0048e000
48000700
0048e000
-
{a=>10,b=>5}
0a000500
0a000500
0a000500
000aa000
0a000500
0a000500
000aa000
0a000500
000aa000
-
{a=>-60,b=>2}
c4ff0200
c4ff0200
c4ff0200
ffc44000
c4ff0200
c4ff0200
ffc44000
c4ff0200
ffc44000
-
{a=>-76,b=>6}
b4ff0600
b4ff0600
b4ff0600
ffb4c000
b4ff0600
b4ff0600
ffb4c000
b4ff0600
ffb4c000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>-4,a=>-67,b=>0}
bdff2000
bdff2000
bdff2000
ffbd1000
bdff2000
bdff2000
ffbd1000
bdff2000
ffbd1000
-
{c=>-3,a=>-101,b=>6}
9bff2e00
9bff2e00
9bff2e00
ff9bd400
9bff2e00
9bff2e00
ff9bd400
9bff2e00
ff9bd400
-
{c=>2,a=>-19,b=>7}
edff1700
edff1700
edff1700
ffede800
edff1700
edff1700
ffede800
edff1700
ffede800
-
{c=>-2,a=>92,b=>7}
5c003700
5c003700
5c003700
005cf800
5c003700
5c003700
005cf800
5c003700
005cf800
-
{c=>3,a=>46,b=>7}
2e001f00
2e001f00
2e001f00
002eec00
2e001f00
2e001f00
002eec00
2e001f00
002eec00
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>-4,a=>79,b=>0,d=>0}
4f002000
4f002000
4f002000
004f1000
4f002000
4f002000
004f1000
4f002000
004f1000
-
{c=>-3,a=>93,b=>4,d=>0}
5d002c00
5d002c00
5d002c00
005d9400
5d002c00
5d002c00
005d9400
5d002c00
005d9400
-
{c=>-3,a=>-14,b=>5,d=>-1}
f2ffed01
f2ffed01
f2ffed01
fff2b780
f2ffed01
f2ffed01
fff2b780
f2ffed01
fff2b780
-
{c=>0,a=>-47,b=>4,d=>-4}
d1ff0401
d1ff0401
d1ff0401
ffd18200
d1ff0401
d1ff0401
ffd18200
d1ff0401
ffd18200
-
{c=>2,a=>-7,b=>5,d=>2}
f9ff9500
f9ff9500
f9ff9500
fff9a900
f9ff9500
f9ff9500
fff9a900
f9ff9500
fff9a900
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>6,c=>-1,a=>-71,b=>2,d=>0}
b9ff3a0c
b9ff3a0c
b9ff3a0c
ffb95c60
b9ff3a0c
b9ff3a0c
ffb95c60
b9ff3a0c
ffb95c60
-
{e=>0,c=>-1,a=>-25,b=>1,d=>3}
e7fff900
e7fff900
e7fff900
ffe73d80
e7fff900
e7fff900
ffe73d80
e7fff900
ffe73d80
-
{e=>0,c=>0,a=>-15,b=>4,d=>-4}
f1ff0401
f1ff0401
f1ff0401
fff18200
f1ff0401
f1ff0401
fff18200
f1ff0401
fff18200
-
{e=>6,c=>-1,a=>26,b=>6,d=>-3}
1a007e0d
1a007e0d
1a007e0d
001adee0
1a007e0d
1a007e0d
001adee0
1a007e0d
001adee0
-
{e=>7,c=>3,a=>-24,b=>1,d=>2}
e8ff990e
e8ff990e
e8ff990e
ffe82d70
e8ff990e
e8ff990e
ffe82d70
e8ff990e
ffe82d70
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
};
-
{e=>2,c=>-3,a=>-20,b=>5,d=>3,f=>'UE1'}
ecffed14
ecffed14
ecffed14
ffecb5a2
ecffed14
ecffed14
ffecb5a2
ecffed14
ffecb5a2
-
{e=>1,c=>2,a=>47,b=>6,d=>2,f=>'UE3'}
2f009632
2f009632
2f009632
002fc916
2f009632
2f009632
002fc916
2f009632
002fc916
-
{e=>6,c=>1,a=>16,b=>5,d=>0,f=>'UE7'}
10000d7c
10000d7c
10000d7c
0010a46e
10000d7c
10000d7c
0010a46e
10000d7c
0010a46e
-
{e=>6,c=>-2,a=>102,b=>5,d=>2,f=>'UE1'}
6600b51c
6600b51c
6600b51c
0066b962
6600b51c
6600b51c
0066b962
6600b51c
0066b962
-
{e=>3,c=>-3,a=>-74,b=>2,d=>-4,f=>'UE7'}
b6ff2a77
b6ff2a77
b6ff2a77
ffb6563e
b6ff2a77
b6ff2a77
ffb6563e
b6ff2a77
ffb6563e
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
};
-
{e=>5,c=>3,a=>65,g=>2,b=>7,d=>0,f=>'UE3'}
41001f3a02000000
41001f3a02000000
41001f3a02000000
0041ec5640000000
41001f3a02000000
41001f3a02000000
0041ec5640000000
41001f3a02000000
0041ec5640000000
-
{e=>1,c=>-1,a=>17,g=>4,b=>3,d=>3,f=>'UE4'}
1100fb4204000000
1100fb4204000000
1100fb4204000000
00117d9880000000
1100fb4204000000
1100fb4204000000
00117d9880000000
1100fb4204000000
00117d9880000000
-
{e=>0,c=>1,a=>100,g=>1,b=>1,d=>1,f=>'UE5'}
6400495001000000
6400495001000000
6400495001000000
0064248a20000000
6400495001000000
6400495001000000
0064248a20000000
6400495001000000
0064248a20000000
-
{e=>5,c=>1,a=>90,g=>5,b=>1,d=>3,f=>'UE4'}
5a00c94a05000000
5a00c94a05000000
5a00c94a05000000
005a25d8a0000000
5a00c94a05000000
5a00c94a05000000
005a25d8a0000000
5a00c94a05000000
005a25d8a0000000
-
{e=>5,c=>3,a=>-34,g=>1,b=>7,d=>1,f=>'UE7'}
deff5f7a01000000
deff5f7a01000000
deff5f7a01000000
ffdeecde20000000
deff5f7a01000000
deff5f7a01000000
ffdeecde20000000
deff5f7a01000000
ffdeecde20000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>6,c=>-1,a=>-29,g=>4,b=>0,d=>0,f=>'UE0'}
e3ff380c04000000
e3ff380c04000000
e3ff380c04000000
ffe31c6080000000
e3ff380c04000000
e3ff380c04000000
ffe31c6080000000
e3ff380c04000000
ffe31c6080000000
-
{e=>4,c=>1,a=>-112,g=>5,b=>1,d=>-4,f=>'UE6'}
90ff096905000000
90ff096905000000
90ff096905000000
ff90264ca0000000
90ff096905000000
90ff096905000000
ff90264ca0000000
90ff096905000000
ff90264ca0000000
-
{e=>4,c=>-1,a=>-66,g=>1,b=>4,d=>2,f=>'UE0'}
beffbc0801000000
beffbc0801000000
beffbc0801000000
ffbe9d4020000000
beffbc0801000000
beffbc0801000000
ffbe9d4020000000
beffbc0801000000
ffbe9d4020000000
-
{e=>7,c=>-3,a=>-106,g=>5,b=>5,d=>-1,f=>'UE2'}
96ffed2f05000000
96ffed2f05000000
96ffed2f05000000
ff96b7f4a0000000
96ffed2f05000000
96ffed2f05000000
ff96b7f4a0000000
96ffed2f05000000
ff96b7f4a0000000
-
{e=>7,c=>3,a=>-85,g=>4,b=>5,d=>-1,f=>'UE5'}
abffdd5f04000000
abffdd5f04000000
abffdd5f04000000
ffabaffa80000000
abffdd5f04000000
abffdd5f04000000
ffabaffa80000000
abffdd5f04000000
ffabaffa80000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>1,a=>-70,d=>3,c=>-2,h=>1,b=>7,g=>0,f=>'UE6'}
bafff7620000000001000000
bafff7620000000001000000
bafff7620000000001000000
ffbaf99c0000000020000000
bafff7620000000001000000
bafff7620000000001000000
ffbaf99c0000000020000000
bafff7620000000001000000
ffbaf99c0000000020000000
-
{e=>3,a=>16,d=>-2,c=>1,h=>1,b=>3,g=>7,f=>'UE2'}
10008b270700000001000000
10008b270700000001000000
10008b270700000001000000
00106734e000000020000000
10008b270700000001000000
10008b270700000001000000
00106734e000000020000000
10008b270700000001000000
00106734e000000020000000
-
{e=>7,a=>34,d=>-3,c=>-1,h=>3,b=>1,g=>4,f=>'UE6'}
2200796f0400000003000000
2200796f0400000003000000
2200796f0400000003000000
00223efc8000000060000000
2200796f0400000003000000
2200796f0400000003000000
00223efc8000000060000000
2200796f0400000003000000
00223efc8000000060000000
-
{e=>1,a=>15,d=>-3,c=>-1,h=>6,b=>7,g=>7,f=>'UE0'}
0f007f030700000006000000
0f007f030700000006000000
0f007f030700000006000000
000ffe90e0000000c0000000
0f007f030700000006000000
0f007f030700000006000000
000ffe90e0000000c0000000
0f007f030700000006000000
000ffe90e0000000c0000000
-
{e=>5,a=>120,d=>0,c=>3,h=>7,b=>7,g=>0,f=>'UE4'}
78001f4a0000000007000000
78001f4a0000000007000000
78001f4a0000000007000000
0078ec5800000000e0000000
78001f4a0000000007000000
78001f4a0000000007000000
0078ec5800000000e0000000
78001f4a0000000007000000
0078ec5800000000e0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>7,a=>110,d=>1,c=>0,h=>3,b=>1,g=>7,f=>'UE3',i=>-3}
6e00413e070000002b000000
6e00413e070000002b000000
6e00413e070000002b000000
006e20f6e000000074000000
6e00413e070000002b000000
6e00413e070000002b000000
006e20f6e000000074000000
6e00413e070000002b000000
006e20f6e000000074000000
-
{e=>4,a=>-31,d=>-2,c=>-4,h=>0,b=>7,g=>7,f=>'UE7',i=>-2}
e1ffa7790700000030000000
e1ffa7790700000030000000
e1ffa7790700000030000000
ffe1f34ee000000018000000
e1ffa7790700000030000000
e1ffa7790700000030000000
ffe1f34ee000000018000000
e1ffa7790700000030000000
ffe1f34ee000000018000000
-
{e=>6,a=>64,d=>2,c=>-1,h=>4,b=>3,g=>5,f=>'UE5',i=>-3}
4000bb5c050000002c000000
4000bb5c050000002c000000
4000bb5c050000002c000000
00407d6aa000000094000000
4000bb5c050000002c000000
4000bb5c050000002c000000
00407d6aa000000094000000
4000bb5c050000002c000000
00407d6aa000000094000000
-
{e=>5,a=>100,d=>1,c=>3,h=>5,b=>4,g=>4,f=>'UE2',i=>-1}
64005c2a040000003d000000
64005c2a040000003d000000
64005c2a040000003d000000
00648cd480000000bc000000
64005c2a040000003d000000
64005c2a040000003d000000
00648cd480000000bc000000
64005c2a040000003d000000
00648cd480000000bc000000
-
{e=>5,a=>-124,d=>-4,c=>-2,h=>6,b=>1,g=>4,f=>'UE4',i=>2}
84ff314b0400000016000000
84ff314b0400000016000000
84ff314b0400000016000000
ff843a5880000000c8000000
84ff314b0400000016000000
84ff314b0400000016000000
ff843a5880000000c8000000
84ff314b0400000016000000
ff843a5880000000c8000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
};
-
{e=>6,a=>-89,d=>2,j=>'SE2',c=>0,h=>7,b=>2,g=>7,f=>'UE6',i=>-4}
a7ff826c07000000a7000000
a7ff826c07000000a7000000
a7ff826c07000000a7000000
ffa7416ce0000000f1000000
a7ff826c07000000a7000000
a7ff826c07000000a7000000
ffa7416ce0000000f1000000
a7ff826c07000000a7000000
ffa7416ce0000000f1000000
-
{e=>6,a=>63,d=>-2,j=>'SEM1',c=>-4,h=>2,b=>6,g=>6,f=>'UE0',i=>-1}
3f00a60d06000000fa010000
3f00a60d06000000fa010000
3f00a60d06000000fa010000
003fd360c00000005f800000
3f00a60d06000000fa010000
3f00a60d06000000fa010000
003fd360c00000005f800000
3f00a60d06000000fa010000
003fd360c00000005f800000
-
{e=>4,a=>93,d=>-4,j=>'SE2',c=>3,h=>7,b=>5,g=>7,f=>'UE7',i=>-1}
5d001d7907000000bf000000
5d001d7907000000bf000000
5d001d7907000000bf000000
005dae4ee0000000fd000000
5d001d7907000000bf000000
5d001d7907000000bf000000
005dae4ee0000000fd000000
5d001d7907000000bf000000
005dae4ee0000000fd000000
-
{e=>4,a=>-43,d=>0,j=>'SE3',c=>-2,h=>1,b=>7,g=>6,f=>'UE6',i=>-1}
d5ff376806000000f9000000
d5ff376806000000f9000000
d5ff376806000000f9000000
ffd5f84cc00000003d800000
d5ff376806000000f9000000
d5ff376806000000f9000000
ffd5f84cc00000003d800000
d5ff376806000000f9000000
ffd5f84cc00000003d800000
-
{e=>1,a=>21,d=>2,j=>'SEM3',c=>-3,h=>0,b=>6,g=>4,f=>'UE4',i=>-2}
1500ae420400000070010000
1500ae420400000070010000
1500ae420400000070010000
0015d518800000001a800000
1500ae420400000070010000
1500ae420400000070010000
0015d518800000001a800000
1500ae420400000070010000
0015d518800000001a800000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
};
-
{e=>4,a=>124,d=>-1,j=>'SE2',c=>2,k=>-23,h=>7,b=>1,g=>2,f=>'UE4',i=>0}
7c00d149020000008700e900
7c00d149020000008700e900
7c00d149020000008700e900
007c2bc840000000e100e900
7c00d149020000008700e900
7c00d149020000008700e900
007c2bc840000000e100e900
7c00d149020000008700e900
007c2bc840000000e100e900
-
{e=>6,a=>-50,d=>-3,j=>'SE2',c=>-3,k=>-66,h=>3,b=>5,g=>2,f=>'UE5',i=>1}
ceff6d5d020000008b00be00
ceff6d5d020000008b00be00
ceff6d5d020000008b00be00
ffceb6ea400000006500be00
ceff6d5d020000008b00be00
ceff6d5d020000008b00be00
ffceb6ea400000006500be00
ceff6d5d020000008b00be00
ffceb6ea400000006500be00
-
{e=>4,a=>31,d=>2,j=>'SEM1',c=>-4,k=>-117,h=>1,b=>4,g=>3,f=>'UE5',i=>0}
1f00a45803000000c1018b00
1f00a45803000000c1018b00
1f00a45803000000c1018b00
001f914a6000000023808b00
1f00a45803000000c1018b00
1f00a45803000000c1018b00
001f914a6000000023808b00
1f00a45803000000c1018b00
001f914a6000000023808b00
-
{e=>0,a=>-107,d=>0,j=>'SEM4',c=>-3,k=>8,h=>7,b=>7,g=>5,f=>'UE5',i=>-1}
95ff2f50050000003f010800
95ff2f50050000003f010800
95ff2f50050000003f010800
ff95f40aa0000000fe000800
95ff2f50050000003f010800
95ff2f50050000003f010800
ff95f40aa0000000fe000800
95ff2f50050000003f010800
ff95f40aa0000000fe000800
-
{e=>7,a=>-5,d=>1,j=>'SEM4',c=>1,k=>71,h=>4,b=>2,g=>6,f=>'UE1',i=>2}
fbff4a1e0600000014014700
fbff4a1e0600000014014700
fbff4a1e0600000014014700
fffb44f2c00000008a004700
fbff4a1e0600000014014700
fbff4a1e0600000014014700
fffb44f2c00000008a004700
fbff4a1e0600000014014700
fffb44f2c00000008a004700
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>2,a=>-31,d=>2,j=>'SE1',l=>0,c=>2,k=>75,h=>7,b=>1,g=>0,f=>'UE1',i=>2}
e1ff91140000000057004b00
e1ff91140000000057004b00
e1ff91140000000057004b00
ffe1292200000000e8804b00
e1ff91140000000057004b00
e1ff91140000000057004b00
ffe1292200000000e8804b00
e1ff91140000000057004b00
ffe1292200000000e8804b00
-
{e=>2,a=>-101,d=>-3,j=>'SEM4',l=>4,c=>-4,k=>-56,h=>0,b=>2,g=>1,f=>'UE0',i=>-3}
9bff6205010000002801c804
9bff6205010000002801c804
9bff6205010000002801c804
ff9b52a0200000001600c880
9bff6205010000002801c804
9bff6205010000002801c804
ff9b52a0200000001600c880
9bff6205010000002801c804
ff9b52a0200000001600c880
-
{e=>7,a=>79,d=>1,j=>'SE2',l=>0,c=>-4,k=>87,h=>0,b=>7,g=>2,f=>'UE6',i=>-1}
4f00676e02000000b8005700
4f00676e02000000b8005700
4f00676e02000000b8005700
004ff0fc400000001d005700
4f00676e02000000b8005700
4f00676e02000000b8005700
004ff0fc400000001d005700
4f00676e02000000b8005700
004ff0fc400000001d005700
-
{e=>1,a=>44,d=>1,j=>'SE0',l=>3,c=>2,k=>97,h=>7,b=>5,g=>3,f=>'UE5',i=>3}
2c005552030000001f006103
2c005552030000001f006103
2c005552030000001f006103
002ca89a60000000ec006160
2c005552030000001f006103
2c005552030000001f006103
002ca89a60000000ec006160
2c005552030000001f006103
002ca89a60000000ec006160
-
{e=>3,a=>59,d=>2,j=>'SEM3',l=>5,c=>2,k=>-17,h=>0,b=>4,g=>3,f=>'UE4',i=>1}
3b009446030000004801ef05
3b009446030000004801ef05
3b009446030000004801ef05
003b8938600000000680efa0
3b009446030000004801ef05
3b009446030000004801ef05
003b8938600000000680efa0
3b009446030000004801ef05
003b8938600000000680efa0
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>0,a=>54,m=>-4,d=>2,j=>'SE2',l=>1,c=>1,k=>91,h=>0,b=>5,g=>5,f=>'UE5',i=>2}
36008d500500000090005b21
36008d500500000090005b21
36008d500500000090005b21
0036a50aa000000009005b30
36008d500500000090005b21
36008d500500000090005b21
0036a50aa000000009005b30
36008d500500000090005b21
0036a50aa000000009005b30
-
{e=>6,a=>-109,m=>-4,d=>1,j=>'SEM1',l=>4,c=>-2,k=>111,h=>7,b=>7,g=>7,f=>'UE7',i=>0}
93ff777c07000000c7016f24
93ff777c07000000c7016f24
93ff777c07000000c7016f24
ff93f8eee0000000e3806f90
93ff777c07000000c7016f24
93ff777c07000000c7016f24
ff93f8eee0000000e3806f90
93ff777c07000000c7016f24
ff93f8eee0000000e3806f90
-
{e=>4,a=>-18,m=>-1,d=>-2,j=>'SEM4',l=>7,c=>3,k=>-106,h=>2,b=>6,g=>7,f=>'UE1',i=>-4}
eeff9e19070000002201963f
eeff9e19070000002201963f
eeff9e19070000002201963f
ffeecf42e0000000520096fc
eeff9e19070000002201963f
eeff9e19070000002201963f
ffeecf42e0000000520096fc
eeff9e19070000002201963f
ffeecf42e0000000520096fc
-
{e=>5,a=>77,m=>1,d=>1,j=>'SE2',l=>6,c=>-2,k=>-38,h=>5,b=>1,g=>6,f=>'UE2',i=>3}
4d00712a060000009d00da0e
4d00712a060000009d00da0e
4d00712a060000009d00da0e
004d38d4c0000000ad00dac4
4d00712a060000009d00da0e
4d00712a060000009d00da0e
004d38d4c0000000ad00dac4
4d00712a060000009d00da0e
004d38d4c0000000ad00dac4
-
{e=>2,a=>63,m=>2,d=>0,j=>'SEM4',l=>4,c=>-3,k=>-13,h=>0,b=>2,g=>5,f=>'UE6',i=>2}
3f002a64050000001001f314
3f002a64050000001001f314
3f002a64050000001001f314
003f542ca00000000a00f388
3f002a64050000001001f314
3f002a64050000001001f314
003f542ca00000000a00f388
3f002a64050000001001f314
003f542ca00000000a00f388
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>7,n=>1,a=>6,m=>2,d=>-1,j=>'SEM1',l=>4,c=>3,k=>-96,h=>7,b=>7,g=>2,f=>'UE0',i=>-2}
0600df0f02000000f701a01401000000
0600df0f02000000f701a01401000000
0600df0f02000000f701a01401000000
0006eff040000000fb80a08820000000
0600df0f02000000f701a01401000000
0600df0f02000000f701a01401000000
0006eff040000000fb80a08820000000
0600df0f02000000f701a01401000000
0006eff040000000fb80a08820000000
-
{e=>1,n=>3,a=>-28,m=>0,d=>1,j=>'SEM4',l=>5,c=>-2,k=>118,h=>2,b=>1,g=>1,f=>'UE1',i=>-2}
e4ff7112010000003201760503000000
e4ff7112010000003201760503000000
e4ff7112010000003201760503000000
ffe43892200000005a0076a060000000
e4ff7112010000003201760503000000
e4ff7112010000003201760503000000
ffe43892200000005a0076a060000000
e4ff7112010000003201760503000000
ffe43892200000005a0076a060000000
-
{e=>6,n=>5,a=>125,m=>-4,d=>1,j=>'SEM1',l=>3,c=>-1,k=>1,h=>5,b=>7,g=>6,f=>'UE6',i=>-1}
7d007f6c06000000fd01012305000000
7d007f6c06000000fd01012305000000
7d007f6c06000000fd01012305000000
007dfcecc0000000bf800170a0000000
7d007f6c06000000fd01012305000000
7d007f6c06000000fd01012305000000
007dfcecc0000000bf800170a0000000
7d007f6c06000000fd01012305000000
007dfcecc0000000bf800170a0000000
-
{e=>3,n=>1,a=>4,m=>-4,d=>-3,j=>'SE1',l=>5,c=>-4,k=>82,h=>7,b=>3,g=>0,f=>'UE5',i=>-4}
04006357000000006700522501000000
04006357000000006700522501000000
04006357000000006700522501000000
000472ba00000000f08052b020000000
04006357000000006700522501000000
04006357000000006700522501000000
000472ba00000000f08052b020000000
04006357000000006700522501000000
000472ba00000000f08052b020000000
-
{e=>4,n=>7,a=>98,m=>1,d=>1,j=>'SE2',l=>5,c=>-3,k=>-32,h=>6,b=>2,g=>3,f=>'UE5',i=>1}
62006a58030000008e00e00d07000000
62006a58030000008e00e00d07000000
62006a58030000008e00e00d07000000
006254ca60000000c500e0a4e0000000
62006a58030000008e00e00d07000000
62006a58030000008e00e00d07000000
006254ca60000000c500e0a4e0000000
62006a58030000008e00e00d07000000
006254ca60000000c500e0a4e0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  short a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>5,n=>6,a=>-72,m=>-2,d=>-3,j=>'SEM1',l=>0,c=>1,k=>95,h=>2,b=>5,g=>7,f=>'UE0',o=>120,i=>-3}
b8ff4d0b07000000ea015f3006780000
b8ff4d0b07000000ea015f3006780000
b8ff4d0b07000000ea015f3006780000
ffb8a6d0e000000057805f18c0780000
b8ff4d0b07000000ea015f3006780000
b8ff4d0b07000000ea015f3006780000
ffb8a6d0e000000057805f18c0780000
b8ff4d0b07000000ea015f3006780000
ffb8a6d0e000000057805f18c0780000
-
{e=>2,n=>0,a=>-69,m=>-1,d=>0,j=>'SE0',l=>0,c=>1,k=>-105,h=>7,b=>6,g=>0,f=>'UE1',o=>44,i=>2}
bbff0e140000000017009738002c0000
bbff0e140000000017009738002c0000
bbff0e140000000017009738002c0000
ffbbc42200000000e800971c002c0000
bbff0e140000000017009738002c0000
bbff0e140000000017009738002c0000
ffbbc42200000000e800971c002c0000
bbff0e140000000017009738002c0000
ffbbc42200000000e800971c002c0000
-
{e=>0,n=>5,a=>94,m=>-3,d=>-2,j=>'SEM3',l=>4,c=>-1,k=>53,h=>7,b=>4,g=>7,f=>'UE3',o=>232,i=>3}
5e00bc31070000005f01352c05e80000
5e00bc31070000005f01352c05e80000
5e00bc31070000005f01352c05e80000
005e9f06e0000000ee803594a0e80000
5e00bc31070000005f01352c05e80000
5e00bc31070000005f01352c05e80000
005e9f06e0000000ee803594a0e80000
5e00bc31070000005f01352c05e80000
005e9f06e0000000ee803594a0e80000
-
{e=>1,n=>0,a=>112,m=>-1,d=>-3,j=>'SE3',l=>4,c=>-2,k=>50,h=>1,b=>4,g=>7,f=>'UE6',o=>103,i=>1}
7000746307000000c900323c00670000
7000746307000000c900323c00670000
7000746307000000c900323c00670000
00709a9ce00000002580329c00670000
7000746307000000c900323c00670000
7000746307000000c900323c00670000
00709a9ce00000002580329c00670000
7000746307000000c900323c00670000
00709a9ce00000002580329c00670000
-
{e=>7,n=>6,a=>-116,m=>1,d=>3,j=>'SEM1',l=>3,c=>0,k=>117,h=>5,b=>5,g=>7,f=>'UE0',o=>207,i=>-1}
8cffc50e07000000fd01750b06cf0000
8cffc50e07000000fd01750b06cf0000
8cffc50e07000000fd01750b06cf0000
ff8ca1f0e0000000bf807564c0cf0000
8cffc50e07000000fd01750b06cf0000
8cffc50e07000000fd01750b06cf0000
ff8ca1f0e0000000bf807564c0cf0000
8cffc50e07000000fd01750b06cf0000
ff8ca1f0e0000000bf807564c0cf0000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
};
-
{a=>59,b=>6}
3b00000006000000
3b00000006000000
3b00000006000000
0000003bc0000000
3b00000006000000
3b00000006000000
0000003bc0000000
3b00000006000000
0000003bc0000000
-
{a=>-72,b=>6}
b8ffffff06000000
b8ffffff06000000
b8ffffff06000000
ffffffb8c0000000
b8ffffff06000000
b8ffffff06000000
ffffffb8c0000000
b8ffffff06000000
ffffffb8c0000000
-
{a=>-11,b=>2}
f5ffffff02000000
f5ffffff02000000
f5ffffff02000000
fffffff540000000
f5ffffff02000000
f5ffffff02000000
fffffff540000000
f5ffffff02000000
fffffff540000000
-
{a=>-120,b=>5}
88ffffff05000000
88ffffff05000000
88ffffff05000000
ffffff88a0000000
88ffffff05000000
88ffffff05000000
ffffff88a0000000
88ffffff05000000
ffffff88a0000000
-
{a=>16,b=>4}
1000000004000000
1000000004000000
1000000004000000
0000001080000000
1000000004000000
1000000004000000
0000001080000000
1000000004000000
0000001080000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>-4,a=>-6,b=>5}
faffffff25000000
faffffff25000000
faffffff25000000
fffffffab0000000
faffffff25000000
faffffff25000000
fffffffab0000000
faffffff25000000
fffffffab0000000
-
{c=>2,a=>-12,b=>0}
f4ffffff10000000
f4ffffff10000000
f4ffffff10000000
fffffff408000000
f4ffffff10000000
f4ffffff10000000
fffffff408000000
f4ffffff10000000
fffffff408000000
-
{c=>-1,a=>-6,b=>7}
faffffff3f000000
faffffff3f000000
faffffff3f000000
fffffffafc000000
faffffff3f000000
faffffff3f000000
fffffffafc000000
faffffff3f000000
fffffffafc000000
-
{c=>-3,a=>126,b=>1}
7e00000029000000
7e00000029000000
7e00000029000000
0000007e34000000
7e00000029000000
7e00000029000000
0000007e34000000
7e00000029000000
0000007e34000000
-
{c=>-2,a=>3,b=>2}
0300000032000000
0300000032000000
0300000032000000
0000000358000000
0300000032000000
0300000032000000
0000000358000000
0300000032000000
0000000358000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>-3,a=>6,b=>4,d=>1}
060000006c000000
060000006c000000
060000006c000000
0000000694800000
060000006c000000
060000006c000000
0000000694800000
060000006c000000
0000000694800000
-
{c=>2,a=>-111,b=>6,d=>-3}
91ffffff56010000
91ffffff56010000
91ffffff56010000
ffffff91ca800000
91ffffff56010000
91ffffff56010000
ffffff91ca800000
91ffffff56010000
ffffff91ca800000
-
{c=>1,a=>-80,b=>4,d=>-3}
b0ffffff4c010000
b0ffffff4c010000
b0ffffff4c010000
ffffffb086800000
b0ffffff4c010000
b0ffffff4c010000
ffffffb086800000
b0ffffff4c010000
ffffffb086800000
-
{c=>3,a=>54,b=>4,d=>0}
360000001c000000
360000001c000000
360000001c000000
000000368c000000
360000001c000000
360000001c000000
000000368c000000
360000001c000000
000000368c000000
-
{c=>-1,a=>-73,b=>5,d=>-4}
b7ffffff3d010000
b7ffffff3d010000
b7ffffff3d010000
ffffffb7be000000
b7ffffff3d010000
b7ffffff3d010000
ffffffb7be000000
b7ffffff3d010000
ffffffb7be000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>1,c=>-2,a=>59,b=>4,d=>1}
3b00000074020000
3b00000074020000
3b00000074020000
0000003b98900000
3b00000074020000
3b00000074020000
0000003b98900000
3b00000074020000
0000003b98900000
-
{e=>4,c=>3,a=>-20,b=>1,d=>-3}
ecffffff59090000
ecffffff59090000
ecffffff59090000
ffffffec2ec00000
ecffffff59090000
ecffffff59090000
ffffffec2ec00000
ecffffff59090000
ffffffec2ec00000
-
{e=>3,c=>-4,a=>59,b=>0,d=>-2}
3b000000a0070000
3b000000a0070000
3b000000a0070000
0000003b13300000
3b000000a0070000
3b000000a0070000
0000003b13300000
3b000000a0070000
0000003b13300000
-
{e=>5,c=>-4,a=>-67,b=>2,d=>2}
bdffffffa20a0000
bdffffffa20a0000
bdffffffa20a0000
ffffffbd51500000
bdffffffa20a0000
bdffffffa20a0000
ffffffbd51500000
bdffffffa20a0000
ffffffbd51500000
-
{e=>7,c=>1,a=>-13,b=>2,d=>2}
f3ffffff8a0e0000
f3ffffff8a0e0000
f3ffffff8a0e0000
fffffff345700000
f3ffffff8a0e0000
f3ffffff8a0e0000
fffffff345700000
f3ffffff8a0e0000
fffffff345700000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
};
-
{e=>4,c=>3,a=>-90,b=>0,d=>-4,f=>'UE5'}
a6ffffff18590000
a6ffffff18590000
a6ffffff18590000
ffffffa60e4a0000
a6ffffff18590000
a6ffffff18590000
ffffffa60e4a0000
a6ffffff18590000
ffffffa60e4a0000
-
{e=>4,c=>-3,a=>-120,b=>6,d=>-4,f=>'UE3'}
88ffffff2e390000
88ffffff2e390000
88ffffff2e390000
ffffff88d6460000
88ffffff2e390000
88ffffff2e390000
ffffff88d6460000
88ffffff2e390000
ffffff88d6460000
-
{e=>2,c=>2,a=>94,b=>0,d=>-1,f=>'UE7'}
5e000000d0750000
5e000000d0750000
5e000000d0750000
0000005e0bae0000
5e000000d0750000
5e000000d0750000
0000005e0bae0000
5e000000d0750000
0000005e0bae0000
-
{e=>7,c=>2,a=>51,b=>2,d=>0,f=>'UE3'}
33000000123e0000
33000000123e0000
33000000123e0000
0000003348760000
33000000123e0000
33000000123e0000
0000003348760000
33000000123e0000
0000003348760000
-
{e=>1,c=>-1,a=>74,b=>1,d=>1,f=>'UE6'}
4a00000079620000
4a00000079620000
4a00000079620000
0000004a3c9c0000
4a00000079620000
4a00000079620000
0000004a3c9c0000
4a00000079620000
0000004a3c9c0000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
};
-
{e=>2,c=>3,a=>-102,g=>2,b=>7,d=>2,f=>'UE1'}
9affffff9f140100
9affffff9f140100
9affffff9f140100
ffffff9aed228000
9affffff9f140100
9affffff9f140100
ffffff9aed228000
9affffff9f140100
ffffff9aed228000
-
{e=>5,c=>0,a=>55,g=>0,b=>3,d=>1,f=>'UE1'}
37000000431a0000
37000000431a0000
37000000431a0000
0000003760d20000
37000000431a0000
37000000431a0000
0000003760d20000
37000000431a0000
0000003760d20000
-
{e=>7,c=>0,a=>-113,g=>0,b=>6,d=>-2,f=>'UE1'}
8fffffff861f0000
8fffffff861f0000
8fffffff861f0000
ffffff8fc3720000
8fffffff861f0000
8fffffff861f0000
ffffff8fc3720000
8fffffff861f0000
ffffff8fc3720000
-
{e=>3,c=>3,a=>56,g=>5,b=>5,d=>-1,f=>'UE3'}
38000000ddb70200
38000000ddb70200
38000000ddb70200
00000038afb74000
38000000ddb70200
38000000ddb70200
00000038afb74000
38000000ddb70200
00000038afb74000
-
{e=>4,c=>-2,a=>-74,g=>2,b=>3,d=>-1,f=>'UE4'}
b6fffffff3490100
b6fffffff3490100
b6fffffff3490100
ffffffb67bc88000
b6fffffff3490100
b6fffffff3490100
ffffffb67bc88000
b6fffffff3490100
ffffffb67bc88000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>1,c=>-4,a=>98,g=>3,b=>6,d=>-4,f=>'UE7'}
6200000026f30100
6200000026f30100
6200000026f30100
00000062d21ec000
6200000026f30100
6200000026f30100
00000062d21ec000
6200000026f30100
00000062d21ec000
-
{e=>6,c=>-1,a=>-100,g=>6,b=>1,d=>-2,f=>'UE2'}
9cffffffb92d0300
9cffffffb92d0300
9cffffffb92d0300
ffffff9c3f658000
9cffffffb92d0300
9cffffffb92d0300
ffffff9c3f658000
9cffffffb92d0300
ffffff9c3f658000
-
{e=>3,c=>0,a=>-41,g=>4,b=>6,d=>1,f=>'UE2'}
d7ffffff46260200
d7ffffff46260200
d7ffffff46260200
ffffffd7c0b50000
d7ffffff46260200
d7ffffff46260200
ffffffd7c0b50000
d7ffffff46260200
ffffffd7c0b50000
-
{e=>3,c=>-4,a=>74,g=>2,b=>2,d=>-3,f=>'UE4'}
4a00000062470100
4a00000062470100
4a00000062470100
0000004a52b88000
4a00000062470100
4a00000062470100
0000004a52b88000
4a00000062470100
0000004a52b88000
-
{e=>2,c=>2,a=>-78,g=>4,b=>4,d=>-2,f=>'UE7'}
b2ffffff94750200
b2ffffff94750200
b2ffffff94750200
ffffffb28b2f0000
b2ffffff94750200
b2ffffff94750200
ffffffb28b2f0000
b2ffffff94750200
ffffffb28b2f0000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>1,a=>14,d=>-2,c=>-3,h=>7,b=>3,g=>7,f=>'UE6'}
0e000000abe3030007000000
0e000000abe3030007000000
0e000000abe3030007000000
0000000e771dc000e0000000
0e000000abe3030007000000
0e000000abe3030007000000
0000000e771dc000e0000000
0e000000abe3030007000000
0000000e771dc000e0000000
-
{e=>5,a=>-111,d=>-2,c=>-2,h=>7,b=>0,g=>5,f=>'UE0'}
91ffffffb08b020007000000
91ffffffb08b020007000000
91ffffffb08b020007000000
ffffff911b514000e0000000
91ffffffb08b020007000000
91ffffffb08b020007000000
ffffff911b514000e0000000
91ffffffb08b020007000000
ffffff911b514000e0000000
-
{e=>6,a=>68,d=>-3,c=>1,h=>7,b=>2,g=>1,f=>'UE2'}
440000004aad000007000000
440000004aad000007000000
440000004aad000007000000
0000004446e44000e0000000
440000004aad000007000000
440000004aad000007000000
0000004446e44000e0000000
440000004aad000007000000
0000004446e44000e0000000
-
{e=>5,a=>-108,d=>1,c=>-3,h=>7,b=>1,g=>4,f=>'UE3'}
94ffffff693a020007000000
94ffffff693a020007000000
94ffffff693a020007000000
ffffff9434d70000e0000000
94ffffff693a020007000000
94ffffff693a020007000000
ffffff9434d70000e0000000
94ffffff693a020007000000
ffffff9434d70000e0000000
-
{e=>3,a=>114,d=>-2,c=>-1,h=>6,b=>1,g=>2,f=>'UE5'}
72000000b957010006000000
72000000b957010006000000
72000000b957010006000000
000000723f3a8000c0000000
72000000b957010006000000
72000000b957010006000000
000000723f3a8000c0000000
72000000b957010006000000
000000723f3a8000c0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>2,a=>-51,d=>-4,c=>2,h=>0,b=>1,g=>7,f=>'UE3',i=>-4}
cdffffff11b5030020000000
cdffffff11b5030020000000
cdffffff11b5030020000000
ffffffcd2a27c00010000000
cdffffff11b5030020000000
cdffffff11b5030020000000
ffffffcd2a27c00010000000
cdffffff11b5030020000000
ffffffcd2a27c00010000000
-
{e=>2,a=>-42,d=>2,c=>3,h=>7,b=>3,g=>2,f=>'UE5',i=>1}
d6ffffff9b5401000f000000
d6ffffff9b5401000f000000
d6ffffff9b5401000f000000
ffffffd66d2a8000e4000000
d6ffffff9b5401000f000000
d6ffffff9b5401000f000000
ffffffd66d2a8000e4000000
d6ffffff9b5401000f000000
ffffffd66d2a8000e4000000
-
{e=>1,a=>47,d=>3,c=>3,h=>1,b=>0,g=>4,f=>'UE0',i=>-4}
2f000000d802020021000000
2f000000d802020021000000
2f000000d802020021000000
0000002f0d91000030000000
2f000000d802020021000000
2f000000d802020021000000
0000002f0d91000030000000
2f000000d802020021000000
0000002f0d91000030000000
-
{e=>0,a=>-80,d=>-1,c=>-4,h=>5,b=>2,g=>4,f=>'UE7',i=>0}
b0ffffffe271020005000000
b0ffffffe271020005000000
b0ffffffe271020005000000
ffffffb0538f0000a0000000
b0ffffffe271020005000000
b0ffffffe271020005000000
ffffffb0538f0000a0000000
b0ffffffe271020005000000
ffffffb0538f0000a0000000
-
{e=>2,a=>-76,d=>-1,c=>1,h=>5,b=>6,g=>3,f=>'UE6',i=>2}
b4ffffffcee5010015000000
b4ffffffcee5010015000000
b4ffffffcee5010015000000
ffffffb4c7acc000a8000000
b4ffffffcee5010015000000
b4ffffffcee5010015000000
ffffffb4c7acc000a8000000
b4ffffffcee5010015000000
ffffffb4c7acc000a8000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
};
-
{e=>5,a=>-74,d=>2,j=>'SEM1',c=>0,h=>7,b=>0,g=>2,f=>'UE7',i=>-3}
b6ffffff807a0100ef010000
b6ffffff807a0100ef010000
b6ffffff807a0100ef010000
ffffffb6015e8000f7800000
b6ffffff807a0100ef010000
b6ffffff807a0100ef010000
ffffffb6015e8000f7800000
b6ffffff807a0100ef010000
ffffffb6015e8000f7800000
-
{e=>5,a=>94,d=>-1,j=>'SEM4',c=>3,h=>3,b=>5,g=>2,f=>'UE6',i=>-3}
5e000000dd6b01002b010000
5e000000dd6b01002b010000
5e000000dd6b01002b010000
0000005eafdc800076000000
5e000000dd6b01002b010000
5e000000dd6b01002b010000
0000005eafdc800076000000
5e000000dd6b01002b010000
0000005eafdc800076000000
-
{e=>6,a=>-63,d=>-3,j=>'SE2',c=>3,h=>3,b=>5,g=>1,f=>'UE1',i=>2}
c1ffffff5d9d000093000000
c1ffffff5d9d000093000000
c1ffffff5d9d000093000000
ffffffc1aee2400069000000
c1ffffff5d9d000093000000
c1ffffff5d9d000093000000
ffffffc1aee2400069000000
c1ffffff5d9d000093000000
ffffffc1aee2400069000000
-
{e=>2,a=>15,d=>3,j=>'SEM3',c=>0,h=>2,b=>4,g=>5,f=>'UE7',i=>-4}
0f000000c4f4020062010000
0f000000c4f4020062010000
0f000000c4f4020062010000
0000000f81af400052800000
0f000000c4f4020062010000
0f000000c4f4020062010000
0000000f81af400052800000
0f000000c4f4020062010000
0000000f81af400052800000
-
{e=>4,a=>-16,d=>-4,j=>'SEM4',c=>-3,h=>4,b=>7,g=>2,f=>'UE3',i=>1}
f0ffffff2f3901000c010000
f0ffffff2f3901000c010000
f0ffffff2f3901000c010000
fffffff0f646800086000000
f0ffffff2f3901000c010000
f0ffffff2f3901000c010000
fffffff0f646800086000000
f0ffffff2f3901000c010000
fffffff0f646800086000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
};
-
{e=>7,a=>-113,d=>0,j=>'SE3',c=>2,k=>96,h=>4,b=>7,g=>5,f=>'UE3',i=>0}
8fffffff17be0200c4006000
8fffffff17be0200c4006000
8fffffff17be0200c4006000
ffffff8fe877400081806000
8fffffff17be0200c4006000
8fffffff17be0200c4006000
ffffff8fe877400081806000
8fffffff17be0200c4006000
ffffff8fe877400081806000
-
{e=>2,a=>-5,d=>-4,j=>'SEM4',c=>-1,k=>28,h=>2,b=>4,g=>0,f=>'UE0',i=>1}
fbffffff3c0500000a011c00
fbffffff3c0500000a011c00
fbffffff3c0500000a011c00
fffffffb9e20000046001c00
fbffffff3c0500000a011c00
fbffffff3c0500000a011c00
fffffffb9e20000046001c00
fbffffff3c0500000a011c00
fffffffb9e20000046001c00
-
{e=>5,a=>52,d=>-3,j=>'SE3',c=>-3,k=>-1,h=>2,b=>6,g=>1,f=>'UE6',i=>1}
340000006eeb0000ca00ff00
340000006eeb0000ca00ff00
340000006eeb0000ca00ff00
00000034d6dc40004580ff00
340000006eeb0000ca00ff00
340000006eeb0000ca00ff00
00000034d6dc40004580ff00
340000006eeb0000ca00ff00
00000034d6dc40004580ff00
-
{e=>4,a=>-47,d=>-3,j=>'SE2',c=>2,k=>112,h=>6,b=>3,g=>2,f=>'UE3',i=>1}
d1ffffff533901008e007000
d1ffffff533901008e007000
d1ffffff533901008e007000
ffffffd16ac68000c5007000
d1ffffff533901008e007000
d1ffffff533901008e007000
ffffffd16ac68000c5007000
d1ffffff533901008e007000
ffffffd16ac68000c5007000
-
{e=>4,a=>-78,d=>2,j=>'SE3',c=>2,k=>55,h=>1,b=>0,g=>5,f=>'UE2',i=>1}
b2ffffff90a80200c9003700
b2ffffff90a80200c9003700
b2ffffff90a80200c9003700
ffffffb20945400025803700
b2ffffff90a80200c9003700
b2ffffff90a80200c9003700
ffffffb20945400025803700
b2ffffff90a80200c9003700
ffffffb20945400025803700
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>0,a=>-33,d=>-4,j=>'SEM1',l=>0,c=>-2,k=>46,h=>6,b=>0,g=>3,f=>'UE7',i=>-2}
dfffffff30f10100f6012e00
dfffffff30f10100f6012e00
dfffffff30f10100f6012e00
ffffffdf1a0ec000db802e00
dfffffff30f10100f6012e00
dfffffff30f10100f6012e00
ffffffdf1a0ec000db802e00
dfffffff30f10100f6012e00
ffffffdf1a0ec000db802e00
-
{e=>3,a=>78,d=>-4,j=>'SE3',l=>1,c=>-1,k=>-21,h=>5,b=>3,g=>5,f=>'UE2',i=>-3}
4e0000003ba70200ed00eb01
4e0000003ba70200ed00eb01
4e0000003ba70200ed00eb01
0000004e7e354000b580eb20
4e0000003ba70200ed00eb01
4e0000003ba70200ed00eb01
0000004e7e354000b580eb20
4e0000003ba70200ed00eb01
0000004e7e354000b580eb20
-
{e=>3,a=>-6,d=>0,j=>'SE0',l=>2,c=>-1,k=>54,h=>1,b=>1,g=>0,f=>'UE6',i=>2}
faffffff3966000011003602
faffffff3966000011003602
faffffff3966000011003602
fffffffa3c3c000028003640
faffffff3966000011003602
faffffff3966000011003602
fffffffa3c3c000028003640
faffffff3966000011003602
fffffffa3c3c000028003640
-
{e=>3,a=>-92,d=>2,j=>'SEM2',l=>3,c=>-3,k=>28,h=>0,b=>5,g=>6,f=>'UE1',i=>0}
a4ffffffad16030080011c03
a4ffffffad16030080011c03
a4ffffffad16030080011c03
ffffffa4b533800003001c60
a4ffffffad16030080011c03
a4ffffffad16030080011c03
ffffffa4b533800003001c60
a4ffffffad16030080011c03
ffffffa4b533800003001c60
-
{e=>0,a=>109,d=>3,j=>'SE1',l=>7,c=>-1,k=>116,h=>4,b=>4,g=>6,f=>'UE3',i=>-3}
6d000000fc3003006c007407
6d000000fc3003006c007407
6d000000fc3003006c007407
0000006d9d878000948074e0
6d000000fc3003006c007407
6d000000fc3003006c007407
0000006d9d878000948074e0
6d000000fc3003006c007407
0000006d9d878000948074e0
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>1,a=>61,m=>0,d=>3,j=>'SEM3',l=>5,c=>-4,k=>-68,h=>1,b=>6,g=>5,f=>'UE4',i=>0}
3d000000e6c202004101bc05
3d000000e6c202004101bc05
3d000000e6c202004101bc05
0000003dd19940002280bca0
3d000000e6c202004101bc05
3d000000e6c202004101bc05
0000003dd19940002280bca0
3d000000e6c202004101bc05
0000003dd19940002280bca0
-
{e=>2,a=>-25,m=>-1,d=>2,j=>'SE2',l=>3,c=>-2,k=>-89,h=>3,b=>3,g=>4,f=>'UE1',i=>0}
e7ffffffb31402008300a73b
e7ffffffb31402008300a73b
e7ffffffb31402008300a73b
ffffffe7792300006100a77c
e7ffffffb31402008300a73b
e7ffffffb31402008300a73b
ffffffe7792300006100a77c
e7ffffffb31402008300a73b
ffffffe7792300006100a77c
-
{e=>2,a=>14,m=>0,d=>3,j=>'SEM3',l=>7,c=>1,k=>75,h=>6,b=>7,g=>6,f=>'UE5',i=>0}
0e000000cf54030046014b07
0e000000cf54030046014b07
0e000000cf54030046014b07
0000000ee5ab8000c2804be0
0e000000cf54030046014b07
0e000000cf54030046014b07
0000000ee5ab8000c2804be0
0e000000cf54030046014b07
0000000ee5ab8000c2804be0
-
{e=>6,a=>-81,m=>-2,d=>3,j=>'SEM1',l=>1,c=>3,k=>45,h=>1,b=>0,g=>2,f=>'UE7',i=>-4}
afffffffd87c0100e1012d31
afffffffd87c0100e1012d31
afffffffd87c0100e1012d31
ffffffaf0dee800033802d38
afffffffd87c0100e1012d31
afffffffd87c0100e1012d31
ffffffaf0dee800033802d38
afffffffd87c0100e1012d31
ffffffaf0dee800033802d38
-
{e=>0,a=>-15,m=>-2,d=>2,j=>'SEM1',l=>6,c=>-4,k=>52,h=>4,b=>4,g=>4,f=>'UE1',i=>2}
f1ffffffa4100200d4013436
f1ffffffa4100200d4013436
f1ffffffa4100200d4013436
fffffff1910300008b8034d8
f1ffffffa4100200d4013436
f1ffffffa4100200d4013436
fffffff1910300008b8034d8
f1ffffffa4100200d4013436
fffffff1910300008b8034d8
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>7,n=>3,a=>-25,m=>2,d=>0,j=>'SE0',l=>5,c=>3,k=>-128,h=>6,b=>7,g=>1,f=>'UE4',i=>2}
e7ffffff1fce00001600801503000000
e7ffffff1fce00001600801503000000
e7ffffff1fce00001600801503000000
ffffffe7ec784000c80080a860000000
e7ffffff1fce00001600801503000000
e7ffffff1fce00001600801503000000
ffffffe7ec784000c80080a860000000
e7ffffff1fce00001600801503000000
ffffffe7ec784000c80080a860000000
-
{e=>4,n=>1,a=>31,m=>2,d=>-1,j=>'SE2',l=>0,c=>-1,k=>-106,h=>3,b=>0,g=>2,f=>'UE7',i=>0}
1f000000f87901008300961001000000
1f000000f87901008300961001000000
1f000000f87901008300961001000000
0000001f1fce80006100960820000000
1f000000f87901008300961001000000
1f000000f87901008300961001000000
0000001f1fce80006100960820000000
1f000000f87901008300961001000000
0000001f1fce80006100960820000000
-
{e=>7,n=>5,a=>42,m=>-4,d=>-4,j=>'SEM2',l=>3,c=>-4,k=>82,h=>1,b=>6,g=>7,f=>'UE0',i=>-1}
2a000000268f0300b901522305000000
2a000000268f0300b901522305000000
2a000000268f0300b901522305000000
0000002ad271c0003f005270a0000000
2a000000268f0300b901522305000000
2a000000268f0300b901522305000000
0000002ad271c0003f005270a0000000
2a000000268f0300b901522305000000
0000002ad271c0003f005270a0000000
-
{e=>3,n=>5,a=>51,m=>-4,d=>2,j=>'SEM4',l=>7,c=>3,k=>-87,h=>1,b=>2,g=>0,f=>'UE5',i=>0}
330000009a5600000101a92705000000
330000009a5600000101a92705000000
330000009a5600000101a92705000000
000000334d3a00002200a9f0a0000000
330000009a5600000101a92705000000
330000009a5600000101a92705000000
000000334d3a00002200a9f0a0000000
330000009a5600000101a92705000000
000000334d3a00002200a9f0a0000000
-
{e=>0,n=>7,a=>31,m=>-3,d=>2,j=>'SE1',l=>2,c=>2,k=>-41,h=>5,b=>4,g=>6,f=>'UE1',i=>2}
1f000000941003005500d72a07000000
1f000000941003005500d72a07000000
1f000000941003005500d72a07000000
0000001f89038000a880d754e0000000
1f000000941003005500d72a07000000
1f000000941003005500d72a07000000
0000001f89038000a880d754e0000000
1f000000941003005500d72a07000000
0000001f89038000a880d754e0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  int a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>0,n=>6,a=>-128,m=>-1,d=>0,j=>'SE2',l=>1,c=>0,k=>-95,h=>3,b=>5,g=>7,f=>'UE6',o=>62,i=>2}
80ffffff05e003009300a139063e0000
80ffffff05e003009300a139063e0000
80ffffff05e003009300a139063e0000
ffffff80a00dc0006900a13cc03e0000
80ffffff05e003009300a139063e0000
80ffffff05e003009300a139063e0000
ffffff80a00dc0006900a13cc03e0000
80ffffff05e003009300a139063e0000
ffffff80a00dc0006900a13cc03e0000
-
{e=>3,n=>5,a=>-9,m=>-4,d=>1,j=>'SEM1',l=>3,c=>3,k=>-61,h=>2,b=>6,g=>0,f=>'UE5',o=>76,i=>1}
f7ffffff5e560000ca01c323054c0000
f7ffffff5e560000ca01c323054c0000
f7ffffff5e560000ca01c323054c0000
fffffff7ccba00004780c370a04c0000
f7ffffff5e560000ca01c323054c0000
f7ffffff5e560000ca01c323054c0000
fffffff7ccba00004780c370a04c0000
f7ffffff5e560000ca01c323054c0000
fffffff7ccba00004780c370a04c0000
-
{e=>4,n=>7,a=>15,m=>1,d=>-2,j=>'SEM2',l=>6,c=>2,k=>-46,h=>3,b=>5,g=>4,f=>'UE0',o=>51,i=>-1}
0f00000095090200bb01d20e07330000
0f00000095090200bb01d20e07330000
0f00000095090200bb01d20e07330000
0000000fab4100007f00d2c4e0330000
0f00000095090200bb01d20e07330000
0f00000095090200bb01d20e07330000
0000000fab4100007f00d2c4e0330000
0f00000095090200bb01d20e07330000
0000000fab4100007f00d2c4e0330000
-
{e=>7,n=>2,a=>-103,m=>2,d=>2,j=>'SEM3',l=>3,c=>-2,k=>75,h=>4,b=>7,g=>4,f=>'UE2',o=>76,i=>-1}
99ffffffb72e02007c014b13024c0000
99ffffffb72e02007c014b13024c0000
99ffffffb72e02007c014b13024c0000
ffffff99f97500009e804b68404c0000
99ffffffb72e02007c014b13024c0000
99ffffffb72e02007c014b13024c0000
ffffff99f97500009e804b68404c0000
99ffffffb72e02007c014b13024c0000
ffffff99f97500009e804b68404c0000
-
{e=>6,n=>2,a=>-114,m=>-3,d=>-4,j=>'SEM1',l=>5,c=>-2,k=>88,h=>6,b=>0,g=>5,f=>'UE3',o=>44,i=>-3}
8effffff30bd0200ee01582d022c0000
8effffff30bd0200ee01582d022c0000
8effffff30bd0200ee01582d022c0000
ffffff8e1a674000d78058b4402c0000
8effffff30bd0200ee01582d022c0000
8effffff30bd0200ee01582d022c0000
ffffff8e1a674000d78058b4402c0000
8effffff30bd0200ee01582d022c0000
ffffff8e1a674000d78058b4402c0000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
};
-
{a=>20,b=>5}
1400000005000000
14000000000000000500000000000000
14000000000000000500000000000000
00000014a0000000
1400000005000000
1400000005000000
0000000000000014a000000000000000
1400000005000000
00000014a0000000
-
{a=>-55,b=>5}
c9ffffff05000000
c9ffffffffffffff0500000000000000
c9ffffffffffffff0500000000000000
ffffffc9a0000000
c9ffffff05000000
c9ffffff05000000
ffffffffffffffc9a000000000000000
c9ffffff05000000
ffffffc9a0000000
-
{a=>98,b=>5}
6200000005000000
62000000000000000500000000000000
62000000000000000500000000000000
00000062a0000000
6200000005000000
6200000005000000
0000000000000062a000000000000000
6200000005000000
00000062a0000000
-
{a=>-119,b=>4}
89ffffff04000000
89ffffffffffffff0400000000000000
89ffffffffffffff0400000000000000
ffffff8980000000
89ffffff04000000
89ffffff04000000
ffffffffffffff898000000000000000
89ffffff04000000
ffffff8980000000
-
{a=>-90,b=>0}
a6ffffff00000000
a6ffffffffffffff0000000000000000
a6ffffffffffffff0000000000000000
ffffffa600000000
a6ffffff00000000
a6ffffff00000000
ffffffffffffffa60000000000000000
a6ffffff00000000
ffffffa600000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
};
-
{c=>-3,a=>-84,b=>3}
acffffff2b000000
acffffffffffffff2b00000000000000
acffffffffffffff2b00000000000000
ffffffac74000000
acffffff2b000000
acffffff2b000000
ffffffffffffffac7400000000000000
acffffff2b000000
ffffffac74000000
-
{c=>-4,a=>5,b=>3}
0500000023000000
05000000000000002300000000000000
05000000000000002300000000000000
0000000570000000
0500000023000000
0500000023000000
00000000000000057000000000000000
0500000023000000
0000000570000000
-
{c=>0,a=>-27,b=>6}
e5ffffff06000000
e5ffffffffffffff0600000000000000
e5ffffffffffffff0600000000000000
ffffffe5c0000000
e5ffffff06000000
e5ffffff06000000
ffffffffffffffe5c000000000000000
e5ffffff06000000
ffffffe5c0000000
-
{c=>1,a=>41,b=>1}
2900000009000000
29000000000000000900000000000000
29000000000000000900000000000000
0000002924000000
2900000009000000
2900000009000000
00000000000000292400000000000000
2900000009000000
0000002924000000
-
{c=>2,a=>-56,b=>5}
c8ffffff15000000
c8ffffffffffffff1500000000000000
c8ffffffffffffff1500000000000000
ffffffc8a8000000
c8ffffff15000000
c8ffffff15000000
ffffffffffffffc8a800000000000000
c8ffffff15000000
ffffffc8a8000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
};
-
{c=>-3,a=>38,b=>5,d=>-1}
26000000ed010000
2600000000000000ed01000000000000
2600000000000000ed01000000000000
00000026b7800000
26000000ed010000
26000000ed010000
0000000000000026b780000000000000
26000000ed010000
00000026b7800000
-
{c=>-4,a=>-66,b=>1,d=>2}
beffffffa1000000
beffffffffffffffa100000000000000
beffffffffffffffa100000000000000
ffffffbe31000000
beffffffa1000000
beffffffa1000000
ffffffffffffffbe3100000000000000
beffffffa1000000
ffffffbe31000000
-
{c=>-2,a=>-17,b=>2,d=>0}
efffffff32000000
efffffffffffffff3200000000000000
efffffffffffffff3200000000000000
ffffffef58000000
efffffff32000000
efffffff32000000
ffffffffffffffef5800000000000000
efffffff32000000
ffffffef58000000
-
{c=>-3,a=>-93,b=>4,d=>3}
a3ffffffec000000
a3ffffffffffffffec00000000000000
a3ffffffffffffffec00000000000000
ffffffa395800000
a3ffffffec000000
a3ffffffec000000
ffffffffffffffa39580000000000000
a3ffffffec000000
ffffffa395800000
-
{c=>3,a=>83,b=>6,d=>0}
530000001e000000
53000000000000001e00000000000000
53000000000000001e00000000000000
00000053cc000000
530000001e000000
530000001e000000
0000000000000053cc00000000000000
530000001e000000
00000053cc000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
};
-
{e=>3,c=>-2,a=>79,b=>7,d=>-1}
4f000000f7070000
4f00000000000000f707000000000000
4f00000000000000f707000000000000
0000004ffbb00000
4f000000f7070000
4f000000f7070000
000000000000004ffbb0000000000000
4f000000f7070000
0000004ffbb00000
-
{e=>0,c=>2,a=>118,b=>4,d=>-4}
7600000014010000
76000000000000001401000000000000
76000000000000001401000000000000
000000768a000000
7600000014010000
7600000014010000
00000000000000768a00000000000000
7600000014010000
000000768a000000
-
{e=>6,c=>0,a=>-24,b=>0,d=>3}
e8ffffffc00c0000
e8ffffffffffffffc00c000000000000
e8ffffffffffffffc00c000000000000
ffffffe801e00000
e8ffffffc00c0000
e8ffffffc00c0000
ffffffffffffffe801e0000000000000
e8ffffffc00c0000
ffffffe801e00000
-
{e=>4,c=>-1,a=>-90,b=>3,d=>-3}
a6ffffff7b090000
a6ffffffffffffff7b09000000000000
a6ffffffffffffff7b09000000000000
ffffffa67ec00000
a6ffffff7b090000
a6ffffff7b090000
ffffffffffffffa67ec0000000000000
a6ffffff7b090000
ffffffa67ec00000
-
{e=>3,c=>1,a=>80,b=>3,d=>2}
500000008b060000
50000000000000008b06000000000000
50000000000000008b06000000000000
0000005065300000
500000008b060000
500000008b060000
00000000000000506530000000000000
500000008b060000
0000005065300000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
};
-
{e=>0,c=>-3,a=>-26,b=>6,d=>-1,f=>'UE1'}
e6ffffffee110000
e6ffffffffffffffee11000000000000
e6ffffffffffffffee11000000000000
ffffffe6d7820000
e6ffffffee110000
e6ffffffee110000
ffffffffffffffe6d782000000000000
e6ffffffee110000
ffffffe6d7820000
-
{e=>4,c=>2,a=>124,b=>4,d=>-4,f=>'UE2'}
7c00000014290000
7c000000000000001429000000000000
7c000000000000001429000000000000
0000007c8a440000
7c00000014290000
7c00000014290000
000000000000007c8a44000000000000
7c00000014290000
0000007c8a440000
-
{e=>7,c=>-2,a=>-9,b=>1,d=>3,f=>'UE2'}
f7fffffff12e0000
f7fffffffffffffff12e000000000000
f7fffffffffffffff12e000000000000
fffffff739f40000
f7fffffff12e0000
f7fffffff12e0000
fffffffffffffff739f4000000000000
f7fffffff12e0000
fffffff739f40000
-
{e=>7,c=>0,a=>122,b=>4,d=>2,f=>'UE5'}
7a000000845e0000
7a00000000000000845e000000000000
7a00000000000000845e000000000000
0000007a817a0000
7a000000845e0000
7a000000845e0000
000000000000007a817a000000000000
7a000000845e0000
0000007a817a0000
-
{e=>1,c=>-4,a=>-12,b=>6,d=>-4,f=>'UE4'}
f4ffffff26430000
f4ffffffffffffff2643000000000000
f4ffffffffffffff2643000000000000
fffffff4d2180000
f4ffffff26430000
f4ffffff26430000
fffffffffffffff4d218000000000000
f4ffffff26430000
fffffff4d2180000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
};
-
{e=>7,c=>-4,a=>-80,g=>7,b=>2,d=>3,f=>'UE2'}
b0ffffffe2ae0300
b0ffffffffffffffe2ae030000000000
b0ffffffffffffffe2ae030000000000
ffffffb051f5c000
b0ffffffe2ae0300
b0ffffffe2ae0300
ffffffffffffffb051f5c00000000000
b0ffffffe2ae0300
ffffffb051f5c000
-
{e=>1,c=>2,a=>93,g=>2,b=>1,d=>3,f=>'UE0'}
5d000000d1020100
5d00000000000000d102010000000000
5d00000000000000d102010000000000
0000005d29908000
5d000000d1020100
5d000000d1020100
000000000000005d2990800000000000
5d000000d1020100
0000005d29908000
-
{e=>0,c=>0,a=>-46,g=>2,b=>3,d=>-3,f=>'UE6'}
d2ffffff43610100
d2ffffffffffffff4361010000000000
d2ffffffffffffff4361010000000000
ffffffd2628c8000
d2ffffff43610100
d2ffffff43610100
ffffffffffffffd2628c800000000000
d2ffffff43610100
ffffffd2628c8000
-
{e=>4,c=>1,a=>120,g=>0,b=>2,d=>1,f=>'UE6'}
780000004a680000
78000000000000004a68000000000000
78000000000000004a68000000000000
0000007844cc0000
780000004a680000
780000004a680000
000000000000007844cc000000000000
780000004a680000
0000007844cc0000
-
{e=>3,c=>0,a=>19,g=>6,b=>7,d=>-4,f=>'UE0'}
1300000007070300
13000000000000000707030000000000
13000000000000000707030000000000
00000013e2318000
1300000007070300
1300000007070300
0000000000000013e231800000000000
1300000007070300
00000013e2318000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
};
-
{e=>6,c=>-2,a=>-99,g=>4,b=>1,d=>0,f=>'UE0'}
9dffffff310c0200
9dffffffffffffff310c020000000000
9dffffffffffffff310c020000000000
ffffff9d38610000
9dffffff310c0200
9dffffff310c0200
ffffffffffffff9d3861000000000000
9dffffff310c0200
ffffff9d38610000
-
{e=>0,c=>0,a=>-111,g=>1,b=>4,d=>-1,f=>'UE6'}
91ffffffc4e10000
91ffffffffffffffc4e1000000000000
91ffffffffffffffc4e1000000000000
ffffff91838c4000
91ffffffc4e10000
91ffffffc4e10000
ffffffffffffff91838c400000000000
91ffffffc4e10000
ffffff91838c4000
-
{e=>0,c=>1,a=>106,g=>1,b=>3,d=>3,f=>'UE0'}
6a000000cb800000
6a00000000000000cb80000000000000
6a00000000000000cb80000000000000
0000006a65804000
6a000000cb800000
6a000000cb800000
000000000000006a6580400000000000
6a000000cb800000
0000006a65804000
-
{e=>4,c=>-3,a=>94,g=>0,b=>2,d=>1,f=>'UE6'}
5e0000006a680000
5e000000000000006a68000000000000
5e000000000000006a68000000000000
0000005e54cc0000
5e0000006a680000
5e0000006a680000
000000000000005e54cc000000000000
5e0000006a680000
0000005e54cc0000
-
{e=>7,c=>-4,a=>-48,g=>2,b=>3,d=>2,f=>'UE6'}
d0ffffffa36e0100
d0ffffffffffffffa36e010000000000
d0ffffffffffffffa36e010000000000
ffffffd0717c8000
d0ffffffa36e0100
d0ffffffa36e0100
ffffffffffffffd0717c800000000000
d0ffffffa36e0100
ffffffd0717c8000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
};
-
{e=>4,a=>-127,d=>2,c=>-2,h=>0,b=>1,g=>6,f=>'UE0'}
81ffffffb108030000000000
81ffffffffffffffb108030000000000
81ffffffffffffffb108030000000000
ffffff813941800000000000
81ffffffb108030000000000
81ffffffb108030000000000
ffffffffffffff813941800000000000
81ffffffb108030000000000
ffffff813941800000000000
-
{e=>0,a=>16,d=>-2,c=>-1,h=>5,b=>0,g=>2,f=>'UE6'}
10000000b861010005000000
1000000000000000b861010005000000
1000000000000000b861010005000000
000000101f0c8000a0000000
10000000b861010005000000
10000000b861010005000000
00000000000000101f0c8000a0000000
10000000b861010005000000
000000101f0c8000a0000000
-
{e=>7,a=>-107,d=>2,c=>0,h=>1,b=>6,g=>7,f=>'UE5'}
95ffffff86de030001000000
95ffffffffffffff86de030001000000
95ffffffffffffff86de030001000000
ffffff95c17bc00020000000
95ffffff86de030001000000
95ffffff86de030001000000
ffffffffffffff95c17bc00020000000
95ffffff86de030001000000
ffffff95c17bc00020000000
-
{e=>3,a=>53,d=>-2,c=>0,h=>0,b=>0,g=>5,f=>'UE0'}
350000008087020000000000
35000000000000008087020000000000
35000000000000008087020000000000
000000350331400000000000
350000008087020000000000
350000008087020000000000
00000000000000350331400000000000
350000008087020000000000
000000350331400000000000
-
{e=>5,a=>33,d=>3,c=>0,h=>6,b=>7,g=>3,f=>'UE7'}
21000000c7fa010006000000
2100000000000000c7fa010006000000
2100000000000000c7fa010006000000
00000021e1dec000c0000000
21000000c7fa010006000000
21000000c7fa010006000000
0000000000000021e1dec000c0000000
21000000c7fa010006000000
00000021e1dec000c0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
};
-
{e=>1,a=>3,d=>0,c=>1,h=>4,b=>3,g=>2,f=>'UE0',i=>-2}
030000000b02010034000000
03000000000000000b02010034000000
03000000000000000b02010034000000
000000036410800098000000
030000000b02010034000000
030000000b02010034000000
00000000000000036410800098000000
030000000b02010034000000
000000036410800098000000
-
{e=>1,a=>-126,d=>0,c=>0,h=>1,b=>1,g=>7,f=>'UE7',i=>-4}
82ffffff01f2030021000000
82ffffffffffffff01f2030021000000
82ffffffffffffff01f2030021000000
ffffff82201fc00030000000
82ffffff01f2030021000000
82ffffff01f2030021000000
ffffffffffffff82201fc00030000000
82ffffff01f2030021000000
ffffff82201fc00030000000
-
{e=>2,a=>58,d=>2,c=>-2,h=>1,b=>2,g=>4,f=>'UE4',i=>0}
3a000000b244020001000000
3a00000000000000b244020001000000
3a00000000000000b244020001000000
0000003a5929000020000000
3a000000b244020001000000
3a000000b244020001000000
000000000000003a5929000020000000
3a000000b244020001000000
0000003a5929000020000000
-
{e=>4,a=>66,d=>-4,c=>-3,h=>7,b=>2,g=>5,f=>'UE4',i=>-4}
420000002ac9020027000000
42000000000000002ac9020027000000
42000000000000002ac9020027000000
0000004256494000f0000000
420000002ac9020027000000
420000002ac9020027000000
000000000000004256494000f0000000
420000002ac9020027000000
0000004256494000f0000000
-
{e=>5,a=>9,d=>-1,c=>3,h=>4,b=>3,g=>3,f=>'UE3',i=>3}
09000000dbbb01001c000000
0900000000000000dbbb01001c000000
0900000000000000dbbb01001c000000
000000096fd6c0008c000000
09000000dbbb01001c000000
09000000dbbb01001c000000
00000000000000096fd6c0008c000000
09000000dbbb01001c000000
000000096fd6c0008c000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
};
-
{e=>6,a=>73,d=>2,j=>'SEM3',c=>-1,h=>3,b=>0,g=>6,f=>'UE4',i=>0}
49000000b84c030043010000
4900000000000000b84c030043010000
4900000000000000b84c030043010000
000000491d69800062800000
49000000b84c030043010000
49000000b84c030043010000
00000000000000491d69800062800000
49000000b84c030043010000
000000491d69800062800000
-
{e=>1,a=>24,d=>0,j=>'SEM2',c=>-3,h=>7,b=>5,g=>1,f=>'UE3',i=>3}
180000002db200009f010000
18000000000000002db200009f010000
18000000000000002db200009f010000
00000018b4164000ef000000
180000002db200009f010000
180000002db200009f010000
0000000000000018b4164000ef000000
180000002db200009f010000
00000018b4164000ef000000
-
{e=>0,a=>-128,d=>0,j=>'SEM3',c=>1,h=>4,b=>7,g=>1,f=>'UE0',i=>-1}
80ffffff0f8000007c010000
80ffffffffffffff0f8000007c010000
80ffffffffffffff0f8000007c010000
ffffff80e40040009e800000
80ffffff0f8000007c010000
80ffffff0f8000007c010000
ffffffffffffff80e40040009e800000
80ffffff0f8000007c010000
ffffff80e40040009e800000
-
{e=>5,a=>-96,d=>1,j=>'SE1',c=>-2,h=>4,b=>4,g=>7,f=>'UE3',i=>-2}
a0ffffff74ba030074000000
a0ffffffffffffff74ba030074000000
a0ffffffffffffff74ba030074000000
ffffffa098d7c00098800000
a0ffffff74ba030074000000
a0ffffff74ba030074000000
ffffffffffffffa098d7c00098800000
a0ffffff74ba030074000000
ffffffa098d7c00098800000
-
{e=>0,a=>54,d=>-1,j=>'SEM1',c=>-3,h=>3,b=>5,g=>0,f=>'UE7',i=>3}
36000000ed710000db010000
3600000000000000ed710000db010000
3600000000000000ed710000db010000
00000036b78e00006f800000
36000000ed710000db010000
36000000ed710000db010000
0000000000000036b78e00006f800000
36000000ed710000db010000
00000036b78e00006f800000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
};
-
{e=>3,a=>-71,d=>-2,j=>'SEM2',c=>-3,k=>-37,h=>1,b=>1,g=>2,f=>'UE1',i=>1}
b9ffffffa91701008901db00
b9ffffffffffffffa91701008901db00
b9ffffffffffffffa91701008901db00
ffffffb9373280002700db00
b9ffffffa91701008901db00
b9ffffffa91701008901db00
ffffffffffffffb9373280002700db00
b9ffffffa91701008901db00
ffffffb9373280002700db00
-
{e=>6,a=>14,d=>1,j=>'SE2',c=>-3,k=>-10,h=>2,b=>0,g=>7,f=>'UE1',i=>1}
0e000000689c03008a00f600
0e00000000000000689c03008a00f600
0e00000000000000689c03008a00f600
0000000e14e3c0004500f600
0e000000689c03008a00f600
0e000000689c03008a00f600
000000000000000e14e3c0004500f600
0e000000689c03008a00f600
0000000e14e3c0004500f600
-
{e=>1,a=>-4,d=>-4,j=>'SE1',c=>0,k=>-70,h=>2,b=>0,g=>7,f=>'UE0',i=>-2}
fcffffff008303007200ba00
fcffffffffffffff008303007200ba00
fcffffffffffffff008303007200ba00
fffffffc0211c0005880ba00
fcffffff008303007200ba00
fcffffff008303007200ba00
fffffffffffffffc0211c0005880ba00
fcffffff008303007200ba00
fffffffc0211c0005880ba00
-
{e=>0,a=>-105,d=>0,j=>'SEM1',c=>3,k=>-94,h=>3,b=>4,g=>4,f=>'UE1',i=>1}
97ffffff1c100200cb01a200
97ffffffffffffff1c100200cb01a200
97ffffffffffffff1c100200cb01a200
ffffff978c0300006780a200
97ffffff1c100200cb01a200
97ffffff1c100200cb01a200
ffffffffffffff978c0300006780a200
97ffffff1c100200cb01a200
ffffff978c0300006780a200
-
{e=>0,a=>-18,d=>3,j=>'SEM4',c=>0,k=>76,h=>6,b=>7,g=>7,f=>'UE1',i=>-3}
eeffffffc79003002e014c00
eeffffffffffffffc79003002e014c00
eeffffffffffffffc79003002e014c00
ffffffeee183c000d6004c00
eeffffffc79003002e014c00
eeffffffc79003002e014c00
ffffffffffffffeee183c000d6004c00
eeffffffc79003002e014c00
ffffffeee183c000d6004c00
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
};
-
{e=>0,a=>-72,d=>1,j=>'SE1',l=>1,c=>2,k=>-123,h=>6,b=>0,g=>0,f=>'UE0',i=>2}
b8ffffff5000000056008501
b8ffffffffffffff5000000056008501
b8ffffffffffffff5000000056008501
ffffffb808800000c8808520
b8ffffff5000000056008501
b8ffffff5000000056008501
ffffffffffffffb808800000c8808520
b8ffffff5000000056008501
ffffffb808800000c8808520
-
{e=>4,a=>38,d=>0,j=>'SE3',l=>3,c=>-3,k=>109,h=>0,b=>0,g=>6,f=>'UE4',i=>-2}
2600000028480300f0006d03
260000000000000028480300f0006d03
260000000000000028480300f0006d03
000000261449800019806d60
2600000028480300f0006d03
2600000028480300f0006d03
00000000000000261449800019806d60
2600000028480300f0006d03
000000261449800019806d60
-
{e=>1,a=>-38,d=>0,j=>'SEM4',l=>7,c=>1,k=>88,h=>4,b=>5,g=>1,f=>'UE2',i=>0}
daffffff0da2000004015807
daffffffffffffff0da2000004015807
daffffffffffffff0da2000004015807
ffffffdaa4144000820058e0
daffffff0da2000004015807
daffffff0da2000004015807
ffffffffffffffdaa4144000820058e0
daffffff0da2000004015807
ffffffdaa4144000820058e0
-
{e=>3,a=>-30,d=>-3,j=>'SEM3',l=>1,c=>0,k=>47,h=>7,b=>3,g=>4,f=>'UE1',i=>1}
e2ffffff431702004f012f01
e2ffffffffffffff431702004f012f01
e2ffffffffffffff431702004f012f01
ffffffe262b30000e6802f20
e2ffffff431702004f012f01
e2ffffff431702004f012f01
ffffffffffffffe262b30000e6802f20
e2ffffff431702004f012f01
ffffffe262b30000e6802f20
-
{e=>2,a=>49,d=>-4,j=>'SEM3',l=>5,c=>2,k=>101,h=>0,b=>0,g=>1,f=>'UE5',i=>-4}
3100000010d5000060016505
310000000000000010d5000060016505
310000000000000010d5000060016505
000000310a2a4000128065a0
3100000010d5000060016505
3100000010d5000060016505
00000000000000310a2a4000128065a0
3100000010d5000060016505
000000310a2a4000128065a0
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
};
-
{e=>2,a=>72,m=>-1,d=>-1,j=>'SE1',l=>2,c=>-3,k=>28,h=>7,b=>0,g=>6,f=>'UE7',i=>0}
48000000e875030047001c3a
4800000000000000e875030047001c3a
4800000000000000e875030047001c3a
0000004817af8000e0801c5c
48000000e875030047001c3a
48000000e875030047001c3a
000000000000004817af8000e0801c5c
48000000e875030047001c3a
0000004817af8000e0801c5c
-
{e=>5,a=>-114,m=>3,d=>3,j=>'SE0',l=>7,c=>-3,k=>-79,h=>1,b=>2,g=>6,f=>'UE1',i=>2}
8effffffea1a03001100b11f
8effffffffffffffea1a03001100b11f
8effffffffffffffea1a03001100b11f
ffffff8e55d380002800b1ec
8effffffea1a03001100b11f
8effffffea1a03001100b11f
ffffffffffffff8e55d380002800b1ec
8effffffea1a03001100b11f
ffffff8e55d380002800b1ec
-
{e=>6,a=>-48,m=>1,d=>-3,j=>'SE2',l=>2,c=>-3,k=>78,h=>0,b=>5,g=>1,f=>'UE7',i=>-4}
d0ffffff6dfd0000a0004e0a
d0ffffffffffffff6dfd0000a0004e0a
d0ffffffffffffff6dfd0000a0004e0a
ffffffd0b6ee400011004e44
d0ffffff6dfd0000a0004e0a
d0ffffff6dfd0000a0004e0a
ffffffffffffffd0b6ee400011004e44
d0ffffff6dfd0000a0004e0a
ffffffd0b6ee400011004e44
-
{e=>5,a=>101,m=>-2,d=>3,j=>'SE3',l=>3,c=>-3,k=>-125,h=>5,b=>4,g=>0,f=>'UE1',i=>-3}
65000000ec1a0000ed008333
6500000000000000ec1a0000ed008333
6500000000000000ec1a0000ed008333
0000006595d20000b5808378
65000000ec1a0000ed008333
65000000ec1a0000ed008333
000000000000006595d20000b5808378
65000000ec1a0000ed008333
0000006595d20000b5808378
-
{e=>4,a=>-7,m=>2,d=>1,j=>'SE1',l=>7,c=>-2,k=>8,h=>4,b=>7,g=>5,f=>'UE1',i=>-2}
f9ffffff7798020074000817
f9ffffffffffffff7798020074000817
f9ffffffffffffff7798020074000817
fffffff9f8c34000988008e8
f9ffffff7798020074000817
f9ffffff7798020074000817
fffffffffffffff9f8c34000988008e8
f9ffffff7798020074000817
fffffff9f8c34000988008e8
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
};
-
{e=>3,n=>2,a=>-110,m=>-1,d=>3,j=>'SEM1',l=>6,c=>-3,k=>119,h=>0,b=>3,g=>3,f=>'UE4',i=>0}
92ffffffebc60100c001773e02000000
92ffffffffffffffebc60100c001773e0200000000000000
92ffffffffffffffebc60100c001773e0200000000000000
ffffff9275b8c000038077dc40000000
92ffffffebc60100c001773e02000000
92ffffffebc60100c001773e02000000
ffffffffffffff9275b8c000038077dc4000000000000000
92ffffffebc60100c001773e02000000
ffffff9275b8c000038077dc40000000
-
{e=>4,n=>0,a=>-68,m=>3,d=>-1,j=>'SEM4',l=>7,c=>0,k=>57,h=>0,b=>3,g=>7,f=>'UE7',i=>-2}
bcffffffc3f903003001391f00000000
bcffffffffffffffc3f903003001391f0000000000000000
bcffffffffffffffc3f903003001391f0000000000000000
ffffffbc63cfc0001a0039ec00000000
bcffffffc3f903003001391f00000000
bcffffffc3f903003001391f00000000
ffffffffffffffbc63cfc0001a0039ec0000000000000000
bcffffffc3f903003001391f00000000
ffffffbc63cfc0001a0039ec00000000
-
{e=>4,n=>6,a=>-6,m=>-2,d=>-1,j=>'SE1',l=>3,c=>3,k=>127,h=>3,b=>6,g=>5,f=>'UE3',i=>2}
faffffffdeb9020053007f3306000000
faffffffffffffffdeb9020053007f330600000000000000
faffffffffffffffdeb9020053007f330600000000000000
fffffffacfc7400068807f78c0000000
faffffffdeb9020053007f3306000000
faffffffdeb9020053007f3306000000
fffffffffffffffacfc7400068807f78c000000000000000
faffffffdeb9020053007f3306000000
fffffffacfc7400068807f78c0000000
-
{e=>1,n=>0,a=>-116,m=>-2,d=>1,j=>'SE1',l=>7,c=>-2,k=>-82,h=>7,b=>1,g=>4,f=>'UE7',i=>3}
8cffffff717202005f00ae3700000000
8cffffffffffffff717202005f00ae370000000000000000
8cffffffffffffff717202005f00ae370000000000000000
ffffff8c389f0000ec80aef800000000
8cffffff717202005f00ae3700000000
8cffffff717202005f00ae3700000000
ffffffffffffff8c389f0000ec80aef80000000000000000
8cffffff717202005f00ae3700000000
ffffff8c389f0000ec80aef800000000
-
{e=>5,n=>5,a=>122,m=>-3,d=>3,j=>'SEM2',l=>2,c=>-2,k=>31,h=>3,b=>1,g=>5,f=>'UE0',i=>1}
7a000000f18a02008b011f2a05000000
7a00000000000000f18a02008b011f2a0500000000000000
7a00000000000000f18a02008b011f2a0500000000000000
0000007a39d1400067001f54a0000000
7a000000f18a02008b011f2a05000000
7a000000f18a02008b011f2a05000000
000000000000007a39d1400067001f54a000000000000000
7a000000f18a02008b011f2a05000000
0000007a39d1400067001f54a0000000
=
typedef int foo;
enum en_u { UE0, UE1, UE2, UE3, UE4, UE5, UE6, UE7 };
enum en_s { SEM4=-4, SEM3, SEM2, SEM1, SE0, SE1, SE2, SE3 };

#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct enum_pack_2 {
  long a;
  unsigned int  b:3;
  signed   int  c:3;
  foo           d:3;
  unsigned char e:3;
  enum en_u     f:3;
  unsigned int  g:3;
  int            :0;
  unsigned char h:3;
  signed   char i:3;
  enum en_s     j:3;
  char          k;
  unsigned char l:3;
  signed   char m:3;
  unsigned int  n:3;
  unsigned char o;
};
-
{e=>5,n=>1,a=>-10,m=>1,d=>-1,j=>'SE2',l=>2,c=>0,k=>99,h=>6,b=>3,g=>7,f=>'UE6',o=>213,i=>-2}
f6ffffffc3eb0300b600630a01d50000
f6ffffffffffffffc3eb0300b600630a01d5000000000000
f6ffffffffffffffc3eb0300b600630a01d5000000000000
fffffff663ddc000d900634420d50000
f6ffffffc3eb0300b600630a01d50000
f6ffffffc3eb0300b600630a01d50000
fffffffffffffff663ddc000d900634420d5000000000000
f6ffffffc3eb0300b600630a01d50000
fffffff663ddc000d900634420d50000
-
{e=>0,n=>3,a=>53,m=>-2,d=>-1,j=>'SE1',l=>7,c=>1,k=>25,h=>3,b=>2,g=>5,f=>'UE3',o=>128,i=>3}
35000000cab102005b00193703800000
3500000000000000cab102005b0019370380000000000000
3500000000000000cab102005b0019370380000000000000
00000035478740006c8019f860800000
35000000cab102005b00193703800000
35000000cab102005b00193703800000
0000000000000035478740006c8019f86080000000000000
35000000cab102005b00193703800000
00000035478740006c8019f860800000
-
{e=>5,n=>2,a=>23,m=>1,d=>-2,j=>'SEM2',l=>3,c=>-3,k=>-114,h=>1,b=>1,g=>2,f=>'UE6',o=>170,i=>-4}
17000000a96b0100a1018e0b02aa0000
1700000000000000a96b0100a1018e0b02aa000000000000
1700000000000000a96b0100a1018e0b02aa000000000000
00000017375c800033008e6440aa0000
17000000a96b0100a1018e0b02aa0000
17000000a96b0100a1018e0b02aa0000
0000000000000017375c800033008e6440aa000000000000
17000000a96b0100a1018e0b02aa0000
00000017375c800033008e6440aa0000
-
{e=>7,n=>7,a=>-19,m=>-1,d=>-1,j=>'SE3',l=>2,c=>0,k=>-61,h=>3,b=>3,g=>7,f=>'UE6',o=>181,i=>-1}
edffffffc3ef0300fb00c33a07b50000
edffffffffffffffc3ef0300fb00c33a07b5000000000000
edffffffffffffffc3ef0300fb00c33a07b5000000000000
ffffffed63fdc0007d80c35ce0b50000
edffffffc3ef0300fb00c33a07b50000
edffffffc3ef0300fb00c33a07b50000
ffffffffffffffed63fdc0007d80c35ce0b5000000000000
edffffffc3ef0300fb00c33a07b50000
ffffffed63fdc0007d80c35ce0b50000
-
{e=>5,n=>5,a=>-62,m=>0,d=>-4,j=>'SEM4',l=>6,c=>-2,k=>-114,h=>3,b=>4,g=>6,f=>'UE0',o=>248,i=>3}
c2ffffff340b03001b018e0605f80000
c2ffffffffffffff340b03001b018e0605f8000000000000
c2ffffffffffffff340b03001b018e0605f8000000000000
ffffffc29a5180006e008ec0a0f80000
c2ffffff340b03001b018e0605f80000
c2ffffff340b03001b018e0605f80000
ffffffffffffffc29a5180006e008ec0a0f8000000000000
c2ffffff340b03001b018e0605f80000
ffffffc29a5180006e008ec0a0f80000
=
struct toobig {
  unsigned char  a:2;
};
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>2}
02
02
02
80
02000000
02
80
02
80
-
{a=>1}
01
01
01
40
01000000
01
40
01
40
-
{a=>1}
01
01
01
40
01000000
01
40
01
40
=
struct toobig {
  unsigned char  a:2;
  unsigned char  b:7;
};
-
{a=>0,b=>93}
005d
005d
005d
00ba
005d0000
005d
00ba
005d
00ba
-
{a=>3,b=>125}
037d
037d
037d
c0fa
037d0000
037d
c0fa
037d
c0fa
-
{a=>1,b=>103}
0167
0167
0167
40ce
01670000
0167
40ce
0167
40ce
-
{a=>0,b=>44}
002c
002c
002c
0058
002c0000
002c
0058
002c
0058
-
{a=>2,b=>56}
0238
0238
0238
8070
02380000
0238
8070
0238
8070
=
struct toobig {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
};
-
{a=>1,b=>105}
0169
0169
0169
40d2
01690000
0169
40d2
0169
40d2
-
{a=>1,b=>69}
0145
0145
0145
408a
01450000
0145
408a
0145
408a
-
{a=>0,b=>100}
0064
0064
0064
00c8
00640000
0064
00c8
0064
00c8
-
{a=>1,b=>64}
0140
0140
0140
4080
01400000
0140
4080
0140
4080
-
{a=>1,b=>29}
011d
011d
011d
403a
011d0000
011d
403a
011d
403a
=
struct toobig {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
};
-
{c=>2,a=>1,b=>120}
01780200
01780200
01780200
40f08000
01780200
01780200
40f08000
01780200
40f08000
-
{c=>3,a=>3,b=>117}
03750300
03750300
03750300
c0eac000
03750300
03750300
c0eac000
03750300
c0eac000
-
{c=>2,a=>3,b=>66}
03420200
03420200
03420200
c0848000
03420200
03420200
c0848000
03420200
c0848000
-
{c=>2,a=>3,b=>40}
03280200
03280200
03280200
c0508000
03280200
03280200
c0508000
03280200
c0508000
-
{c=>3,a=>1,b=>78}
014e0300
014e0300
014e0300
409cc000
014e0300
014e0300
409cc000
014e0300
409cc000
=
struct toobig {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
};
-
{c=>1,a=>0,b=>40,d=>29011}
002801005371
002801005371
002801005371
00504000e2a6
0028010053710000
002801005371
00504000e2a6
002801005371
00504000e2a6
-
{c=>1,a=>1,b=>52,d=>7870}
01340100be1e
01340100be1e
01340100be1e
406840003d7c
01340100be1e0000
01340100be1e
406840003d7c
01340100be1e
406840003d7c
-
{c=>3,a=>0,b=>127,d=>24484}
007f0300a45f
007f0300a45f
007f0300a45f
00fec000bf48
007f0300a45f0000
007f0300a45f
00fec000bf48
007f0300a45f
00fec000bf48
-
{c=>0,a=>1,b=>117,d=>2770}
01750000d20a
01750000d20a
01750000d20a
40ea000015a4
01750000d20a0000
01750000d20a
40ea000015a4
01750000d20a
40ea000015a4
-
{c=>0,a=>2,b=>117,d=>21525}
027500001554
027500001554
027500001554
80ea0000a82a
0275000015540000
027500001554
80ea0000a82a
027500001554
80ea0000a82a
=
struct toobig {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
};
-
{c=>0,a=>2,b=>47,d=>5532}
022f00009c150000
022f00009c150000
022f00009c150000
805e00002b380000
022f00009c150000
022f00009c150000
805e00002b380000
022f00009c150000
805e00002b380000
-
{c=>0,a=>2,b=>53,d=>17293}
023500008d430000
023500008d430000
023500008d430000
806a0000871a0000
023500008d430000
023500008d430000
806a0000871a0000
023500008d430000
806a0000871a0000
-
{c=>0,a=>0,b=>42,d=>15065}
002a0000d93a0000
002a0000d93a0000
002a0000d93a0000
0054000075b20000
002a0000d93a0000
002a0000d93a0000
0054000075b20000
002a0000d93a0000
0054000075b20000
-
{c=>1,a=>2,b=>43,d=>26082}
022b0100e2650000
022b0100e2650000
022b0100e2650000
80564000cbc40000
022b0100e2650000
022b0100e2650000
80564000cbc40000
022b0100e2650000
80564000cbc40000
-
{c=>2,a=>0,b=>3,d=>23011}
00030200e3590000
00030200e3590000
00030200e3590000
00068000b3c60000
00030200e3590000
00030200e3590000
00068000b3c60000
00030200e3590000
00068000b3c60000
=
struct toobig {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
  unsigned int   e:2;
};
-
{e=>0,c=>2,a=>1,b=>107,d=>14008}
016b0200b836000000000000
016b0200b836000000000000
016b0200b836000000000000
40d680006d70000000000000
016b0200b836000000000000
016b0200b836000000000000
40d680006d70000000000000
016b0200b836000000000000
40d680006d70000000000000
-
{e=>1,c=>1,a=>0,b=>109,d=>31882}
006d01008a7c000001000000
006d01008a7c000001000000
006d01008a7c000001000000
00da4000f914000040000000
006d01008a7c000001000000
006d01008a7c000001000000
00da4000f914000040000000
006d01008a7c000001000000
00da4000f914000040000000
-
{e=>2,c=>1,a=>0,b=>83,d=>27991}
00530100576d000002000000
00530100576d000002000000
00530100576d000002000000
00a64000daae000080000000
00530100576d000002000000
00530100576d000002000000
00a64000daae000080000000
00530100576d000002000000
00a64000daae000080000000
-
{e=>0,c=>3,a=>1,b=>74,d=>7214}
014a03002e1c000000000000
014a03002e1c000000000000
014a03002e1c000000000000
4094c000385c000000000000
014a03002e1c000000000000
014a03002e1c000000000000
4094c000385c000000000000
014a03002e1c000000000000
4094c000385c000000000000
-
{e=>0,c=>1,a=>0,b=>93,d=>28404}
005d0100f46e000000000000
005d0100f46e000000000000
005d0100f46e000000000000
00ba4000dde8000000000000
005d0100f46e000000000000
005d0100f46e000000000000
00ba4000dde8000000000000
005d0100f46e000000000000
00ba4000dde8000000000000
=
struct toobig {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
  unsigned int   e:2;
  unsigned int   f:31;
};
-
{e=>2,c=>3,a=>2,b=>66,d=>17839,f=>37720169}
02420300af4500000200000069903f02
02420300af4500000200000069903f02
02420300af4500000200000069903f02
8084c0008b5e000080000000047f20d2
02420300af4500000200000069903f02
02420300af4500000200000069903f02
8084c0008b5e000080000000047f20d2
02420300af4500000200000069903f02
8084c0008b5e000080000000047f20d2
-
{e=>2,c=>0,a=>2,b=>81,d=>29158,f=>19309962}
02510000e6710000020000008aa52601
02510000e6710000020000008aa52601
02510000e6710000020000008aa52601
80a20000e3cc000080000000024d4b14
02510000e6710000020000008aa52601
02510000e6710000020000008aa52601
80a20000e3cc000080000000024d4b14
02510000e6710000020000008aa52601
80a20000e3cc000080000000024d4b14
-
{e=>0,c=>1,a=>2,b=>98,d=>18169,f=>163308787}
02620100f946000000000000f3e4bb09
02620100f946000000000000f3e4bb09
02620100f946000000000000f3e4bb09
80c440008df20000000000001377c9e6
02620100f946000000000000f3e4bb09
02620100f946000000000000f3e4bb09
80c440008df20000000000001377c9e6
02620100f946000000000000f3e4bb09
80c440008df20000000000001377c9e6
-
{e=>0,c=>3,a=>3,b=>41,d=>24753,f=>707702915}
03290300b16000000000000083b02e2a
03290300b16000000000000083b02e2a
03290300b16000000000000083b02e2a
c052c000c162000000000000545d6106
03290300b16000000000000083b02e2a
03290300b16000000000000083b02e2a
c052c000c162000000000000545d6106
03290300b16000000000000083b02e2a
c052c000c162000000000000545d6106
-
{e=>3,c=>0,a=>2,b=>18,d=>28569,f=>199312493}
02120000996f0000030000006d44e10b
02120000996f0000030000006d44e10b
02120000996f0000030000006d44e10b
80240000df320000c000000017c288da
02120000996f0000030000006d44e10b
02120000996f0000030000006d44e10b
80240000df320000c000000017c288da
02120000996f0000030000006d44e10b
80240000df320000c000000017c288da
=
struct toobig {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
  unsigned int   e:2;
  unsigned int   f:31;
  unsigned char  g;
};
-
{e=>3,c=>0,a=>3,g=>253,b=>73,d=>20290,f=>324422081}
03490000424f000003000000c1495613fd000000
03490000424f000003000000c1495613fd000000
03490000424f000003000000c1495613fd000000
c09200009e840000c000000026ac9382fd000000
03490000424f000003000000c1495613fd000000
03490000424f000003000000c1495613fd000000
c09200009e840000c000000026ac9382fd000000
03490000424f000003000000c1495613fd000000
c09200009e840000c000000026ac9382fd000000
-
{e=>2,c=>1,a=>2,g=>98,b=>58,d=>14829,f=>1109100526}
023a0100ed39000002000000ee871b4262000000
023a0100ed39000002000000ee871b4262000000
023a0100ed39000002000000ee871b4262000000
8074400073da00008000000084370fdc62000000
023a0100ed39000002000000ee871b4262000000
023a0100ed39000002000000ee871b4262000000
8074400073da00008000000084370fdc62000000
023a0100ed39000002000000ee871b4262000000
8074400073da00008000000084370fdc62000000
-
{e=>1,c=>2,a=>3,g=>243,b=>82,d=>31588,f=>727978398}
03520200647b0000010000009e11642bf3000000
03520200647b0000010000009e11642bf3000000
03520200647b0000010000009e11642bf3000000
c0a48000f6c800004000000056c8233cf3000000
03520200647b0000010000009e11642bf3000000
03520200647b0000010000009e11642bf3000000
c0a48000f6c800004000000056c8233cf3000000
03520200647b0000010000009e11642bf3000000
c0a48000f6c800004000000056c8233cf3000000
-
{e=>1,c=>1,a=>1,g=>104,b=>26,d=>22162,f=>432784954}
011a010092560000010000003ac6cb1968000000
011a010092560000010000003ac6cb1968000000
011a010092560000010000003ac6cb1968000000
40344000ad2400004000000033978c7468000000
011a010092560000010000003ac6cb1968000000
011a010092560000010000003ac6cb1968000000
40344000ad2400004000000033978c7468000000
011a010092560000010000003ac6cb1968000000
40344000ad2400004000000033978c7468000000
-
{e=>0,c=>3,a=>3,g=>167,b=>62,d=>17539,f=>1939871904}
033e03008344000000000000a018a073a7000000
033e03008344000000000000a018a073a7000000
033e03008344000000000000a018a073a7000000
c07cc0008906000000000000e7403140a7000000
033e03008344000000000000a018a073a7000000
033e03008344000000000000a018a073a7000000
c07cc0008906000000000000e7403140a7000000
033e03008344000000000000a018a073a7000000
c07cc0008906000000000000e7403140a7000000
=
struct toobig {
  char a;
  unsigned char  b:2;
};
-
{a=>-24,b=>1}
e801
e801
e801
e840
e8010000
e801
e840
e801
e840
-
{a=>61,b=>3}
3d03
3d03
3d03
3dc0
3d030000
3d03
3dc0
3d03
3dc0
-
{a=>-95,b=>1}
a101
a101
a101
a140
a1010000
a101
a140
a101
a140
-
{a=>-2,b=>2}
fe02
fe02
fe02
fe80
fe020000
fe02
fe80
fe02
fe80
-
{a=>-71,b=>3}
b903
b903
b903
b9c0
b9030000
b903
b9c0
b903
b9c0
=
struct toobig {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>113,a=>-30,b=>1}
e20171
e20171
e20171
e240e2
e2017100
e20171
e240e2
e20171
e240e2
-
{c=>77,a=>93,b=>3}
5d034d
5d034d
5d034d
5dc09a
5d034d00
5d034d
5dc09a
5d034d
5dc09a
-
{c=>76,a=>-105,b=>0}
97004c
97004c
97004c
970098
97004c00
97004c
970098
97004c
970098
-
{c=>113,a=>-106,b=>0}
960071
960071
960071
9600e2
96007100
960071
9600e2
960071
9600e2
-
{c=>111,a=>21,b=>3}
15036f
15036f
15036f
15c0de
15036f00
15036f
15c0de
15036f
15c0de
=
struct toobig {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>117,a=>4,b=>0}
04007500
04007500
04007500
0400ea00
04007500
04007500
0400ea00
04007500
0400ea00
-
{c=>110,a=>92,b=>1}
5c016e00
5c016e00
5c016e00
5c40dc00
5c016e00
5c016e00
5c40dc00
5c016e00
5c40dc00
-
{c=>80,a=>1,b=>0}
01005000
01005000
01005000
0100a000
01005000
01005000
0100a000
01005000
0100a000
-
{c=>115,a=>49,b=>0}
31007300
31007300
31007300
3100e600
31007300
31007300
3100e600
31007300
3100e600
-
{c=>119,a=>-53,b=>1}
cb017700
cb017700
cb017700
cb40ee00
cb017700
cb017700
cb40ee00
cb017700
cb40ee00
=
struct toobig {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>119,a=>99,b=>1,d=>2}
630177000200
630177000200
630177000200
6340ee008000
6301770002000000
630177000200
6340ee008000
630177000200
6340ee008000
-
{c=>52,a=>-52,b=>2,d=>1}
cc0234000100
cc0234000100
cc0234000100
cc8068004000
cc02340001000000
cc0234000100
cc8068004000
cc0234000100
cc8068004000
-
{c=>59,a=>2,b=>2,d=>0}
02023b000000
02023b000000
02023b000000
028076000000
02023b0000000000
02023b000000
028076000000
02023b000000
028076000000
-
{c=>25,a=>59,b=>3,d=>1}
3b0319000100
3b0319000100
3b0319000100
3bc032004000
3b03190001000000
3b0319000100
3bc032004000
3b0319000100
3bc032004000
-
{c=>52,a=>-19,b=>0,d=>0}
ed0034000000
ed0034000000
ed0034000000
ed0068000000
ed00340000000000
ed0034000000
ed0068000000
ed0034000000
ed0068000000
=
struct toobig {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>10626,c=>62,a=>76,b=>3,d=>2}
4c033e0002008229
4c033e0002008229
4c033e0002008229
4cc07c0080005304
4c033e0002008229
4c033e0002008229
4cc07c0080005304
4c033e0002008229
4cc07c0080005304
-
{e=>16013,c=>106,a=>-123,b=>2,d=>2}
85026a0002008d3e
85026a0002008d3e
85026a0002008d3e
8580d40080007d1a
85026a0002008d3e
85026a0002008d3e
8580d40080007d1a
85026a0002008d3e
8580d40080007d1a
-
{e=>15778,c=>84,a=>-66,b=>1,d=>3}
be0154000300a23d
be0154000300a23d
be0154000300a23d
be40a800c0007b44
be0154000300a23d
be0154000300a23d
be40a800c0007b44
be0154000300a23d
be40a800c0007b44
-
{e=>3225,c=>25,a=>-124,b=>1,d=>1}
840119000100990c
840119000100990c
840119000100990c
8440320040001932
840119000100990c
840119000100990c
8440320040001932
840119000100990c
8440320040001932
-
{e=>27218,c=>32,a=>-118,b=>0,d=>2}
8a0020000200526a
8a0020000200526a
8a0020000200526a
8a0040008000d4a4
8a0020000200526a
8a0020000200526a
8a0040008000d4a4
8a0020000200526a
8a0040008000d4a4
=
struct toobig {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>21377,c=>115,a=>-29,b=>0,d=>3}
e300730003008153
e300730003008153
e300730003008153
e300e600c000a702
e300730003008153
e300730003008153
e300e600c000a702
e300730003008153
e300e600c000a702
-
{e=>21700,c=>42,a=>-64,b=>3,d=>0}
c0032a000000c454
c0032a000000c454
c0032a000000c454
c0c054000000a988
c0032a000000c454
c0032a000000c454
c0c054000000a988
c0032a000000c454
c0c054000000a988
-
{e=>20468,c=>93,a=>104,b=>0,d=>3}
68005d000300f44f
68005d000300f44f
68005d000300f44f
6800ba00c0009fe8
68005d000300f44f
68005d000300f44f
6800ba00c0009fe8
68005d000300f44f
6800ba00c0009fe8
-
{e=>31677,c=>22,a=>109,b=>2,d=>3}
6d0216000300bd7b
6d0216000300bd7b
6d0216000300bd7b
6d802c00c000f77a
6d0216000300bd7b
6d0216000300bd7b
6d802c00c000f77a
6d0216000300bd7b
6d802c00c000f77a
-
{e=>23636,c=>112,a=>-2,b=>1,d=>0}
fe0170000000545c
fe0170000000545c
fe0170000000545c
fe40e0000000b8a8
fe0170000000545c
fe0170000000545c
fe40e0000000b8a8
fe0170000000545c
fe40e0000000b8a8
=
struct toobig {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>1537,c=>102,a=>-45,b=>3,d=>3,f=>0}
d30366000300010600000000
d30366000300010600000000
d30366000300010600000000
d3c0cc00c0000c0200000000
d30366000300010600000000
d30366000300010600000000
d3c0cc00c0000c0200000000
d30366000300010600000000
d3c0cc00c0000c0200000000
-
{e=>22539,c=>10,a=>-66,b=>3,d=>1,f=>1}
be030a0001000b5801000000
be030a0001000b5801000000
be030a0001000b5801000000
bec014004000b01640000000
be030a0001000b5801000000
be030a0001000b5801000000
bec014004000b01640000000
be030a0001000b5801000000
bec014004000b01640000000
-
{e=>28767,c=>112,a=>28,b=>1,d=>1,f=>1}
1c01700001005f7001000000
1c01700001005f7001000000
1c01700001005f7001000000
1c40e0004000e0be40000000
1c01700001005f7001000000
1c01700001005f7001000000
1c40e0004000e0be40000000
1c01700001005f7001000000
1c40e0004000e0be40000000
-
{e=>10945,c=>37,a=>-128,b=>0,d=>0,f=>1}
800025000000c12a01000000
800025000000c12a01000000
800025000000c12a01000000
80004a000000558240000000
800025000000c12a01000000
800025000000c12a01000000
80004a000000558240000000
800025000000c12a01000000
80004a000000558240000000
-
{e=>7837,c=>65,a=>-30,b=>2,d=>1,f=>2}
e202410001009d1e02000000
e202410001009d1e02000000
e202410001009d1e02000000
e280820040003d3a80000000
e202410001009d1e02000000
e202410001009d1e02000000
e280820040003d3a80000000
e202410001009d1e02000000
e280820040003d3a80000000
=
struct toobig {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>16952,c=>81,a=>-69,g=>1806494585,b=>0,d=>0,f=>1}
bb005100000038420100000079ebac6b
bb005100000038420100000079ebac6b
bb005100000038420100000079ebac6b
bb00a2000000847040000000d759d6f2
bb005100000038420100000079ebac6b
bb005100000038420100000079ebac6b
bb00a2000000847040000000d759d6f2
bb005100000038420100000079ebac6b
bb00a2000000847040000000d759d6f2
-
{e=>22905,c=>42,a=>28,g=>718498820,b=>3,d=>3,f=>0}
1c032a000300795900000000046cd32a
1c032a000300795900000000046cd32a
1c032a000300795900000000046cd32a
1cc05400c000b2f20000000055a6d808
1c032a000300795900000000046cd32a
1c032a000300795900000000046cd32a
1cc05400c000b2f20000000055a6d808
1c032a000300795900000000046cd32a
1cc05400c000b2f20000000055a6d808
-
{e=>25314,c=>59,a=>-52,g=>851143488,b=>3,d=>3,f=>0}
cc033b000300e26200000000406bbb32
cc033b000300e26200000000406bbb32
cc033b000300e26200000000406bbb32
ccc07600c000c5c4000000006576d680
cc033b000300e26200000000406bbb32
cc033b000300e26200000000406bbb32
ccc07600c000c5c4000000006576d680
cc033b000300e26200000000406bbb32
ccc07600c000c5c4000000006576d680
-
{e=>9562,c=>91,a=>-56,g=>17470223,b=>0,d=>1,f=>0}
c8005b0001005a25000000000f930a01
c8005b0001005a25000000000f930a01
c8005b0001005a25000000000f930a01
c800b60040004ab4000000000215261e
c8005b0001005a25000000000f930a01
c8005b0001005a25000000000f930a01
c800b60040004ab4000000000215261e
c8005b0001005a25000000000f930a01
c800b60040004ab4000000000215261e
-
{e=>19455,c=>19,a=>7,g=>1006255369,b=>0,d=>2,f=>3}
070013000200ff4b03000000093dfa3b
070013000200ff4b03000000093dfa3b
070013000200ff4b03000000093dfa3b
07002600800097fec000000077f47a12
070013000200ff4b03000000093dfa3b
070013000200ff4b03000000093dfa3b
07002600800097fec000000077f47a12
070013000200ff4b03000000093dfa3b
07002600800097fec000000077f47a12
=
struct toobig {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>19431,a=>126,d=>3,c=>84,h=>119,b=>2,g=>10182399,f=>1}
7e0254000300e74b01000000ff5e9b0077000000
7e0254000300e74b01000000ff5e9b0077000000
7e0254000300e74b01000000ff5e9b0077000000
7e80a800c00097ce400000000136bdfe77000000
7e0254000300e74b01000000ff5e9b0077000000
7e0254000300e74b01000000ff5e9b0077000000
7e80a800c00097ce400000000136bdfe77000000
7e0254000300e74b01000000ff5e9b0077000000
7e80a800c00097ce400000000136bdfe77000000
-
{e=>1236,a=>51,d=>0,c=>82,h=>240,b=>2,g=>1480777427,f=>1}
330252000000d40401000000d3de4258f0000000
330252000000d40401000000d3de4258f0000000
330252000000d40401000000d3de4258f0000000
3380a400000009a840000000b085bda6f0000000
330252000000d40401000000d3de4258f0000000
330252000000d40401000000d3de4258f0000000
3380a400000009a840000000b085bda6f0000000
330252000000d40401000000d3de4258f0000000
3380a400000009a840000000b085bda6f0000000
-
{e=>30136,a=>-73,d=>2,c=>69,h=>69,b=>0,g=>579636421,f=>2}
b70045000200b87502000000c58c8c2245000000
b70045000200b87502000000c58c8c2245000000
b70045000200b87502000000c58c8c2245000000
b7008a008000eb70800000004519198a45000000
b70045000200b87502000000c58c8c2245000000
b70045000200b87502000000c58c8c2245000000
b7008a008000eb70800000004519198a45000000
b70045000200b87502000000c58c8c2245000000
b7008a008000eb70800000004519198a45000000
-
{e=>25530,a=>-39,d=>2,c=>73,h=>143,b=>3,g=>1327623552,f=>3}
d90349000200ba630300000080ed214f8f000000
d90349000200ba630300000080ed214f8f000000
d90349000200ba630300000080ed214f8f000000
d9c092008000c774c00000009e43db008f000000
d90349000200ba630300000080ed214f8f000000
d90349000200ba630300000080ed214f8f000000
d9c092008000c774c00000009e43db008f000000
d90349000200ba630300000080ed214f8f000000
d9c092008000c774c00000009e43db008f000000
-
{e=>29715,a=>81,d=>0,c=>33,h=>85,b=>0,g=>909633605,f=>1}
51002100000013740100000045e8373655000000
51002100000013740100000045e8373655000000
51002100000013740100000045e8373655000000
510042000000e826400000006c6fd08a55000000
51002100000013740100000045e8373655000000
51002100000013740100000045e8373655000000
510042000000e826400000006c6fd08a55000000
51002100000013740100000045e8373655000000
510042000000e826400000006c6fd08a55000000
=
struct toobig {
  short a;
  unsigned char  b:2;
};
-
{a=>-69,b=>3}
bbff0300
bbff0300
bbff0300
ffbbc000
bbff0300
bbff0300
ffbbc000
bbff0300
ffbbc000
-
{a=>-109,b=>1}
93ff0100
93ff0100
93ff0100
ff934000
93ff0100
93ff0100
ff934000
93ff0100
ff934000
-
{a=>68,b=>2}
44000200
44000200
44000200
00448000
44000200
44000200
00448000
44000200
00448000
-
{a=>-46,b=>1}
d2ff0100
d2ff0100
d2ff0100
ffd24000
d2ff0100
d2ff0100
ffd24000
d2ff0100
ffd24000
-
{a=>109,b=>0}
6d000000
6d000000
6d000000
006d0000
6d000000
6d000000
006d0000
6d000000
006d0000
=
struct toobig {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>54,a=>-126,b=>1}
82ff0136
82ff0136
82ff0136
ff82406c
82ff0136
82ff0136
ff82406c
82ff0136
ff82406c
-
{c=>117,a=>49,b=>0}
31000075
31000075
31000075
003100ea
31000075
31000075
003100ea
31000075
003100ea
-
{c=>60,a=>-49,b=>3}
cfff033c
cfff033c
cfff033c
ffcfc078
cfff033c
cfff033c
ffcfc078
cfff033c
ffcfc078
-
{c=>21,a=>117,b=>0}
75000015
75000015
75000015
0075002a
75000015
75000015
0075002a
75000015
0075002a
-
{c=>6,a=>-91,b=>2}
a5ff0206
a5ff0206
a5ff0206
ffa5800c
a5ff0206
a5ff0206
ffa5800c
a5ff0206
ffa5800c
=
struct toobig {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>126,a=>87,b=>0}
5700007e
5700007e
5700007e
005700fc
5700007e
5700007e
005700fc
5700007e
005700fc
-
{c=>27,a=>-45,b=>1}
d3ff011b
d3ff011b
d3ff011b
ffd34036
d3ff011b
d3ff011b
ffd34036
d3ff011b
ffd34036
-
{c=>6,a=>-11,b=>2}
f5ff0206
f5ff0206
f5ff0206
fff5800c
f5ff0206
f5ff0206
fff5800c
f5ff0206
fff5800c
-
{c=>55,a=>63,b=>0}
3f000037
3f000037
3f000037
003f006e
3f000037
3f000037
003f006e
3f000037
003f006e
-
{c=>121,a=>81,b=>0}
51000079
51000079
51000079
005100f2
51000079
51000079
005100f2
51000079
005100f2
=
struct toobig {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>11,a=>-34,b=>0,d=>1}
deff000b0100
deff000b0100
deff000b0100
ffde00164000
deff000b01000000
deff000b0100
ffde00164000
deff000b0100
ffde00164000
-
{c=>109,a=>-11,b=>2,d=>1}
f5ff026d0100
f5ff026d0100
f5ff026d0100
fff580da4000
f5ff026d01000000
f5ff026d0100
fff580da4000
f5ff026d0100
fff580da4000
-
{c=>79,a=>-9,b=>1,d=>2}
f7ff014f0200
f7ff014f0200
f7ff014f0200
fff7409e8000
f7ff014f02000000
f7ff014f0200
fff7409e8000
f7ff014f0200
fff7409e8000
-
{c=>12,a=>121,b=>3,d=>3}
7900030c0300
7900030c0300
7900030c0300
0079c018c000
7900030c03000000
7900030c0300
0079c018c000
7900030c0300
0079c018c000
-
{c=>3,a=>-105,b=>1,d=>0}
97ff01030000
97ff01030000
97ff01030000
ff9740060000
97ff010300000000
97ff01030000
ff9740060000
97ff01030000
ff9740060000
=
struct toobig {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>16815,c=>31,a=>-103,b=>3,d=>0}
99ff031f0000af41
99ff031f0000af41
99ff031f0000af41
ff99c03e0000835e
99ff031f0000af41
99ff031f0000af41
ff99c03e0000835e
99ff031f0000af41
ff99c03e0000835e
-
{e=>30240,c=>36,a=>-51,b=>1,d=>2}
cdff012402002076
cdff012402002076
cdff012402002076
ffcd40488000ec40
cdff012402002076
cdff012402002076
ffcd40488000ec40
cdff012402002076
ffcd40488000ec40
-
{e=>7916,c=>40,a=>47,b=>3,d=>1}
2f0003280100ec1e
2f0003280100ec1e
2f0003280100ec1e
002fc05040003dd8
2f0003280100ec1e
2f0003280100ec1e
002fc05040003dd8
2f0003280100ec1e
002fc05040003dd8
-
{e=>18293,c=>39,a=>19,b=>3,d=>2}
1300032702007547
1300032702007547
1300032702007547
0013c04e80008eea
1300032702007547
1300032702007547
0013c04e80008eea
1300032702007547
0013c04e80008eea
-
{e=>20458,c=>127,a=>-47,b=>1,d=>3}
d1ff017f0300ea4f
d1ff017f0300ea4f
d1ff017f0300ea4f
ffd140fec0009fd4
d1ff017f0300ea4f
d1ff017f0300ea4f
ffd140fec0009fd4
d1ff017f0300ea4f
ffd140fec0009fd4
=
struct toobig {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>4625,c=>71,a=>-47,b=>0,d=>0}
d1ff004700001112
d1ff004700001112
d1ff004700001112
ffd1008e00002422
d1ff004700001112
d1ff004700001112
ffd1008e00002422
d1ff004700001112
ffd1008e00002422
-
{e=>32168,c=>81,a=>26,b=>2,d=>1}
1a0002510100a87d
1a0002510100a87d
1a0002510100a87d
001a80a24000fb50
1a0002510100a87d
1a0002510100a87d
001a80a24000fb50
1a0002510100a87d
001a80a24000fb50
-
{e=>16938,c=>8,a=>95,b=>0,d=>2}
5f00000802002a42
5f00000802002a42
5f00000802002a42
005f001080008454
5f00000802002a42
5f00000802002a42
005f001080008454
5f00000802002a42
005f001080008454
-
{e=>7085,c=>73,a=>-59,b=>0,d=>1}
c5ff00490100ad1b
c5ff00490100ad1b
c5ff00490100ad1b
ffc500924000375a
c5ff00490100ad1b
c5ff00490100ad1b
ffc500924000375a
c5ff00490100ad1b
ffc500924000375a
-
{e=>22949,c=>98,a=>-95,b=>2,d=>0}
a1ff02620000a559
a1ff02620000a559
a1ff02620000a559
ffa180c40000b34a
a1ff02620000a559
a1ff02620000a559
ffa180c40000b34a
a1ff02620000a559
ffa180c40000b34a
=
struct toobig {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>15082,c=>111,a=>-95,b=>0,d=>0,f=>2}
a1ff006f0000ea3a02000000
a1ff006f0000ea3a02000000
a1ff006f0000ea3a02000000
ffa100de000075d480000000
a1ff006f0000ea3a02000000
a1ff006f0000ea3a02000000
ffa100de000075d480000000
a1ff006f0000ea3a02000000
ffa100de000075d480000000
-
{e=>2765,c=>57,a=>35,b=>3,d=>0,f=>3}
230003390000cd0a03000000
230003390000cd0a03000000
230003390000cd0a03000000
0023c0720000159ac0000000
230003390000cd0a03000000
230003390000cd0a03000000
0023c0720000159ac0000000
230003390000cd0a03000000
0023c0720000159ac0000000
-
{e=>10395,c=>112,a=>-21,b=>2,d=>3,f=>1}
ebff027003009b2801000000
ebff027003009b2801000000
ebff027003009b2801000000
ffeb80e0c000513640000000
ebff027003009b2801000000
ebff027003009b2801000000
ffeb80e0c000513640000000
ebff027003009b2801000000
ffeb80e0c000513640000000
-
{e=>27935,c=>81,a=>-93,b=>3,d=>1,f=>3}
a3ff035101001f6d03000000
a3ff035101001f6d03000000
a3ff035101001f6d03000000
ffa3c0a24000da3ec0000000
a3ff035101001f6d03000000
a3ff035101001f6d03000000
ffa3c0a24000da3ec0000000
a3ff035101001f6d03000000
ffa3c0a24000da3ec0000000
-
{e=>9978,c=>10,a=>-112,b=>2,d=>1,f=>0}
90ff020a0100fa2600000000
90ff020a0100fa2600000000
90ff020a0100fa2600000000
ff90801440004df400000000
90ff020a0100fa2600000000
90ff020a0100fa2600000000
ff90801440004df400000000
90ff020a0100fa2600000000
ff90801440004df400000000
=
struct toobig {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>7540,c=>19,a=>-11,g=>1471494247,b=>0,d=>2,f=>2}
f5ff00130200741d020000006738b557
f5ff00130200741d020000006738b557
f5ff00130200741d020000006738b557
fff5002680003ae880000000af6a70ce
f5ff00130200741d020000006738b557
f5ff00130200741d020000006738b557
fff5002680003ae880000000af6a70ce
f5ff00130200741d020000006738b557
fff5002680003ae880000000af6a70ce
-
{e=>21082,c=>15,a=>-52,g=>380642011,b=>2,d=>3,f=>0}
ccff020f03005a5200000000db22b016
ccff020f03005a5200000000db22b016
ccff020f03005a5200000000db22b016
ffcc801ec000a4b4000000002d6045b6
ccff020f03005a5200000000db22b016
ccff020f03005a5200000000db22b016
ffcc801ec000a4b4000000002d6045b6
ccff020f03005a5200000000db22b016
ffcc801ec000a4b4000000002d6045b6
-
{e=>20626,c=>108,a=>-96,g=>1260212640,b=>2,d=>1,f=>2}
a0ff026c0100925002000000a0511d4b
a0ff026c0100925002000000a0511d4b
a0ff026c0100925002000000a0511d4b
ffa080d84000a12480000000963aa340
a0ff026c0100925002000000a0511d4b
a0ff026c0100925002000000a0511d4b
ffa080d84000a12480000000963aa340
a0ff026c0100925002000000a0511d4b
ffa080d84000a12480000000963aa340
-
{e=>9472,c=>8,a=>-4,g=>1691591019,b=>2,d=>1,f=>2}
fcff020801000025020000006ba1d364
fcff020801000025020000006ba1d364
fcff020801000025020000006ba1d364
fffc801040004a0080000000c9a742d6
fcff020801000025020000006ba1d364
fcff020801000025020000006ba1d364
fffc801040004a0080000000c9a742d6
fcff020801000025020000006ba1d364
fffc801040004a0080000000c9a742d6
-
{e=>9356,c=>8,a=>78,g=>959851153,b=>3,d=>3,f=>2}
4e00030803008c2402000000912a3639
4e00030803008c2402000000912a3639
4e00030803008c2402000000912a3639
004ec010c000491880000000726c5522
4e00030803008c2402000000912a3639
4e00030803008c2402000000912a3639
004ec010c000491880000000726c5522
4e00030803008c2402000000912a3639
004ec010c000491880000000726c5522
=
struct toobig {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>15569,a=>49,d=>0,c=>98,h=>100,b=>2,g=>783521155,f=>1}
310002620000d13c010000008395b32e64000000
310002620000d13c010000008395b32e64000000
310002620000d13c010000008395b32e64000000
003180c4000079a2400000005d672b0664000000
310002620000d13c010000008395b32e64000000
310002620000d13c010000008395b32e64000000
003180c4000079a2400000005d672b0664000000
310002620000d13c010000008395b32e64000000
003180c4000079a2400000005d672b0664000000
-
{e=>16972,a=>63,d=>1,c=>69,h=>90,b=>2,g=>609013294,f=>3}
3f00024501004c42030000002ece4c245a000000
3f00024501004c42030000002ece4c245a000000
3f00024501004c42030000002ece4c245a000000
003f808a40008498c000000048999c5c5a000000
3f00024501004c42030000002ece4c245a000000
3f00024501004c42030000002ece4c245a000000
003f808a40008498c000000048999c5c5a000000
3f00024501004c42030000002ece4c245a000000
003f808a40008498c000000048999c5c5a000000
-
{e=>28524,a=>82,d=>1,c=>98,h=>95,b=>0,g=>948610449,f=>0}
5200006201006c6f0000000091a58a385f000000
5200006201006c6f0000000091a58a385f000000
5200006201006c6f0000000091a58a385f000000
005200c44000ded80000000071154b225f000000
5200006201006c6f0000000091a58a385f000000
5200006201006c6f0000000091a58a385f000000
005200c44000ded80000000071154b225f000000
5200006201006c6f0000000091a58a385f000000
005200c44000ded80000000071154b225f000000
-
{e=>15555,a=>-7,d=>0,c=>124,h=>184,b=>1,g=>1579365922,f=>3}
f9ff017c0000c33c030000002236235eb8000000
f9ff017c0000c33c030000002236235eb8000000
f9ff017c0000c33c030000002236235eb8000000
fff940f800007986c0000000bc466c44b8000000
f9ff017c0000c33c030000002236235eb8000000
f9ff017c0000c33c030000002236235eb8000000
fff940f800007986c0000000bc466c44b8000000
f9ff017c0000c33c030000002236235eb8000000
fff940f800007986c0000000bc466c44b8000000
-
{e=>30807,a=>89,d=>3,c=>74,h=>1,b=>3,g=>681792943,f=>3}
5900034a0300577803000000af55a32801000000
5900034a0300577803000000af55a32801000000
5900034a0300577803000000af55a32801000000
0059c094c000f0aec00000005146ab5e01000000
5900034a0300577803000000af55a32801000000
5900034a0300577803000000af55a32801000000
0059c094c000f0aec00000005146ab5e01000000
5900034a0300577803000000af55a32801000000
0059c094c000f0aec00000005146ab5e01000000
=
struct toobig {
  int a;
  unsigned char  b:2;
};
-
{a=>95,b=>2}
5f00000002000000
5f00000002000000
5f00000002000000
0000005f80000000
5f00000002000000
5f00000002000000
0000005f80000000
5f00000002000000
0000005f80000000
-
{a=>81,b=>1}
5100000001000000
5100000001000000
5100000001000000
0000005140000000
5100000001000000
5100000001000000
0000005140000000
5100000001000000
0000005140000000
-
{a=>-17,b=>1}
efffffff01000000
efffffff01000000
efffffff01000000
ffffffef40000000
efffffff01000000
efffffff01000000
ffffffef40000000
efffffff01000000
ffffffef40000000
-
{a=>-1,b=>2}
ffffffff02000000
ffffffff02000000
ffffffff02000000
ffffffff80000000
ffffffff02000000
ffffffff02000000
ffffffff80000000
ffffffff02000000
ffffffff80000000
-
{a=>117,b=>2}
7500000002000000
7500000002000000
7500000002000000
0000007580000000
7500000002000000
7500000002000000
0000007580000000
7500000002000000
0000007580000000
=
struct toobig {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>67,a=>69,b=>0}
4500000000430000
4500000000430000
4500000000430000
0000004500860000
4500000000430000
4500000000430000
0000004500860000
4500000000430000
0000004500860000
-
{c=>61,a=>-71,b=>3}
b9ffffff033d0000
b9ffffff033d0000
b9ffffff033d0000
ffffffb9c07a0000
b9ffffff033d0000
b9ffffff033d0000
ffffffb9c07a0000
b9ffffff033d0000
ffffffb9c07a0000
-
{c=>36,a=>-65,b=>0}
bfffffff00240000
bfffffff00240000
bfffffff00240000
ffffffbf00480000
bfffffff00240000
bfffffff00240000
ffffffbf00480000
bfffffff00240000
ffffffbf00480000
-
{c=>115,a=>-65,b=>2}
bfffffff02730000
bfffffff02730000
bfffffff02730000
ffffffbf80e60000
bfffffff02730000
bfffffff02730000
ffffffbf80e60000
bfffffff02730000
ffffffbf80e60000
-
{c=>98,a=>-9,b=>1}
f7ffffff01620000
f7ffffff01620000
f7ffffff01620000
fffffff740c40000
f7ffffff01620000
f7ffffff01620000
fffffff740c40000
f7ffffff01620000
fffffff740c40000
=
struct toobig {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>110,a=>-90,b=>2}
a6ffffff026e0000
a6ffffff026e0000
a6ffffff026e0000
ffffffa680dc0000
a6ffffff026e0000
a6ffffff026e0000
ffffffa680dc0000
a6ffffff026e0000
ffffffa680dc0000
-
{c=>89,a=>109,b=>3}
6d00000003590000
6d00000003590000
6d00000003590000
0000006dc0b20000
6d00000003590000
6d00000003590000
0000006dc0b20000
6d00000003590000
0000006dc0b20000
-
{c=>119,a=>55,b=>2}
3700000002770000
3700000002770000
3700000002770000
0000003780ee0000
3700000002770000
3700000002770000
0000003780ee0000
3700000002770000
0000003780ee0000
-
{c=>78,a=>-95,b=>2}
a1ffffff024e0000
a1ffffff024e0000
a1ffffff024e0000
ffffffa1809c0000
a1ffffff024e0000
a1ffffff024e0000
ffffffa1809c0000
a1ffffff024e0000
ffffffa1809c0000
-
{c=>108,a=>-76,b=>2}
b4ffffff026c0000
b4ffffff026c0000
b4ffffff026c0000
ffffffb480d80000
b4ffffff026c0000
b4ffffff026c0000
ffffffb480d80000
b4ffffff026c0000
ffffffb480d80000
=
struct toobig {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>67,a=>-11,b=>2,d=>2}
f5ffffff02430200
f5ffffff02430200
f5ffffff02430200
fffffff580868000
f5ffffff02430200
f5ffffff02430200
fffffff580868000
f5ffffff02430200
fffffff580868000
-
{c=>94,a=>-43,b=>2,d=>0}
d5ffffff025e0000
d5ffffff025e0000
d5ffffff025e0000
ffffffd580bc0000
d5ffffff025e0000
d5ffffff025e0000
ffffffd580bc0000
d5ffffff025e0000
ffffffd580bc0000
-
{c=>13,a=>12,b=>0,d=>3}
0c000000000d0300
0c000000000d0300
0c000000000d0300
0000000c001ac000
0c000000000d0300
0c000000000d0300
0000000c001ac000
0c000000000d0300
0000000c001ac000
-
{c=>20,a=>75,b=>1,d=>3}
4b00000001140300
4b00000001140300
4b00000001140300
0000004b4028c000
4b00000001140300
4b00000001140300
0000004b4028c000
4b00000001140300
0000004b4028c000
-
{c=>16,a=>99,b=>2,d=>0}
6300000002100000
6300000002100000
6300000002100000
0000006380200000
6300000002100000
6300000002100000
0000006380200000
6300000002100000
0000006380200000
=
struct toobig {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>15944,c=>81,a=>-88,b=>1,d=>1}
a8ffffff01510100483e0000
a8ffffff01510100483e0000
a8ffffff01510100483e0000
ffffffa840a240007c900000
a8ffffff01510100483e0000
a8ffffff01510100483e0000
ffffffa840a240007c900000
a8ffffff01510100483e0000
ffffffa840a240007c900000
-
{e=>28784,c=>113,a=>-26,b=>3,d=>2}
e6ffffff0371020070700000
e6ffffff0371020070700000
e6ffffff0371020070700000
ffffffe6c0e28000e0e00000
e6ffffff0371020070700000
e6ffffff0371020070700000
ffffffe6c0e28000e0e00000
e6ffffff0371020070700000
ffffffe6c0e28000e0e00000
-
{e=>25323,c=>4,a=>3,b=>2,d=>3}
0300000002040300eb620000
0300000002040300eb620000
0300000002040300eb620000
000000038008c000c5d60000
0300000002040300eb620000
0300000002040300eb620000
000000038008c000c5d60000
0300000002040300eb620000
000000038008c000c5d60000
-
{e=>5631,c=>25,a=>126,b=>2,d=>2}
7e00000002190200ff150000
7e00000002190200ff150000
7e00000002190200ff150000
0000007e803280002bfe0000
7e00000002190200ff150000
7e00000002190200ff150000
0000007e803280002bfe0000
7e00000002190200ff150000
0000007e803280002bfe0000
-
{e=>30242,c=>81,a=>43,b=>1,d=>2}
2b0000000151020022760000
2b0000000151020022760000
2b0000000151020022760000
0000002b40a28000ec440000
2b0000000151020022760000
2b0000000151020022760000
0000002b40a28000ec440000
2b0000000151020022760000
0000002b40a28000ec440000
=
struct toobig {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>26399,c=>49,a=>-62,b=>2,d=>1}
c2ffffff023101001f670000
c2ffffff023101001f670000
c2ffffff023101001f670000
ffffffc280624000ce3e0000
c2ffffff023101001f670000
c2ffffff023101001f670000
ffffffc280624000ce3e0000
c2ffffff023101001f670000
ffffffc280624000ce3e0000
-
{e=>29626,c=>6,a=>-98,b=>2,d=>1}
9effffff02060100ba730000
9effffff02060100ba730000
9effffff02060100ba730000
ffffff9e800c4000e7740000
9effffff02060100ba730000
9effffff02060100ba730000
ffffff9e800c4000e7740000
9effffff02060100ba730000
ffffff9e800c4000e7740000
-
{e=>10198,c=>108,a=>64,b=>2,d=>1}
40000000026c0100d6270000
40000000026c0100d6270000
40000000026c0100d6270000
0000004080d840004fac0000
40000000026c0100d6270000
40000000026c0100d6270000
0000004080d840004fac0000
40000000026c0100d6270000
0000004080d840004fac0000
-
{e=>10521,c=>124,a=>34,b=>0,d=>3}
22000000007c030019290000
22000000007c030019290000
22000000007c030019290000
0000002200f8c00052320000
22000000007c030019290000
22000000007c030019290000
0000002200f8c00052320000
22000000007c030019290000
0000002200f8c00052320000
-
{e=>25536,c=>37,a=>88,b=>3,d=>3}
5800000003250300c0630000
5800000003250300c0630000
5800000003250300c0630000
00000058c04ac000c7800000
5800000003250300c0630000
5800000003250300c0630000
00000058c04ac000c7800000
5800000003250300c0630000
00000058c04ac000c7800000
=
struct toobig {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>22897,c=>65,a=>-113,b=>1,d=>3,f=>2}
8fffffff014103007159000002000000
8fffffff014103007159000002000000
8fffffff014103007159000002000000
ffffff8f4082c000b2e2000080000000
8fffffff014103007159000002000000
8fffffff014103007159000002000000
ffffff8f4082c000b2e2000080000000
8fffffff014103007159000002000000
ffffff8f4082c000b2e2000080000000
-
{e=>28655,c=>21,a=>107,b=>1,d=>3,f=>0}
6b00000001150300ef6f000000000000
6b00000001150300ef6f000000000000
6b00000001150300ef6f000000000000
0000006b402ac000dfde000000000000
6b00000001150300ef6f000000000000
6b00000001150300ef6f000000000000
0000006b402ac000dfde000000000000
6b00000001150300ef6f000000000000
0000006b402ac000dfde000000000000
-
{e=>11486,c=>82,a=>27,b=>0,d=>2,f=>1}
1b00000000520200de2c000001000000
1b00000000520200de2c000001000000
1b00000000520200de2c000001000000
0000001b00a4800059bc000040000000
1b00000000520200de2c000001000000
1b00000000520200de2c000001000000
0000001b00a4800059bc000040000000
1b00000000520200de2c000001000000
0000001b00a4800059bc000040000000
-
{e=>8829,c=>47,a=>-44,b=>2,d=>1,f=>3}
d4ffffff022f01007d22000003000000
d4ffffff022f01007d22000003000000
d4ffffff022f01007d22000003000000
ffffffd4805e400044fa0000c0000000
d4ffffff022f01007d22000003000000
d4ffffff022f01007d22000003000000
ffffffd4805e400044fa0000c0000000
d4ffffff022f01007d22000003000000
ffffffd4805e400044fa0000c0000000
-
{e=>24395,c=>33,a=>-122,b=>1,d=>0,f=>0}
86ffffff012100004b5f000000000000
86ffffff012100004b5f000000000000
86ffffff012100004b5f000000000000
ffffff8640420000be96000000000000
86ffffff012100004b5f000000000000
86ffffff012100004b5f000000000000
ffffff8640420000be96000000000000
86ffffff012100004b5f000000000000
ffffff8640420000be96000000000000
=
struct toobig {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>21026,c=>66,a=>92,g=>1659281310,b=>0,d=>2,f=>1}
5c0000000042020022520000010000009e9fe662
5c0000000042020022520000010000009e9fe662
5c0000000042020022520000010000009e9fe662
0000005c00848000a444000040000000c5cd3f3c
5c0000000042020022520000010000009e9fe662
5c0000000042020022520000010000009e9fe662
0000005c00848000a444000040000000c5cd3f3c
5c0000000042020022520000010000009e9fe662
0000005c00848000a444000040000000c5cd3f3c
-
{e=>12920,c=>104,a=>10,g=>2107984876,b=>2,d=>2,f=>2}
0a000000026802007832000002000000ec4ba57d
0a000000026802007832000002000000ec4ba57d
0a000000026802007832000002000000ec4ba57d
0000000a80d0800064f0000080000000fb4a97d8
0a000000026802007832000002000000ec4ba57d
0a000000026802007832000002000000ec4ba57d
0000000a80d0800064f0000080000000fb4a97d8
0a000000026802007832000002000000ec4ba57d
0000000a80d0800064f0000080000000fb4a97d8
-
{e=>3821,c=>93,a=>-11,g=>664990743,b=>1,d=>0,f=>0}
f5ffffff015d0000ed0e00000000000017f4a227
f5ffffff015d0000ed0e00000000000017f4a227
f5ffffff015d0000ed0e00000000000017f4a227
fffffff540ba00001dda0000000000004f45e82e
f5ffffff015d0000ed0e00000000000017f4a227
f5ffffff015d0000ed0e00000000000017f4a227
fffffff540ba00001dda0000000000004f45e82e
f5ffffff015d0000ed0e00000000000017f4a227
fffffff540ba00001dda0000000000004f45e82e
-
{e=>5353,c=>99,a=>-47,g=>171749847,b=>0,d=>1,f=>1}
d1ffffff00630100e914000001000000d7b13c0a
d1ffffff00630100e914000001000000d7b13c0a
d1ffffff00630100e914000001000000d7b13c0a
ffffffd100c6400029d2000040000000147963ae
d1ffffff00630100e914000001000000d7b13c0a
d1ffffff00630100e914000001000000d7b13c0a
ffffffd100c6400029d2000040000000147963ae
d1ffffff00630100e914000001000000d7b13c0a
ffffffd100c6400029d2000040000000147963ae
-
{e=>3580,c=>89,a=>24,g=>668072177,b=>3,d=>3,f=>0}
1800000003590300fc0d000000000000f1f8d127
1800000003590300fc0d000000000000f1f8d127
1800000003590300fc0d000000000000f1f8d127
00000018c0b2c0001bf80000000000004fa3f1e2
1800000003590300fc0d000000000000f1f8d127
1800000003590300fc0d000000000000f1f8d127
00000018c0b2c0001bf80000000000004fa3f1e2
1800000003590300fc0d000000000000f1f8d127
00000018c0b2c0001bf80000000000004fa3f1e2
=
struct toobig {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>26214,a=>3,d=>3,c=>2,h=>13,b=>0,g=>1018602210,f=>1}
03000000000203006666000001000000e2a2b63c0d000000
03000000000203006666000001000000e2a2b63c0d000000
03000000000203006666000001000000e2a2b63c0d000000
000000030004c000cccc000040000000796d45c40d000000
03000000000203006666000001000000e2a2b63c0d000000
03000000000203006666000001000000e2a2b63c0d000000
000000030004c000cccc000040000000796d45c40d000000
03000000000203006666000001000000e2a2b63c0d000000
000000030004c000cccc000040000000796d45c40d000000
-
{e=>1638,a=>90,d=>0,c=>29,h=>15,b=>0,g=>1932291266,f=>2}
5a000000001d00006606000002000000c26c2c730f000000
5a000000001d00006606000002000000c26c2c730f000000
5a000000001d00006606000002000000c26c2c730f000000
0000005a003a00000ccc000080000000e658d9840f000000
5a000000001d00006606000002000000c26c2c730f000000
5a000000001d00006606000002000000c26c2c730f000000
0000005a003a00000ccc000080000000e658d9840f000000
5a000000001d00006606000002000000c26c2c730f000000
0000005a003a00000ccc000080000000e658d9840f000000
-
{e=>19392,a=>98,d=>2,c=>117,h=>142,b=>2,g=>1646528382,f=>3}
6200000002750200c04b0000030000007e0724628e000000
6200000002750200c04b0000030000007e0724628e000000
6200000002750200c04b0000030000007e0724628e000000
0000006280ea800097800000c0000000c4480efc8e000000
6200000002750200c04b0000030000007e0724628e000000
6200000002750200c04b0000030000007e0724628e000000
0000006280ea800097800000c0000000c4480efc8e000000
6200000002750200c04b0000030000007e0724628e000000
0000006280ea800097800000c0000000c4480efc8e000000
-
{e=>9394,a=>18,d=>2,c=>23,h=>96,b=>0,g=>1695469510,f=>0}
1200000000170200b224000000000000c6cf0e6560000000
1200000000170200b224000000000000c6cf0e6560000000
1200000000170200b224000000000000c6cf0e6560000000
00000012002e80004964000000000000ca1d9f8c60000000
1200000000170200b224000000000000c6cf0e6560000000
1200000000170200b224000000000000c6cf0e6560000000
00000012002e80004964000000000000ca1d9f8c60000000
1200000000170200b224000000000000c6cf0e6560000000
00000012002e80004964000000000000ca1d9f8c60000000
-
{e=>21676,a=>69,d=>2,c=>106,h=>240,b=>1,g=>2126836617,f=>2}
45000000016a0200ac5400000200000089f3c47ef0000000
45000000016a0200ac5400000200000089f3c47ef0000000
45000000016a0200ac5400000200000089f3c47ef0000000
0000004540d48000a958000080000000fd89e712f0000000
45000000016a0200ac5400000200000089f3c47ef0000000
45000000016a0200ac5400000200000089f3c47ef0000000
0000004540d48000a958000080000000fd89e712f0000000
45000000016a0200ac5400000200000089f3c47ef0000000
0000004540d48000a958000080000000fd89e712f0000000
=
struct toobig {
  long a;
  unsigned char  b:2;
};
-
{a=>-12,b=>2}
f4ffffff02000000
f4ffffffffffffff0200000000000000
f4ffffffffffffff0200000000000000
fffffff480000000
f4ffffff02000000
f4ffffff02000000
fffffffffffffff48000000000000000
f4ffffff02000000
fffffff480000000
-
{a=>0,b=>1}
0000000001000000
00000000000000000100000000000000
00000000000000000100000000000000
0000000040000000
0000000001000000
0000000001000000
00000000000000004000000000000000
0000000001000000
0000000040000000
-
{a=>60,b=>2}
3c00000002000000
3c000000000000000200000000000000
3c000000000000000200000000000000
0000003c80000000
3c00000002000000
3c00000002000000
000000000000003c8000000000000000
3c00000002000000
0000003c80000000
-
{a=>61,b=>3}
3d00000003000000
3d000000000000000300000000000000
3d000000000000000300000000000000
0000003dc0000000
3d00000003000000
3d00000003000000
000000000000003dc000000000000000
3d00000003000000
0000003dc0000000
-
{a=>122,b=>1}
7a00000001000000
7a000000000000000100000000000000
7a000000000000000100000000000000
0000007a40000000
7a00000001000000
7a00000001000000
000000000000007a4000000000000000
7a00000001000000
0000007a40000000
=
struct toobig {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>127,a=>-21,b=>2}
ebffffff027f0000
ebffffffffffffff027f000000000000
ebffffffffffffff027f000000000000
ffffffeb80fe0000
ebffffff027f0000
ebffffff027f0000
ffffffffffffffeb80fe000000000000
ebffffff027f0000
ffffffeb80fe0000
-
{c=>6,a=>-60,b=>0}
c4ffffff00060000
c4ffffffffffffff0006000000000000
c4ffffffffffffff0006000000000000
ffffffc4000c0000
c4ffffff00060000
c4ffffff00060000
ffffffffffffffc4000c000000000000
c4ffffff00060000
ffffffc4000c0000
-
{c=>118,a=>-112,b=>2}
90ffffff02760000
90ffffffffffffff0276000000000000
90ffffffffffffff0276000000000000
ffffff9080ec0000
90ffffff02760000
90ffffff02760000
ffffffffffffff9080ec000000000000
90ffffff02760000
ffffff9080ec0000
-
{c=>100,a=>-92,b=>3}
a4ffffff03640000
a4ffffffffffffff0364000000000000
a4ffffffffffffff0364000000000000
ffffffa4c0c80000
a4ffffff03640000
a4ffffff03640000
ffffffffffffffa4c0c8000000000000
a4ffffff03640000
ffffffa4c0c80000
-
{c=>11,a=>123,b=>1}
7b000000010b0000
7b00000000000000010b000000000000
7b00000000000000010b000000000000
0000007b40160000
7b000000010b0000
7b000000010b0000
000000000000007b4016000000000000
7b000000010b0000
0000007b40160000
=
struct toobig {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>82,a=>18,b=>3}
1200000003520000
12000000000000000352000000000000
12000000000000000352000000000000
00000012c0a40000
1200000003520000
1200000003520000
0000000000000012c0a4000000000000
1200000003520000
00000012c0a40000
-
{c=>34,a=>45,b=>2}
2d00000002220000
2d000000000000000222000000000000
2d000000000000000222000000000000
0000002d80440000
2d00000002220000
2d00000002220000
000000000000002d8044000000000000
2d00000002220000
0000002d80440000
-
{c=>18,a=>-66,b=>2}
beffffff02120000
beffffffffffffff0212000000000000
beffffffffffffff0212000000000000
ffffffbe80240000
beffffff02120000
beffffff02120000
ffffffffffffffbe8024000000000000
beffffff02120000
ffffffbe80240000
-
{c=>41,a=>53,b=>1}
3500000001290000
35000000000000000129000000000000
35000000000000000129000000000000
0000003540520000
3500000001290000
3500000001290000
00000000000000354052000000000000
3500000001290000
0000003540520000
-
{c=>97,a=>60,b=>0}
3c00000000610000
3c000000000000000061000000000000
3c000000000000000061000000000000
0000003c00c20000
3c00000000610000
3c00000000610000
000000000000003c00c2000000000000
3c00000000610000
0000003c00c20000
=
struct toobig {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>124,a=>18,b=>1,d=>1}
12000000017c0100
1200000000000000017c010000000000
1200000000000000017c010000000000
0000001240f84000
12000000017c0100
12000000017c0100
000000000000001240f8400000000000
12000000017c0100
0000001240f84000
-
{c=>4,a=>-25,b=>3,d=>0}
e7ffffff03040000
e7ffffffffffffff0304000000000000
e7ffffffffffffff0304000000000000
ffffffe7c0080000
e7ffffff03040000
e7ffffff03040000
ffffffffffffffe7c008000000000000
e7ffffff03040000
ffffffe7c0080000
-
{c=>9,a=>8,b=>0,d=>2}
0800000000090200
08000000000000000009020000000000
08000000000000000009020000000000
0000000800128000
0800000000090200
0800000000090200
00000000000000080012800000000000
0800000000090200
0000000800128000
-
{c=>74,a=>-10,b=>2,d=>3}
f6ffffff024a0300
f6ffffffffffffff024a030000000000
f6ffffffffffffff024a030000000000
fffffff68094c000
f6ffffff024a0300
f6ffffff024a0300
fffffffffffffff68094c00000000000
f6ffffff024a0300
fffffff68094c000
-
{c=>20,a=>-100,b=>0,d=>3}
9cffffff00140300
9cffffffffffffff0014030000000000
9cffffffffffffff0014030000000000
ffffff9c0028c000
9cffffff00140300
9cffffff00140300
ffffffffffffff9c0028c00000000000
9cffffff00140300
ffffff9c0028c000
=
struct toobig {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>8288,c=>27,a=>27,b=>1,d=>0}
1b000000011b000060200000
1b00000000000000011b000060200000
1b00000000000000011b000060200000
0000001b4036000040c00000
1b000000011b000060200000
1b000000011b000060200000
000000000000001b4036000040c00000
1b000000011b000060200000
0000001b4036000040c00000
-
{e=>31476,c=>62,a=>15,b=>2,d=>0}
0f000000023e0000f47a0000
0f00000000000000023e0000f47a0000
0f00000000000000023e0000f47a0000
0000000f807c0000f5e80000
0f000000023e0000f47a0000
0f000000023e0000f47a0000
000000000000000f807c0000f5e80000
0f000000023e0000f47a0000
0000000f807c0000f5e80000
-
{e=>28645,c=>102,a=>-2,b=>0,d=>3}
feffffff00660300e56f0000
feffffffffffffff00660300e56f0000
feffffffffffffff00660300e56f0000
fffffffe00ccc000dfca0000
feffffff00660300e56f0000
feffffff00660300e56f0000
fffffffffffffffe00ccc000dfca0000
feffffff00660300e56f0000
fffffffe00ccc000dfca0000
-
{e=>5175,c=>47,a=>123,b=>3,d=>3}
7b000000032f030037140000
7b00000000000000032f030037140000
7b00000000000000032f030037140000
0000007bc05ec000286e0000
7b000000032f030037140000
7b000000032f030037140000
000000000000007bc05ec000286e0000
7b000000032f030037140000
0000007bc05ec000286e0000
-
{e=>3986,c=>9,a=>92,b=>2,d=>2}
5c00000002090200920f0000
5c0000000000000002090200920f0000
5c0000000000000002090200920f0000
0000005c801280001f240000
5c00000002090200920f0000
5c00000002090200920f0000
000000000000005c801280001f240000
5c00000002090200920f0000
0000005c801280001f240000
=
struct toobig {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>26564,c=>47,a=>75,b=>2,d=>1}
4b000000022f0100c4670000
4b00000000000000022f0100c4670000
4b00000000000000022f0100c4670000
0000004b805e4000cf880000
4b000000022f0100c4670000
4b000000022f0100c4670000
000000000000004b805e4000cf880000
4b000000022f0100c4670000
0000004b805e4000cf880000
-
{e=>13162,c=>83,a=>-7,b=>3,d=>2}
f9ffffff035302006a330000
f9ffffffffffffff035302006a330000
f9ffffffffffffff035302006a330000
fffffff9c0a6800066d40000
f9ffffff035302006a330000
f9ffffff035302006a330000
fffffffffffffff9c0a6800066d40000
f9ffffff035302006a330000
fffffff9c0a6800066d40000
-
{e=>21769,c=>111,a=>-87,b=>3,d=>2}
a9ffffff036f020009550000
a9ffffffffffffff036f020009550000
a9ffffffffffffff036f020009550000
ffffffa9c0de8000aa120000
a9ffffff036f020009550000
a9ffffff036f020009550000
ffffffffffffffa9c0de8000aa120000
a9ffffff036f020009550000
ffffffa9c0de8000aa120000
-
{e=>5436,c=>68,a=>-101,b=>3,d=>0}
9bffffff034400003c150000
9bffffffffffffff034400003c150000
9bffffffffffffff034400003c150000
ffffff9bc08800002a780000
9bffffff034400003c150000
9bffffff034400003c150000
ffffffffffffff9bc08800002a780000
9bffffff034400003c150000
ffffff9bc08800002a780000
-
{e=>13380,c=>90,a=>86,b=>2,d=>0}
56000000025a000044340000
5600000000000000025a000044340000
5600000000000000025a000044340000
0000005680b4000068880000
56000000025a000044340000
56000000025a000044340000
000000000000005680b4000068880000
56000000025a000044340000
0000005680b4000068880000
=
struct toobig {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>23505,c=>0,a=>-30,b=>2,d=>3,f=>3}
e2ffffff02000300d15b000003000000
e2ffffffffffffff02000300d15b00000300000000000000
e2ffffffffffffff02000300d15b00000300000000000000
ffffffe28000c000b7a20000c0000000
e2ffffff02000300d15b000003000000
e2ffffff02000300d15b000003000000
ffffffffffffffe28000c000b7a20000c000000000000000
e2ffffff02000300d15b000003000000
ffffffe28000c000b7a20000c0000000
-
{e=>29524,c=>34,a=>72,b=>2,d=>2,f=>0}
48000000022202005473000000000000
480000000000000002220200547300000000000000000000
480000000000000002220200547300000000000000000000
0000004880448000e6a8000000000000
48000000022202005473000000000000
48000000022202005473000000000000
000000000000004880448000e6a800000000000000000000
48000000022202005473000000000000
0000004880448000e6a8000000000000
-
{e=>8502,c=>60,a=>85,b=>1,d=>1,f=>1}
55000000013c01003621000001000000
5500000000000000013c0100362100000100000000000000
5500000000000000013c0100362100000100000000000000
0000005540784000426c000040000000
55000000013c01003621000001000000
55000000013c01003621000001000000
000000000000005540784000426c00004000000000000000
55000000013c01003621000001000000
0000005540784000426c000040000000
-
{e=>3686,c=>42,a=>-13,b=>2,d=>0,f=>1}
f3ffffff022a0000660e000001000000
f3ffffffffffffff022a0000660e00000100000000000000
f3ffffffffffffff022a0000660e00000100000000000000
fffffff3805400001ccc000040000000
f3ffffff022a0000660e000001000000
f3ffffff022a0000660e000001000000
fffffffffffffff3805400001ccc00004000000000000000
f3ffffff022a0000660e000001000000
fffffff3805400001ccc000040000000
-
{e=>26261,c=>48,a=>-62,b=>1,d=>0,f=>1}
c2ffffff013000009566000001000000
c2ffffffffffffff01300000956600000100000000000000
c2ffffffffffffff01300000956600000100000000000000
ffffffc240600000cd2a000040000000
c2ffffff013000009566000001000000
c2ffffff013000009566000001000000
ffffffffffffffc240600000cd2a00004000000000000000
c2ffffff013000009566000001000000
ffffffc240600000cd2a000040000000
=
struct toobig {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>25271,c=>5,a=>23,g=>1549434592,b=>0,d=>0,f=>3}
1700000000050000b762000003000000e07e5a5c
170000000000000000050000b762000003000000e07e5a5c
170000000000000000050000b762000003000000e07e5a5c
00000017000a0000c56e0000c0000000b8b4fdc0
1700000000050000b762000003000000e07e5a5c
1700000000050000b762000003000000e07e5a5c
0000000000000017000a0000c56e0000c0000000b8b4fdc0
1700000000050000b762000003000000e07e5a5c
00000017000a0000c56e0000c0000000b8b4fdc0
-
{e=>29769,c=>70,a=>53,g=>485498167,b=>3,d=>3,f=>3}
35000000034603004974000003000000371df01c
3500000000000000034603004974000003000000371df01c
3500000000000000034603004974000003000000371df01c
00000035c08cc000e8920000c000000039e03a6e
35000000034603004974000003000000371df01c
35000000034603004974000003000000371df01c
0000000000000035c08cc000e8920000c000000039e03a6e
35000000034603004974000003000000371df01c
00000035c08cc000e8920000c000000039e03a6e
-
{e=>4324,c=>68,a=>105,g=>554750747,b=>0,d=>0,f=>1}
6900000000440000e4100000010000001bd31021
690000000000000000440000e4100000010000001bd31021
690000000000000000440000e4100000010000001bd31021
000000690088000021c80000400000004221a636
6900000000440000e4100000010000001bd31021
6900000000440000e4100000010000001bd31021
00000000000000690088000021c80000400000004221a636
6900000000440000e4100000010000001bd31021
000000690088000021c80000400000004221a636
-
{e=>17511,c=>94,a=>58,g=>250165519,b=>2,d=>2,f=>3}
3a000000025e020067440000030000000f39e90e
3a00000000000000025e020067440000030000000f39e90e
3a00000000000000025e020067440000030000000f39e90e
0000003a80bc800088ce0000c00000001dd2721e
3a000000025e020067440000030000000f39e90e
3a000000025e020067440000030000000f39e90e
000000000000003a80bc800088ce0000c00000001dd2721e
3a000000025e020067440000030000000f39e90e
0000003a80bc800088ce0000c00000001dd2721e
-
{e=>14283,c=>79,a=>-97,g=>1714885120,b=>1,d=>2,f=>1}
9fffffff014f0200cb3700000100000000123766
9fffffffffffffff014f0200cb3700000100000000123766
9fffffffffffffff014f0200cb3700000100000000123766
ffffff9f409e80006f96000040000000cc6e2400
9fffffff014f0200cb3700000100000000123766
9fffffff014f0200cb3700000100000000123766
ffffffffffffff9f409e80006f96000040000000cc6e2400
9fffffff014f0200cb3700000100000000123766
ffffff9f409e80006f96000040000000cc6e2400
=
struct toobig {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>22593,a=>-105,d=>2,c=>125,h=>86,b=>2,g=>490502662,f=>2}
97ffffff027d02004158000002000000067a3c1d56000000
97ffffffffffffff027d02004158000002000000067a3c1d5600000000000000
97ffffffffffffff027d02004158000002000000067a3c1d5600000000000000
ffffff9780fa8000b0820000800000003a78f40c56000000
97ffffff027d02004158000002000000067a3c1d56000000
97ffffff027d02004158000002000000067a3c1d56000000
ffffffffffffff9780fa8000b0820000800000003a78f40c5600000000000000
97ffffff027d02004158000002000000067a3c1d56000000
ffffff9780fa8000b0820000800000003a78f40c56000000
-
{e=>22467,a=>-25,d=>0,c=>60,h=>208,b=>0,g=>371229021,f=>0}
e7ffffff003c0000c3570000000000005d812016d0000000
e7ffffffffffffff003c0000c3570000000000005d812016d000000000000000
e7ffffffffffffff003c0000c3570000000000005d812016d000000000000000
ffffffe700780000af860000000000002c4102bad0000000
e7ffffff003c0000c3570000000000005d812016d0000000
e7ffffff003c0000c3570000000000005d812016d0000000
ffffffffffffffe700780000af860000000000002c4102bad000000000000000
e7ffffff003c0000c3570000000000005d812016d0000000
ffffffe700780000af860000000000002c4102bad0000000
-
{e=>31600,a=>-7,d=>2,c=>78,h=>234,b=>0,g=>1056003073,f=>2}
f9ffffff004e0200707b0000020000000154f13eea000000
f9ffffffffffffff004e0200707b0000020000000154f13eea00000000000000
f9ffffffffffffff004e0200707b0000020000000154f13eea00000000000000
fffffff9009c8000f6e00000800000007de2a802ea000000
f9ffffff004e0200707b0000020000000154f13eea000000
f9ffffff004e0200707b0000020000000154f13eea000000
fffffffffffffff9009c8000f6e00000800000007de2a802ea00000000000000
f9ffffff004e0200707b0000020000000154f13eea000000
fffffff9009c8000f6e00000800000007de2a802ea000000
-
{e=>12252,a=>38,d=>2,c=>1,h=>15,b=>1,g=>1441179725,f=>2}
2600000001010200dc2f0000020000004da8e6550f000000
260000000000000001010200dc2f0000020000004da8e6550f00000000000000
260000000000000001010200dc2f0000020000004da8e6550f00000000000000
00000026400280005fb8000080000000abcd509a0f000000
2600000001010200dc2f0000020000004da8e6550f000000
2600000001010200dc2f0000020000004da8e6550f000000
0000000000000026400280005fb8000080000000abcd509a0f00000000000000
2600000001010200dc2f0000020000004da8e6550f000000
00000026400280005fb8000080000000abcd509a0f000000
-
{e=>29268,a=>28,d=>0,c=>18,h=>157,b=>1,g=>2064430442,f=>1}
1c0000000112000054720000010000006ab50c7b9d000000
1c000000000000000112000054720000010000006ab50c7b9d00000000000000
1c000000000000000112000054720000010000006ab50c7b9d00000000000000
0000001c40240000e4a8000040000000f6196ad49d000000
1c0000000112000054720000010000006ab50c7b9d000000
1c0000000112000054720000010000006ab50c7b9d000000
000000000000001c40240000e4a8000040000000f6196ad49d00000000000000
1c0000000112000054720000010000006ab50c7b9d000000
0000001c40240000e4a8000040000000f6196ad49d000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
};
-
{a=>2}
02
02
02
80
02000000
02
80
02
80
-
{a=>3}
03
03
03
c0
03000000
03
c0
03
c0
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>3}
03
03
03
c0
03000000
03
c0
03
c0
-
{a=>1}
01
01
01
40
01000000
01
40
01
40
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
};
-
{a=>3,b=>122}
037a
037a
037a
c0f4
037a0000
037a
c0f4
037a
c0f4
-
{a=>0,b=>7}
0007
0007
0007
000e
00070000
0007
000e
0007
000e
-
{a=>3,b=>2}
0302
0302
0302
c004
03020000
0302
c004
0302
c004
-
{a=>1,b=>102}
0166
0166
0166
40cc
01660000
0166
40cc
0166
40cc
-
{a=>1,b=>57}
0139
0139
0139
4072
01390000
0139
4072
0139
4072
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
};
-
{a=>3,b=>86}
0356
0356
0356
c0ac
03560000
0356
c0ac
0356
c0ac
-
{a=>2,b=>116}
0274
0274
0274
80e8
02740000
0274
80e8
0274
80e8
-
{a=>2,b=>29}
021d
021d
021d
803a
021d0000
021d
803a
021d
803a
-
{a=>3,b=>95}
035f
035f
035f
c0be
035f0000
035f
c0be
035f
c0be
-
{a=>1,b=>22}
0116
0116
0116
402c
01160000
0116
402c
0116
402c
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
};
-
{c=>0,a=>1,b=>74}
014a0000
014a0000
014a0000
40940000
014a0000
014a0000
40940000
014a0000
40940000
-
{c=>0,a=>2,b=>114}
02720000
02720000
02720000
80e40000
02720000
02720000
80e40000
02720000
80e40000
-
{c=>2,a=>3,b=>123}
037b0200
037b0200
037b0200
c0f68000
037b0200
037b0200
c0f68000
037b0200
c0f68000
-
{c=>1,a=>2,b=>78}
024e0100
024e0100
024e0100
809c4000
024e0100
024e0100
809c4000
024e0100
809c4000
-
{c=>1,a=>2,b=>67}
02430100
02430100
02430100
80864000
02430100
02430100
80864000
02430100
80864000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
};
-
{c=>0,a=>2,b=>89,d=>17148}
02590000fc42
02590000fc42
02590000fc42
80b2000085f8
02590000fc420000
02590000fc42
80b2000085f8
02590000fc42
80b2000085f8
-
{c=>3,a=>3,b=>1,d=>7923}
03010300f31e
03010300f31e
03010300f31e
c002c0003de6
03010300f31e0000
03010300f31e
c002c0003de6
03010300f31e
c002c0003de6
-
{c=>3,a=>3,b=>36,d=>24620}
032403002c60
032403002c60
032403002c60
c048c000c058
032403002c600000
032403002c60
c048c000c058
032403002c60
c048c000c058
-
{c=>1,a=>1,b=>110,d=>27219}
016e0100536a
016e0100536a
016e0100536a
40dc4000d4a6
016e0100536a0000
016e0100536a
40dc4000d4a6
016e0100536a
40dc4000d4a6
-
{c=>1,a=>2,b=>119,d=>25127}
027701002762
027701002762
027701002762
80ee4000c44e
0277010027620000
027701002762
80ee4000c44e
027701002762
80ee4000c44e
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
};
-
{c=>2,a=>1,b=>55,d=>24370}
01370200325f0000
01370200325f0000
01370200325f0000
406e8000be640000
01370200325f0000
01370200325f0000
406e8000be640000
01370200325f0000
406e8000be640000
-
{c=>3,a=>1,b=>76,d=>484}
014c0300e4010000
014c0300e4010000
014c0300e4010000
4098c00003c80000
014c0300e4010000
014c0300e4010000
4098c00003c80000
014c0300e4010000
4098c00003c80000
-
{c=>3,a=>0,b=>72,d=>28441}
00480300196f0000
00480300196f0000
00480300196f0000
0090c000de320000
00480300196f0000
00480300196f0000
0090c000de320000
00480300196f0000
0090c000de320000
-
{c=>0,a=>1,b=>4,d=>20335}
010400006f4f0000
010400006f4f0000
010400006f4f0000
400800009ede0000
010400006f4f0000
010400006f4f0000
400800009ede0000
010400006f4f0000
400800009ede0000
-
{c=>1,a=>3,b=>108,d=>25748}
036c010094640000
036c010094640000
036c010094640000
c0d84000c9280000
036c010094640000
036c010094640000
c0d84000c9280000
036c010094640000
c0d84000c9280000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
  unsigned int   e:2;
};
-
{e=>2,c=>1,a=>3,b=>25,d=>14129}
031901003137000002000000
031901003137000002000000
031901003137000002000000
c03240006e62000080000000
031901003137000002000000
031901003137000002000000
c03240006e62000080000000
031901003137000002000000
c03240006e62000080000000
-
{e=>2,c=>1,a=>0,b=>43,d=>29105}
002b0100b171000002000000
002b0100b171000002000000
002b0100b171000002000000
00564000e362000080000000
002b0100b171000002000000
002b0100b171000002000000
00564000e362000080000000
002b0100b171000002000000
00564000e362000080000000
-
{e=>2,c=>0,a=>2,b=>27,d=>17807}
021b00008f45000002000000
021b00008f45000002000000
021b00008f45000002000000
803600008b1e000080000000
021b00008f45000002000000
021b00008f45000002000000
803600008b1e000080000000
021b00008f45000002000000
803600008b1e000080000000
-
{e=>3,c=>0,a=>0,b=>93,d=>809}
005d00002903000003000000
005d00002903000003000000
005d00002903000003000000
00ba000006520000c0000000
005d00002903000003000000
005d00002903000003000000
00ba000006520000c0000000
005d00002903000003000000
00ba000006520000c0000000
-
{e=>0,c=>3,a=>1,b=>44,d=>30562}
012c03006277000000000000
012c03006277000000000000
012c03006277000000000000
4058c000eec4000000000000
012c03006277000000000000
012c03006277000000000000
4058c000eec4000000000000
012c03006277000000000000
4058c000eec4000000000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
  unsigned int   e:2;
  unsigned int   f:31;
};
-
{e=>3,c=>2,a=>2,b=>10,d=>5501,f=>1254374167}
020a02007d15000003000000173bc44a
020a02007d15000003000000173bc44a
020a02007d15000003000000173bc44a
801480002afa0000c00000009588762e
020a02007d15000003000000173bc44a
020a02007d15000003000000173bc44a
801480002afa0000c00000009588762e
020a02007d15000003000000173bc44a
801480002afa0000c00000009588762e
-
{e=>0,c=>3,a=>3,b=>108,d=>4783,f=>549387562}
036c0300af120000000000002afdbe20
036c0300af120000000000002afdbe20
036c0300af120000000000002afdbe20
c0d8c000255e000000000000417dfa54
036c0300af120000000000002afdbe20
036c0300af120000000000002afdbe20
c0d8c000255e000000000000417dfa54
036c0300af120000000000002afdbe20
c0d8c000255e000000000000417dfa54
-
{e=>2,c=>1,a=>1,b=>71,d=>5216,f=>457981324}
0147010060140000020000008c3d4c1b
0147010060140000020000008c3d4c1b
0147010060140000020000008c3d4c1b
408e400028c000008000000036987b18
0147010060140000020000008c3d4c1b
0147010060140000020000008c3d4c1b
408e400028c000008000000036987b18
0147010060140000020000008c3d4c1b
408e400028c000008000000036987b18
-
{e=>0,c=>1,a=>0,b=>108,d=>3389,f=>260729659}
006c01003d0d0000000000003b6b8a0f
006c01003d0d0000000000003b6b8a0f
006c01003d0d0000000000003b6b8a0f
00d840001a7a0000000000001f14d676
006c01003d0d0000000000003b6b8a0f
006c01003d0d0000000000003b6b8a0f
00d840001a7a0000000000001f14d676
006c01003d0d0000000000003b6b8a0f
00d840001a7a0000000000001f14d676
-
{e=>2,c=>3,a=>3,b=>78,d=>9795,f=>22588338}
034e03004326000002000000b2ab5801
034e03004326000002000000b2ab5801
034e03004326000002000000b2ab5801
c09cc0004c8600008000000002b15764
034e03004326000002000000b2ab5801
034e03004326000002000000b2ab5801
c09cc0004c8600008000000002b15764
034e03004326000002000000b2ab5801
c09cc0004c8600008000000002b15764
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
  unsigned int   e:2;
  unsigned int   f:31;
  unsigned char  g;
};
-
{e=>0,c=>0,a=>3,g=>96,b=>9,d=>3499,f=>226878349}
03090000ab0d0000000000008de3850d60000000
03090000ab0d0000000000008de3850d60000000
03090000ab0d0000000000008de3850d60000000
c01200001b560000000000001b0bc71a60000000
03090000ab0d0000000000008de3850d60000000
03090000ab0d0000000000008de3850d60000000
c01200001b560000000000001b0bc71a60000000
03090000ab0d0000000000008de3850d60000000
c01200001b560000000000001b0bc71a60000000
-
{e=>2,c=>0,a=>0,g=>93,b=>30,d=>5449,f=>524944825}
001e00004915000002000000b9054a1f5d000000
001e00004915000002000000b9054a1f5d000000
001e00004915000002000000b9054a1f5d000000
003c00002a920000800000003e940b725d000000
001e00004915000002000000b9054a1f5d000000
001e00004915000002000000b9054a1f5d000000
003c00002a920000800000003e940b725d000000
001e00004915000002000000b9054a1f5d000000
003c00002a920000800000003e940b725d000000
-
{e=>3,c=>2,a=>0,g=>121,b=>95,d=>26776,f=>1524019449}
005f02009868000003000000f9b0d65a79000000
005f02009868000003000000f9b0d65a79000000
005f02009868000003000000f9b0d65a79000000
00be8000d1300000c0000000b5ad61f279000000
005f02009868000003000000f9b0d65a79000000
005f02009868000003000000f9b0d65a79000000
00be8000d1300000c0000000b5ad61f279000000
005f02009868000003000000f9b0d65a79000000
00be8000d1300000c0000000b5ad61f279000000
-
{e=>0,c=>1,a=>1,g=>154,b=>21,d=>23517,f=>1699556351}
01150100dd5b000000000000ff2b4d659a000000
01150100dd5b000000000000ff2b4d659a000000
01150100dd5b000000000000ff2b4d659a000000
402a4000b7ba000000000000ca9a57fe9a000000
01150100dd5b000000000000ff2b4d659a000000
01150100dd5b000000000000ff2b4d659a000000
402a4000b7ba000000000000ca9a57fe9a000000
01150100dd5b000000000000ff2b4d659a000000
402a4000b7ba000000000000ca9a57fe9a000000
-
{e=>0,c=>0,a=>1,g=>149,b=>13,d=>27687,f=>223666191}
010d0000276c0000000000000fe0540d95000000
010d0000276c0000000000000fe0540d95000000
010d0000276c0000000000000fe0540d95000000
401a0000d84e0000000000001aa9c01e95000000
010d0000276c0000000000000fe0540d95000000
010d0000276c0000000000000fe0540d95000000
401a0000d84e0000000000001aa9c01e95000000
010d0000276c0000000000000fe0540d95000000
401a0000d84e0000000000001aa9c01e95000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
};
-
{a=>-93,b=>2}
a302
a302
a302
a380
a3020000
a302
a380
a302
a380
-
{a=>-56,b=>0}
c800
c800
c800
c800
c8000000
c800
c800
c800
c800
-
{a=>-79,b=>1}
b101
b101
b101
b140
b1010000
b101
b140
b101
b140
-
{a=>-126,b=>2}
8202
8202
8202
8280
82020000
8202
8280
8202
8280
-
{a=>44,b=>0}
2c00
2c00
2c00
2c00
2c000000
2c00
2c00
2c00
2c00
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>88,a=>99,b=>0}
630058
630058
630058
6300b0
63005800
630058
6300b0
630058
6300b0
-
{c=>14,a=>-42,b=>3}
d6030e
d6030e
d6030e
d6c01c
d6030e00
d6030e
d6c01c
d6030e
d6c01c
-
{c=>110,a=>-33,b=>2}
df026e
df026e
df026e
df80dc
df026e00
df026e
df80dc
df026e
df80dc
-
{c=>83,a=>37,b=>3}
250353
250353
250353
25c0a6
25035300
250353
25c0a6
250353
25c0a6
-
{c=>75,a=>2,b=>0}
02004b
02004b
02004b
020096
02004b00
02004b
020096
02004b
020096
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>63,a=>-71,b=>0}
b9003f00
b9003f00
b9003f00
b9007e00
b9003f00
b9003f00
b9007e00
b9003f00
b9007e00
-
{c=>61,a=>68,b=>0}
44003d00
44003d00
44003d00
44007a00
44003d00
44003d00
44007a00
44003d00
44007a00
-
{c=>111,a=>-7,b=>1}
f9016f00
f9016f00
f9016f00
f940de00
f9016f00
f9016f00
f940de00
f9016f00
f940de00
-
{c=>6,a=>-14,b=>3}
f2030600
f2030600
f2030600
f2c00c00
f2030600
f2030600
f2c00c00
f2030600
f2c00c00
-
{c=>25,a=>42,b=>0}
2a001900
2a001900
2a001900
2a003200
2a001900
2a001900
2a003200
2a001900
2a003200
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>78,a=>-62,b=>3,d=>2}
c2034e000200
c2034e000200
c2034e000200
c2c09c008000
c2034e0002000000
c2034e000200
c2c09c008000
c2034e000200
c2c09c008000
-
{c=>120,a=>110,b=>1,d=>1}
6e0178000100
6e0178000100
6e0178000100
6e40f0004000
6e01780001000000
6e0178000100
6e40f0004000
6e0178000100
6e40f0004000
-
{c=>125,a=>-39,b=>1,d=>2}
d9017d000200
d9017d000200
d9017d000200
d940fa008000
d9017d0002000000
d9017d000200
d940fa008000
d9017d000200
d940fa008000
-
{c=>49,a=>-83,b=>1,d=>3}
ad0131000300
ad0131000300
ad0131000300
ad406200c000
ad01310003000000
ad0131000300
ad406200c000
ad0131000300
ad406200c000
-
{c=>102,a=>-96,b=>2,d=>3}
a00266000300
a00266000300
a00266000300
a080cc00c000
a002660003000000
a00266000300
a080cc00c000
a00266000300
a080cc00c000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>11659,c=>16,a=>72,b=>3,d=>2}
4803100002008b2d
4803100002008b2d
4803100002008b2d
48c0200080005b16
4803100002008b2d
4803100002008b2d
48c0200080005b16
4803100002008b2d
48c0200080005b16
-
{e=>3023,c=>30,a=>121,b=>2,d=>1}
79021e000100cf0b
79021e000100cf0b
79021e000100cf0b
79803c004000179e
79021e000100cf0b
79021e000100cf0b
79803c004000179e
79021e000100cf0b
79803c004000179e
-
{e=>8049,c=>55,a=>-115,b=>1,d=>2}
8d0137000200711f
8d0137000200711f
8d0137000200711f
8d406e0080003ee2
8d0137000200711f
8d0137000200711f
8d406e0080003ee2
8d0137000200711f
8d406e0080003ee2
-
{e=>11589,c=>80,a=>-12,b=>1,d=>1}
f40150000100452d
f40150000100452d
f40150000100452d
f440a00040005a8a
f40150000100452d
f40150000100452d
f440a00040005a8a
f40150000100452d
f440a00040005a8a
-
{e=>1954,c=>66,a=>-32,b=>0,d=>0}
e00042000000a207
e00042000000a207
e00042000000a207
e000840000000f44
e00042000000a207
e00042000000a207
e000840000000f44
e00042000000a207
e000840000000f44
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>5026,c=>9,a=>122,b=>2,d=>3}
7a0209000300a213
7a0209000300a213
7a0209000300a213
7a801200c0002744
7a0209000300a213
7a0209000300a213
7a801200c0002744
7a0209000300a213
7a801200c0002744
-
{e=>31797,c=>98,a=>-83,b=>0,d=>2}
ad0062000200357c
ad0062000200357c
ad0062000200357c
ad00c4008000f86a
ad0062000200357c
ad0062000200357c
ad00c4008000f86a
ad0062000200357c
ad00c4008000f86a
-
{e=>10931,c=>103,a=>-107,b=>2,d=>2}
950267000200b32a
950267000200b32a
950267000200b32a
9580ce0080005566
950267000200b32a
950267000200b32a
9580ce0080005566
950267000200b32a
9580ce0080005566
-
{e=>6859,c=>82,a=>6,b=>1,d=>3}
060152000300cb1a
060152000300cb1a
060152000300cb1a
0640a400c0003596
060152000300cb1a
060152000300cb1a
0640a400c0003596
060152000300cb1a
0640a400c0003596
-
{e=>27967,c=>53,a=>90,b=>1,d=>2}
5a01350002003f6d
5a01350002003f6d
5a01350002003f6d
5a406a008000da7e
5a01350002003f6d
5a01350002003f6d
5a406a008000da7e
5a01350002003f6d
5a406a008000da7e
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>32078,c=>33,a=>90,b=>0,d=>1,f=>1}
5a00210001004e7d01000000
5a00210001004e7d01000000
5a00210001004e7d01000000
5a0042004000fa9c40000000
5a00210001004e7d01000000
5a00210001004e7d01000000
5a0042004000fa9c40000000
5a00210001004e7d01000000
5a0042004000fa9c40000000
-
{e=>30999,c=>21,a=>-47,b=>1,d=>1,f=>2}
d10115000100177902000000
d10115000100177902000000
d10115000100177902000000
d1402a004000f22e80000000
d10115000100177902000000
d10115000100177902000000
d1402a004000f22e80000000
d10115000100177902000000
d1402a004000f22e80000000
-
{e=>5469,c=>52,a=>117,b=>0,d=>2,f=>0}
7500340002005d1500000000
7500340002005d1500000000
7500340002005d1500000000
7500680080002aba00000000
7500340002005d1500000000
7500340002005d1500000000
7500680080002aba00000000
7500340002005d1500000000
7500680080002aba00000000
-
{e=>30192,c=>87,a=>-54,b=>3,d=>3,f=>1}
ca0357000300f07501000000
ca0357000300f07501000000
ca0357000300f07501000000
cac0ae00c000ebe040000000
ca0357000300f07501000000
ca0357000300f07501000000
cac0ae00c000ebe040000000
ca0357000300f07501000000
cac0ae00c000ebe040000000
-
{e=>5881,c=>2,a=>23,b=>1,d=>3,f=>0}
170102000300f91600000000
170102000300f91600000000
170102000300f91600000000
17400400c0002df200000000
170102000300f91600000000
170102000300f91600000000
17400400c0002df200000000
170102000300f91600000000
17400400c0002df200000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>16281,c=>25,a=>111,g=>1820714982,b=>1,d=>0,f=>0}
6f0119000000993f00000000e6e7856c
6f0119000000993f00000000e6e7856c
6f0119000000993f00000000e6e7856c
6f40320000007f3200000000d90bcfcc
6f0119000000993f00000000e6e7856c
6f0119000000993f00000000e6e7856c
6f40320000007f3200000000d90bcfcc
6f0119000000993f00000000e6e7856c
6f40320000007f3200000000d90bcfcc
-
{e=>6891,c=>53,a=>-40,g=>97596344,b=>2,d=>2,f=>0}
d80235000200eb1a00000000b833d105
d80235000200eb1a00000000b833d105
d80235000200eb1a00000000b833d105
d8806a00800035d6000000000ba26770
d80235000200eb1a00000000b833d105
d80235000200eb1a00000000b833d105
d8806a00800035d6000000000ba26770
d80235000200eb1a00000000b833d105
d8806a00800035d6000000000ba26770
-
{e=>3360,c=>31,a=>63,g=>761179706,b=>1,d=>0,f=>0}
3f011f000000200d000000003aae5e2d
3f011f000000200d000000003aae5e2d
3f011f000000200d000000003aae5e2d
3f403e0000001a40000000005abd5c74
3f011f000000200d000000003aae5e2d
3f011f000000200d000000003aae5e2d
3f403e0000001a40000000005abd5c74
3f011f000000200d000000003aae5e2d
3f403e0000001a40000000005abd5c74
-
{e=>16476,c=>63,a=>-85,g=>512020589,b=>3,d=>0,f=>3}
ab033f0000005c40030000006dd0841e
ab033f0000005c40030000006dd0841e
ab033f0000005c40030000006dd0841e
abc07e00000080b8c00000003d09a0da
ab033f0000005c40030000006dd0841e
ab033f0000005c40030000006dd0841e
abc07e00000080b8c00000003d09a0da
ab033f0000005c40030000006dd0841e
abc07e00000080b8c00000003d09a0da
-
{e=>15061,c=>102,a=>-67,g=>473075273,b=>1,d=>1,f=>0}
bd0166000100d53a00000000498e321c
bd0166000100d53a00000000498e321c
bd0166000100d53a00000000498e321c
bd40cc00400075aa0000000038651c92
bd0166000100d53a00000000498e321c
bd0166000100d53a00000000498e321c
bd40cc00400075aa0000000038651c92
bd0166000100d53a00000000498e321c
bd40cc00400075aa0000000038651c92
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>22977,a=>-2,d=>2,c=>83,h=>109,b=>1,g=>868418545,f=>3}
fe0153000200c15903000000f103c3336d000000
fe0153000200c15903000000f103c3336d000000
fe0153000200c15903000000f103c3336d000000
fe40a6008000b382c0000000678607e26d000000
fe0153000200c15903000000f103c3336d000000
fe0153000200c15903000000f103c3336d000000
fe40a6008000b382c0000000678607e26d000000
fe0153000200c15903000000f103c3336d000000
fe40a6008000b382c0000000678607e26d000000
-
{e=>12366,a=>-40,d=>0,c=>7,h=>103,b=>1,g=>1323876095,f=>1}
d801070000004e3001000000ffbee84e67000000
d801070000004e3001000000ffbee84e67000000
d801070000004e3001000000ffbee84e67000000
d8400e000000609c400000009dd17dfe67000000
d801070000004e3001000000ffbee84e67000000
d801070000004e3001000000ffbee84e67000000
d8400e000000609c400000009dd17dfe67000000
d801070000004e3001000000ffbee84e67000000
d8400e000000609c400000009dd17dfe67000000
-
{e=>28796,a=>-113,d=>1,c=>90,h=>201,b=>3,g=>1452786621,f=>3}
8f035a0001007c7003000000bdc39756c9000000
8f035a0001007c7003000000bdc39756c9000000
8f035a0001007c7003000000bdc39756c9000000
8fc0b4004000e0f8c0000000ad2f877ac9000000
8f035a0001007c7003000000bdc39756c9000000
8f035a0001007c7003000000bdc39756c9000000
8fc0b4004000e0f8c0000000ad2f877ac9000000
8f035a0001007c7003000000bdc39756c9000000
8fc0b4004000e0f8c0000000ad2f877ac9000000
-
{e=>11159,a=>98,d=>2,c=>57,h=>40,b=>0,g=>1298924782,f=>1}
620039000200972b01000000ee046c4d28000000
620039000200972b01000000ee046c4d28000000
620039000200972b01000000ee046c4d28000000
620072008000572e400000009ad809dc28000000
620039000200972b01000000ee046c4d28000000
620039000200972b01000000ee046c4d28000000
620072008000572e400000009ad809dc28000000
620039000200972b01000000ee046c4d28000000
620072008000572e400000009ad809dc28000000
-
{e=>2986,a=>35,d=>3,c=>121,h=>161,b=>3,g=>287355737,f=>1}
230379000300aa0b0100000059b32011a1000000
230379000300aa0b0100000059b32011a1000000
230379000300aa0b0100000059b32011a1000000
23c0f200c000175440000000224166b2a1000000
230379000300aa0b0100000059b32011a1000000
230379000300aa0b0100000059b32011a1000000
23c0f200c000175440000000224166b2a1000000
230379000300aa0b0100000059b32011a1000000
23c0f200c000175440000000224166b2a1000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
};
-
{a=>36,b=>2}
24000200
24000200
24000200
00248000
24000200
24000200
00248000
24000200
00248000
-
{a=>-42,b=>0}
d6ff0000
d6ff0000
d6ff0000
ffd60000
d6ff0000
d6ff0000
ffd60000
d6ff0000
ffd60000
-
{a=>52,b=>2}
34000200
34000200
34000200
00348000
34000200
34000200
00348000
34000200
00348000
-
{a=>52,b=>2}
34000200
34000200
34000200
00348000
34000200
34000200
00348000
34000200
00348000
-
{a=>-48,b=>1}
d0ff0100
d0ff0100
d0ff0100
ffd04000
d0ff0100
d0ff0100
ffd04000
d0ff0100
ffd04000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>9,a=>-31,b=>1}
e1ff0109
e1ff0109
e1ff0109
ffe14012
e1ff0109
e1ff0109
ffe14012
e1ff0109
ffe14012
-
{c=>116,a=>-67,b=>0}
bdff0074
bdff0074
bdff0074
ffbd00e8
bdff0074
bdff0074
ffbd00e8
bdff0074
ffbd00e8
-
{c=>96,a=>-109,b=>3}
93ff0360
93ff0360
93ff0360
ff93c0c0
93ff0360
93ff0360
ff93c0c0
93ff0360
ff93c0c0
-
{c=>112,a=>110,b=>1}
6e000170
6e000170
6e000170
006e40e0
6e000170
6e000170
006e40e0
6e000170
006e40e0
-
{c=>85,a=>-99,b=>1}
9dff0155
9dff0155
9dff0155
ff9d40aa
9dff0155
9dff0155
ff9d40aa
9dff0155
ff9d40aa
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>59,a=>-96,b=>3}
a0ff033b
a0ff033b
a0ff033b
ffa0c076
a0ff033b
a0ff033b
ffa0c076
a0ff033b
ffa0c076
-
{c=>67,a=>-103,b=>2}
99ff0243
99ff0243
99ff0243
ff998086
99ff0243
99ff0243
ff998086
99ff0243
ff998086
-
{c=>92,a=>-115,b=>1}
8dff015c
8dff015c
8dff015c
ff8d40b8
8dff015c
8dff015c
ff8d40b8
8dff015c
ff8d40b8
-
{c=>64,a=>19,b=>0}
13000040
13000040
13000040
00130080
13000040
13000040
00130080
13000040
00130080
-
{c=>112,a=>95,b=>0}
5f000070
5f000070
5f000070
005f00e0
5f000070
5f000070
005f00e0
5f000070
005f00e0
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>78,a=>-30,b=>0,d=>1}
e2ff004e0100
e2ff004e0100
e2ff004e0100
ffe2009c4000
e2ff004e01000000
e2ff004e0100
ffe2009c4000
e2ff004e0100
ffe2009c4000
-
{c=>18,a=>106,b=>3,d=>1}
6a0003120100
6a0003120100
6a0003120100
006ac0244000
6a00031201000000
6a0003120100
006ac0244000
6a0003120100
006ac0244000
-
{c=>55,a=>-74,b=>1,d=>2}
b6ff01370200
b6ff01370200
b6ff01370200
ffb6406e8000
b6ff013702000000
b6ff01370200
ffb6406e8000
b6ff01370200
ffb6406e8000
-
{c=>73,a=>20,b=>2,d=>0}
140002490000
140002490000
140002490000
001480920000
1400024900000000
140002490000
001480920000
140002490000
001480920000
-
{c=>17,a=>-82,b=>2,d=>0}
aeff02110000
aeff02110000
aeff02110000
ffae80220000
aeff021100000000
aeff02110000
ffae80220000
aeff02110000
ffae80220000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>23152,c=>68,a=>35,b=>3,d=>1}
230003440100705a
230003440100705a
230003440100705a
0023c0884000b4e0
230003440100705a
230003440100705a
0023c0884000b4e0
230003440100705a
0023c0884000b4e0
-
{e=>11271,c=>14,a=>65,b=>1,d=>1}
4100010e0100072c
4100010e0100072c
4100010e0100072c
0041401c4000580e
4100010e0100072c
4100010e0100072c
0041401c4000580e
4100010e0100072c
0041401c4000580e
-
{e=>14141,c=>13,a=>16,b=>1,d=>2}
1000010d02003d37
1000010d02003d37
1000010d02003d37
0010401a80006e7a
1000010d02003d37
1000010d02003d37
0010401a80006e7a
1000010d02003d37
0010401a80006e7a
-
{e=>13679,c=>79,a=>119,b=>3,d=>0}
7700034f00006f35
7700034f00006f35
7700034f00006f35
0077c09e00006ade
7700034f00006f35
7700034f00006f35
0077c09e00006ade
7700034f00006f35
0077c09e00006ade
-
{e=>32421,c=>57,a=>49,b=>1,d=>0}
310001390000a57e
310001390000a57e
310001390000a57e
003140720000fd4a
310001390000a57e
310001390000a57e
003140720000fd4a
310001390000a57e
003140720000fd4a
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>13261,c=>104,a=>-64,b=>3,d=>2}
c0ff03680200cd33
c0ff03680200cd33
c0ff03680200cd33
ffc0c0d08000679a
c0ff03680200cd33
c0ff03680200cd33
ffc0c0d08000679a
c0ff03680200cd33
ffc0c0d08000679a
-
{e=>14081,c=>16,a=>118,b=>2,d=>0}
7600021000000137
7600021000000137
7600021000000137
0076802000006e02
7600021000000137
7600021000000137
0076802000006e02
7600021000000137
0076802000006e02
-
{e=>18138,c=>125,a=>-105,b=>3,d=>3}
97ff037d0300da46
97ff037d0300da46
97ff037d0300da46
ff97c0fac0008db4
97ff037d0300da46
97ff037d0300da46
ff97c0fac0008db4
97ff037d0300da46
ff97c0fac0008db4
-
{e=>10748,c=>38,a=>-13,b=>0,d=>0}
f3ff00260000fc29
f3ff00260000fc29
f3ff00260000fc29
fff3004c000053f8
f3ff00260000fc29
f3ff00260000fc29
fff3004c000053f8
f3ff00260000fc29
fff3004c000053f8
-
{e=>2078,c=>92,a=>59,b=>0,d=>1}
3b00005c01001e08
3b00005c01001e08
3b00005c01001e08
003b00b84000103c
3b00005c01001e08
3b00005c01001e08
003b00b84000103c
3b00005c01001e08
003b00b84000103c
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>7575,c=>96,a=>14,b=>1,d=>2,f=>0}
0e0001600200971d00000000
0e0001600200971d00000000
0e0001600200971d00000000
000e40c080003b2e00000000
0e0001600200971d00000000
0e0001600200971d00000000
000e40c080003b2e00000000
0e0001600200971d00000000
000e40c080003b2e00000000
-
{e=>14550,c=>56,a=>-116,b=>1,d=>0,f=>0}
8cff01380000d63800000000
8cff01380000d63800000000
8cff01380000d63800000000
ff8c4070000071ac00000000
8cff01380000d63800000000
8cff01380000d63800000000
ff8c4070000071ac00000000
8cff01380000d63800000000
ff8c4070000071ac00000000
-
{e=>31077,c=>102,a=>118,b=>0,d=>3,f=>0}
760000660300657900000000
760000660300657900000000
760000660300657900000000
007600ccc000f2ca00000000
760000660300657900000000
760000660300657900000000
007600ccc000f2ca00000000
760000660300657900000000
007600ccc000f2ca00000000
-
{e=>14802,c=>1,a=>-81,b=>2,d=>0,f=>3}
afff02010000d23903000000
afff02010000d23903000000
afff02010000d23903000000
ffaf8002000073a4c0000000
afff02010000d23903000000
afff02010000d23903000000
ffaf8002000073a4c0000000
afff02010000d23903000000
ffaf8002000073a4c0000000
-
{e=>14877,c=>55,a=>26,b=>2,d=>2,f=>2}
1a00023702001d3a02000000
1a00023702001d3a02000000
1a00023702001d3a02000000
001a806e8000743a80000000
1a00023702001d3a02000000
1a00023702001d3a02000000
001a806e8000743a80000000
1a00023702001d3a02000000
001a806e8000743a80000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>7844,c=>54,a=>27,g=>751275513,b=>0,d=>2,f=>1}
1b0000360200a41e01000000f98dc72c
1b0000360200a41e01000000f98dc72c
1b0000360200a41e01000000f98dc72c
001b006c80003d4840000000598f1bf2
1b0000360200a41e01000000f98dc72c
1b0000360200a41e01000000f98dc72c
001b006c80003d4840000000598f1bf2
1b0000360200a41e01000000f98dc72c
001b006c80003d4840000000598f1bf2
-
{e=>11268,c=>97,a=>-121,g=>109432832,b=>2,d=>3,f=>3}
87ff02610300042c0300000000d08506
87ff02610300042c0300000000d08506
87ff02610300042c0300000000d08506
ff8780c2c0005808c00000000d0ba000
87ff02610300042c0300000000d08506
87ff02610300042c0300000000d08506
ff8780c2c0005808c00000000d0ba000
87ff02610300042c0300000000d08506
ff8780c2c0005808c00000000d0ba000
-
{e=>23652,c=>90,a=>107,g=>836655276,b=>1,d=>3,f=>1}
6b00015a0300645c01000000ac58de31
6b00015a0300645c01000000ac58de31
6b00015a0300645c01000000ac58de31
006b40b4c000b8c84000000063bcb158
6b00015a0300645c01000000ac58de31
6b00015a0300645c01000000ac58de31
006b40b4c000b8c84000000063bcb158
6b00015a0300645c01000000ac58de31
006b40b4c000b8c84000000063bcb158
-
{e=>29274,c=>92,a=>101,g=>1563176679,b=>1,d=>1,f=>1}
6500015c01005a7201000000e72e2c5d
6500015c01005a7201000000e72e2c5d
6500015c01005a7201000000e72e2c5d
006540b84000e4b440000000ba585dce
6500015c01005a7201000000e72e2c5d
6500015c01005a7201000000e72e2c5d
006540b84000e4b440000000ba585dce
6500015c01005a7201000000e72e2c5d
006540b84000e4b440000000ba585dce
-
{e=>24723,c=>105,a=>-77,g=>980506780,b=>0,d=>3,f=>2}
b3ff006903009360020000009c58713a
b3ff006903009360020000009c58713a
b3ff006903009360020000009c58713a
ffb300d2c000c1268000000074e2b138
b3ff006903009360020000009c58713a
b3ff006903009360020000009c58713a
ffb300d2c000c1268000000074e2b138
b3ff006903009360020000009c58713a
ffb300d2c000c1268000000074e2b138
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>17518,a=>-39,d=>3,c=>91,h=>162,b=>3,g=>1543066247,f=>1}
d9ff035b03006e44010000008752f95ba2000000
d9ff035b03006e44010000008752f95ba2000000
d9ff035b03006e44010000008752f95ba2000000
ffd9c0b6c00088dc40000000b7f2a50ea2000000
d9ff035b03006e44010000008752f95ba2000000
d9ff035b03006e44010000008752f95ba2000000
ffd9c0b6c00088dc40000000b7f2a50ea2000000
d9ff035b03006e44010000008752f95ba2000000
ffd9c0b6c00088dc40000000b7f2a50ea2000000
-
{e=>8378,a=>71,d=>1,c=>66,h=>137,b=>0,g=>834780984,f=>3}
470000420100ba200300000038bfc13189000000
470000420100ba200300000038bfc13189000000
470000420100ba200300000038bfc13189000000
0047008440004174c000000063837e7089000000
470000420100ba200300000038bfc13189000000
470000420100ba200300000038bfc13189000000
0047008440004174c000000063837e7089000000
470000420100ba200300000038bfc13189000000
0047008440004174c000000063837e7089000000
-
{e=>28729,a=>-103,d=>3,c=>19,h=>150,b=>3,g=>458128972,f=>2}
99ff031303003970020000004c7e4e1b96000000
99ff031303003970020000004c7e4e1b96000000
99ff031303003970020000004c7e4e1b96000000
ff99c026c000e07280000000369cfc9896000000
99ff031303003970020000004c7e4e1b96000000
99ff031303003970020000004c7e4e1b96000000
ff99c026c000e07280000000369cfc9896000000
99ff031303003970020000004c7e4e1b96000000
ff99c026c000e07280000000369cfc9896000000
-
{e=>2388,a=>86,d=>2,c=>85,h=>7,b=>2,g=>1947211790,f=>3}
5600025502005409030000000e18107407000000
5600025502005409030000000e18107407000000
5600025502005409030000000e18107407000000
005680aa800012a8c0000000e820301c07000000
5600025502005409030000000e18107407000000
5600025502005409030000000e18107407000000
005680aa800012a8c0000000e820301c07000000
5600025502005409030000000e18107407000000
005680aa800012a8c0000000e820301c07000000
-
{e=>25964,a=>-72,d=>2,c=>127,h=>252,b=>3,g=>338601299,f=>3}
b8ff037f02006c650300000053a52e14fc000000
b8ff037f02006c650300000053a52e14fc000000
b8ff037f02006c650300000053a52e14fc000000
ffb8c0fe8000cad8c0000000285d4aa6fc000000
b8ff037f02006c650300000053a52e14fc000000
b8ff037f02006c650300000053a52e14fc000000
ffb8c0fe8000cad8c0000000285d4aa6fc000000
b8ff037f02006c650300000053a52e14fc000000
ffb8c0fe8000cad8c0000000285d4aa6fc000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
};
-
{a=>23,b=>3}
1700000003000000
1700000003000000
1700000003000000
00000017c0000000
1700000003000000
1700000003000000
00000017c0000000
1700000003000000
00000017c0000000
-
{a=>93,b=>0}
5d00000000000000
5d00000000000000
5d00000000000000
0000005d00000000
5d00000000000000
5d00000000000000
0000005d00000000
5d00000000000000
0000005d00000000
-
{a=>82,b=>3}
5200000003000000
5200000003000000
5200000003000000
00000052c0000000
5200000003000000
5200000003000000
00000052c0000000
5200000003000000
00000052c0000000
-
{a=>-120,b=>3}
88ffffff03000000
88ffffff03000000
88ffffff03000000
ffffff88c0000000
88ffffff03000000
88ffffff03000000
ffffff88c0000000
88ffffff03000000
ffffff88c0000000
-
{a=>-6,b=>2}
faffffff02000000
faffffff02000000
faffffff02000000
fffffffa80000000
faffffff02000000
faffffff02000000
fffffffa80000000
faffffff02000000
fffffffa80000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>118,a=>39,b=>1}
2700000001760000
2700000001760000
2700000001760000
0000002740ec0000
2700000001760000
2700000001760000
0000002740ec0000
2700000001760000
0000002740ec0000
-
{c=>36,a=>70,b=>1}
4600000001240000
4600000001240000
4600000001240000
0000004640480000
4600000001240000
4600000001240000
0000004640480000
4600000001240000
0000004640480000
-
{c=>28,a=>12,b=>1}
0c000000011c0000
0c000000011c0000
0c000000011c0000
0000000c40380000
0c000000011c0000
0c000000011c0000
0000000c40380000
0c000000011c0000
0000000c40380000
-
{c=>0,a=>-92,b=>0}
a4ffffff00000000
a4ffffff00000000
a4ffffff00000000
ffffffa400000000
a4ffffff00000000
a4ffffff00000000
ffffffa400000000
a4ffffff00000000
ffffffa400000000
-
{c=>54,a=>84,b=>0}
5400000000360000
5400000000360000
5400000000360000
00000054006c0000
5400000000360000
5400000000360000
00000054006c0000
5400000000360000
00000054006c0000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>29,a=>0,b=>1}
00000000011d0000
00000000011d0000
00000000011d0000
00000000403a0000
00000000011d0000
00000000011d0000
00000000403a0000
00000000011d0000
00000000403a0000
-
{c=>42,a=>-2,b=>3}
feffffff032a0000
feffffff032a0000
feffffff032a0000
fffffffec0540000
feffffff032a0000
feffffff032a0000
fffffffec0540000
feffffff032a0000
fffffffec0540000
-
{c=>79,a=>100,b=>2}
64000000024f0000
64000000024f0000
64000000024f0000
00000064809e0000
64000000024f0000
64000000024f0000
00000064809e0000
64000000024f0000
00000064809e0000
-
{c=>46,a=>-76,b=>2}
b4ffffff022e0000
b4ffffff022e0000
b4ffffff022e0000
ffffffb4805c0000
b4ffffff022e0000
b4ffffff022e0000
ffffffb4805c0000
b4ffffff022e0000
ffffffb4805c0000
-
{c=>57,a=>13,b=>3}
0d00000003390000
0d00000003390000
0d00000003390000
0000000dc0720000
0d00000003390000
0d00000003390000
0000000dc0720000
0d00000003390000
0000000dc0720000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>42,a=>54,b=>1,d=>3}
36000000012a0300
36000000012a0300
36000000012a0300
000000364054c000
36000000012a0300
36000000012a0300
000000364054c000
36000000012a0300
000000364054c000
-
{c=>23,a=>120,b=>3,d=>1}
7800000003170100
7800000003170100
7800000003170100
00000078c02e4000
7800000003170100
7800000003170100
00000078c02e4000
7800000003170100
00000078c02e4000
-
{c=>65,a=>67,b=>3,d=>3}
4300000003410300
4300000003410300
4300000003410300
00000043c082c000
4300000003410300
4300000003410300
00000043c082c000
4300000003410300
00000043c082c000
-
{c=>36,a=>-14,b=>0,d=>2}
f2ffffff00240200
f2ffffff00240200
f2ffffff00240200
fffffff200488000
f2ffffff00240200
f2ffffff00240200
fffffff200488000
f2ffffff00240200
fffffff200488000
-
{c=>6,a=>61,b=>2,d=>3}
3d00000002060300
3d00000002060300
3d00000002060300
0000003d800cc000
3d00000002060300
3d00000002060300
0000003d800cc000
3d00000002060300
0000003d800cc000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>6171,c=>80,a=>-30,b=>1,d=>0}
e2ffffff015000001b180000
e2ffffff015000001b180000
e2ffffff015000001b180000
ffffffe240a0000030360000
e2ffffff015000001b180000
e2ffffff015000001b180000
ffffffe240a0000030360000
e2ffffff015000001b180000
ffffffe240a0000030360000
-
{e=>13986,c=>17,a=>16,b=>2,d=>1}
1000000002110100a2360000
1000000002110100a2360000
1000000002110100a2360000
00000010802240006d440000
1000000002110100a2360000
1000000002110100a2360000
00000010802240006d440000
1000000002110100a2360000
00000010802240006d440000
-
{e=>10321,c=>77,a=>-41,b=>2,d=>1}
d7ffffff024d010051280000
d7ffffff024d010051280000
d7ffffff024d010051280000
ffffffd7809a400050a20000
d7ffffff024d010051280000
d7ffffff024d010051280000
ffffffd7809a400050a20000
d7ffffff024d010051280000
ffffffd7809a400050a20000
-
{e=>4855,c=>52,a=>-59,b=>2,d=>2}
c5ffffff02340200f7120000
c5ffffff02340200f7120000
c5ffffff02340200f7120000
ffffffc58068800025ee0000
c5ffffff02340200f7120000
c5ffffff02340200f7120000
ffffffc58068800025ee0000
c5ffffff02340200f7120000
ffffffc58068800025ee0000
-
{e=>4433,c=>3,a=>-57,b=>2,d=>2}
c7ffffff0203020051110000
c7ffffff0203020051110000
c7ffffff0203020051110000
ffffffc78006800022a20000
c7ffffff0203020051110000
c7ffffff0203020051110000
ffffffc78006800022a20000
c7ffffff0203020051110000
ffffffc78006800022a20000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>924,c=>33,a=>-21,b=>0,d=>1}
ebffffff002101009c030000
ebffffff002101009c030000
ebffffff002101009c030000
ffffffeb0042400007380000
ebffffff002101009c030000
ebffffff002101009c030000
ffffffeb0042400007380000
ebffffff002101009c030000
ffffffeb0042400007380000
-
{e=>6351,c=>54,a=>-34,b=>1,d=>0}
deffffff01360000cf180000
deffffff01360000cf180000
deffffff01360000cf180000
ffffffde406c0000319e0000
deffffff01360000cf180000
deffffff01360000cf180000
ffffffde406c0000319e0000
deffffff01360000cf180000
ffffffde406c0000319e0000
-
{e=>1879,c=>52,a=>35,b=>1,d=>1}
230000000134010057070000
230000000134010057070000
230000000134010057070000
00000023406840000eae0000
230000000134010057070000
230000000134010057070000
00000023406840000eae0000
230000000134010057070000
00000023406840000eae0000
-
{e=>8238,c=>76,a=>32,b=>2,d=>1}
20000000024c01002e200000
20000000024c01002e200000
20000000024c01002e200000
0000002080984000405c0000
20000000024c01002e200000
20000000024c01002e200000
0000002080984000405c0000
20000000024c01002e200000
0000002080984000405c0000
-
{e=>31420,c=>54,a=>0,b=>1,d=>3}
0000000001360300bc7a0000
0000000001360300bc7a0000
0000000001360300bc7a0000
00000000406cc000f5780000
0000000001360300bc7a0000
0000000001360300bc7a0000
00000000406cc000f5780000
0000000001360300bc7a0000
00000000406cc000f5780000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>26010,c=>9,a=>2,b=>3,d=>0,f=>0}
02000000030900009a65000000000000
02000000030900009a65000000000000
02000000030900009a65000000000000
00000002c0120000cb34000000000000
02000000030900009a65000000000000
02000000030900009a65000000000000
00000002c0120000cb34000000000000
02000000030900009a65000000000000
00000002c0120000cb34000000000000
-
{e=>2064,c=>80,a=>-119,b=>3,d=>3,f=>3}
89ffffff035003001008000003000000
89ffffff035003001008000003000000
89ffffff035003001008000003000000
ffffff89c0a0c00010200000c0000000
89ffffff035003001008000003000000
89ffffff035003001008000003000000
ffffff89c0a0c00010200000c0000000
89ffffff035003001008000003000000
ffffff89c0a0c00010200000c0000000
-
{e=>31255,c=>2,a=>-82,b=>0,d=>0,f=>2}
aeffffff00020000177a000002000000
aeffffff00020000177a000002000000
aeffffff00020000177a000002000000
ffffffae00040000f42e000080000000
aeffffff00020000177a000002000000
aeffffff00020000177a000002000000
ffffffae00040000f42e000080000000
aeffffff00020000177a000002000000
ffffffae00040000f42e000080000000
-
{e=>3569,c=>113,a=>86,b=>2,d=>2,f=>1}
5600000002710200f10d000001000000
5600000002710200f10d000001000000
5600000002710200f10d000001000000
0000005680e280001be2000040000000
5600000002710200f10d000001000000
5600000002710200f10d000001000000
0000005680e280001be2000040000000
5600000002710200f10d000001000000
0000005680e280001be2000040000000
-
{e=>17551,c=>23,a=>-128,b=>1,d=>3,f=>3}
80ffffff011703008f44000003000000
80ffffff011703008f44000003000000
80ffffff011703008f44000003000000
ffffff80402ec000891e0000c0000000
80ffffff011703008f44000003000000
80ffffff011703008f44000003000000
ffffff80402ec000891e0000c0000000
80ffffff011703008f44000003000000
ffffff80402ec000891e0000c0000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>22897,c=>67,a=>93,g=>236819416,b=>2,d=>0,f=>0}
5d000000024300007159000000000000d8931d0e
5d000000024300007159000000000000d8931d0e
5d000000024300007159000000000000d8931d0e
0000005d80860000b2e20000000000001c3b27b0
5d000000024300007159000000000000d8931d0e
5d000000024300007159000000000000d8931d0e
0000005d80860000b2e20000000000001c3b27b0
5d000000024300007159000000000000d8931d0e
0000005d80860000b2e20000000000001c3b27b0
-
{e=>31111,c=>74,a=>119,g=>1459711425,b=>2,d=>1,f=>3}
77000000024a01008779000003000000c16d0157
77000000024a01008779000003000000c16d0157
77000000024a01008779000003000000c16d0157
0000007780944000f30e0000c0000000ae02db82
77000000024a01008779000003000000c16d0157
77000000024a01008779000003000000c16d0157
0000007780944000f30e0000c0000000ae02db82
77000000024a01008779000003000000c16d0157
0000007780944000f30e0000c0000000ae02db82
-
{e=>13989,c=>102,a=>70,g=>1058309672,b=>3,d=>0,f=>2}
4600000003660000a5360000020000002886143f
4600000003660000a5360000020000002886143f
4600000003660000a5360000020000002886143f
00000046c0cc00006d4a0000800000007e290c50
4600000003660000a5360000020000002886143f
4600000003660000a5360000020000002886143f
00000046c0cc00006d4a0000800000007e290c50
4600000003660000a5360000020000002886143f
00000046c0cc00006d4a0000800000007e290c50
-
{e=>26791,c=>57,a=>7,g=>1365065929,b=>1,d=>2,f=>1}
0700000001390200a768000001000000c9405d51
0700000001390200a768000001000000c9405d51
0700000001390200a768000001000000c9405d51
0000000740728000d14e000040000000a2ba8192
0700000001390200a768000001000000c9405d51
0700000001390200a768000001000000c9405d51
0000000740728000d14e000040000000a2ba8192
0700000001390200a768000001000000c9405d51
0000000740728000d14e000040000000a2ba8192
-
{e=>6858,c=>70,a=>-7,g=>1686921269,b=>3,d=>3,f=>1}
f9ffffff03460300ca1a00000100000035608c64
f9ffffff03460300ca1a00000100000035608c64
f9ffffff03460300ca1a00000100000035608c64
fffffff9c08cc0003594000040000000c918c06a
f9ffffff03460300ca1a00000100000035608c64
f9ffffff03460300ca1a00000100000035608c64
fffffff9c08cc0003594000040000000c918c06a
f9ffffff03460300ca1a00000100000035608c64
fffffff9c08cc0003594000040000000c918c06a
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>32326,a=>82,d=>2,c=>71,h=>163,b=>1,g=>1658102310,f=>1}
5200000001470200467e00000100000026a2d462a3000000
5200000001470200467e00000100000026a2d462a3000000
5200000001470200467e00000100000026a2d462a3000000
00000052408e8000fc8c000040000000c5a9444ca3000000
5200000001470200467e00000100000026a2d462a3000000
5200000001470200467e00000100000026a2d462a3000000
00000052408e8000fc8c000040000000c5a9444ca3000000
5200000001470200467e00000100000026a2d462a3000000
00000052408e8000fc8c000040000000c5a9444ca3000000
-
{e=>6558,a=>54,d=>0,c=>114,h=>224,b=>0,g=>240808537,f=>1}
36000000007200009e1900000100000059725a0ee0000000
36000000007200009e1900000100000059725a0ee0000000
36000000007200009e1900000100000059725a0ee0000000
0000003600e40000333c0000400000001cb4e4b2e0000000
36000000007200009e1900000100000059725a0ee0000000
36000000007200009e1900000100000059725a0ee0000000
0000003600e40000333c0000400000001cb4e4b2e0000000
36000000007200009e1900000100000059725a0ee0000000
0000003600e40000333c0000400000001cb4e4b2e0000000
-
{e=>7128,a=>-105,d=>3,c=>78,h=>139,b=>2,g=>1841705631,f=>2}
97ffffff024e0300d81b0000020000009f32c66d8b000000
97ffffff024e0300d81b0000020000009f32c66d8b000000
97ffffff024e0300d81b0000020000009f32c66d8b000000
ffffff97809cc00037b0000080000000db8c653e8b000000
97ffffff024e0300d81b0000020000009f32c66d8b000000
97ffffff024e0300d81b0000020000009f32c66d8b000000
ffffff97809cc00037b0000080000000db8c653e8b000000
97ffffff024e0300d81b0000020000009f32c66d8b000000
ffffff97809cc00037b0000080000000db8c653e8b000000
-
{e=>30661,a=>87,d=>2,c=>117,h=>158,b=>1,g=>176849329,f=>1}
5700000001750200c577000001000000b1818a0a9e000000
5700000001750200c577000001000000b1818a0a9e000000
5700000001750200c577000001000000b1818a0a9e000000
0000005740ea8000ef8a000040000000151503629e000000
5700000001750200c577000001000000b1818a0a9e000000
5700000001750200c577000001000000b1818a0a9e000000
0000005740ea8000ef8a000040000000151503629e000000
5700000001750200c577000001000000b1818a0a9e000000
0000005740ea8000ef8a000040000000151503629e000000
-
{e=>20458,a=>-35,d=>3,c=>6,h=>255,b=>3,g=>1305982333,f=>0}
ddffffff03060300ea4f0000000000007db5d74dff000000
ddffffff03060300ea4f0000000000007db5d74dff000000
ddffffff03060300ea4f0000000000007db5d74dff000000
ffffffddc00cc0009fd40000000000009baf6afaff000000
ddffffff03060300ea4f0000000000007db5d74dff000000
ddffffff03060300ea4f0000000000007db5d74dff000000
ffffffddc00cc0009fd40000000000009baf6afaff000000
ddffffff03060300ea4f0000000000007db5d74dff000000
ffffffddc00cc0009fd40000000000009baf6afaff000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
};
-
{a=>-94,b=>3}
a2ffffff03000000
a2ffffffffffffff0300000000000000
a2ffffffffffffff0300000000000000
ffffffa2c0000000
a2ffffff03000000
a2ffffff03000000
ffffffffffffffa2c000000000000000
a2ffffff03000000
ffffffa2c0000000
-
{a=>-70,b=>3}
baffffff03000000
baffffffffffffff0300000000000000
baffffffffffffff0300000000000000
ffffffbac0000000
baffffff03000000
baffffff03000000
ffffffffffffffbac000000000000000
baffffff03000000
ffffffbac0000000
-
{a=>-56,b=>0}
c8ffffff00000000
c8ffffffffffffff0000000000000000
c8ffffffffffffff0000000000000000
ffffffc800000000
c8ffffff00000000
c8ffffff00000000
ffffffffffffffc80000000000000000
c8ffffff00000000
ffffffc800000000
-
{a=>42,b=>1}
2a00000001000000
2a000000000000000100000000000000
2a000000000000000100000000000000
0000002a40000000
2a00000001000000
2a00000001000000
000000000000002a4000000000000000
2a00000001000000
0000002a40000000
-
{a=>80,b=>0}
5000000000000000
50000000000000000000000000000000
50000000000000000000000000000000
0000005000000000
5000000000000000
5000000000000000
00000000000000500000000000000000
5000000000000000
0000005000000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>70,a=>33,b=>2}
2100000002460000
21000000000000000246000000000000
21000000000000000246000000000000
00000021808c0000
2100000002460000
2100000002460000
0000000000000021808c000000000000
2100000002460000
00000021808c0000
-
{c=>99,a=>28,b=>2}
1c00000002630000
1c000000000000000263000000000000
1c000000000000000263000000000000
0000001c80c60000
1c00000002630000
1c00000002630000
000000000000001c80c6000000000000
1c00000002630000
0000001c80c60000
-
{c=>31,a=>-81,b=>3}
afffffff031f0000
afffffffffffffff031f000000000000
afffffffffffffff031f000000000000
ffffffafc03e0000
afffffff031f0000
afffffff031f0000
ffffffffffffffafc03e000000000000
afffffff031f0000
ffffffafc03e0000
-
{c=>60,a=>50,b=>1}
32000000013c0000
3200000000000000013c000000000000
3200000000000000013c000000000000
0000003240780000
32000000013c0000
32000000013c0000
00000000000000324078000000000000
32000000013c0000
0000003240780000
-
{c=>63,a=>-105,b=>3}
97ffffff033f0000
97ffffffffffffff033f000000000000
97ffffffffffffff033f000000000000
ffffff97c07e0000
97ffffff033f0000
97ffffff033f0000
ffffffffffffff97c07e000000000000
97ffffff033f0000
ffffff97c07e0000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>48,a=>-2,b=>1}
feffffff01300000
feffffffffffffff0130000000000000
feffffffffffffff0130000000000000
fffffffe40600000
feffffff01300000
feffffff01300000
fffffffffffffffe4060000000000000
feffffff01300000
fffffffe40600000
-
{c=>12,a=>35,b=>1}
23000000010c0000
2300000000000000010c000000000000
2300000000000000010c000000000000
0000002340180000
23000000010c0000
23000000010c0000
00000000000000234018000000000000
23000000010c0000
0000002340180000
-
{c=>66,a=>83,b=>0}
5300000000420000
53000000000000000042000000000000
53000000000000000042000000000000
0000005300840000
5300000000420000
5300000000420000
00000000000000530084000000000000
5300000000420000
0000005300840000
-
{c=>88,a=>9,b=>0}
0900000000580000
09000000000000000058000000000000
09000000000000000058000000000000
0000000900b00000
0900000000580000
0900000000580000
000000000000000900b0000000000000
0900000000580000
0000000900b00000
-
{c=>96,a=>41,b=>1}
2900000001600000
29000000000000000160000000000000
29000000000000000160000000000000
0000002940c00000
2900000001600000
2900000001600000
000000000000002940c0000000000000
2900000001600000
0000002940c00000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>116,a=>-52,b=>3,d=>2}
ccffffff03740200
ccffffffffffffff0374020000000000
ccffffffffffffff0374020000000000
ffffffccc0e88000
ccffffff03740200
ccffffff03740200
ffffffffffffffccc0e8800000000000
ccffffff03740200
ffffffccc0e88000
-
{c=>2,a=>-30,b=>3,d=>2}
e2ffffff03020200
e2ffffffffffffff0302020000000000
e2ffffffffffffff0302020000000000
ffffffe2c0048000
e2ffffff03020200
e2ffffff03020200
ffffffffffffffe2c004800000000000
e2ffffff03020200
ffffffe2c0048000
-
{c=>22,a=>31,b=>3,d=>2}
1f00000003160200
1f000000000000000316020000000000
1f000000000000000316020000000000
0000001fc02c8000
1f00000003160200
1f00000003160200
000000000000001fc02c800000000000
1f00000003160200
0000001fc02c8000
-
{c=>103,a=>99,b=>1,d=>1}
6300000001670100
63000000000000000167010000000000
63000000000000000167010000000000
0000006340ce4000
6300000001670100
6300000001670100
000000000000006340ce400000000000
6300000001670100
0000006340ce4000
-
{c=>110,a=>-15,b=>0,d=>3}
f1ffffff006e0300
f1ffffffffffffff006e030000000000
f1ffffffffffffff006e030000000000
fffffff100dcc000
f1ffffff006e0300
f1ffffff006e0300
fffffffffffffff100dcc00000000000
f1ffffff006e0300
fffffff100dcc000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>13673,c=>84,a=>122,b=>1,d=>3}
7a0000000154030069350000
7a000000000000000154030069350000
7a000000000000000154030069350000
0000007a40a8c0006ad20000
7a0000000154030069350000
7a0000000154030069350000
000000000000007a40a8c0006ad20000
7a0000000154030069350000
0000007a40a8c0006ad20000
-
{e=>31547,c=>111,a=>-80,b=>1,d=>0}
b0ffffff016f00003b7b0000
b0ffffffffffffff016f00003b7b0000
b0ffffffffffffff016f00003b7b0000
ffffffb040de0000f6760000
b0ffffff016f00003b7b0000
b0ffffff016f00003b7b0000
ffffffffffffffb040de0000f6760000
b0ffffff016f00003b7b0000
ffffffb040de0000f6760000
-
{e=>19845,c=>63,a=>77,b=>1,d=>3}
4d000000013f0300854d0000
4d00000000000000013f0300854d0000
4d00000000000000013f0300854d0000
0000004d407ec0009b0a0000
4d000000013f0300854d0000
4d000000013f0300854d0000
000000000000004d407ec0009b0a0000
4d000000013f0300854d0000
0000004d407ec0009b0a0000
-
{e=>6913,c=>104,a=>127,b=>2,d=>1}
7f00000002680100011b0000
7f0000000000000002680100011b0000
7f0000000000000002680100011b0000
0000007f80d0400036020000
7f00000002680100011b0000
7f00000002680100011b0000
000000000000007f80d0400036020000
7f00000002680100011b0000
0000007f80d0400036020000
-
{e=>16426,c=>0,a=>57,b=>1,d=>0}
39000000010000002a400000
3900000000000000010000002a400000
3900000000000000010000002a400000
000000394000000080540000
39000000010000002a400000
39000000010000002a400000
00000000000000394000000080540000
39000000010000002a400000
000000394000000080540000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>30485,c=>17,a=>-61,b=>1,d=>2}
c3ffffff0111020015770000
c3ffffffffffffff0111020015770000
c3ffffffffffffff0111020015770000
ffffffc340228000ee2a0000
c3ffffff0111020015770000
c3ffffff0111020015770000
ffffffffffffffc340228000ee2a0000
c3ffffff0111020015770000
ffffffc340228000ee2a0000
-
{e=>4491,c=>69,a=>-114,b=>1,d=>3}
8effffff014503008b110000
8effffffffffffff014503008b110000
8effffffffffffff014503008b110000
ffffff8e408ac00023160000
8effffff014503008b110000
8effffff014503008b110000
ffffffffffffff8e408ac00023160000
8effffff014503008b110000
ffffff8e408ac00023160000
-
{e=>1064,c=>91,a=>-67,b=>0,d=>0}
bdffffff005b000028040000
bdffffffffffffff005b000028040000
bdffffffffffffff005b000028040000
ffffffbd00b6000008500000
bdffffff005b000028040000
bdffffff005b000028040000
ffffffffffffffbd00b6000008500000
bdffffff005b000028040000
ffffffbd00b6000008500000
-
{e=>26263,c=>40,a=>2,b=>2,d=>1}
020000000228010097660000
02000000000000000228010097660000
02000000000000000228010097660000
0000000280504000cd2e0000
020000000228010097660000
020000000228010097660000
000000000000000280504000cd2e0000
020000000228010097660000
0000000280504000cd2e0000
-
{e=>1533,c=>107,a=>-62,b=>3,d=>3}
c2ffffff036b0300fd050000
c2ffffffffffffff036b0300fd050000
c2ffffffffffffff036b0300fd050000
ffffffc2c0d6c0000bfa0000
c2ffffff036b0300fd050000
c2ffffff036b0300fd050000
ffffffffffffffc2c0d6c0000bfa0000
c2ffffff036b0300fd050000
ffffffc2c0d6c0000bfa0000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>6622,c=>119,a=>103,b=>2,d=>1,f=>3}
6700000002770100de19000003000000
670000000000000002770100de1900000300000000000000
670000000000000002770100de1900000300000000000000
0000006780ee400033bc0000c0000000
6700000002770100de19000003000000
6700000002770100de19000003000000
000000000000006780ee400033bc0000c000000000000000
6700000002770100de19000003000000
0000006780ee400033bc0000c0000000
-
{e=>7645,c=>92,a=>55,b=>0,d=>1,f=>3}
37000000005c0100dd1d000003000000
3700000000000000005c0100dd1d00000300000000000000
3700000000000000005c0100dd1d00000300000000000000
0000003700b840003bba0000c0000000
37000000005c0100dd1d000003000000
37000000005c0100dd1d000003000000
000000000000003700b840003bba0000c000000000000000
37000000005c0100dd1d000003000000
0000003700b840003bba0000c0000000
-
{e=>23069,c=>56,a=>60,b=>3,d=>0,f=>2}
3c000000033800001d5a000002000000
3c00000000000000033800001d5a00000200000000000000
3c00000000000000033800001d5a00000200000000000000
0000003cc0700000b43a000080000000
3c000000033800001d5a000002000000
3c000000033800001d5a000002000000
000000000000003cc0700000b43a00008000000000000000
3c000000033800001d5a000002000000
0000003cc0700000b43a000080000000
-
{e=>27949,c=>1,a=>-7,b=>2,d=>3,f=>3}
f9ffffff020103002d6d000003000000
f9ffffffffffffff020103002d6d00000300000000000000
f9ffffffffffffff020103002d6d00000300000000000000
fffffff98002c000da5a0000c0000000
f9ffffff020103002d6d000003000000
f9ffffff020103002d6d000003000000
fffffffffffffff98002c000da5a0000c000000000000000
f9ffffff020103002d6d000003000000
fffffff98002c000da5a0000c0000000
-
{e=>11648,c=>90,a=>72,b=>2,d=>3,f=>1}
48000000025a0300802d000001000000
4800000000000000025a0300802d00000100000000000000
4800000000000000025a0300802d00000100000000000000
0000004880b4c0005b00000040000000
48000000025a0300802d000001000000
48000000025a0300802d000001000000
000000000000004880b4c0005b0000004000000000000000
48000000025a0300802d000001000000
0000004880b4c0005b00000040000000
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>20058,c=>21,a=>-54,g=>527765798,b=>2,d=>1,f=>2}
caffffff021501005a4e0000020000002611751f
caffffffffffffff021501005a4e0000020000002611751f
caffffffffffffff021501005a4e0000020000002611751f
ffffffca802a40009cb40000800000003eea224c
caffffff021501005a4e0000020000002611751f
caffffff021501005a4e0000020000002611751f
ffffffffffffffca802a40009cb40000800000003eea224c
caffffff021501005a4e0000020000002611751f
ffffffca802a40009cb40000800000003eea224c
-
{e=>31782,c=>68,a=>19,g=>946001649,b=>3,d=>0,f=>3}
1300000003440000267c000003000000f1d66238
130000000000000003440000267c000003000000f1d66238
130000000000000003440000267c000003000000f1d66238
00000013c0880000f84c0000c000000070c5ade2
1300000003440000267c000003000000f1d66238
1300000003440000267c000003000000f1d66238
0000000000000013c0880000f84c0000c000000070c5ade2
1300000003440000267c000003000000f1d66238
00000013c0880000f84c0000c000000070c5ade2
-
{e=>7380,c=>37,a=>-52,g=>464958575,b=>2,d=>3,f=>1}
ccffffff02250300d41c0000010000006fb4b61b
ccffffffffffffff02250300d41c0000010000006fb4b61b
ccffffffffffffff02250300d41c0000010000006fb4b61b
ffffffcc804ac00039a8000040000000376d68de
ccffffff02250300d41c0000010000006fb4b61b
ccffffff02250300d41c0000010000006fb4b61b
ffffffffffffffcc804ac00039a8000040000000376d68de
ccffffff02250300d41c0000010000006fb4b61b
ffffffcc804ac00039a8000040000000376d68de
-
{e=>21112,c=>42,a=>42,g=>906361925,b=>1,d=>0,f=>2}
2a000000012a0000785200000200000045fc0536
2a00000000000000012a0000785200000200000045fc0536
2a00000000000000012a0000785200000200000045fc0536
0000002a40540000a4f00000800000006c0bf88a
2a000000012a0000785200000200000045fc0536
2a000000012a0000785200000200000045fc0536
000000000000002a40540000a4f00000800000006c0bf88a
2a000000012a0000785200000200000045fc0536
0000002a40540000a4f00000800000006c0bf88a
-
{e=>30855,c=>1,a=>53,g=>1190588411,b=>0,d=>0,f=>1}
35000000000100008778000001000000fbeff646
3500000000000000000100008778000001000000fbeff646
3500000000000000000100008778000001000000fbeff646
0000003500020000f10e0000400000008deddff6
35000000000100008778000001000000fbeff646
35000000000100008778000001000000fbeff646
000000000000003500020000f10e0000400000008deddff6
35000000000100008778000001000000fbeff646
0000003500020000f10e0000400000008deddff6
=
#if defined PACK_PAREN
#pragma pack( 1 )
#elif defined PACK_NO_PAREN
#pragma pack 1
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>12949,a=>112,d=>2,c=>46,h=>27,b=>1,g=>348067209,f=>0}
70000000012e020095320000000000008915bf141b000000
7000000000000000012e020095320000000000008915bf141b00000000000000
7000000000000000012e020095320000000000008915bf141b00000000000000
00000070405c8000652a000000000000297e2b121b000000
70000000012e020095320000000000008915bf141b000000
70000000012e020095320000000000008915bf141b000000
0000000000000070405c8000652a000000000000297e2b121b00000000000000
70000000012e020095320000000000008915bf141b000000
00000070405c8000652a000000000000297e2b121b000000
-
{e=>12614,a=>-75,d=>0,c=>88,h=>124,b=>2,g=>2115801870,f=>3}
b5ffffff0258000046310000030000000e931c7e7c000000
b5ffffffffffffff0258000046310000030000000e931c7e7c00000000000000
b5ffffffffffffff0258000046310000030000000e931c7e7c00000000000000
ffffffb580b00000628c0000c0000000fc39261c7c000000
b5ffffff0258000046310000030000000e931c7e7c000000
b5ffffff0258000046310000030000000e931c7e7c000000
ffffffffffffffb580b00000628c0000c0000000fc39261c7c00000000000000
b5ffffff0258000046310000030000000e931c7e7c000000
ffffffb580b00000628c0000c0000000fc39261c7c000000
-
{e=>22026,a=>-26,d=>1,c=>44,h=>122,b=>2,g=>1176974089,f=>1}
e6ffffff022c01000a56000001000000093327467a000000
e6ffffffffffffff022c01000a56000001000000093327467a00000000000000
e6ffffffffffffff022c01000a56000001000000093327467a00000000000000
ffffffe680584000ac140000400000008c4e66127a000000
e6ffffff022c01000a56000001000000093327467a000000
e6ffffff022c01000a56000001000000093327467a000000
ffffffffffffffe680584000ac140000400000008c4e66127a00000000000000
e6ffffff022c01000a56000001000000093327467a000000
ffffffe680584000ac140000400000008c4e66127a000000
-
{e=>23544,a=>64,d=>3,c=>24,h=>65,b=>3,g=>598810224,f=>3}
4000000003180300f85b000003000000701eb12341000000
400000000000000003180300f85b000003000000701eb1234100000000000000
400000000000000003180300f85b000003000000701eb1234100000000000000
00000040c030c000b7f00000c000000047623ce041000000
4000000003180300f85b000003000000701eb12341000000
4000000003180300f85b000003000000701eb12341000000
0000000000000040c030c000b7f00000c000000047623ce04100000000000000
4000000003180300f85b000003000000701eb12341000000
00000040c030c000b7f00000c000000047623ce041000000
-
{e=>30624,a=>65,d=>0,c=>53,h=>114,b=>1,g=>378284213,f=>2}
4100000001350000a077000002000000b5288c1672000000
410000000000000001350000a077000002000000b5288c167200000000000000
410000000000000001350000a077000002000000b5288c167200000000000000
00000041406a0000ef400000800000002d18516a72000000
4100000001350000a077000002000000b5288c1672000000
4100000001350000a077000002000000b5288c1672000000
0000000000000041406a0000ef400000800000002d18516a7200000000000000
4100000001350000a077000002000000b5288c1672000000
00000041406a0000ef400000800000002d18516a72000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
};
-
{a=>0}
00
00
00
00
00000000
00
00
00
00
-
{a=>3}
03
03
03
c0
03000000
03
c0
03
c0
-
{a=>2}
02
02
02
80
02000000
02
80
02
80
-
{a=>1}
01
01
01
40
01000000
01
40
01
40
-
{a=>3}
03
03
03
c0
03000000
03
c0
03
c0
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
};
-
{a=>1,b=>60}
013c
013c
013c
4078
013c0000
013c
4078
013c
4078
-
{a=>3,b=>93}
035d
035d
035d
c0ba
035d0000
035d
c0ba
035d
c0ba
-
{a=>3,b=>13}
030d
030d
030d
c01a
030d0000
030d
c01a
030d
c01a
-
{a=>0,b=>66}
0042
0042
0042
0084
00420000
0042
0084
0042
0084
-
{a=>0,b=>56}
0038
0038
0038
0070
00380000
0038
0070
0038
0070
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
};
-
{a=>2,b=>26}
021a
021a
021a
8034
021a0000
021a
8034
021a
8034
-
{a=>1,b=>51}
0133
0133
0133
4066
01330000
0133
4066
0133
4066
-
{a=>0,b=>90}
005a
005a
005a
00b4
005a0000
005a
00b4
005a
00b4
-
{a=>0,b=>63}
003f
003f
003f
007e
003f0000
003f
007e
003f
007e
-
{a=>3,b=>46}
032e
032e
032e
c05c
032e0000
032e
c05c
032e
c05c
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
};
-
{c=>0,a=>3,b=>10}
030a0000
030a0000
030a0000
c0140000
030a0000
030a0000
c0140000
030a0000
c0140000
-
{c=>2,a=>1,b=>22}
01160200
01160200
01160200
402c8000
01160200
01160200
402c8000
01160200
402c8000
-
{c=>2,a=>3,b=>21}
03150200
03150200
03150200
c02a8000
03150200
03150200
c02a8000
03150200
c02a8000
-
{c=>3,a=>1,b=>40}
01280300
01280300
01280300
4050c000
01280300
01280300
4050c000
01280300
4050c000
-
{c=>3,a=>2,b=>35}
02230300
02230300
02230300
8046c000
02230300
02230300
8046c000
02230300
8046c000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
};
-
{c=>1,a=>3,b=>106,d=>4863}
036a0100ff12
036a0100ff12
036a0100ff12
c0d4400025fe
036a0100ff120000
036a0100ff12
c0d4400025fe
036a0100ff12
c0d4400025fe
-
{c=>2,a=>3,b=>103,d=>15834}
03670200da3d
03670200da3d
03670200da3d
c0ce80007bb4
03670200da3d0000
03670200da3d
c0ce80007bb4
03670200da3d
c0ce80007bb4
-
{c=>2,a=>0,b=>63,d=>15070}
003f0200de3a
003f0200de3a
003f0200de3a
007e800075bc
003f0200de3a0000
003f0200de3a
007e800075bc
003f0200de3a
007e800075bc
-
{c=>2,a=>3,b=>122,d=>25867}
037a02000b65
037a02000b65
037a02000b65
c0f48000ca16
037a02000b650000
037a02000b65
c0f48000ca16
037a02000b65
c0f48000ca16
-
{c=>3,a=>3,b=>3,d=>19726}
030303000e4d
030303000e4d
030303000e4d
c006c0009a1c
030303000e4d0000
030303000e4d
c006c0009a1c
030303000e4d
c006c0009a1c
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
};
-
{c=>3,a=>2,b=>61,d=>16632}
023d0300f8400000
023d0300f8400000
023d0300f8400000
807ac00081f00000
023d0300f8400000
023d0300f8400000
807ac00081f00000
023d0300f8400000
807ac00081f00000
-
{c=>3,a=>2,b=>27,d=>3303}
021b0300e70c0000
021b0300e70c0000
021b0300e70c0000
8036c00019ce0000
021b0300e70c0000
021b0300e70c0000
8036c00019ce0000
021b0300e70c0000
8036c00019ce0000
-
{c=>3,a=>0,b=>104,d=>32422}
00680300a67e0000
00680300a67e0000
00680300a67e0000
00d0c000fd4c0000
00680300a67e0000
00680300a67e0000
00d0c000fd4c0000
00680300a67e0000
00d0c000fd4c0000
-
{c=>2,a=>2,b=>11,d=>4097}
020b020001100000
020b020001100000
020b020001100000
8016800020020000
020b020001100000
020b020001100000
8016800020020000
020b020001100000
8016800020020000
-
{c=>0,a=>2,b=>22,d=>2075}
021600001b080000
021600001b080000
021600001b080000
802c000010360000
021600001b080000
021600001b080000
802c000010360000
021600001b080000
802c000010360000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
  unsigned int   e:2;
};
-
{e=>3,c=>2,a=>3,b=>70,d=>22538}
034602000a58000003000000
034602000a58000003000000
034602000a58000003000000
c08c8000b0140000c0000000
034602000a58000003000000
034602000a58000003000000
c08c8000b0140000c0000000
034602000a58000003000000
c08c8000b0140000c0000000
-
{e=>1,c=>0,a=>2,b=>126,d=>20675}
027e0000c350000001000000
027e0000c350000001000000
027e0000c350000001000000
80fc0000a186000040000000
027e0000c350000001000000
027e0000c350000001000000
80fc0000a186000040000000
027e0000c350000001000000
80fc0000a186000040000000
-
{e=>2,c=>0,a=>1,b=>97,d=>22568}
016100002858000002000000
016100002858000002000000
016100002858000002000000
40c20000b050000080000000
016100002858000002000000
016100002858000002000000
40c20000b050000080000000
016100002858000002000000
40c20000b050000080000000
-
{e=>2,c=>0,a=>3,b=>84,d=>1178}
035400009a04000002000000
035400009a04000002000000
035400009a04000002000000
c0a800000934000080000000
035400009a04000002000000
035400009a04000002000000
c0a800000934000080000000
035400009a04000002000000
c0a800000934000080000000
-
{e=>0,c=>3,a=>0,b=>125,d=>500}
007d0300f401000000000000
007d0300f401000000000000
007d0300f401000000000000
00fac00003e8000000000000
007d0300f401000000000000
007d0300f401000000000000
00fac00003e8000000000000
007d0300f401000000000000
00fac00003e8000000000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
  unsigned int   e:2;
  unsigned int   f:31;
};
-
{e=>3,c=>3,a=>1,b=>44,d=>24620,f=>1808311042}
012c03002c6000000300000002a3c86b
012c03002c6000000300000002a3c86b
012c03002c6000000300000002a3c86b
4058c000c0580000c0000000d7914604
012c03002c6000000300000002a3c86b
012c03002c6000000300000002a3c86b
4058c000c0580000c0000000d7914604
012c03002c6000000300000002a3c86b
4058c000c0580000c0000000d7914604
-
{e=>1,c=>2,a=>1,b=>25,d=>25227,f=>801958710}
011902008b6200000100000036ebcc2f
011902008b6200000100000036ebcc2f
011902008b6200000100000036ebcc2f
40328000c5160000400000005f99d66c
011902008b6200000100000036ebcc2f
011902008b6200000100000036ebcc2f
40328000c5160000400000005f99d66c
011902008b6200000100000036ebcc2f
40328000c5160000400000005f99d66c
-
{e=>1,c=>3,a=>3,b=>101,d=>18705,f=>1451666857}
036503001149000001000000a9ad8656
036503001149000001000000a9ad8656
036503001149000001000000a9ad8656
c0cac0009222000040000000ad0d5b52
036503001149000001000000a9ad8656
036503001149000001000000a9ad8656
c0cac0009222000040000000ad0d5b52
036503001149000001000000a9ad8656
c0cac0009222000040000000ad0d5b52
-
{e=>0,c=>1,a=>3,b=>11,d=>27785,f=>1658211394}
030b0100896c000000000000424cd662
030b0100896c000000000000424cd662
030b0100896c000000000000424cd662
c0164000d912000000000000c5ac9884
030b0100896c000000000000424cd662
030b0100896c000000000000424cd662
c0164000d912000000000000c5ac9884
030b0100896c000000000000424cd662
c0164000d912000000000000c5ac9884
-
{e=>2,c=>3,a=>2,b=>99,d=>30270,f=>922018987}
026303003e76000002000000abe4f436
026303003e76000002000000abe4f436
026303003e76000002000000abe4f436
80c6c000ec7c0000800000006de9c956
026303003e76000002000000abe4f436
026303003e76000002000000abe4f436
80c6c000ec7c0000800000006de9c956
026303003e76000002000000abe4f436
80c6c000ec7c0000800000006de9c956
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
  unsigned int   e:2;
  unsigned int   f:31;
  unsigned char  g;
};
-
{e=>2,c=>1,a=>3,g=>159,b=>94,d=>10039,f=>410307155}
035e0100372700000200000053ca74189f000000
035e0100372700000200000053ca74189f000000
035e0100372700000200000053ca74189f000000
c0bc40004e6e00008000000030e994a69f000000
035e0100372700000200000053ca74189f000000
035e0100372700000200000053ca74189f000000
c0bc40004e6e00008000000030e994a69f000000
035e0100372700000200000053ca74189f000000
c0bc40004e6e00008000000030e994a69f000000
-
{e=>2,c=>1,a=>2,g=>50,b=>106,d=>11247,f=>668484590}
026a0100ef2b000002000000ee43d82732000000
026a0100ef2b000002000000ee43d82732000000
026a0100ef2b000002000000ee43d82732000000
80d4400057de0000800000004fb087dc32000000
026a0100ef2b000002000000ee43d82732000000
026a0100ef2b000002000000ee43d82732000000
80d4400057de0000800000004fb087dc32000000
026a0100ef2b000002000000ee43d82732000000
80d4400057de0000800000004fb087dc32000000
-
{e=>0,c=>0,a=>3,g=>181,b=>49,d=>12908,f=>38446332}
033100006c32000000000000fca44a02b5000000
033100006c32000000000000fca44a02b5000000
033100006c32000000000000fca44a02b5000000
c062000064d8000000000000049549f8b5000000
033100006c32000000000000fca44a02b5000000
033100006c32000000000000fca44a02b5000000
c062000064d8000000000000049549f8b5000000
033100006c32000000000000fca44a02b5000000
c062000064d8000000000000049549f8b5000000
-
{e=>0,c=>2,a=>0,g=>106,b=>119,d=>27698,f=>1629435493}
00770200326c00000000000065361f616a000000
00770200326c00000000000065361f616a000000
00770200326c00000000000065361f616a000000
00ee8000d864000000000000c23e6cca6a000000
00770200326c00000000000065361f616a000000
00770200326c00000000000065361f616a000000
00ee8000d864000000000000c23e6cca6a000000
00770200326c00000000000065361f616a000000
00ee8000d864000000000000c23e6cca6a000000
-
{e=>3,c=>2,a=>3,g=>36,b=>28,d=>17585,f=>1462750237}
031c0200b1440000030000001dcc2f5724000000
031c0200b1440000030000001dcc2f5724000000
031c0200b1440000030000001dcc2f5724000000
c038800089620000c0000000ae5f983a24000000
031c0200b1440000030000001dcc2f5724000000
031c0200b1440000030000001dcc2f5724000000
c038800089620000c0000000ae5f983a24000000
031c0200b1440000030000001dcc2f5724000000
c038800089620000c0000000ae5f983a24000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
};
-
{a=>97,b=>0}
6100
6100
6100
6100
61000000
6100
6100
6100
6100
-
{a=>-113,b=>1}
8f01
8f01
8f01
8f40
8f010000
8f01
8f40
8f01
8f40
-
{a=>97,b=>1}
6101
6101
6101
6140
61010000
6101
6140
6101
6140
-
{a=>43,b=>0}
2b00
2b00
2b00
2b00
2b000000
2b00
2b00
2b00
2b00
-
{a=>8,b=>2}
0802
0802
0802
0880
08020000
0802
0880
0802
0880
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>121,a=>95,b=>1}
5f0179
5f0179
5f0179
5f40f2
5f017900
5f0179
5f40f2
5f0179
5f40f2
-
{c=>47,a=>-39,b=>1}
d9012f
d9012f
d9012f
d9405e
d9012f00
d9012f
d9405e
d9012f
d9405e
-
{c=>126,a=>-116,b=>3}
8c037e
8c037e
8c037e
8cc0fc
8c037e00
8c037e
8cc0fc
8c037e
8cc0fc
-
{c=>60,a=>-8,b=>3}
f8033c
f8033c
f8033c
f8c078
f8033c00
f8033c
f8c078
f8033c
f8c078
-
{c=>50,a=>-3,b=>3}
fd0332
fd0332
fd0332
fdc064
fd033200
fd0332
fdc064
fd0332
fdc064
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>91,a=>-79,b=>2}
b1025b00
b1025b00
b1025b00
b180b600
b1025b00
b1025b00
b180b600
b1025b00
b180b600
-
{c=>51,a=>-12,b=>1}
f4013300
f4013300
f4013300
f4406600
f4013300
f4013300
f4406600
f4013300
f4406600
-
{c=>113,a=>104,b=>2}
68027100
68027100
68027100
6880e200
68027100
68027100
6880e200
68027100
6880e200
-
{c=>40,a=>105,b=>3}
69032800
69032800
69032800
69c05000
69032800
69032800
69c05000
69032800
69c05000
-
{c=>3,a=>-77,b=>3}
b3030300
b3030300
b3030300
b3c00600
b3030300
b3030300
b3c00600
b3030300
b3c00600
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>80,a=>-57,b=>1,d=>2}
c70150000200
c70150000200
c70150000200
c740a0008000
c701500002000000
c70150000200
c740a0008000
c70150000200
c740a0008000
-
{c=>73,a=>13,b=>2,d=>0}
0d0249000000
0d0249000000
0d0249000000
0d8092000000
0d02490000000000
0d0249000000
0d8092000000
0d0249000000
0d8092000000
-
{c=>36,a=>-29,b=>0,d=>0}
e30024000000
e30024000000
e30024000000
e30048000000
e300240000000000
e30024000000
e30048000000
e30024000000
e30048000000
-
{c=>123,a=>-35,b=>1,d=>3}
dd017b000300
dd017b000300
dd017b000300
dd40f600c000
dd017b0003000000
dd017b000300
dd40f600c000
dd017b000300
dd40f600c000
-
{c=>124,a=>10,b=>3,d=>0}
0a037c000000
0a037c000000
0a037c000000
0ac0f8000000
0a037c0000000000
0a037c000000
0ac0f8000000
0a037c000000
0ac0f8000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>28834,c=>110,a=>-15,b=>3,d=>3}
f1036e000300a270
f1036e000300a270
f1036e000300a270
f1c0dc00c000e144
f1036e000300a270
f1036e000300a270
f1c0dc00c000e144
f1036e000300a270
f1c0dc00c000e144
-
{e=>1691,c=>38,a=>110,b=>1,d=>3}
6e01260003009b06
6e01260003009b06
6e01260003009b06
6e404c00c0000d36
6e01260003009b06
6e01260003009b06
6e404c00c0000d36
6e01260003009b06
6e404c00c0000d36
-
{e=>28902,c=>77,a=>121,b=>0,d=>0}
79004d000000e670
79004d000000e670
79004d000000e670
79009a000000e1cc
79004d000000e670
79004d000000e670
79009a000000e1cc
79004d000000e670
79009a000000e1cc
-
{e=>5288,c=>45,a=>70,b=>1,d=>3}
46012d000300a814
46012d000300a814
46012d000300a814
46405a00c0002950
46012d000300a814
46012d000300a814
46405a00c0002950
46012d000300a814
46405a00c0002950
-
{e=>5983,c=>60,a=>35,b=>2,d=>1}
23023c0001005f17
23023c0001005f17
23023c0001005f17
2380780040002ebe
23023c0001005f17
23023c0001005f17
2380780040002ebe
23023c0001005f17
2380780040002ebe
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>22747,c=>99,a=>17,b=>0,d=>3}
110063000300db58
110063000300db58
110063000300db58
1100c600c000b1b6
110063000300db58
110063000300db58
1100c600c000b1b6
110063000300db58
1100c600c000b1b6
-
{e=>8890,c=>116,a=>111,b=>3,d=>0}
6f0374000000ba22
6f0374000000ba22
6f0374000000ba22
6fc0e80000004574
6f0374000000ba22
6f0374000000ba22
6fc0e80000004574
6f0374000000ba22
6fc0e80000004574
-
{e=>26859,c=>36,a=>-47,b=>3,d=>0}
d10324000000eb68
d10324000000eb68
d10324000000eb68
d1c048000000d1d6
d10324000000eb68
d10324000000eb68
d1c048000000d1d6
d10324000000eb68
d1c048000000d1d6
-
{e=>4561,c=>1,a=>-82,b=>1,d=>2}
ae0101000200d111
ae0101000200d111
ae0101000200d111
ae400200800023a2
ae0101000200d111
ae0101000200d111
ae400200800023a2
ae0101000200d111
ae400200800023a2
-
{e=>862,c=>125,a=>22,b=>1,d=>3}
16017d0003005e03
16017d0003005e03
16017d0003005e03
1640fa00c00006bc
16017d0003005e03
16017d0003005e03
1640fa00c00006bc
16017d0003005e03
1640fa00c00006bc
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>7083,c=>105,a=>101,b=>1,d=>1,f=>1}
650169000100ab1b01000000
650169000100ab1b01000000
650169000100ab1b01000000
6540d2004000375640000000
650169000100ab1b01000000
650169000100ab1b01000000
6540d2004000375640000000
650169000100ab1b01000000
6540d2004000375640000000
-
{e=>26777,c=>7,a=>85,b=>2,d=>2,f=>0}
550207000200996800000000
550207000200996800000000
550207000200996800000000
55800e008000d13200000000
550207000200996800000000
550207000200996800000000
55800e008000d13200000000
550207000200996800000000
55800e008000d13200000000
-
{e=>2370,c=>62,a=>-56,b=>3,d=>0,f=>0}
c8033e000000420900000000
c8033e000000420900000000
c8033e000000420900000000
c8c07c000000128400000000
c8033e000000420900000000
c8033e000000420900000000
c8c07c000000128400000000
c8033e000000420900000000
c8c07c000000128400000000
-
{e=>17701,c=>23,a=>112,b=>0,d=>2,f=>0}
700017000200254500000000
700017000200254500000000
700017000200254500000000
70002e0080008a4a00000000
700017000200254500000000
700017000200254500000000
70002e0080008a4a00000000
700017000200254500000000
70002e0080008a4a00000000
-
{e=>7327,c=>107,a=>105,b=>0,d=>1,f=>1}
69006b0001009f1c01000000
69006b0001009f1c01000000
69006b0001009f1c01000000
6900d6004000393e40000000
69006b0001009f1c01000000
69006b0001009f1c01000000
6900d6004000393e40000000
69006b0001009f1c01000000
6900d6004000393e40000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>25941,c=>65,a=>-78,g=>738858833,b=>0,d=>1,f=>3}
b2004100010055650300000051170a2c
b2004100010055650300000051170a2c
b2004100010055650300000051170a2c
b20082004000caaac000000058142ea2
b2004100010055650300000051170a2c
b2004100010055650300000051170a2c
b20082004000caaac000000058142ea2
b2004100010055650300000051170a2c
b20082004000caaac000000058142ea2
-
{e=>16369,c=>84,a=>23,g=>253726160,b=>2,d=>3,f=>0}
170254000300f13f00000000d08d1f0f
170254000300f13f00000000d08d1f0f
170254000300f13f00000000d08d1f0f
1780a800c0007fe2000000001e3f1ba0
170254000300f13f00000000d08d1f0f
170254000300f13f00000000d08d1f0f
1780a800c0007fe2000000001e3f1ba0
170254000300f13f00000000d08d1f0f
1780a800c0007fe2000000001e3f1ba0
-
{e=>20549,c=>68,a=>-90,g=>1840050508,b=>0,d=>3,f=>2}
a600440003004550020000004cf1ac6d
a600440003004550020000004cf1ac6d
a600440003004550020000004cf1ac6d
a6008800c000a08a80000000db59e298
a600440003004550020000004cf1ac6d
a600440003004550020000004cf1ac6d
a6008800c000a08a80000000db59e298
a600440003004550020000004cf1ac6d
a6008800c000a08a80000000db59e298
-
{e=>4229,c=>122,a=>68,g=>163350911,b=>3,d=>1,f=>3}
44037a0001008510030000007f89bc09
44037a0001008510030000007f89bc09
44037a0001008510030000007f89bc09
44c0f4004000210ac0000000137912fe
44037a0001008510030000007f89bc09
44037a0001008510030000007f89bc09
44c0f4004000210ac0000000137912fe
44037a0001008510030000007f89bc09
44c0f4004000210ac0000000137912fe
-
{e=>2131,c=>18,a=>-48,g=>1460988621,b=>3,d=>3,f=>1}
d00312000300530801000000cdea1457
d00312000300530801000000cdea1457
d00312000300530801000000cdea1457
d0c02400c00010a640000000ae29d59a
d00312000300530801000000cdea1457
d00312000300530801000000cdea1457
d0c02400c00010a640000000ae29d59a
d00312000300530801000000cdea1457
d0c02400c00010a640000000ae29d59a
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>28672,a=>-38,d=>3,c=>3,h=>230,b=>0,g=>1572591659,f=>3}
da00030003000070030000002bd8bb5de6000000
da00030003000070030000002bd8bb5de6000000
da00030003000070030000002bd8bb5de6000000
da000600c000e000c0000000bb77b056e6000000
da00030003000070030000002bd8bb5de6000000
da00030003000070030000002bd8bb5de6000000
da000600c000e000c0000000bb77b056e6000000
da00030003000070030000002bd8bb5de6000000
da000600c000e000c0000000bb77b056e6000000
-
{e=>21420,a=>6,d=>3,c=>126,h=>29,b=>1,g=>1987843785,f=>2}
06017e000300ac5302000000c9167c761d000000
06017e000300ac5302000000c9167c761d000000
06017e000300ac5302000000c9167c761d000000
0640fc00c000a75880000000ecf82d921d000000
06017e000300ac5302000000c9167c761d000000
06017e000300ac5302000000c9167c761d000000
0640fc00c000a75880000000ecf82d921d000000
06017e000300ac5302000000c9167c761d000000
0640fc00c000a75880000000ecf82d921d000000
-
{e=>24974,a=>83,d=>3,c=>26,h=>197,b=>0,g=>375167546,f=>0}
53001a0003008e61000000003a9a5c16c5000000
53001a0003008e61000000003a9a5c16c5000000
53001a0003008e61000000003a9a5c16c5000000
53003400c000c31c000000002cb93474c5000000
53001a0003008e61000000003a9a5c16c5000000
53001a0003008e61000000003a9a5c16c5000000
53003400c000c31c000000002cb93474c5000000
53001a0003008e61000000003a9a5c16c5000000
53003400c000c31c000000002cb93474c5000000
-
{e=>10987,a=>91,d=>0,c=>96,h=>171,b=>1,g=>1441248927,f=>3}
5b0160000000eb2a030000009fb6e755ab000000
5b0160000000eb2a030000009fb6e755ab000000
5b0160000000eb2a030000009fb6e755ab000000
5b40c000000055d6c0000000abcf6d3eab000000
5b0160000000eb2a030000009fb6e755ab000000
5b0160000000eb2a030000009fb6e755ab000000
5b40c000000055d6c0000000abcf6d3eab000000
5b0160000000eb2a030000009fb6e755ab000000
5b40c000000055d6c0000000abcf6d3eab000000
-
{e=>7107,a=>62,d=>3,c=>84,h=>49,b=>0,g=>1539603978,f=>0}
3e0054000300c31b000000000a7ec45b31000000
3e0054000300c31b000000000a7ec45b31000000
3e0054000300c31b000000000a7ec45b31000000
3e00a800c000378600000000b788fc1431000000
3e0054000300c31b000000000a7ec45b31000000
3e0054000300c31b000000000a7ec45b31000000
3e00a800c000378600000000b788fc1431000000
3e0054000300c31b000000000a7ec45b31000000
3e00a800c000378600000000b788fc1431000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
};
-
{a=>-78,b=>1}
b2ff0100
b2ff0100
b2ff0100
ffb24000
b2ff0100
b2ff0100
ffb24000
b2ff0100
ffb24000
-
{a=>-18,b=>2}
eeff0200
eeff0200
eeff0200
ffee8000
eeff0200
eeff0200
ffee8000
eeff0200
ffee8000
-
{a=>3,b=>3}
03000300
03000300
03000300
0003c000
03000300
03000300
0003c000
03000300
0003c000
-
{a=>-8,b=>0}
f8ff0000
f8ff0000
f8ff0000
fff80000
f8ff0000
f8ff0000
fff80000
f8ff0000
fff80000
-
{a=>114,b=>1}
72000100
72000100
72000100
00724000
72000100
72000100
00724000
72000100
00724000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>46,a=>40,b=>3}
2800032e
2800032e
2800032e
0028c05c
2800032e
2800032e
0028c05c
2800032e
0028c05c
-
{c=>26,a=>116,b=>1}
7400011a
7400011a
7400011a
00744034
7400011a
7400011a
00744034
7400011a
00744034
-
{c=>116,a=>-66,b=>3}
beff0374
beff0374
beff0374
ffbec0e8
beff0374
beff0374
ffbec0e8
beff0374
ffbec0e8
-
{c=>45,a=>-35,b=>2}
ddff022d
ddff022d
ddff022d
ffdd805a
ddff022d
ddff022d
ffdd805a
ddff022d
ffdd805a
-
{c=>30,a=>75,b=>3}
4b00031e
4b00031e
4b00031e
004bc03c
4b00031e
4b00031e
004bc03c
4b00031e
004bc03c
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>51,a=>56,b=>2}
38000233
38000233
38000233
00388066
38000233
38000233
00388066
38000233
00388066
-
{c=>76,a=>38,b=>0}
2600004c
2600004c
2600004c
00260098
2600004c
2600004c
00260098
2600004c
00260098
-
{c=>31,a=>-74,b=>3}
b6ff031f
b6ff031f
b6ff031f
ffb6c03e
b6ff031f
b6ff031f
ffb6c03e
b6ff031f
ffb6c03e
-
{c=>95,a=>53,b=>0}
3500005f
3500005f
3500005f
003500be
3500005f
3500005f
003500be
3500005f
003500be
-
{c=>65,a=>-118,b=>2}
8aff0241
8aff0241
8aff0241
ff8a8082
8aff0241
8aff0241
ff8a8082
8aff0241
ff8a8082
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>104,a=>-99,b=>1,d=>3}
9dff01680300
9dff01680300
9dff01680300
ff9d40d0c000
9dff016803000000
9dff01680300
ff9d40d0c000
9dff01680300
ff9d40d0c000
-
{c=>113,a=>-77,b=>0,d=>3}
b3ff00710300
b3ff00710300
b3ff00710300
ffb300e2c000
b3ff007103000000
b3ff00710300
ffb300e2c000
b3ff00710300
ffb300e2c000
-
{c=>38,a=>119,b=>1,d=>3}
770001260300
770001260300
770001260300
0077404cc000
7700012603000000
770001260300
0077404cc000
770001260300
0077404cc000
-
{c=>120,a=>-5,b=>0,d=>0}
fbff00780000
fbff00780000
fbff00780000
fffb00f00000
fbff007800000000
fbff00780000
fffb00f00000
fbff00780000
fffb00f00000
-
{c=>94,a=>-19,b=>3,d=>2}
edff035e0200
edff035e0200
edff035e0200
ffedc0bc8000
edff035e02000000
edff035e0200
ffedc0bc8000
edff035e0200
ffedc0bc8000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>9932,c=>43,a=>-80,b=>2,d=>3}
b0ff022b0300cc26
b0ff022b0300cc26
b0ff022b0300cc26
ffb08056c0004d98
b0ff022b0300cc26
b0ff022b0300cc26
ffb08056c0004d98
b0ff022b0300cc26
ffb08056c0004d98
-
{e=>30764,c=>117,a=>-54,b=>0,d=>2}
caff007502002c78
caff007502002c78
caff007502002c78
ffca00ea8000f058
caff007502002c78
caff007502002c78
ffca00ea8000f058
caff007502002c78
ffca00ea8000f058
-
{e=>13093,c=>118,a=>118,b=>3,d=>0}
7600037600002533
7600037600002533
7600037600002533
0076c0ec0000664a
7600037600002533
7600037600002533
0076c0ec0000664a
7600037600002533
0076c0ec0000664a
-
{e=>20007,c=>75,a=>-56,b=>3,d=>2}
c8ff034b0200274e
c8ff034b0200274e
c8ff034b0200274e
ffc8c09680009c4e
c8ff034b0200274e
c8ff034b0200274e
ffc8c09680009c4e
c8ff034b0200274e
ffc8c09680009c4e
-
{e=>29692,c=>120,a=>45,b=>1,d=>3}
2d0001780300fc73
2d0001780300fc73
2d0001780300fc73
002d40f0c000e7f8
2d0001780300fc73
2d0001780300fc73
002d40f0c000e7f8
2d0001780300fc73
002d40f0c000e7f8
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>1707,c=>51,a=>-92,b=>2,d=>0}
a4ff02330000ab06
a4ff02330000ab06
a4ff02330000ab06
ffa4806600000d56
a4ff02330000ab06
a4ff02330000ab06
ffa4806600000d56
a4ff02330000ab06
ffa4806600000d56
-
{e=>22195,c=>16,a=>-106,b=>0,d=>3}
96ff00100300b356
96ff00100300b356
96ff00100300b356
ff960020c000ad66
96ff00100300b356
96ff00100300b356
ff960020c000ad66
96ff00100300b356
ff960020c000ad66
-
{e=>26092,c=>101,a=>-52,b=>3,d=>0}
ccff03650000ec65
ccff03650000ec65
ccff03650000ec65
ffccc0ca0000cbd8
ccff03650000ec65
ccff03650000ec65
ffccc0ca0000cbd8
ccff03650000ec65
ffccc0ca0000cbd8
-
{e=>10767,c=>23,a=>120,b=>3,d=>0}
7800031700000f2a
7800031700000f2a
7800031700000f2a
0078c02e0000541e
7800031700000f2a
7800031700000f2a
0078c02e0000541e
7800031700000f2a
0078c02e0000541e
-
{e=>22371,c=>42,a=>97,b=>0,d=>3}
6100002a03006357
6100002a03006357
6100002a03006357
00610054c000aec6
6100002a03006357
6100002a03006357
00610054c000aec6
6100002a03006357
00610054c000aec6
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>5426,c=>73,a=>107,b=>1,d=>2,f=>3}
6b0001490200321503000000
6b0001490200321503000000
6b0001490200321503000000
006b409280002a64c0000000
6b0001490200321503000000
6b0001490200321503000000
006b409280002a64c0000000
6b0001490200321503000000
006b409280002a64c0000000
-
{e=>25684,c=>82,a=>-99,b=>3,d=>2,f=>1}
9dff03520200546401000000
9dff03520200546401000000
9dff03520200546401000000
ff9dc0a48000c8a840000000
9dff03520200546401000000
9dff03520200546401000000
ff9dc0a48000c8a840000000
9dff03520200546401000000
ff9dc0a48000c8a840000000
-
{e=>5420,c=>23,a=>75,b=>2,d=>1,f=>0}
4b00021701002c1500000000
4b00021701002c1500000000
4b00021701002c1500000000
004b802e40002a5800000000
4b00021701002c1500000000
4b00021701002c1500000000
004b802e40002a5800000000
4b00021701002c1500000000
004b802e40002a5800000000
-
{e=>2354,c=>11,a=>-63,b=>0,d=>1,f=>3}
c1ff000b0100320903000000
c1ff000b0100320903000000
c1ff000b0100320903000000
ffc1001640001264c0000000
c1ff000b0100320903000000
c1ff000b0100320903000000
ffc1001640001264c0000000
c1ff000b0100320903000000
ffc1001640001264c0000000
-
{e=>14868,c=>64,a=>-6,b=>1,d=>3,f=>0}
faff01400300143a00000000
faff01400300143a00000000
faff01400300143a00000000
fffa4080c000742800000000
faff01400300143a00000000
faff01400300143a00000000
fffa4080c000742800000000
faff01400300143a00000000
fffa4080c000742800000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>7432,c=>46,a=>-97,g=>1876506977,b=>1,d=>2,f=>0}
9fff012e0200081d000000006139d96f
9fff012e0200081d000000006139d96f
9fff012e0200081d000000006139d96f
ff9f405c80003a1000000000dfb272c2
9fff012e0200081d000000006139d96f
9fff012e0200081d000000006139d96f
ff9f405c80003a1000000000dfb272c2
9fff012e0200081d000000006139d96f
ff9f405c80003a1000000000dfb272c2
-
{e=>19949,c=>124,a=>32,g=>396727791,b=>2,d=>1,f=>2}
2000027c0100ed4d02000000ef95a517
2000027c0100ed4d02000000ef95a517
2000027c0100ed4d02000000ef95a517
002080f840009bda800000002f4b2bde
2000027c0100ed4d02000000ef95a517
2000027c0100ed4d02000000ef95a517
002080f840009bda800000002f4b2bde
2000027c0100ed4d02000000ef95a517
002080f840009bda800000002f4b2bde
-
{e=>1774,c=>10,a=>110,g=>861455959,b=>0,d=>3,f=>3}
6e00000a0300ee060300000057c65833
6e00000a0300ee060300000057c65833
6e00000a0300ee060300000057c65833
006e0014c0000ddcc000000066b18cae
6e00000a0300ee060300000057c65833
6e00000a0300ee060300000057c65833
006e0014c0000ddcc000000066b18cae
6e00000a0300ee060300000057c65833
006e0014c0000ddcc000000066b18cae
-
{e=>17159,c=>124,a=>-113,g=>2079899019,b=>2,d=>3,f=>0}
8fff027c03000743000000008bbdf87b
8fff027c03000743000000008bbdf87b
8fff027c03000743000000008bbdf87b
ff8f80f8c000860e00000000f7f17b16
8fff027c03000743000000008bbdf87b
8fff027c03000743000000008bbdf87b
ff8f80f8c000860e00000000f7f17b16
8fff027c03000743000000008bbdf87b
ff8f80f8c000860e00000000f7f17b16
-
{e=>30127,c=>49,a=>-70,g=>1975146991,b=>0,d=>0,f=>3}
baff00310000af7503000000ef59ba75
baff00310000af7503000000ef59ba75
baff00310000af7503000000ef59ba75
ffba00620000eb5ec0000000eb74b3de
baff00310000af7503000000ef59ba75
baff00310000af7503000000ef59ba75
ffba00620000eb5ec0000000eb74b3de
baff00310000af7503000000ef59ba75
ffba00620000eb5ec0000000eb74b3de
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>3,a=>85,d=>1,c=>69,h=>236,b=>0,g=>486067682,f=>2}
550000450100030002000000e2cdf81cec000000
550000450100030002000000e2cdf81cec000000
550000450100030002000000e2cdf81cec000000
0055008a400000068000000039f19bc4ec000000
550000450100030002000000e2cdf81cec000000
550000450100030002000000e2cdf81cec000000
0055008a400000068000000039f19bc4ec000000
550000450100030002000000e2cdf81cec000000
0055008a400000068000000039f19bc4ec000000
-
{e=>30273,a=>-71,d=>3,c=>51,h=>105,b=>2,g=>1361574005,f=>3}
b9ff0233030041760300000075f8275169000000
b9ff0233030041760300000075f8275169000000
b9ff0233030041760300000075f8275169000000
ffb98066c000ec82c0000000a24ff0ea69000000
b9ff0233030041760300000075f8275169000000
b9ff0233030041760300000075f8275169000000
ffb98066c000ec82c0000000a24ff0ea69000000
b9ff0233030041760300000075f8275169000000
ffb98066c000ec82c0000000a24ff0ea69000000
-
{e=>25503,a=>-67,d=>3,c=>19,h=>175,b=>1,g=>190963807,f=>1}
bdff011303009f63010000005fe0610baf000000
bdff011303009f63010000005fe0610baf000000
bdff011303009f63010000005fe0610baf000000
ffbd4026c000c73e4000000016c3c0beaf000000
bdff011303009f63010000005fe0610baf000000
bdff011303009f63010000005fe0610baf000000
ffbd4026c000c73e4000000016c3c0beaf000000
bdff011303009f63010000005fe0610baf000000
ffbd4026c000c73e4000000016c3c0beaf000000
-
{e=>18177,a=>-30,d=>1,c=>47,h=>200,b=>1,g=>976748818,f=>3}
e2ff012f01000147030000001201383ac8000000
e2ff012f01000147030000001201383ac8000000
e2ff012f01000147030000001201383ac8000000
ffe2405e40008e02c000000074700224c8000000
e2ff012f01000147030000001201383ac8000000
e2ff012f01000147030000001201383ac8000000
ffe2405e40008e02c000000074700224c8000000
e2ff012f01000147030000001201383ac8000000
ffe2405e40008e02c000000074700224c8000000
-
{e=>29900,a=>97,d=>1,c=>20,h=>124,b=>0,g=>261624382,f=>3}
610000140100cc74030000003e12980f7c000000
610000140100cc74030000003e12980f7c000000
610000140100cc74030000003e12980f7c000000
006100284000e998c00000001f30247c7c000000
610000140100cc74030000003e12980f7c000000
610000140100cc74030000003e12980f7c000000
006100284000e998c00000001f30247c7c000000
610000140100cc74030000003e12980f7c000000
006100284000e998c00000001f30247c7c000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
};
-
{a=>-90,b=>3}
a6ffffff03000000
a6ffffff03000000
a6ffffff03000000
ffffffa6c0000000
a6ffffff03000000
a6ffffff03000000
ffffffa6c0000000
a6ffffff03000000
ffffffa6c0000000
-
{a=>41,b=>1}
2900000001000000
2900000001000000
2900000001000000
0000002940000000
2900000001000000
2900000001000000
0000002940000000
2900000001000000
0000002940000000
-
{a=>-89,b=>0}
a7ffffff00000000
a7ffffff00000000
a7ffffff00000000
ffffffa700000000
a7ffffff00000000
a7ffffff00000000
ffffffa700000000
a7ffffff00000000
ffffffa700000000
-
{a=>96,b=>0}
6000000000000000
6000000000000000
6000000000000000
0000006000000000
6000000000000000
6000000000000000
0000006000000000
6000000000000000
0000006000000000
-
{a=>-20,b=>3}
ecffffff03000000
ecffffff03000000
ecffffff03000000
ffffffecc0000000
ecffffff03000000
ecffffff03000000
ffffffecc0000000
ecffffff03000000
ffffffecc0000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>30,a=>-27,b=>1}
e5ffffff011e0000
e5ffffff011e0000
e5ffffff011e0000
ffffffe5403c0000
e5ffffff011e0000
e5ffffff011e0000
ffffffe5403c0000
e5ffffff011e0000
ffffffe5403c0000
-
{c=>124,a=>-69,b=>0}
bbffffff007c0000
bbffffff007c0000
bbffffff007c0000
ffffffbb00f80000
bbffffff007c0000
bbffffff007c0000
ffffffbb00f80000
bbffffff007c0000
ffffffbb00f80000
-
{c=>28,a=>-28,b=>0}
e4ffffff001c0000
e4ffffff001c0000
e4ffffff001c0000
ffffffe400380000
e4ffffff001c0000
e4ffffff001c0000
ffffffe400380000
e4ffffff001c0000
ffffffe400380000
-
{c=>99,a=>50,b=>0}
3200000000630000
3200000000630000
3200000000630000
0000003200c60000
3200000000630000
3200000000630000
0000003200c60000
3200000000630000
0000003200c60000
-
{c=>63,a=>-67,b=>3}
bdffffff033f0000
bdffffff033f0000
bdffffff033f0000
ffffffbdc07e0000
bdffffff033f0000
bdffffff033f0000
ffffffbdc07e0000
bdffffff033f0000
ffffffbdc07e0000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>26,a=>-54,b=>2}
caffffff021a0000
caffffff021a0000
caffffff021a0000
ffffffca80340000
caffffff021a0000
caffffff021a0000
ffffffca80340000
caffffff021a0000
ffffffca80340000
-
{c=>38,a=>126,b=>2}
7e00000002260000
7e00000002260000
7e00000002260000
0000007e804c0000
7e00000002260000
7e00000002260000
0000007e804c0000
7e00000002260000
0000007e804c0000
-
{c=>107,a=>-7,b=>0}
f9ffffff006b0000
f9ffffff006b0000
f9ffffff006b0000
fffffff900d60000
f9ffffff006b0000
f9ffffff006b0000
fffffff900d60000
f9ffffff006b0000
fffffff900d60000
-
{c=>13,a=>98,b=>3}
62000000030d0000
62000000030d0000
62000000030d0000
00000062c01a0000
62000000030d0000
62000000030d0000
00000062c01a0000
62000000030d0000
00000062c01a0000
-
{c=>97,a=>84,b=>2}
5400000002610000
5400000002610000
5400000002610000
0000005480c20000
5400000002610000
5400000002610000
0000005480c20000
5400000002610000
0000005480c20000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>110,a=>-46,b=>1,d=>2}
d2ffffff016e0200
d2ffffff016e0200
d2ffffff016e0200
ffffffd240dc8000
d2ffffff016e0200
d2ffffff016e0200
ffffffd240dc8000
d2ffffff016e0200
ffffffd240dc8000
-
{c=>99,a=>-7,b=>1,d=>1}
f9ffffff01630100
f9ffffff01630100
f9ffffff01630100
fffffff940c64000
f9ffffff01630100
f9ffffff01630100
fffffff940c64000
f9ffffff01630100
fffffff940c64000
-
{c=>88,a=>-1,b=>1,d=>2}
ffffffff01580200
ffffffff01580200
ffffffff01580200
ffffffff40b08000
ffffffff01580200
ffffffff01580200
ffffffff40b08000
ffffffff01580200
ffffffff40b08000
-
{c=>65,a=>-40,b=>0,d=>2}
d8ffffff00410200
d8ffffff00410200
d8ffffff00410200
ffffffd800828000
d8ffffff00410200
d8ffffff00410200
ffffffd800828000
d8ffffff00410200
ffffffd800828000
-
{c=>59,a=>-76,b=>0,d=>0}
b4ffffff003b0000
b4ffffff003b0000
b4ffffff003b0000
ffffffb400760000
b4ffffff003b0000
b4ffffff003b0000
ffffffb400760000
b4ffffff003b0000
ffffffb400760000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>32442,c=>51,a=>3,b=>0,d=>0}
0300000000330000ba7e0000
0300000000330000ba7e0000
0300000000330000ba7e0000
0000000300660000fd740000
0300000000330000ba7e0000
0300000000330000ba7e0000
0000000300660000fd740000
0300000000330000ba7e0000
0000000300660000fd740000
-
{e=>9995,c=>67,a=>48,b=>2,d=>2}
30000000024302000b270000
30000000024302000b270000
30000000024302000b270000
00000030808680004e160000
30000000024302000b270000
30000000024302000b270000
00000030808680004e160000
30000000024302000b270000
00000030808680004e160000
-
{e=>29590,c=>74,a=>75,b=>0,d=>2}
4b000000004a020096730000
4b000000004a020096730000
4b000000004a020096730000
0000004b00948000e72c0000
4b000000004a020096730000
4b000000004a020096730000
0000004b00948000e72c0000
4b000000004a020096730000
0000004b00948000e72c0000
-
{e=>31156,c=>54,a=>-49,b=>1,d=>3}
cfffffff01360300b4790000
cfffffff01360300b4790000
cfffffff01360300b4790000
ffffffcf406cc000f3680000
cfffffff01360300b4790000
cfffffff01360300b4790000
ffffffcf406cc000f3680000
cfffffff01360300b4790000
ffffffcf406cc000f3680000
-
{e=>29653,c=>12,a=>-35,b=>3,d=>0}
ddffffff030c0000d5730000
ddffffff030c0000d5730000
ddffffff030c0000d5730000
ffffffddc0180000e7aa0000
ddffffff030c0000d5730000
ddffffff030c0000d5730000
ffffffddc0180000e7aa0000
ddffffff030c0000d5730000
ffffffddc0180000e7aa0000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>29970,c=>42,a=>-35,b=>0,d=>2}
ddffffff002a020012750000
ddffffff002a020012750000
ddffffff002a020012750000
ffffffdd00548000ea240000
ddffffff002a020012750000
ddffffff002a020012750000
ffffffdd00548000ea240000
ddffffff002a020012750000
ffffffdd00548000ea240000
-
{e=>5805,c=>46,a=>15,b=>0,d=>0}
0f000000002e0000ad160000
0f000000002e0000ad160000
0f000000002e0000ad160000
0000000f005c00002d5a0000
0f000000002e0000ad160000
0f000000002e0000ad160000
0000000f005c00002d5a0000
0f000000002e0000ad160000
0000000f005c00002d5a0000
-
{e=>32451,c=>91,a=>82,b=>3,d=>1}
52000000035b0100c37e0000
52000000035b0100c37e0000
52000000035b0100c37e0000
00000052c0b64000fd860000
52000000035b0100c37e0000
52000000035b0100c37e0000
00000052c0b64000fd860000
52000000035b0100c37e0000
00000052c0b64000fd860000
-
{e=>4579,c=>50,a=>-33,b=>2,d=>1}
dfffffff02320100e3110000
dfffffff02320100e3110000
dfffffff02320100e3110000
ffffffdf8064400023c60000
dfffffff02320100e3110000
dfffffff02320100e3110000
ffffffdf8064400023c60000
dfffffff02320100e3110000
ffffffdf8064400023c60000
-
{e=>21164,c=>115,a=>-64,b=>0,d=>2}
c0ffffff00730200ac520000
c0ffffff00730200ac520000
c0ffffff00730200ac520000
ffffffc000e68000a5580000
c0ffffff00730200ac520000
c0ffffff00730200ac520000
ffffffc000e68000a5580000
c0ffffff00730200ac520000
ffffffc000e68000a5580000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>23029,c=>127,a=>-67,b=>1,d=>3,f=>0}
bdffffff017f0300f559000000000000
bdffffff017f0300f559000000000000
bdffffff017f0300f559000000000000
ffffffbd40fec000b3ea000000000000
bdffffff017f0300f559000000000000
bdffffff017f0300f559000000000000
ffffffbd40fec000b3ea000000000000
bdffffff017f0300f559000000000000
ffffffbd40fec000b3ea000000000000
-
{e=>16590,c=>24,a=>-103,b=>2,d=>3,f=>0}
99ffffff02180300ce40000000000000
99ffffff02180300ce40000000000000
99ffffff02180300ce40000000000000
ffffff998030c000819c000000000000
99ffffff02180300ce40000000000000
99ffffff02180300ce40000000000000
ffffff998030c000819c000000000000
99ffffff02180300ce40000000000000
ffffff998030c000819c000000000000
-
{e=>6342,c=>83,a=>-124,b=>3,d=>2,f=>3}
84ffffff03530200c618000003000000
84ffffff03530200c618000003000000
84ffffff03530200c618000003000000
ffffff84c0a68000318c0000c0000000
84ffffff03530200c618000003000000
84ffffff03530200c618000003000000
ffffff84c0a68000318c0000c0000000
84ffffff03530200c618000003000000
ffffff84c0a68000318c0000c0000000
-
{e=>20449,c=>25,a=>51,b=>1,d=>2,f=>0}
3300000001190200e14f000000000000
3300000001190200e14f000000000000
3300000001190200e14f000000000000
00000033403280009fc2000000000000
3300000001190200e14f000000000000
3300000001190200e14f000000000000
00000033403280009fc2000000000000
3300000001190200e14f000000000000
00000033403280009fc2000000000000
-
{e=>6146,c=>52,a=>40,b=>2,d=>0,f=>3}
28000000023400000218000003000000
28000000023400000218000003000000
28000000023400000218000003000000
000000288068000030040000c0000000
28000000023400000218000003000000
28000000023400000218000003000000
000000288068000030040000c0000000
28000000023400000218000003000000
000000288068000030040000c0000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>3892,c=>48,a=>-46,g=>316743879,b=>2,d=>1,f=>3}
d2ffffff02300100340f000003000000c720e112
d2ffffff02300100340f000003000000c720e112
d2ffffff02300100340f000003000000c720e112
ffffffd2806040001e680000c000000025c2418e
d2ffffff02300100340f000003000000c720e112
d2ffffff02300100340f000003000000c720e112
ffffffd2806040001e680000c000000025c2418e
d2ffffff02300100340f000003000000c720e112
ffffffd2806040001e680000c000000025c2418e
-
{e=>26400,c=>46,a=>-27,g=>151740613,b=>2,d=>3,f=>1}
e5ffffff022e03002067000001000000c5600b09
e5ffffff022e03002067000001000000c5600b09
e5ffffff022e03002067000001000000c5600b09
ffffffe5805cc000ce400000400000001216c18a
e5ffffff022e03002067000001000000c5600b09
e5ffffff022e03002067000001000000c5600b09
ffffffe5805cc000ce400000400000001216c18a
e5ffffff022e03002067000001000000c5600b09
ffffffe5805cc000ce400000400000001216c18a
-
{e=>26192,c=>62,a=>24,g=>1861908220,b=>2,d=>0,f=>3}
18000000023e00005066000003000000fc76fa6e
18000000023e00005066000003000000fc76fa6e
18000000023e00005066000003000000fc76fa6e
00000018807c0000cca00000c0000000ddf4edf8
18000000023e00005066000003000000fc76fa6e
18000000023e00005066000003000000fc76fa6e
00000018807c0000cca00000c0000000ddf4edf8
18000000023e00005066000003000000fc76fa6e
00000018807c0000cca00000c0000000ddf4edf8
-
{e=>21869,c=>35,a=>48,g=>1165253908,b=>2,d=>3,f=>1}
30000000022303006d55000001000000145d7445
30000000022303006d55000001000000145d7445
30000000022303006d55000001000000145d7445
000000308046c000aada0000400000008ae8ba28
30000000022303006d55000001000000145d7445
30000000022303006d55000001000000145d7445
000000308046c000aada0000400000008ae8ba28
30000000022303006d55000001000000145d7445
000000308046c000aada0000400000008ae8ba28
-
{e=>31408,c=>111,a=>30,g=>1811810369,b=>1,d=>0,f=>0}
1e000000016f0000b07a0000000000004108fe6b
1e000000016f0000b07a0000000000004108fe6b
1e000000016f0000b07a0000000000004108fe6b
0000001e40de0000f560000000000000d7fc1082
1e000000016f0000b07a0000000000004108fe6b
1e000000016f0000b07a0000000000004108fe6b
0000001e40de0000f560000000000000d7fc1082
1e000000016f0000b07a0000000000004108fe6b
0000001e40de0000f560000000000000d7fc1082
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>22792,a=>69,d=>0,c=>81,h=>223,b=>0,g=>1807892872,f=>2}
450000000051000008590000020000008841c26bdf000000
450000000051000008590000020000008841c26bdf000000
450000000051000008590000020000008841c26bdf000000
0000004500a20000b210000080000000d7848310df000000
450000000051000008590000020000008841c26bdf000000
450000000051000008590000020000008841c26bdf000000
0000004500a20000b210000080000000d7848310df000000
450000000051000008590000020000008841c26bdf000000
0000004500a20000b210000080000000d7848310df000000
-
{e=>6988,a=>-93,d=>1,c=>27,h=>182,b=>3,g=>374359030,f=>1}
a3ffffff031b01004c1b000001000000f6435016b6000000
a3ffffff031b01004c1b000001000000f6435016b6000000
a3ffffff031b01004c1b000001000000f6435016b6000000
ffffffa3c036400036980000400000002ca087ecb6000000
a3ffffff031b01004c1b000001000000f6435016b6000000
a3ffffff031b01004c1b000001000000f6435016b6000000
ffffffa3c036400036980000400000002ca087ecb6000000
a3ffffff031b01004c1b000001000000f6435016b6000000
ffffffa3c036400036980000400000002ca087ecb6000000
-
{e=>14822,a=>-84,d=>0,c=>16,h=>181,b=>0,g=>1852459803,f=>2}
acffffff00100000e6390000020000001b4b6a6eb5000000
acffffff00100000e6390000020000001b4b6a6eb5000000
acffffff00100000e6390000020000001b4b6a6eb5000000
ffffffac0020000073cc000080000000dcd49636b5000000
acffffff00100000e6390000020000001b4b6a6eb5000000
acffffff00100000e6390000020000001b4b6a6eb5000000
ffffffac0020000073cc000080000000dcd49636b5000000
acffffff00100000e6390000020000001b4b6a6eb5000000
ffffffac0020000073cc000080000000dcd49636b5000000
-
{e=>21205,a=>118,d=>1,c=>107,h=>123,b=>2,g=>1241312097,f=>2}
76000000026b0100d55200000200000061ebfc497b000000
76000000026b0100d55200000200000061ebfc497b000000
76000000026b0100d55200000200000061ebfc497b000000
0000007680d64000a5aa00008000000093f9d6c27b000000
76000000026b0100d55200000200000061ebfc497b000000
76000000026b0100d55200000200000061ebfc497b000000
0000007680d64000a5aa00008000000093f9d6c27b000000
76000000026b0100d55200000200000061ebfc497b000000
0000007680d64000a5aa00008000000093f9d6c27b000000
-
{e=>15889,a=>-72,d=>3,c=>115,h=>148,b=>3,g=>812033748,f=>2}
b8ffffff03730300113e000002000000d4a6663094000000
b8ffffff03730300113e000002000000d4a6663094000000
b8ffffff03730300113e000002000000d4a6663094000000
ffffffb8c0e6c0007c2200008000000060cd4da894000000
b8ffffff03730300113e000002000000d4a6663094000000
b8ffffff03730300113e000002000000d4a6663094000000
ffffffb8c0e6c0007c2200008000000060cd4da894000000
b8ffffff03730300113e000002000000d4a6663094000000
ffffffb8c0e6c0007c2200008000000060cd4da894000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
};
-
{a=>-83,b=>1}
adffffff01000000
adffffffffffffff0100000000000000
adffffffffffffff0100000000000000
ffffffad40000000
adffffff01000000
adffffff01000000
ffffffffffffffad4000000000000000
adffffff01000000
ffffffad40000000
-
{a=>-66,b=>2}
beffffff02000000
beffffffffffffff0200000000000000
beffffffffffffff0200000000000000
ffffffbe80000000
beffffff02000000
beffffff02000000
ffffffffffffffbe8000000000000000
beffffff02000000
ffffffbe80000000
-
{a=>29,b=>2}
1d00000002000000
1d000000000000000200000000000000
1d000000000000000200000000000000
0000001d80000000
1d00000002000000
1d00000002000000
000000000000001d8000000000000000
1d00000002000000
0000001d80000000
-
{a=>3,b=>3}
0300000003000000
03000000000000000300000000000000
03000000000000000300000000000000
00000003c0000000
0300000003000000
0300000003000000
0000000000000003c000000000000000
0300000003000000
00000003c0000000
-
{a=>96,b=>0}
6000000000000000
60000000000000000000000000000000
60000000000000000000000000000000
0000006000000000
6000000000000000
6000000000000000
00000000000000600000000000000000
6000000000000000
0000006000000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>65,a=>58,b=>1}
3a00000001410000
3a000000000000000141000000000000
3a000000000000000141000000000000
0000003a40820000
3a00000001410000
3a00000001410000
000000000000003a4082000000000000
3a00000001410000
0000003a40820000
-
{c=>69,a=>121,b=>3}
7900000003450000
79000000000000000345000000000000
79000000000000000345000000000000
00000079c08a0000
7900000003450000
7900000003450000
0000000000000079c08a000000000000
7900000003450000
00000079c08a0000
-
{c=>64,a=>43,b=>0}
2b00000000400000
2b000000000000000040000000000000
2b000000000000000040000000000000
0000002b00800000
2b00000000400000
2b00000000400000
000000000000002b0080000000000000
2b00000000400000
0000002b00800000
-
{c=>119,a=>-117,b=>3}
8bffffff03770000
8bffffffffffffff0377000000000000
8bffffffffffffff0377000000000000
ffffff8bc0ee0000
8bffffff03770000
8bffffff03770000
ffffffffffffff8bc0ee000000000000
8bffffff03770000
ffffff8bc0ee0000
-
{c=>121,a=>-9,b=>2}
f7ffffff02790000
f7ffffffffffffff0279000000000000
f7ffffffffffffff0279000000000000
fffffff780f20000
f7ffffff02790000
f7ffffff02790000
fffffffffffffff780f2000000000000
f7ffffff02790000
fffffff780f20000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>105,a=>-106,b=>1}
96ffffff01690000
96ffffffffffffff0169000000000000
96ffffffffffffff0169000000000000
ffffff9640d20000
96ffffff01690000
96ffffff01690000
ffffffffffffff9640d2000000000000
96ffffff01690000
ffffff9640d20000
-
{c=>123,a=>94,b=>1}
5e000000017b0000
5e00000000000000017b000000000000
5e00000000000000017b000000000000
0000005e40f60000
5e000000017b0000
5e000000017b0000
000000000000005e40f6000000000000
5e000000017b0000
0000005e40f60000
-
{c=>116,a=>-82,b=>1}
aeffffff01740000
aeffffffffffffff0174000000000000
aeffffffffffffff0174000000000000
ffffffae40e80000
aeffffff01740000
aeffffff01740000
ffffffffffffffae40e8000000000000
aeffffff01740000
ffffffae40e80000
-
{c=>123,a=>72,b=>2}
48000000027b0000
4800000000000000027b000000000000
4800000000000000027b000000000000
0000004880f60000
48000000027b0000
48000000027b0000
000000000000004880f6000000000000
48000000027b0000
0000004880f60000
-
{c=>73,a=>-126,b=>3}
82ffffff03490000
82ffffffffffffff0349000000000000
82ffffffffffffff0349000000000000
ffffff82c0920000
82ffffff03490000
82ffffff03490000
ffffffffffffff82c092000000000000
82ffffff03490000
ffffff82c0920000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>95,a=>0,b=>2,d=>1}
00000000025f0100
0000000000000000025f010000000000
0000000000000000025f010000000000
0000000080be4000
00000000025f0100
00000000025f0100
000000000000000080be400000000000
00000000025f0100
0000000080be4000
-
{c=>66,a=>121,b=>3,d=>3}
7900000003420300
79000000000000000342030000000000
79000000000000000342030000000000
00000079c084c000
7900000003420300
7900000003420300
0000000000000079c084c00000000000
7900000003420300
00000079c084c000
-
{c=>26,a=>99,b=>2,d=>2}
63000000021a0200
6300000000000000021a020000000000
6300000000000000021a020000000000
0000006380348000
63000000021a0200
63000000021a0200
00000000000000638034800000000000
63000000021a0200
0000006380348000
-
{c=>88,a=>98,b=>0,d=>1}
6200000000580100
62000000000000000058010000000000
62000000000000000058010000000000
0000006200b04000
6200000000580100
6200000000580100
000000000000006200b0400000000000
6200000000580100
0000006200b04000
-
{c=>3,a=>-14,b=>2,d=>3}
f2ffffff02030300
f2ffffffffffffff0203030000000000
f2ffffffffffffff0203030000000000
fffffff28006c000
f2ffffff02030300
f2ffffff02030300
fffffffffffffff28006c00000000000
f2ffffff02030300
fffffff28006c000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>9767,c=>60,a=>-61,b=>1,d=>2}
c3ffffff013c020027260000
c3ffffffffffffff013c020027260000
c3ffffffffffffff013c020027260000
ffffffc3407880004c4e0000
c3ffffff013c020027260000
c3ffffff013c020027260000
ffffffffffffffc3407880004c4e0000
c3ffffff013c020027260000
ffffffc3407880004c4e0000
-
{e=>12740,c=>73,a=>45,b=>1,d=>0}
2d00000001490000c4310000
2d0000000000000001490000c4310000
2d0000000000000001490000c4310000
0000002d4092000063880000
2d00000001490000c4310000
2d00000001490000c4310000
000000000000002d4092000063880000
2d00000001490000c4310000
0000002d4092000063880000
-
{e=>19242,c=>24,a=>3,b=>2,d=>3}
03000000021803002a4b0000
0300000000000000021803002a4b0000
0300000000000000021803002a4b0000
000000038030c00096540000
03000000021803002a4b0000
03000000021803002a4b0000
00000000000000038030c00096540000
03000000021803002a4b0000
000000038030c00096540000
-
{e=>22616,c=>113,a=>104,b=>2,d=>0}
680000000271000058580000
68000000000000000271000058580000
68000000000000000271000058580000
0000006880e20000b0b00000
680000000271000058580000
680000000271000058580000
000000000000006880e20000b0b00000
680000000271000058580000
0000006880e20000b0b00000
-
{e=>25298,c=>80,a=>59,b=>3,d=>0}
3b00000003500000d2620000
3b0000000000000003500000d2620000
3b0000000000000003500000d2620000
0000003bc0a00000c5a40000
3b00000003500000d2620000
3b00000003500000d2620000
000000000000003bc0a00000c5a40000
3b00000003500000d2620000
0000003bc0a00000c5a40000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>20592,c=>52,a=>-37,b=>2,d=>2}
dbffffff0234020070500000
dbffffffffffffff0234020070500000
dbffffffffffffff0234020070500000
ffffffdb80688000a0e00000
dbffffff0234020070500000
dbffffff0234020070500000
ffffffffffffffdb80688000a0e00000
dbffffff0234020070500000
ffffffdb80688000a0e00000
-
{e=>276,c=>125,a=>90,b=>3,d=>0}
5a000000037d000014010000
5a00000000000000037d000014010000
5a00000000000000037d000014010000
0000005ac0fa000002280000
5a000000037d000014010000
5a000000037d000014010000
000000000000005ac0fa000002280000
5a000000037d000014010000
0000005ac0fa000002280000
-
{e=>32279,c=>46,a=>100,b=>2,d=>3}
64000000022e0300177e0000
6400000000000000022e0300177e0000
6400000000000000022e0300177e0000
00000064805cc000fc2e0000
64000000022e0300177e0000
64000000022e0300177e0000
0000000000000064805cc000fc2e0000
64000000022e0300177e0000
00000064805cc000fc2e0000
-
{e=>25090,c=>74,a=>5,b=>1,d=>2}
05000000014a020002620000
0500000000000000014a020002620000
0500000000000000014a020002620000
0000000540948000c4040000
05000000014a020002620000
05000000014a020002620000
000000000000000540948000c4040000
05000000014a020002620000
0000000540948000c4040000
-
{e=>3865,c=>84,a=>-99,b=>0,d=>1}
9dffffff00540100190f0000
9dffffffffffffff00540100190f0000
9dffffffffffffff00540100190f0000
ffffff9d00a840001e320000
9dffffff00540100190f0000
9dffffff00540100190f0000
ffffffffffffff9d00a840001e320000
9dffffff00540100190f0000
ffffff9d00a840001e320000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>21175,c=>59,a=>-120,b=>1,d=>1,f=>3}
88ffffff013b0100b752000003000000
88ffffffffffffff013b0100b75200000300000000000000
88ffffffffffffff013b0100b75200000300000000000000
ffffff8840764000a56e0000c0000000
88ffffff013b0100b752000003000000
88ffffff013b0100b752000003000000
ffffffffffffff8840764000a56e0000c000000000000000
88ffffff013b0100b752000003000000
ffffff8840764000a56e0000c0000000
-
{e=>28600,c=>26,a=>40,b=>1,d=>0,f=>3}
28000000011a0000b86f000003000000
2800000000000000011a0000b86f00000300000000000000
2800000000000000011a0000b86f00000300000000000000
0000002840340000df700000c0000000
28000000011a0000b86f000003000000
28000000011a0000b86f000003000000
000000000000002840340000df700000c000000000000000
28000000011a0000b86f000003000000
0000002840340000df700000c0000000
-
{e=>28585,c=>40,a=>111,b=>2,d=>1,f=>0}
6f00000002280100a96f000000000000
6f0000000000000002280100a96f00000000000000000000
6f0000000000000002280100a96f00000000000000000000
0000006f80504000df52000000000000
6f00000002280100a96f000000000000
6f00000002280100a96f000000000000
000000000000006f80504000df5200000000000000000000
6f00000002280100a96f000000000000
0000006f80504000df52000000000000
-
{e=>5446,c=>49,a=>-10,b=>0,d=>3,f=>2}
f6ffffff003103004615000002000000
f6ffffffffffffff00310300461500000200000000000000
f6ffffffffffffff00310300461500000200000000000000
fffffff60062c0002a8c000080000000
f6ffffff003103004615000002000000
f6ffffff003103004615000002000000
fffffffffffffff60062c0002a8c00008000000000000000
f6ffffff003103004615000002000000
fffffff60062c0002a8c000080000000
-
{e=>8086,c=>115,a=>71,b=>1,d=>3,f=>2}
4700000001730300961f000002000000
470000000000000001730300961f00000200000000000000
470000000000000001730300961f00000200000000000000
0000004740e6c0003f2c000080000000
4700000001730300961f000002000000
4700000001730300961f000002000000
000000000000004740e6c0003f2c00008000000000000000
4700000001730300961f000002000000
0000004740e6c0003f2c000080000000
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>2515,c=>39,a=>-81,g=>1557846639,b=>0,d=>2,f=>0}
afffffff00270200d3090000000000006fdada5c
afffffffffffffff00270200d3090000000000006fdada5c
afffffffffffffff00270200d3090000000000006fdada5c
ffffffaf004e800013a6000000000000b9b5b4de
afffffff00270200d3090000000000006fdada5c
afffffff00270200d3090000000000006fdada5c
ffffffffffffffaf004e800013a6000000000000b9b5b4de
afffffff00270200d3090000000000006fdada5c
ffffffaf004e800013a6000000000000b9b5b4de
-
{e=>24554,c=>76,a=>-55,g=>397475554,b=>0,d=>3,f=>1}
c9ffffff004c0300ea5f000001000000e2feb017
c9ffffffffffffff004c0300ea5f000001000000e2feb017
c9ffffffffffffff004c0300ea5f000001000000e2feb017
ffffffc90098c000bfd40000400000002f61fdc4
c9ffffff004c0300ea5f000001000000e2feb017
c9ffffff004c0300ea5f000001000000e2feb017
ffffffffffffffc90098c000bfd40000400000002f61fdc4
c9ffffff004c0300ea5f000001000000e2feb017
ffffffc90098c000bfd40000400000002f61fdc4
-
{e=>21564,c=>75,a=>-60,g=>1965999580,b=>1,d=>1,f=>0}
c4ffffff014b01003c54000000000000dcc52e75
c4ffffffffffffff014b01003c54000000000000dcc52e75
c4ffffffffffffff014b01003c54000000000000dcc52e75
ffffffc440964000a878000000000000ea5d8bb8
c4ffffff014b01003c54000000000000dcc52e75
c4ffffff014b01003c54000000000000dcc52e75
ffffffffffffffc440964000a878000000000000ea5d8bb8
c4ffffff014b01003c54000000000000dcc52e75
ffffffc440964000a878000000000000ea5d8bb8
-
{e=>4819,c=>95,a=>5,g=>1426045861,b=>2,d=>3,f=>0}
05000000025f0300d312000000000000a5bbff54
0500000000000000025f0300d312000000000000a5bbff54
0500000000000000025f0300d312000000000000a5bbff54
0000000580bec00025a6000000000000a9ff774a
05000000025f0300d312000000000000a5bbff54
05000000025f0300d312000000000000a5bbff54
000000000000000580bec00025a6000000000000a9ff774a
05000000025f0300d312000000000000a5bbff54
0000000580bec00025a6000000000000a9ff774a
-
{e=>9300,c=>73,a=>-128,g=>2026652952,b=>2,d=>2,f=>0}
80ffffff0249020054240000000000001845cc78
80ffffffffffffff0249020054240000000000001845cc78
80ffffffffffffff0249020054240000000000001845cc78
ffffff808092800048a8000000000000f1988a30
80ffffff0249020054240000000000001845cc78
80ffffff0249020054240000000000001845cc78
ffffffffffffff808092800048a8000000000000f1988a30
80ffffff0249020054240000000000001845cc78
ffffff808092800048a8000000000000f1988a30
=
#if defined PACK_PAREN
#pragma pack( 2 )
#elif defined PACK_NO_PAREN
#pragma pack 2
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>21952,a=>-109,d=>2,c=>25,h=>45,b=>2,g=>1114185827,f=>3}
93ffffff02190200c055000003000000632069422d000000
93ffffffffffffff02190200c055000003000000632069422d00000000000000
93ffffffffffffff02190200c055000003000000632069422d00000000000000
ffffff9380328000ab800000c000000084d240c62d000000
93ffffff02190200c055000003000000632069422d000000
93ffffff02190200c055000003000000632069422d000000
ffffffffffffff9380328000ab800000c000000084d240c62d00000000000000
93ffffff02190200c055000003000000632069422d000000
ffffff9380328000ab800000c000000084d240c62d000000
-
{e=>26940,a=>-113,d=>2,c=>52,h=>252,b=>0,g=>1775585392,f=>2}
8fffffff003402003c690000020000007048d569fc000000
8fffffffffffffff003402003c690000020000007048d569fc00000000000000
8fffffffffffffff003402003c690000020000007048d569fc00000000000000
ffffff8f00688000d278000080000000d3aa90e0fc000000
8fffffff003402003c690000020000007048d569fc000000
8fffffff003402003c690000020000007048d569fc000000
ffffffffffffff8f00688000d278000080000000d3aa90e0fc00000000000000
8fffffff003402003c690000020000007048d569fc000000
ffffff8f00688000d278000080000000d3aa90e0fc000000
-
{e=>15281,a=>-108,d=>2,c=>32,h=>104,b=>0,g=>334972013,f=>0}
94ffffff00200200b13b0000000000006d44f71368000000
94ffffffffffffff00200200b13b0000000000006d44f7136800000000000000
94ffffffffffffff00200200b13b0000000000006d44f7136800000000000000
ffffff9400408000776200000000000027ee88da68000000
94ffffff00200200b13b0000000000006d44f71368000000
94ffffff00200200b13b0000000000006d44f71368000000
ffffffffffffff9400408000776200000000000027ee88da6800000000000000
94ffffff00200200b13b0000000000006d44f71368000000
ffffff9400408000776200000000000027ee88da68000000
-
{e=>2768,a=>-8,d=>2,c=>44,h=>179,b=>0,g=>1813704477,f=>2}
f8ffffff002c0200d00a0000020000001def1a6cb3000000
f8ffffffffffffff002c0200d00a0000020000001def1a6cb300000000000000
f8ffffffffffffff002c0200d00a0000020000001def1a6cb300000000000000
fffffff80058800015a0000080000000d835de3ab3000000
f8ffffff002c0200d00a0000020000001def1a6cb3000000
f8ffffff002c0200d00a0000020000001def1a6cb3000000
fffffffffffffff80058800015a0000080000000d835de3ab300000000000000
f8ffffff002c0200d00a0000020000001def1a6cb3000000
fffffff80058800015a0000080000000d835de3ab3000000
-
{e=>4766,a=>-98,d=>1,c=>110,h=>87,b=>3,g=>1617177070,f=>1}
9effffff036e01009e12000001000000ee29646057000000
9effffffffffffff036e01009e12000001000000ee2964605700000000000000
9effffffffffffff036e01009e12000001000000ee2964605700000000000000
ffffff9ec0dc4000253c000040000000c0c853dc57000000
9effffff036e01009e12000001000000ee29646057000000
9effffff036e01009e12000001000000ee29646057000000
ffffffffffffff9ec0dc4000253c000040000000c0c853dc5700000000000000
9effffff036e01009e12000001000000ee29646057000000
ffffff9ec0dc4000253c000040000000c0c853dc57000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
};
-
{a=>2}
02
02
02
80
02000000
02
80
02
80
-
{a=>1}
01
01
01
40
01000000
01
40
01
40
-
{a=>2}
02
02
02
80
02000000
02
80
02
80
-
{a=>3}
03
03
03
c0
03000000
03
c0
03
c0
-
{a=>3}
03
03
03
c0
03000000
03
c0
03
c0
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
};
-
{a=>1,b=>53}
0135
0135
0135
406a
01350000
0135
406a
0135
406a
-
{a=>1,b=>50}
0132
0132
0132
4064
01320000
0132
4064
0132
4064
-
{a=>1,b=>123}
017b
017b
017b
40f6
017b0000
017b
40f6
017b
40f6
-
{a=>1,b=>14}
010e
010e
010e
401c
010e0000
010e
401c
010e
401c
-
{a=>1,b=>30}
011e
011e
011e
403c
011e0000
011e
403c
011e
403c
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
};
-
{a=>0,b=>46}
002e
002e
002e
005c
002e0000
002e
005c
002e
005c
-
{a=>0,b=>81}
0051
0051
0051
00a2
00510000
0051
00a2
0051
00a2
-
{a=>2,b=>74}
024a
024a
024a
8094
024a0000
024a
8094
024a
8094
-
{a=>0,b=>65}
0041
0041
0041
0082
00410000
0041
0082
0041
0082
-
{a=>2,b=>109}
026d
026d
026d
80da
026d0000
026d
80da
026d
80da
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
};
-
{c=>3,a=>2,b=>16}
02100300
02100300
02100300
8020c000
02100300
02100300
8020c000
02100300
8020c000
-
{c=>1,a=>2,b=>62}
023e0100
023e0100
023e0100
807c4000
023e0100
023e0100
807c4000
023e0100
807c4000
-
{c=>3,a=>1,b=>111}
016f0300
016f0300
016f0300
40dec000
016f0300
016f0300
40dec000
016f0300
40dec000
-
{c=>1,a=>1,b=>68}
01440100
01440100
01440100
40884000
01440100
01440100
40884000
01440100
40884000
-
{c=>2,a=>2,b=>45}
022d0200
022d0200
022d0200
805a8000
022d0200
022d0200
805a8000
022d0200
805a8000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
};
-
{c=>3,a=>1,b=>26,d=>16785}
011a03009141
011a03009141
011a03009141
4034c0008322
011a030091410000
011a03009141
4034c0008322
011a03009141
4034c0008322
-
{c=>1,a=>2,b=>72,d=>27478}
02480100566b
02480100566b
02480100566b
80904000d6ac
02480100566b0000
02480100566b
80904000d6ac
02480100566b
80904000d6ac
-
{c=>0,a=>2,b=>38,d=>5575}
02260000c715
02260000c715
02260000c715
804c00002b8e
02260000c7150000
02260000c715
804c00002b8e
02260000c715
804c00002b8e
-
{c=>0,a=>0,b=>9,d=>15309}
00090000cd3b
00090000cd3b
00090000cd3b
00120000779a
00090000cd3b0000
00090000cd3b
00120000779a
00090000cd3b
00120000779a
-
{c=>1,a=>0,b=>50,d=>15196}
003201005c3b
003201005c3b
003201005c3b
0064400076b8
003201005c3b0000
003201005c3b
0064400076b8
003201005c3b
0064400076b8
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
};
-
{c=>3,a=>0,b=>45,d=>19854}
002d03008e4d0000
002d03008e4d0000
002d03008e4d0000
005ac0009b1c0000
002d03008e4d0000
002d03008e4d0000
005ac0009b1c0000
002d03008e4d0000
005ac0009b1c0000
-
{c=>1,a=>1,b=>98,d=>13023}
01620100df320000
01620100df320000
01620100df320000
40c4400065be0000
01620100df320000
01620100df320000
40c4400065be0000
01620100df320000
40c4400065be0000
-
{c=>0,a=>0,b=>60,d=>21600}
003c000060540000
003c000060540000
003c000060540000
00780000a8c00000
003c000060540000
003c000060540000
00780000a8c00000
003c000060540000
00780000a8c00000
-
{c=>0,a=>3,b=>66,d=>5095}
03420000e7130000
03420000e7130000
03420000e7130000
c084000027ce0000
03420000e7130000
03420000e7130000
c084000027ce0000
03420000e7130000
c084000027ce0000
-
{c=>1,a=>2,b=>6,d=>28001}
02060100616d0000
02060100616d0000
02060100616d0000
800c4000dac20000
02060100616d0000
02060100616d0000
800c4000dac20000
02060100616d0000
800c4000dac20000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
  unsigned int   e:2;
};
-
{e=>3,c=>3,a=>0,b=>58,d=>11881}
003a0300692e000003000000
003a0300692e000003000000
003a0300692e000003000000
0074c0005cd20000c0000000
003a0300692e000003000000
003a0300692e000003000000
0074c0005cd20000c0000000
003a0300692e000003000000
0074c0005cd20000c0000000
-
{e=>1,c=>2,a=>3,b=>55,d=>28258}
03370200626e000001000000
03370200626e000001000000
03370200626e000001000000
c06e8000dcc4000040000000
03370200626e000001000000
03370200626e000001000000
c06e8000dcc4000040000000
03370200626e000001000000
c06e8000dcc4000040000000
-
{e=>0,c=>2,a=>0,b=>80,d=>21967}
00500200cf55000000000000
00500200cf55000000000000
00500200cf55000000000000
00a08000ab9e000000000000
00500200cf55000000000000
00500200cf55000000000000
00a08000ab9e000000000000
00500200cf55000000000000
00a08000ab9e000000000000
-
{e=>3,c=>1,a=>2,b=>45,d=>10113}
022d01008127000003000000
022d01008127000003000000
022d01008127000003000000
805a40004f020000c0000000
022d01008127000003000000
022d01008127000003000000
805a40004f020000c0000000
022d01008127000003000000
805a40004f020000c0000000
-
{e=>2,c=>1,a=>1,b=>95,d=>17218}
015f01004243000002000000
015f01004243000002000000
015f01004243000002000000
40be40008684000080000000
015f01004243000002000000
015f01004243000002000000
40be40008684000080000000
015f01004243000002000000
40be40008684000080000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
  unsigned int   e:2;
  unsigned int   f:31;
};
-
{e=>0,c=>2,a=>3,b=>80,d=>2111,f=>1422571903}
035002003f080000000000007fb9ca54
035002003f080000000000007fb9ca54
035002003f080000000000007fb9ca54
c0a08000107e000000000000a99572fe
035002003f080000000000007fb9ca54
035002003f080000000000007fb9ca54
c0a08000107e000000000000a99572fe
035002003f080000000000007fb9ca54
c0a08000107e000000000000a99572fe
-
{e=>2,c=>1,a=>3,b=>64,d=>2000,f=>1965034422}
03400100d007000002000000b60b2075
03400100d007000002000000b60b2075
03400100d007000002000000b60b2075
c08040000fa0000080000000ea40176c
03400100d007000002000000b60b2075
03400100d007000002000000b60b2075
c08040000fa0000080000000ea40176c
03400100d007000002000000b60b2075
c08040000fa0000080000000ea40176c
-
{e=>2,c=>3,a=>1,b=>54,d=>28927,f=>969485170}
01360300ff70000002000000722bc939
01360300ff70000002000000722bc939
01360300ff70000002000000722bc939
406cc000e1fe000080000000739256e4
01360300ff70000002000000722bc939
01360300ff70000002000000722bc939
406cc000e1fe000080000000739256e4
01360300ff70000002000000722bc939
406cc000e1fe000080000000739256e4
-
{e=>2,c=>1,a=>3,b=>123,d=>20823,f=>1458057064}
037b01005751000002000000682fe856
037b01005751000002000000682fe856
037b01005751000002000000682fe856
c0f64000a2ae000080000000add05ed0
037b01005751000002000000682fe856
037b01005751000002000000682fe856
c0f64000a2ae000080000000add05ed0
037b01005751000002000000682fe856
c0f64000a2ae000080000000add05ed0
-
{e=>1,c=>2,a=>0,b=>6,d=>12501,f=>1351383989}
00060200d530000001000000b57b8c50
00060200d530000001000000b57b8c50
00060200d530000001000000b57b8c50
000c800061aa000040000000a118f76a
00060200d530000001000000b57b8c50
00060200d530000001000000b57b8c50
000c800061aa000040000000a118f76a
00060200d530000001000000b57b8c50
000c800061aa000040000000a118f76a
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  unsigned char  a:2;
  unsigned char  b:7;
  short           :0;
  unsigned short c:2;
  unsigned short d:15;
  int             :0;
  unsigned int   e:2;
  unsigned int   f:31;
  unsigned char  g;
};
-
{e=>0,c=>2,a=>3,g=>84,b=>89,d=>9214,f=>106393136}
03590200fe23000000000000306e570654000000
03590200fe23000000000000306e570654000000
03590200fe23000000000000306e570654000000
c0b2800047fc0000000000000caedc6054000000
03590200fe23000000000000306e570654000000
03590200fe23000000000000306e570654000000
c0b2800047fc0000000000000caedc6054000000
03590200fe23000000000000306e570654000000
c0b2800047fc0000000000000caedc6054000000
-
{e=>0,c=>1,a=>3,g=>127,b=>82,d=>23276,f=>741050135}
03520100ec5a00000000000017872b2c7f000000
03520100ec5a00000000000017872b2c7f000000
03520100ec5a00000000000017872b2c7f000000
c0a44000b5d800000000000058570e2e7f000000
03520100ec5a00000000000017872b2c7f000000
03520100ec5a00000000000017872b2c7f000000
c0a44000b5d800000000000058570e2e7f000000
03520100ec5a00000000000017872b2c7f000000
c0a44000b5d800000000000058570e2e7f000000
-
{e=>1,c=>2,a=>3,g=>51,b=>86,d=>27154,f=>843170060}
03560200126a0000010000000cc1413233000000
03560200126a0000010000000cc1413233000000
03560200126a0000010000000cc1413233000000
c0ac8000d4240000400000006483821833000000
03560200126a0000010000000cc1413233000000
03560200126a0000010000000cc1413233000000
c0ac8000d4240000400000006483821833000000
03560200126a0000010000000cc1413233000000
c0ac8000d4240000400000006483821833000000
-
{e=>2,c=>0,a=>1,g=>50,b=>109,d=>21142,f=>302068161}
016d00009652000002000000c131011232000000
016d00009652000002000000c131011232000000
016d00009652000002000000c131011232000000
40da0000a52c0000800000002402638232000000
016d00009652000002000000c131011232000000
016d00009652000002000000c131011232000000
40da0000a52c0000800000002402638232000000
016d00009652000002000000c131011232000000
40da0000a52c0000800000002402638232000000
-
{e=>0,c=>0,a=>0,g=>115,b=>39,d=>28818,f=>1653939669}
002700009270000000000000d51d956273000000
002700009270000000000000d51d956273000000
002700009270000000000000d51d956273000000
004e0000e124000000000000c52a3baa73000000
002700009270000000000000d51d956273000000
002700009270000000000000d51d956273000000
004e0000e124000000000000c52a3baa73000000
002700009270000000000000d51d956273000000
004e0000e124000000000000c52a3baa73000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
};
-
{a=>127,b=>3}
7f03
7f03
7f03
7fc0
7f030000
7f03
7fc0
7f03
7fc0
-
{a=>80,b=>3}
5003
5003
5003
50c0
50030000
5003
50c0
5003
50c0
-
{a=>-62,b=>3}
c203
c203
c203
c2c0
c2030000
c203
c2c0
c203
c2c0
-
{a=>-100,b=>0}
9c00
9c00
9c00
9c00
9c000000
9c00
9c00
9c00
9c00
-
{a=>14,b=>0}
0e00
0e00
0e00
0e00
0e000000
0e00
0e00
0e00
0e00
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>39,a=>-40,b=>3}
d80327
d80327
d80327
d8c04e
d8032700
d80327
d8c04e
d80327
d8c04e
-
{c=>16,a=>1,b=>2}
010210
010210
010210
018020
01021000
010210
018020
010210
018020
-
{c=>127,a=>117,b=>2}
75027f
75027f
75027f
7580fe
75027f00
75027f
7580fe
75027f
7580fe
-
{c=>19,a=>-78,b=>3}
b20313
b20313
b20313
b2c026
b2031300
b20313
b2c026
b20313
b2c026
-
{c=>78,a=>-31,b=>3}
e1034e
e1034e
e1034e
e1c09c
e1034e00
e1034e
e1c09c
e1034e
e1c09c
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>49,a=>86,b=>0}
56003100
56003100
56003100
56006200
56003100
56003100
56006200
56003100
56006200
-
{c=>37,a=>-76,b=>0}
b4002500
b4002500
b4002500
b4004a00
b4002500
b4002500
b4004a00
b4002500
b4004a00
-
{c=>41,a=>-78,b=>1}
b2012900
b2012900
b2012900
b2405200
b2012900
b2012900
b2405200
b2012900
b2405200
-
{c=>48,a=>-122,b=>1}
86013000
86013000
86013000
86406000
86013000
86013000
86406000
86013000
86406000
-
{c=>80,a=>38,b=>1}
26015000
26015000
26015000
2640a000
26015000
26015000
2640a000
26015000
2640a000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>64,a=>67,b=>0,d=>3}
430040000300
430040000300
430040000300
43008000c000
4300400003000000
430040000300
43008000c000
430040000300
43008000c000
-
{c=>7,a=>32,b=>0,d=>3}
200007000300
200007000300
200007000300
20000e00c000
2000070003000000
200007000300
20000e00c000
200007000300
20000e00c000
-
{c=>48,a=>-66,b=>2,d=>3}
be0230000300
be0230000300
be0230000300
be806000c000
be02300003000000
be0230000300
be806000c000
be0230000300
be806000c000
-
{c=>36,a=>98,b=>1,d=>0}
620124000000
620124000000
620124000000
624048000000
6201240000000000
620124000000
624048000000
620124000000
624048000000
-
{c=>52,a=>-93,b=>0,d=>0}
a30034000000
a30034000000
a30034000000
a30068000000
a300340000000000
a30034000000
a30068000000
a30034000000
a30068000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>26785,c=>119,a=>-1,b=>1,d=>0}
ff0177000000a168
ff0177000000a168
ff0177000000a168
ff40ee000000d142
ff0177000000a168
ff0177000000a168
ff40ee000000d142
ff0177000000a168
ff40ee000000d142
-
{e=>21340,c=>96,a=>-74,b=>2,d=>0}
b602600000005c53
b602600000005c53
b602600000005c53
b680c0000000a6b8
b602600000005c53
b602600000005c53
b680c0000000a6b8
b602600000005c53
b680c0000000a6b8
-
{e=>28806,c=>61,a=>26,b=>3,d=>1}
1a033d0001008670
1a033d0001008670
1a033d0001008670
1ac07a004000e10c
1a033d0001008670
1a033d0001008670
1ac07a004000e10c
1a033d0001008670
1ac07a004000e10c
-
{e=>28589,c=>26,a=>-114,b=>2,d=>2}
8e021a000200ad6f
8e021a000200ad6f
8e021a000200ad6f
8e8034008000df5a
8e021a000200ad6f
8e021a000200ad6f
8e8034008000df5a
8e021a000200ad6f
8e8034008000df5a
-
{e=>26902,c=>48,a=>-95,b=>0,d=>1}
a100300001001669
a100300001001669
a100300001001669
a10060004000d22c
a100300001001669
a100300001001669
a10060004000d22c
a100300001001669
a10060004000d22c
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>3552,c=>17,a=>-7,b=>2,d=>3}
f90211000300e00d
f90211000300e00d
f90211000300e00d
f9802200c0001bc0
f90211000300e00d
f90211000300e00d
f9802200c0001bc0
f90211000300e00d
f9802200c0001bc0
-
{e=>26031,c=>93,a=>25,b=>2,d=>2}
19025d000200af65
19025d000200af65
19025d000200af65
1980ba008000cb5e
19025d000200af65
19025d000200af65
1980ba008000cb5e
19025d000200af65
1980ba008000cb5e
-
{e=>22073,c=>127,a=>50,b=>3,d=>2}
32037f0002003956
32037f0002003956
32037f0002003956
32c0fe008000ac72
32037f0002003956
32037f0002003956
32c0fe008000ac72
32037f0002003956
32c0fe008000ac72
-
{e=>2767,c=>28,a=>125,b=>3,d=>0}
7d031c000000cf0a
7d031c000000cf0a
7d031c000000cf0a
7dc038000000159e
7d031c000000cf0a
7d031c000000cf0a
7dc038000000159e
7d031c000000cf0a
7dc038000000159e
-
{e=>13191,c=>78,a=>100,b=>1,d=>0}
64014e0000008733
64014e0000008733
64014e0000008733
64409c000000670e
64014e0000008733
64014e0000008733
64409c000000670e
64014e0000008733
64409c000000670e
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>30976,c=>57,a=>34,b=>3,d=>1,f=>2}
220339000100007902000000
220339000100007902000000
220339000100007902000000
22c072004000f20080000000
220339000100007902000000
220339000100007902000000
22c072004000f20080000000
220339000100007902000000
22c072004000f20080000000
-
{e=>6346,c=>73,a=>-3,b=>3,d=>2,f=>2}
fd0349000200ca1802000000
fd0349000200ca1802000000
fd0349000200ca1802000000
fdc092008000319480000000
fd0349000200ca1802000000
fd0349000200ca1802000000
fdc092008000319480000000
fd0349000200ca1802000000
fdc092008000319480000000
-
{e=>6949,c=>88,a=>-4,b=>0,d=>0,f=>1}
fc0058000000251b01000000
fc0058000000251b01000000
fc0058000000251b01000000
fc00b0000000364a40000000
fc0058000000251b01000000
fc0058000000251b01000000
fc00b0000000364a40000000
fc0058000000251b01000000
fc00b0000000364a40000000
-
{e=>28006,c=>111,a=>-33,b=>1,d=>1,f=>2}
df016f000100666d02000000
df016f000100666d02000000
df016f000100666d02000000
df40de004000dacc80000000
df016f000100666d02000000
df016f000100666d02000000
df40de004000dacc80000000
df016f000100666d02000000
df40de004000dacc80000000
-
{e=>14019,c=>108,a=>-96,b=>0,d=>2,f=>0}
a0006c000200c33600000000
a0006c000200c33600000000
a0006c000200c33600000000
a000d80080006d8600000000
a0006c000200c33600000000
a0006c000200c33600000000
a000d80080006d8600000000
a0006c000200c33600000000
a000d80080006d8600000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>9791,c=>22,a=>-47,g=>647164236,b=>2,d=>2,f=>1}
d102160002003f26010000004cf19226
d102160002003f26010000004cf19226
d102160002003f26010000004cf19226
d1802c0080004c7e400000004d25e298
d102160002003f26010000004cf19226
d102160002003f26010000004cf19226
d1802c0080004c7e400000004d25e298
d102160002003f26010000004cf19226
d1802c0080004c7e400000004d25e298
-
{e=>27793,c=>21,a=>-62,g=>1814066393,b=>1,d=>3,f=>1}
c20115000300916c01000000d974206c
c20115000300916c01000000d974206c
c20115000300916c01000000d974206c
c2402a00c000d92240000000d840e9b2
c20115000300916c01000000d974206c
c20115000300916c01000000d974206c
c2402a00c000d92240000000d840e9b2
c20115000300916c01000000d974206c
c2402a00c000d92240000000d840e9b2
-
{e=>21047,c=>89,a=>-117,g=>455211358,b=>1,d=>2,f=>2}
8b01590002003752020000005ef9211b
8b01590002003752020000005ef9211b
8b01590002003752020000005ef9211b
8b40b2008000a46e800000003643f2bc
8b01590002003752020000005ef9211b
8b01590002003752020000005ef9211b
8b40b2008000a46e800000003643f2bc
8b01590002003752020000005ef9211b
8b40b2008000a46e800000003643f2bc
-
{e=>17235,c=>47,a=>-82,g=>2001830733,b=>1,d=>1,f=>0}
ae012f0001005343000000004d835177
ae012f0001005343000000004d835177
ae012f0001005343000000004d835177
ae405e00400086a600000000eea3069a
ae012f0001005343000000004d835177
ae012f0001005343000000004d835177
ae405e00400086a600000000eea3069a
ae012f0001005343000000004d835177
ae405e00400086a600000000eea3069a
-
{e=>1178,c=>72,a=>-128,g=>1850197261,b=>3,d=>2,f=>2}
8003480002009a04020000000dc5476e
8003480002009a04020000000dc5476e
8003480002009a04020000000dc5476e
80c090008000093480000000dc8f8a1a
8003480002009a04020000000dc5476e
8003480002009a04020000000dc5476e
80c090008000093480000000dc8f8a1a
8003480002009a04020000000dc5476e
80c090008000093480000000dc8f8a1a
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  char a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>4992,a=>101,d=>0,c=>45,h=>179,b=>3,g=>1764834428,f=>2}
65032d0000008013020000007c3c3169b3000000
65032d0000008013020000007c3c3169b3000000
65032d0000008013020000007c3c3169b3000000
65c05a000000270080000000d26278f8b3000000
65032d0000008013020000007c3c3169b3000000
65032d0000008013020000007c3c3169b3000000
65c05a000000270080000000d26278f8b3000000
65032d0000008013020000007c3c3169b3000000
65c05a000000270080000000d26278f8b3000000
-
{e=>28162,a=>-27,d=>2,c=>19,h=>16,b=>1,g=>1368222481,f=>3}
e50113000200026e03000000116b8d5110000000
e50113000200026e03000000116b8d5110000000
e50113000200026e03000000116b8d5110000000
e54026008000dc04c0000000a31ad62210000000
e50113000200026e03000000116b8d5110000000
e50113000200026e03000000116b8d5110000000
e54026008000dc04c0000000a31ad62210000000
e50113000200026e03000000116b8d5110000000
e54026008000dc04c0000000a31ad62210000000
-
{e=>9500,a=>102,d=>2,c=>48,h=>250,b=>2,g=>153279384,f=>3}
6602300002001c250300000098db2209fa000000
6602300002001c250300000098db2209fa000000
6602300002001c250300000098db2209fa000000
6680600080004a38c00000001245b730fa000000
6602300002001c250300000098db2209fa000000
6602300002001c250300000098db2209fa000000
6680600080004a38c00000001245b730fa000000
6602300002001c250300000098db2209fa000000
6680600080004a38c00000001245b730fa000000
-
{e=>6190,a=>-9,d=>3,c=>84,h=>49,b=>1,g=>1357610161,f=>0}
f701540003002e1800000000b17ceb5031000000
f701540003002e1800000000b17ceb5031000000
f701540003002e1800000000b17ceb5031000000
f740a800c000305c00000000a1d6f96231000000
f701540003002e1800000000b17ceb5031000000
f701540003002e1800000000b17ceb5031000000
f740a800c000305c00000000a1d6f96231000000
f701540003002e1800000000b17ceb5031000000
f740a800c000305c00000000a1d6f96231000000
-
{e=>18540,a=>-57,d=>3,c=>110,h=>172,b=>1,g=>1540619102,f=>1}
c7016e0003006c48010000005efbd35bac000000
c7016e0003006c48010000005efbd35bac000000
c7016e0003006c48010000005efbd35bac000000
c740dc00c00090d840000000b7a7f6bcac000000
c7016e0003006c48010000005efbd35bac000000
c7016e0003006c48010000005efbd35bac000000
c740dc00c00090d840000000b7a7f6bcac000000
c7016e0003006c48010000005efbd35bac000000
c740dc00c00090d840000000b7a7f6bcac000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
};
-
{a=>12,b=>0}
0c000000
0c000000
0c000000
000c0000
0c000000
0c000000
000c0000
0c000000
000c0000
-
{a=>56,b=>0}
38000000
38000000
38000000
00380000
38000000
38000000
00380000
38000000
00380000
-
{a=>-4,b=>1}
fcff0100
fcff0100
fcff0100
fffc4000
fcff0100
fcff0100
fffc4000
fcff0100
fffc4000
-
{a=>-26,b=>1}
e6ff0100
e6ff0100
e6ff0100
ffe64000
e6ff0100
e6ff0100
ffe64000
e6ff0100
ffe64000
-
{a=>108,b=>0}
6c000000
6c000000
6c000000
006c0000
6c000000
6c000000
006c0000
6c000000
006c0000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>4,a=>-80,b=>3}
b0ff0304
b0ff0304
b0ff0304
ffb0c008
b0ff0304
b0ff0304
ffb0c008
b0ff0304
ffb0c008
-
{c=>37,a=>1,b=>1}
01000125
01000125
01000125
0001404a
01000125
01000125
0001404a
01000125
0001404a
-
{c=>79,a=>-80,b=>2}
b0ff024f
b0ff024f
b0ff024f
ffb0809e
b0ff024f
b0ff024f
ffb0809e
b0ff024f
ffb0809e
-
{c=>19,a=>36,b=>0}
24000013
24000013
24000013
00240026
24000013
24000013
00240026
24000013
00240026
-
{c=>71,a=>74,b=>3}
4a000347
4a000347
4a000347
004ac08e
4a000347
4a000347
004ac08e
4a000347
004ac08e
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>100,a=>40,b=>1}
28000164
28000164
28000164
002840c8
28000164
28000164
002840c8
28000164
002840c8
-
{c=>34,a=>-110,b=>1}
92ff0122
92ff0122
92ff0122
ff924044
92ff0122
92ff0122
ff924044
92ff0122
ff924044
-
{c=>74,a=>109,b=>2}
6d00024a
6d00024a
6d00024a
006d8094
6d00024a
6d00024a
006d8094
6d00024a
006d8094
-
{c=>106,a=>85,b=>3}
5500036a
5500036a
5500036a
0055c0d4
5500036a
5500036a
0055c0d4
5500036a
0055c0d4
-
{c=>103,a=>-49,b=>2}
cfff0267
cfff0267
cfff0267
ffcf80ce
cfff0267
cfff0267
ffcf80ce
cfff0267
ffcf80ce
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>65,a=>120,b=>3,d=>2}
780003410200
780003410200
780003410200
0078c0828000
7800034102000000
780003410200
0078c0828000
780003410200
0078c0828000
-
{c=>0,a=>-65,b=>1,d=>0}
bfff01000000
bfff01000000
bfff01000000
ffbf40000000
bfff010000000000
bfff01000000
ffbf40000000
bfff01000000
ffbf40000000
-
{c=>45,a=>-28,b=>3,d=>3}
e4ff032d0300
e4ff032d0300
e4ff032d0300
ffe4c05ac000
e4ff032d03000000
e4ff032d0300
ffe4c05ac000
e4ff032d0300
ffe4c05ac000
-
{c=>47,a=>-69,b=>0,d=>1}
bbff002f0100
bbff002f0100
bbff002f0100
ffbb005e4000
bbff002f01000000
bbff002f0100
ffbb005e4000
bbff002f0100
ffbb005e4000
-
{c=>58,a=>-126,b=>2,d=>3}
82ff023a0300
82ff023a0300
82ff023a0300
ff828074c000
82ff023a03000000
82ff023a0300
ff828074c000
82ff023a0300
ff828074c000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>23184,c=>121,a=>-111,b=>3,d=>2}
91ff03790200905a
91ff03790200905a
91ff03790200905a
ff91c0f28000b520
91ff03790200905a
91ff03790200905a
ff91c0f28000b520
91ff03790200905a
ff91c0f28000b520
-
{e=>10634,c=>6,a=>0,b=>0,d=>1}
0000000601008a29
0000000601008a29
0000000601008a29
0000000c40005314
0000000601008a29
0000000601008a29
0000000c40005314
0000000601008a29
0000000c40005314
-
{e=>1052,c=>95,a=>-110,b=>0,d=>3}
92ff005f03001c04
92ff005f03001c04
92ff005f03001c04
ff9200bec0000838
92ff005f03001c04
92ff005f03001c04
ff9200bec0000838
92ff005f03001c04
ff9200bec0000838
-
{e=>30124,c=>4,a=>-80,b=>0,d=>1}
b0ff00040100ac75
b0ff00040100ac75
b0ff00040100ac75
ffb000084000eb58
b0ff00040100ac75
b0ff00040100ac75
ffb000084000eb58
b0ff00040100ac75
ffb000084000eb58
-
{e=>6111,c=>70,a=>-3,b=>0,d=>2}
fdff00460200df17
fdff00460200df17
fdff00460200df17
fffd008c80002fbe
fdff00460200df17
fdff00460200df17
fffd008c80002fbe
fdff00460200df17
fffd008c80002fbe
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>27293,c=>0,a=>6,b=>1,d=>1}
0600010001009d6a
0600010001009d6a
0600010001009d6a
000640004000d53a
0600010001009d6a
0600010001009d6a
000640004000d53a
0600010001009d6a
000640004000d53a
-
{e=>7905,c=>88,a=>-84,b=>2,d=>1}
acff02580100e11e
acff02580100e11e
acff02580100e11e
ffac80b040003dc2
acff02580100e11e
acff02580100e11e
ffac80b040003dc2
acff02580100e11e
ffac80b040003dc2
-
{e=>25121,c=>6,a=>8,b=>1,d=>3}
0800010603002162
0800010603002162
0800010603002162
0008400cc000c442
0800010603002162
0800010603002162
0008400cc000c442
0800010603002162
0008400cc000c442
-
{e=>31153,c=>31,a=>-128,b=>0,d=>1}
80ff001f0100b179
80ff001f0100b179
80ff001f0100b179
ff80003e4000f362
80ff001f0100b179
80ff001f0100b179
ff80003e4000f362
80ff001f0100b179
ff80003e4000f362
-
{e=>26840,c=>3,a=>-81,b=>0,d=>1}
afff00030100d868
afff00030100d868
afff00030100d868
ffaf00064000d1b0
afff00030100d868
afff00030100d868
ffaf00064000d1b0
afff00030100d868
ffaf00064000d1b0
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>14623,c=>76,a=>81,b=>1,d=>0,f=>0}
5100014c00001f3900000000
5100014c00001f3900000000
5100014c00001f3900000000
005140980000723e00000000
5100014c00001f3900000000
5100014c00001f3900000000
005140980000723e00000000
5100014c00001f3900000000
005140980000723e00000000
-
{e=>15019,c=>26,a=>124,b=>1,d=>1,f=>0}
7c00011a0100ab3a00000000
7c00011a0100ab3a00000000
7c00011a0100ab3a00000000
007c40344000755600000000
7c00011a0100ab3a00000000
7c00011a0100ab3a00000000
007c40344000755600000000
7c00011a0100ab3a00000000
007c40344000755600000000
-
{e=>20293,c=>73,a=>-24,b=>3,d=>1,f=>2}
e8ff03490100454f02000000
e8ff03490100454f02000000
e8ff03490100454f02000000
ffe8c09240009e8a80000000
e8ff03490100454f02000000
e8ff03490100454f02000000
ffe8c09240009e8a80000000
e8ff03490100454f02000000
ffe8c09240009e8a80000000
-
{e=>10913,c=>40,a=>116,b=>1,d=>3,f=>3}
740001280300a12a03000000
740001280300a12a03000000
740001280300a12a03000000
00744050c0005542c0000000
740001280300a12a03000000
740001280300a12a03000000
00744050c0005542c0000000
740001280300a12a03000000
00744050c0005542c0000000
-
{e=>7039,c=>44,a=>-19,b=>1,d=>3,f=>3}
edff012c03007f1b03000000
edff012c03007f1b03000000
edff012c03007f1b03000000
ffed4058c00036fec0000000
edff012c03007f1b03000000
edff012c03007f1b03000000
ffed4058c00036fec0000000
edff012c03007f1b03000000
ffed4058c00036fec0000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>24746,c=>73,a=>96,g=>1050064470,b=>1,d=>2,f=>3}
600001490200aa600300000056b6963e
600001490200aa600300000056b6963e
600001490200aa600300000056b6963e
006040928000c154c00000007d2d6cac
600001490200aa600300000056b6963e
600001490200aa600300000056b6963e
006040928000c154c00000007d2d6cac
600001490200aa600300000056b6963e
006040928000c154c00000007d2d6cac
-
{e=>3803,c=>22,a=>94,g=>1842484087,b=>1,d=>2,f=>1}
5e0001160200db0e010000007713d26d
5e0001160200db0e010000007713d26d
5e0001160200db0e010000007713d26d
005e402c80001db640000000dba426ee
5e0001160200db0e010000007713d26d
5e0001160200db0e010000007713d26d
005e402c80001db640000000dba426ee
5e0001160200db0e010000007713d26d
005e402c80001db640000000dba426ee
-
{e=>214,c=>123,a=>77,g=>1848243584,b=>0,d=>3,f=>3}
4d00007b0300d6000300000080f5296e
4d00007b0300d6000300000080f5296e
4d00007b0300d6000300000080f5296e
004d00f6c00001acc0000000dc53eb00
4d00007b0300d6000300000080f5296e
4d00007b0300d6000300000080f5296e
004d00f6c00001acc0000000dc53eb00
4d00007b0300d6000300000080f5296e
004d00f6c00001acc0000000dc53eb00
-
{e=>26881,c=>70,a=>-34,g=>434815639,b=>2,d=>3,f=>2}
deff0246030001690200000097c2ea19
deff0246030001690200000097c2ea19
deff0246030001690200000097c2ea19
ffde808cc000d2028000000033d5852e
deff0246030001690200000097c2ea19
deff0246030001690200000097c2ea19
ffde808cc000d2028000000033d5852e
deff0246030001690200000097c2ea19
ffde808cc000d2028000000033d5852e
-
{e=>29110,c=>65,a=>70,g=>1149188362,b=>3,d=>1,f=>1}
460003410100b671010000000a397f44
460003410100b671010000000a397f44
460003410100b671010000000a397f44
0046c0824000e36c4000000088fe7214
460003410100b671010000000a397f44
460003410100b671010000000a397f44
0046c0824000e36c4000000088fe7214
460003410100b671010000000a397f44
0046c0824000e36c4000000088fe7214
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  short a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>14421,a=>-30,d=>3,c=>26,h=>141,b=>1,g=>4188654,f=>3}
e2ff011a0300553803000000eee93f008d000000
e2ff011a0300553803000000eee93f008d000000
e2ff011a0300553803000000eee93f008d000000
ffe24034c00070aac0000000007fd3dc8d000000
e2ff011a0300553803000000eee93f008d000000
e2ff011a0300553803000000eee93f008d000000
ffe24034c00070aac0000000007fd3dc8d000000
e2ff011a0300553803000000eee93f008d000000
ffe24034c00070aac0000000007fd3dc8d000000
-
{e=>8456,a=>9,d=>3,c=>14,h=>64,b=>1,g=>622335221,f=>2}
0900010e0300082102000000f514182540000000
0900010e0300082102000000f514182540000000
0900010e0300082102000000f514182540000000
0009401cc0004210800000004a3029ea40000000
0900010e0300082102000000f514182540000000
0900010e0300082102000000f514182540000000
0009401cc0004210800000004a3029ea40000000
0900010e0300082102000000f514182540000000
0009401cc0004210800000004a3029ea40000000
-
{e=>4776,a=>81,d=>2,c=>60,h=>86,b=>1,g=>767737936,f=>2}
5100013c0200a8120200000050c0c22d56000000
5100013c0200a8120200000050c0c22d56000000
5100013c0200a8120200000050c0c22d56000000
0051407880002550800000005b8580a056000000
5100013c0200a8120200000050c0c22d56000000
5100013c0200a8120200000050c0c22d56000000
0051407880002550800000005b8580a056000000
5100013c0200a8120200000050c0c22d56000000
0051407880002550800000005b8580a056000000
-
{e=>23388,a=>-75,d=>2,c=>8,h=>15,b=>3,g=>884282703,f=>1}
b5ff030802005c5b010000004f15b5340f000000
b5ff030802005c5b010000004f15b5340f000000
b5ff030802005c5b010000004f15b5340f000000
ffb5c0108000b6b840000000696a2a9e0f000000
b5ff030802005c5b010000004f15b5340f000000
b5ff030802005c5b010000004f15b5340f000000
ffb5c0108000b6b840000000696a2a9e0f000000
b5ff030802005c5b010000004f15b5340f000000
ffb5c0108000b6b840000000696a2a9e0f000000
-
{e=>12562,a=>25,d=>1,c=>64,h=>193,b=>0,g=>817252271,f=>0}
190000400100123100000000af47b630c1000000
190000400100123100000000af47b630c1000000
190000400100123100000000af47b630c1000000
001900804000622400000000616c8f5ec1000000
190000400100123100000000af47b630c1000000
190000400100123100000000af47b630c1000000
001900804000622400000000616c8f5ec1000000
190000400100123100000000af47b630c1000000
001900804000622400000000616c8f5ec1000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
};
-
{a=>103,b=>3}
6700000003000000
6700000003000000
6700000003000000
00000067c0000000
6700000003000000
6700000003000000
00000067c0000000
6700000003000000
00000067c0000000
-
{a=>40,b=>0}
2800000000000000
2800000000000000
2800000000000000
0000002800000000
2800000000000000
2800000000000000
0000002800000000
2800000000000000
0000002800000000
-
{a=>49,b=>1}
3100000001000000
3100000001000000
3100000001000000
0000003140000000
3100000001000000
3100000001000000
0000003140000000
3100000001000000
0000003140000000
-
{a=>21,b=>0}
1500000000000000
1500000000000000
1500000000000000
0000001500000000
1500000000000000
1500000000000000
0000001500000000
1500000000000000
0000001500000000
-
{a=>111,b=>0}
6f00000000000000
6f00000000000000
6f00000000000000
0000006f00000000
6f00000000000000
6f00000000000000
0000006f00000000
6f00000000000000
0000006f00000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>103,a=>-126,b=>1}
82ffffff01670000
82ffffff01670000
82ffffff01670000
ffffff8240ce0000
82ffffff01670000
82ffffff01670000
ffffff8240ce0000
82ffffff01670000
ffffff8240ce0000
-
{c=>66,a=>-92,b=>1}
a4ffffff01420000
a4ffffff01420000
a4ffffff01420000
ffffffa440840000
a4ffffff01420000
a4ffffff01420000
ffffffa440840000
a4ffffff01420000
ffffffa440840000
-
{c=>11,a=>61,b=>0}
3d000000000b0000
3d000000000b0000
3d000000000b0000
0000003d00160000
3d000000000b0000
3d000000000b0000
0000003d00160000
3d000000000b0000
0000003d00160000
-
{c=>87,a=>-84,b=>2}
acffffff02570000
acffffff02570000
acffffff02570000
ffffffac80ae0000
acffffff02570000
acffffff02570000
ffffffac80ae0000
acffffff02570000
ffffffac80ae0000
-
{c=>62,a=>-50,b=>2}
ceffffff023e0000
ceffffff023e0000
ceffffff023e0000
ffffffce807c0000
ceffffff023e0000
ceffffff023e0000
ffffffce807c0000
ceffffff023e0000
ffffffce807c0000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>107,a=>0,b=>0}
00000000006b0000
00000000006b0000
00000000006b0000
0000000000d60000
00000000006b0000
00000000006b0000
0000000000d60000
00000000006b0000
0000000000d60000
-
{c=>118,a=>-118,b=>1}
8affffff01760000
8affffff01760000
8affffff01760000
ffffff8a40ec0000
8affffff01760000
8affffff01760000
ffffff8a40ec0000
8affffff01760000
ffffff8a40ec0000
-
{c=>69,a=>-37,b=>1}
dbffffff01450000
dbffffff01450000
dbffffff01450000
ffffffdb408a0000
dbffffff01450000
dbffffff01450000
ffffffdb408a0000
dbffffff01450000
ffffffdb408a0000
-
{c=>30,a=>91,b=>2}
5b000000021e0000
5b000000021e0000
5b000000021e0000
0000005b803c0000
5b000000021e0000
5b000000021e0000
0000005b803c0000
5b000000021e0000
0000005b803c0000
-
{c=>29,a=>124,b=>0}
7c000000001d0000
7c000000001d0000
7c000000001d0000
0000007c003a0000
7c000000001d0000
7c000000001d0000
0000007c003a0000
7c000000001d0000
0000007c003a0000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>61,a=>67,b=>2,d=>0}
43000000023d0000
43000000023d0000
43000000023d0000
00000043807a0000
43000000023d0000
43000000023d0000
00000043807a0000
43000000023d0000
00000043807a0000
-
{c=>127,a=>17,b=>2,d=>1}
11000000027f0100
11000000027f0100
11000000027f0100
0000001180fe4000
11000000027f0100
11000000027f0100
0000001180fe4000
11000000027f0100
0000001180fe4000
-
{c=>119,a=>32,b=>1,d=>1}
2000000001770100
2000000001770100
2000000001770100
0000002040ee4000
2000000001770100
2000000001770100
0000002040ee4000
2000000001770100
0000002040ee4000
-
{c=>65,a=>-115,b=>0,d=>2}
8dffffff00410200
8dffffff00410200
8dffffff00410200
ffffff8d00828000
8dffffff00410200
8dffffff00410200
ffffff8d00828000
8dffffff00410200
ffffff8d00828000
-
{c=>83,a=>98,b=>1,d=>1}
6200000001530100
6200000001530100
6200000001530100
0000006240a64000
6200000001530100
6200000001530100
0000006240a64000
6200000001530100
0000006240a64000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>5523,c=>25,a=>-32,b=>3,d=>2}
e0ffffff0319020093150000
e0ffffff0319020093150000
e0ffffff0319020093150000
ffffffe0c03280002b260000
e0ffffff0319020093150000
e0ffffff0319020093150000
ffffffe0c03280002b260000
e0ffffff0319020093150000
ffffffe0c03280002b260000
-
{e=>17834,c=>17,a=>118,b=>3,d=>1}
7600000003110100aa450000
7600000003110100aa450000
7600000003110100aa450000
00000076c02240008b540000
7600000003110100aa450000
7600000003110100aa450000
00000076c02240008b540000
7600000003110100aa450000
00000076c02240008b540000
-
{e=>25877,c=>64,a=>-78,b=>2,d=>3}
b2ffffff0240030015650000
b2ffffff0240030015650000
b2ffffff0240030015650000
ffffffb28080c000ca2a0000
b2ffffff0240030015650000
b2ffffff0240030015650000
ffffffb28080c000ca2a0000
b2ffffff0240030015650000
ffffffb28080c000ca2a0000
-
{e=>5816,c=>42,a=>71,b=>2,d=>3}
47000000022a0300b8160000
47000000022a0300b8160000
47000000022a0300b8160000
000000478054c0002d700000
47000000022a0300b8160000
47000000022a0300b8160000
000000478054c0002d700000
47000000022a0300b8160000
000000478054c0002d700000
-
{e=>29371,c=>34,a=>49,b=>0,d=>0}
3100000000220000bb720000
3100000000220000bb720000
3100000000220000bb720000
0000003100440000e5760000
3100000000220000bb720000
3100000000220000bb720000
0000003100440000e5760000
3100000000220000bb720000
0000003100440000e5760000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>24240,c=>104,a=>-100,b=>1,d=>0}
9cffffff01680000b05e0000
9cffffff01680000b05e0000
9cffffff01680000b05e0000
ffffff9c40d00000bd600000
9cffffff01680000b05e0000
9cffffff01680000b05e0000
ffffff9c40d00000bd600000
9cffffff01680000b05e0000
ffffff9c40d00000bd600000
-
{e=>12831,c=>111,a=>9,b=>1,d=>3}
09000000016f03001f320000
09000000016f03001f320000
09000000016f03001f320000
0000000940dec000643e0000
09000000016f03001f320000
09000000016f03001f320000
0000000940dec000643e0000
09000000016f03001f320000
0000000940dec000643e0000
-
{e=>30312,c=>91,a=>97,b=>1,d=>2}
61000000015b020068760000
61000000015b020068760000
61000000015b020068760000
0000006140b68000ecd00000
61000000015b020068760000
61000000015b020068760000
0000006140b68000ecd00000
61000000015b020068760000
0000006140b68000ecd00000
-
{e=>10363,c=>58,a=>-82,b=>1,d=>0}
aeffffff013a00007b280000
aeffffff013a00007b280000
aeffffff013a00007b280000
ffffffae4074000050f60000
aeffffff013a00007b280000
aeffffff013a00007b280000
ffffffae4074000050f60000
aeffffff013a00007b280000
ffffffae4074000050f60000
-
{e=>29377,c=>72,a=>39,b=>0,d=>0}
2700000000480000c1720000
2700000000480000c1720000
2700000000480000c1720000
0000002700900000e5820000
2700000000480000c1720000
2700000000480000c1720000
0000002700900000e5820000
2700000000480000c1720000
0000002700900000e5820000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>17692,c=>26,a=>9,b=>2,d=>0,f=>3}
09000000021a00001c45000003000000
09000000021a00001c45000003000000
09000000021a00001c45000003000000
00000009803400008a380000c0000000
09000000021a00001c45000003000000
09000000021a00001c45000003000000
00000009803400008a380000c0000000
09000000021a00001c45000003000000
00000009803400008a380000c0000000
-
{e=>27254,c=>68,a=>-9,b=>3,d=>1,f=>2}
f7ffffff03440100766a000002000000
f7ffffff03440100766a000002000000
f7ffffff03440100766a000002000000
fffffff7c0884000d4ec000080000000
f7ffffff03440100766a000002000000
f7ffffff03440100766a000002000000
fffffff7c0884000d4ec000080000000
f7ffffff03440100766a000002000000
fffffff7c0884000d4ec000080000000
-
{e=>6512,c=>116,a=>59,b=>0,d=>3,f=>0}
3b000000007403007019000000000000
3b000000007403007019000000000000
3b000000007403007019000000000000
0000003b00e8c00032e0000000000000
3b000000007403007019000000000000
3b000000007403007019000000000000
0000003b00e8c00032e0000000000000
3b000000007403007019000000000000
0000003b00e8c00032e0000000000000
-
{e=>1930,c=>119,a=>83,b=>0,d=>0,f=>3}
53000000007700008a07000003000000
53000000007700008a07000003000000
53000000007700008a07000003000000
0000005300ee00000f140000c0000000
53000000007700008a07000003000000
53000000007700008a07000003000000
0000005300ee00000f140000c0000000
53000000007700008a07000003000000
0000005300ee00000f140000c0000000
-
{e=>15816,c=>57,a=>52,b=>1,d=>3,f=>3}
3400000001390300c83d000003000000
3400000001390300c83d000003000000
3400000001390300c83d000003000000
000000344072c0007b900000c0000000
3400000001390300c83d000003000000
3400000001390300c83d000003000000
000000344072c0007b900000c0000000
3400000001390300c83d000003000000
000000344072c0007b900000c0000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>30223,c=>33,a=>-100,g=>121180495,b=>1,d=>2,f=>0}
9cffffff012102000f760000000000004f113907
9cffffff012102000f760000000000004f113907
9cffffff012102000f760000000000004f113907
ffffff9c40428000ec1e0000000000000e72229e
9cffffff012102000f760000000000004f113907
9cffffff012102000f760000000000004f113907
ffffff9c40428000ec1e0000000000000e72229e
9cffffff012102000f760000000000004f113907
ffffff9c40428000ec1e0000000000000e72229e
-
{e=>18201,c=>67,a=>-52,g=>392025226,b=>0,d=>0,f=>2}
ccffffff0043000019470000020000008ad45d17
ccffffff0043000019470000020000008ad45d17
ccffffff0043000019470000020000008ad45d17
ffffffcc008600008e320000800000002ebba914
ccffffff0043000019470000020000008ad45d17
ccffffff0043000019470000020000008ad45d17
ffffffcc008600008e320000800000002ebba914
ccffffff0043000019470000020000008ad45d17
ffffffcc008600008e320000800000002ebba914
-
{e=>17360,c=>19,a=>-73,g=>394570984,b=>1,d=>1,f=>3}
b7ffffff01130100d043000003000000e8ac8417
b7ffffff01130100d043000003000000e8ac8417
b7ffffff01130100d043000003000000e8ac8417
ffffffb74026400087a00000c00000002f0959d0
b7ffffff01130100d043000003000000e8ac8417
b7ffffff01130100d043000003000000e8ac8417
ffffffb74026400087a00000c00000002f0959d0
b7ffffff01130100d043000003000000e8ac8417
ffffffb74026400087a00000c00000002f0959d0
-
{e=>10287,c=>34,a=>-106,g=>498558563,b=>2,d=>3,f=>3}
96ffffff022203002f280000030000006366b71d
96ffffff022203002f280000030000006366b71d
96ffffff022203002f280000030000006366b71d
ffffff968044c000505e0000c00000003b6eccc6
96ffffff022203002f280000030000006366b71d
96ffffff022203002f280000030000006366b71d
ffffff968044c000505e0000c00000003b6eccc6
96ffffff022203002f280000030000006366b71d
ffffff968044c000505e0000c00000003b6eccc6
-
{e=>9740,c=>45,a=>86,g=>1880755291,b=>1,d=>0,f=>2}
56000000012d00000c260000020000005b0c1a70
56000000012d00000c260000020000005b0c1a70
56000000012d00000c260000020000005b0c1a70
00000056405a00004c18000080000000e03418b6
56000000012d00000c260000020000005b0c1a70
56000000012d00000c260000020000005b0c1a70
00000056405a00004c18000080000000e03418b6
56000000012d00000c260000020000005b0c1a70
00000056405a00004c18000080000000e03418b6
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  int a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>23079,a=>112,d=>1,c=>76,h=>172,b=>0,g=>635357675,f=>2}
70000000004c0100275a000002000000ebc9de25ac000000
70000000004c0100275a000002000000ebc9de25ac000000
70000000004c0100275a000002000000ebc9de25ac000000
0000007000984000b44e0000800000004bbd93d6ac000000
70000000004c0100275a000002000000ebc9de25ac000000
70000000004c0100275a000002000000ebc9de25ac000000
0000007000984000b44e0000800000004bbd93d6ac000000
70000000004c0100275a000002000000ebc9de25ac000000
0000007000984000b44e0000800000004bbd93d6ac000000
-
{e=>26130,a=>-73,d=>3,c=>118,h=>116,b=>0,g=>1812500274,f=>1}
b7ffffff007603001266000001000000328f086c74000000
b7ffffff007603001266000001000000328f086c74000000
b7ffffff007603001266000001000000328f086c74000000
ffffffb700ecc000cc24000040000000d8111e6474000000
b7ffffff007603001266000001000000328f086c74000000
b7ffffff007603001266000001000000328f086c74000000
ffffffb700ecc000cc24000040000000d8111e6474000000
b7ffffff007603001266000001000000328f086c74000000
ffffffb700ecc000cc24000040000000d8111e6474000000
-
{e=>24159,a=>-26,d=>2,c=>104,h=>134,b=>0,g=>700333779,f=>0}
e6ffffff006802005f5e000000000000d33ebe2986000000
e6ffffff006802005f5e000000000000d33ebe2986000000
e6ffffff006802005f5e000000000000d33ebe2986000000
ffffffe600d08000bcbe000000000000537c7da686000000
e6ffffff006802005f5e000000000000d33ebe2986000000
e6ffffff006802005f5e000000000000d33ebe2986000000
ffffffe600d08000bcbe000000000000537c7da686000000
e6ffffff006802005f5e000000000000d33ebe2986000000
ffffffe600d08000bcbe000000000000537c7da686000000
-
{e=>2660,a=>-41,d=>2,c=>126,h=>49,b=>2,g=>1088641385,f=>0}
d7ffffff027e0200640a0000000000006959e34031000000
d7ffffff027e0200640a0000000000006959e34031000000
d7ffffff027e0200640a0000000000006959e34031000000
ffffffd780fc800014c800000000000081c6b2d231000000
d7ffffff027e0200640a0000000000006959e34031000000
d7ffffff027e0200640a0000000000006959e34031000000
ffffffd780fc800014c800000000000081c6b2d231000000
d7ffffff027e0200640a0000000000006959e34031000000
ffffffd780fc800014c800000000000081c6b2d231000000
-
{e=>25739,a=>-16,d=>2,c=>114,h=>244,b=>1,g=>1079005221,f=>1}
f0ffffff017202008b6400000100000025505040f4000000
f0ffffff017202008b6400000100000025505040f4000000
f0ffffff017202008b6400000100000025505040f4000000
fffffff040e48000c91600004000000080a0a04af4000000
f0ffffff017202008b6400000100000025505040f4000000
f0ffffff017202008b6400000100000025505040f4000000
fffffff040e48000c91600004000000080a0a04af4000000
f0ffffff017202008b6400000100000025505040f4000000
fffffff040e48000c91600004000000080a0a04af4000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
};
-
{a=>90,b=>1}
5a00000001000000
5a000000000000000100000000000000
5a000000000000000100000000000000
0000005a40000000
5a00000001000000
5a00000001000000
000000000000005a4000000000000000
5a00000001000000
0000005a40000000
-
{a=>-80,b=>0}
b0ffffff00000000
b0ffffffffffffff0000000000000000
b0ffffffffffffff0000000000000000
ffffffb000000000
b0ffffff00000000
b0ffffff00000000
ffffffffffffffb00000000000000000
b0ffffff00000000
ffffffb000000000
-
{a=>68,b=>2}
4400000002000000
44000000000000000200000000000000
44000000000000000200000000000000
0000004480000000
4400000002000000
4400000002000000
00000000000000448000000000000000
4400000002000000
0000004480000000
-
{a=>-83,b=>3}
adffffff03000000
adffffffffffffff0300000000000000
adffffffffffffff0300000000000000
ffffffadc0000000
adffffff03000000
adffffff03000000
ffffffffffffffadc000000000000000
adffffff03000000
ffffffadc0000000
-
{a=>-41,b=>3}
d7ffffff03000000
d7ffffffffffffff0300000000000000
d7ffffffffffffff0300000000000000
ffffffd7c0000000
d7ffffff03000000
d7ffffff03000000
ffffffffffffffd7c000000000000000
d7ffffff03000000
ffffffd7c0000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
};
-
{c=>109,a=>96,b=>1}
60000000016d0000
6000000000000000016d000000000000
6000000000000000016d000000000000
0000006040da0000
60000000016d0000
60000000016d0000
000000000000006040da000000000000
60000000016d0000
0000006040da0000
-
{c=>31,a=>-56,b=>2}
c8ffffff021f0000
c8ffffffffffffff021f000000000000
c8ffffffffffffff021f000000000000
ffffffc8803e0000
c8ffffff021f0000
c8ffffff021f0000
ffffffffffffffc8803e000000000000
c8ffffff021f0000
ffffffc8803e0000
-
{c=>61,a=>16,b=>3}
10000000033d0000
1000000000000000033d000000000000
1000000000000000033d000000000000
00000010c07a0000
10000000033d0000
10000000033d0000
0000000000000010c07a000000000000
10000000033d0000
00000010c07a0000
-
{c=>108,a=>110,b=>1}
6e000000016c0000
6e00000000000000016c000000000000
6e00000000000000016c000000000000
0000006e40d80000
6e000000016c0000
6e000000016c0000
000000000000006e40d8000000000000
6e000000016c0000
0000006e40d80000
-
{c=>19,a=>38,b=>3}
2600000003130000
26000000000000000313000000000000
26000000000000000313000000000000
00000026c0260000
2600000003130000
2600000003130000
0000000000000026c026000000000000
2600000003130000
00000026c0260000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
};
-
{c=>11,a=>-122,b=>1}
86ffffff010b0000
86ffffffffffffff010b000000000000
86ffffffffffffff010b000000000000
ffffff8640160000
86ffffff010b0000
86ffffff010b0000
ffffffffffffff864016000000000000
86ffffff010b0000
ffffff8640160000
-
{c=>97,a=>16,b=>1}
1000000001610000
10000000000000000161000000000000
10000000000000000161000000000000
0000001040c20000
1000000001610000
1000000001610000
000000000000001040c2000000000000
1000000001610000
0000001040c20000
-
{c=>80,a=>-128,b=>2}
80ffffff02500000
80ffffffffffffff0250000000000000
80ffffffffffffff0250000000000000
ffffff8080a00000
80ffffff02500000
80ffffff02500000
ffffffffffffff8080a0000000000000
80ffffff02500000
ffffff8080a00000
-
{c=>14,a=>123,b=>0}
7b000000000e0000
7b00000000000000000e000000000000
7b00000000000000000e000000000000
0000007b001c0000
7b000000000e0000
7b000000000e0000
000000000000007b001c000000000000
7b000000000e0000
0000007b001c0000
-
{c=>103,a=>47,b=>2}
2f00000002670000
2f000000000000000267000000000000
2f000000000000000267000000000000
0000002f80ce0000
2f00000002670000
2f00000002670000
000000000000002f80ce000000000000
2f00000002670000
0000002f80ce0000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
};
-
{c=>34,a=>-101,b=>0,d=>3}
9bffffff00220300
9bffffffffffffff0022030000000000
9bffffffffffffff0022030000000000
ffffff9b0044c000
9bffffff00220300
9bffffff00220300
ffffffffffffff9b0044c00000000000
9bffffff00220300
ffffff9b0044c000
-
{c=>68,a=>-41,b=>0,d=>2}
d7ffffff00440200
d7ffffffffffffff0044020000000000
d7ffffffffffffff0044020000000000
ffffffd700888000
d7ffffff00440200
d7ffffff00440200
ffffffffffffffd70088800000000000
d7ffffff00440200
ffffffd700888000
-
{c=>43,a=>8,b=>0,d=>3}
08000000002b0300
0800000000000000002b030000000000
0800000000000000002b030000000000
000000080056c000
08000000002b0300
08000000002b0300
00000000000000080056c00000000000
08000000002b0300
000000080056c000
-
{c=>1,a=>-35,b=>1,d=>1}
ddffffff01010100
ddffffffffffffff0101010000000000
ddffffffffffffff0101010000000000
ffffffdd40024000
ddffffff01010100
ddffffff01010100
ffffffffffffffdd4002400000000000
ddffffff01010100
ffffffdd40024000
-
{c=>76,a=>104,b=>1,d=>0}
68000000014c0000
6800000000000000014c000000000000
6800000000000000014c000000000000
0000006840980000
68000000014c0000
68000000014c0000
00000000000000684098000000000000
68000000014c0000
0000006840980000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
};
-
{e=>24942,c=>46,a=>6,b=>3,d=>1}
06000000032e01006e610000
0600000000000000032e01006e610000
0600000000000000032e01006e610000
00000006c05c4000c2dc0000
06000000032e01006e610000
06000000032e01006e610000
0000000000000006c05c4000c2dc0000
06000000032e01006e610000
00000006c05c4000c2dc0000
-
{e=>21474,c=>50,a=>-44,b=>1,d=>1}
d4ffffff01320100e2530000
d4ffffffffffffff01320100e2530000
d4ffffffffffffff01320100e2530000
ffffffd440644000a7c40000
d4ffffff01320100e2530000
d4ffffff01320100e2530000
ffffffffffffffd440644000a7c40000
d4ffffff01320100e2530000
ffffffd440644000a7c40000
-
{e=>3529,c=>20,a=>82,b=>2,d=>1}
5200000002140100c90d0000
520000000000000002140100c90d0000
520000000000000002140100c90d0000
00000052802840001b920000
5200000002140100c90d0000
5200000002140100c90d0000
0000000000000052802840001b920000
5200000002140100c90d0000
00000052802840001b920000
-
{e=>17185,c=>27,a=>101,b=>1,d=>1}
65000000011b010021430000
6500000000000000011b010021430000
6500000000000000011b010021430000
000000654036400086420000
65000000011b010021430000
65000000011b010021430000
00000000000000654036400086420000
65000000011b010021430000
000000654036400086420000
-
{e=>16801,c=>73,a=>65,b=>2,d=>0}
4100000002490000a1410000
410000000000000002490000a1410000
410000000000000002490000a1410000
000000418092000083420000
4100000002490000a1410000
4100000002490000a1410000
00000000000000418092000083420000
4100000002490000a1410000
000000418092000083420000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
};
-
{e=>19824,c=>4,a=>-13,b=>0,d=>3}
f3ffffff00040300704d0000
f3ffffffffffffff00040300704d0000
f3ffffffffffffff00040300704d0000
fffffff30008c0009ae00000
f3ffffff00040300704d0000
f3ffffff00040300704d0000
fffffffffffffff30008c0009ae00000
f3ffffff00040300704d0000
fffffff30008c0009ae00000
-
{e=>26529,c=>110,a=>-18,b=>0,d=>0}
eeffffff006e0000a1670000
eeffffffffffffff006e0000a1670000
eeffffffffffffff006e0000a1670000
ffffffee00dc0000cf420000
eeffffff006e0000a1670000
eeffffff006e0000a1670000
ffffffffffffffee00dc0000cf420000
eeffffff006e0000a1670000
ffffffee00dc0000cf420000
-
{e=>19156,c=>80,a=>-61,b=>3,d=>3}
c3ffffff03500300d44a0000
c3ffffffffffffff03500300d44a0000
c3ffffffffffffff03500300d44a0000
ffffffc3c0a0c00095a80000
c3ffffff03500300d44a0000
c3ffffff03500300d44a0000
ffffffffffffffc3c0a0c00095a80000
c3ffffff03500300d44a0000
ffffffc3c0a0c00095a80000
-
{e=>3691,c=>27,a=>-58,b=>3,d=>1}
c6ffffff031b01006b0e0000
c6ffffffffffffff031b01006b0e0000
c6ffffffffffffff031b01006b0e0000
ffffffc6c03640001cd60000
c6ffffff031b01006b0e0000
c6ffffff031b01006b0e0000
ffffffffffffffc6c03640001cd60000
c6ffffff031b01006b0e0000
ffffffc6c03640001cd60000
-
{e=>19252,c=>104,a=>-126,b=>0,d=>3}
82ffffff00680300344b0000
82ffffffffffffff00680300344b0000
82ffffffffffffff00680300344b0000
ffffff8200d0c00096680000
82ffffff00680300344b0000
82ffffff00680300344b0000
ffffffffffffff8200d0c00096680000
82ffffff00680300344b0000
ffffff8200d0c00096680000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
};
-
{e=>26648,c=>18,a=>21,b=>0,d=>0,f=>3}
15000000001200001868000003000000
150000000000000000120000186800000300000000000000
150000000000000000120000186800000300000000000000
0000001500240000d0300000c0000000
15000000001200001868000003000000
15000000001200001868000003000000
000000000000001500240000d0300000c000000000000000
15000000001200001868000003000000
0000001500240000d0300000c0000000
-
{e=>4058,c=>41,a=>53,b=>2,d=>1,f=>1}
3500000002290100da0f000001000000
350000000000000002290100da0f00000100000000000000
350000000000000002290100da0f00000100000000000000
00000035805240001fb4000040000000
3500000002290100da0f000001000000
3500000002290100da0f000001000000
0000000000000035805240001fb400004000000000000000
3500000002290100da0f000001000000
00000035805240001fb4000040000000
-
{e=>32076,c=>52,a=>69,b=>0,d=>3,f=>0}
45000000003403004c7d000000000000
4500000000000000003403004c7d00000000000000000000
4500000000000000003403004c7d00000000000000000000
000000450068c000fa98000000000000
45000000003403004c7d000000000000
45000000003403004c7d000000000000
00000000000000450068c000fa9800000000000000000000
45000000003403004c7d000000000000
000000450068c000fa98000000000000
-
{e=>1444,c=>19,a=>67,b=>0,d=>3,f=>2}
4300000000130300a405000002000000
430000000000000000130300a40500000200000000000000
430000000000000000130300a40500000200000000000000
000000430026c0000b48000080000000
4300000000130300a405000002000000
4300000000130300a405000002000000
00000000000000430026c0000b4800008000000000000000
4300000000130300a405000002000000
000000430026c0000b48000080000000
-
{e=>24969,c=>106,a=>-88,b=>3,d=>1,f=>2}
a8ffffff036a01008961000002000000
a8ffffffffffffff036a0100896100000200000000000000
a8ffffffffffffff036a0100896100000200000000000000
ffffffa8c0d44000c312000080000000
a8ffffff036a01008961000002000000
a8ffffff036a01008961000002000000
ffffffffffffffa8c0d44000c31200008000000000000000
a8ffffff036a01008961000002000000
ffffffa8c0d44000c312000080000000
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
};
-
{e=>16632,c=>60,a=>-40,g=>1817886941,b=>2,d=>3,f=>0}
d8ffffff023c0300f840000000000000ddc05a6c
d8ffffffffffffff023c0300f840000000000000ddc05a6c
d8ffffffffffffff023c0300f840000000000000ddc05a6c
ffffffd88078c00081f0000000000000d8b581ba
d8ffffff023c0300f840000000000000ddc05a6c
d8ffffff023c0300f840000000000000ddc05a6c
ffffffffffffffd88078c00081f0000000000000d8b581ba
d8ffffff023c0300f840000000000000ddc05a6c
ffffffd88078c00081f0000000000000d8b581ba
-
{e=>473,c=>72,a=>-41,g=>52496826,b=>2,d=>0,f=>3}
d7ffffff02480000d901000003000000ba092103
d7ffffffffffffff02480000d901000003000000ba092103
d7ffffffffffffff02480000d901000003000000ba092103
ffffffd78090000003b20000c000000006421374
d7ffffff02480000d901000003000000ba092103
d7ffffff02480000d901000003000000ba092103
ffffffffffffffd78090000003b20000c000000006421374
d7ffffff02480000d901000003000000ba092103
ffffffd78090000003b20000c000000006421374
-
{e=>11344,c=>93,a=>112,g=>612815542,b=>2,d=>3,f=>3}
70000000025d0300502c000003000000b6d28624
7000000000000000025d0300502c000003000000b6d28624
7000000000000000025d0300502c000003000000b6d28624
0000007080bac00058a00000c0000000490da56c
70000000025d0300502c000003000000b6d28624
70000000025d0300502c000003000000b6d28624
000000000000007080bac00058a00000c0000000490da56c
70000000025d0300502c000003000000b6d28624
0000007080bac00058a00000c0000000490da56c
-
{e=>19196,c=>13,a=>-21,g=>359321552,b=>3,d=>0,f=>1}
ebffffff030d0000fc4a000001000000d0cf6a15
ebffffffffffffff030d0000fc4a000001000000d0cf6a15
ebffffffffffffff030d0000fc4a000001000000d0cf6a15
ffffffebc01a000095f80000400000002ad59fa0
ebffffff030d0000fc4a000001000000d0cf6a15
ebffffff030d0000fc4a000001000000d0cf6a15
ffffffffffffffebc01a000095f80000400000002ad59fa0
ebffffff030d0000fc4a000001000000d0cf6a15
ffffffebc01a000095f80000400000002ad59fa0
-
{e=>17883,c=>107,a=>108,g=>578088007,b=>3,d=>0,f=>1}
6c000000036b0000db4500000100000047ec7422
6c00000000000000036b0000db4500000100000047ec7422
6c00000000000000036b0000db4500000100000047ec7422
0000006cc0d600008bb600004000000044e9d88e
6c000000036b0000db4500000100000047ec7422
6c000000036b0000db4500000100000047ec7422
000000000000006cc0d600008bb600004000000044e9d88e
6c000000036b0000db4500000100000047ec7422
0000006cc0d600008bb600004000000044e9d88e
=
#if defined PACK_PAREN
#pragma pack( 4 )
#elif defined PACK_NO_PAREN
#pragma pack 4
#endif
struct toobig_pack_1 {
  long a;
  unsigned char  b:2;
  unsigned char  c:7;
  short           :0;
  unsigned short d:2;
  unsigned short e:15;
  int             :0;
  unsigned int   f:2;
  unsigned int   g:31;
  unsigned char  h;
};
-
{e=>12541,a=>64,d=>0,c=>105,h=>135,b=>2,g=>30539544,f=>0}
4000000002690000fd3000000000000018ffd10187000000
400000000000000002690000fd3000000000000018ffd1018700000000000000
400000000000000002690000fd3000000000000018ffd1018700000000000000
0000004080d2000061fa00000000000003a3fe3087000000
4000000002690000fd3000000000000018ffd10187000000
4000000002690000fd3000000000000018ffd10187000000
000000000000004080d2000061fa00000000000003a3fe308700000000000000
4000000002690000fd3000000000000018ffd10187000000
0000004080d2000061fa00000000000003a3fe3087000000
-
{e=>20492,a=>-87,d=>3,c=>8,h=>213,b=>1,g=>1628818689,f=>3}
a9ffffff010803000c5000000300000001cd1561d5000000
a9ffffffffffffff010803000c5000000300000001cd1561d500000000000000
a9ffffffffffffff010803000c5000000300000001cd1561d500000000000000
ffffffa94010c000a0180000c0000000c22b9a02d5000000
a9ffffff010803000c5000000300000001cd1561d5000000
a9ffffff010803000c5000000300000001cd1561d5000000
ffffffffffffffa94010c000a0180000c0000000c22b9a02d500000000000000
a9ffffff010803000c5000000300000001cd1561d5000000
ffffffa94010c000a0180000c0000000c22b9a02d5000000
-
{e=>19965,a=>102,d=>3,c=>44,h=>160,b=>1,g=>1186990891,f=>0}
66000000012c0300fd4d0000000000002b0bc046a0000000
6600000000000000012c0300fd4d0000000000002b0bc046a000000000000000
6600000000000000012c0300fd4d0000000000002b0bc046a000000000000000
000000664058c0009bfa0000000000008d801656a0000000
66000000012c0300fd4d0000000000002b0bc046a0000000
66000000012c0300fd4d0000000000002b0bc046a0000000
00000000000000664058c0009bfa0000000000008d801656a000000000000000
66000000012c0300fd4d0000000000002b0bc046a0000000
000000664058c0009bfa0000000000008d801656a0000000
-
{e=>4623,a=>123,d=>0,c=>12,h=>32,b=>0,g=>776268733,f=>1}
7b000000000c00000f12000001000000bdeb442e20000000
7b00000000000000000c00000f12000001000000bdeb442e2000000000000000
7b00000000000000000c00000f12000001000000bdeb442e2000000000000000
0000007b00180000241e0000400000005c89d77a20000000
7b000000000c00000f12000001000000bdeb442e20000000
7b000000000c00000f12000001000000bdeb442e20000000
000000000000007b00180000241e0000400000005c89d77a2000000000000000
7b000000000c00000f12000001000000bdeb442e20000000
0000007b00180000241e0000400000005c89d77a20000000
-
{e=>32210,a=>87,d=>3,c=>96,h=>9,b=>0,g=>416850484,f=>1}
5700000000600300d27d00000100000034a2d81809000000
570000000000000000600300d27d00000100000034a2d8180900000000000000
570000000000000000600300d27d00000100000034a2d8180900000000000000
0000005700c0c000fba400004000000031b1446809000000
5700000000600300d27d00000100000034a2d81809000000
5700000000600300d27d00000100000034a2d81809000000
000000000000005700c0c000fba400004000000031b144680900000000000000
5700000000600300d27d00000100000034a2d81809000000
0000005700c0c000fba400004000000031b1446809000000
=
